import reflex as rx

class DiAndroid(rx.Component):
    library = "react-icons/di"
    tag = "DiAndroid"


class DiAngularSimple(rx.Component):
    library = "react-icons/di"
    tag = "DiAngularSimple"


class DiAppcelerator(rx.Component):
    library = "react-icons/di"
    tag = "DiAppcelerator"


class DiApple(rx.Component):
    library = "react-icons/di"
    tag = "DiApple"


class DiAppstore(rx.Component):
    library = "react-icons/di"
    tag = "DiAppstore"


class DiAptana(rx.Component):
    library = "react-icons/di"
    tag = "DiAptana"


class DiAsterisk(rx.Component):
    library = "react-icons/di"
    tag = "DiAsterisk"


class DiAtlassian(rx.Component):
    library = "react-icons/di"
    tag = "DiAtlassian"


class DiAtom(rx.Component):
    library = "react-icons/di"
    tag = "DiAtom"


class DiAws(rx.Component):
    library = "react-icons/di"
    tag = "DiAws"


class DiBackbone(rx.Component):
    library = "react-icons/di"
    tag = "DiBackbone"


class DiBingSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiBingSmall"


class DiBintray(rx.Component):
    library = "react-icons/di"
    tag = "DiBintray"


class DiBitbucket(rx.Component):
    library = "react-icons/di"
    tag = "DiBitbucket"


class DiBlackberry(rx.Component):
    library = "react-icons/di"
    tag = "DiBlackberry"


class DiBootstrap(rx.Component):
    library = "react-icons/di"
    tag = "DiBootstrap"


class DiBower(rx.Component):
    library = "react-icons/di"
    tag = "DiBower"


class DiBrackets(rx.Component):
    library = "react-icons/di"
    tag = "DiBrackets"


class DiBugsense(rx.Component):
    library = "react-icons/di"
    tag = "DiBugsense"


class DiCelluloid(rx.Component):
    library = "react-icons/di"
    tag = "DiCelluloid"


class DiChrome(rx.Component):
    library = "react-icons/di"
    tag = "DiChrome"


class DiCisco(rx.Component):
    library = "react-icons/di"
    tag = "DiCisco"


class DiClojureAlt(rx.Component):
    library = "react-icons/di"
    tag = "DiClojureAlt"


class DiClojure(rx.Component):
    library = "react-icons/di"
    tag = "DiClojure"


class DiCloud9(rx.Component):
    library = "react-icons/di"
    tag = "DiCloud9"


class DiCoda(rx.Component):
    library = "react-icons/di"
    tag = "DiCoda"


class DiCodeBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiCodeBadge"


class DiCode(rx.Component):
    library = "react-icons/di"
    tag = "DiCode"


class DiCodeigniter(rx.Component):
    library = "react-icons/di"
    tag = "DiCodeigniter"


class DiCodepen(rx.Component):
    library = "react-icons/di"
    tag = "DiCodepen"


class DiCodrops(rx.Component):
    library = "react-icons/di"
    tag = "DiCodrops"


class DiCoffeescript(rx.Component):
    library = "react-icons/di"
    tag = "DiCoffeescript"


class DiCompass(rx.Component):
    library = "react-icons/di"
    tag = "DiCompass"


class DiComposer(rx.Component):
    library = "react-icons/di"
    tag = "DiComposer"


class DiCreativecommonsBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiCreativecommonsBadge"


class DiCreativecommons(rx.Component):
    library = "react-icons/di"
    tag = "DiCreativecommons"


class DiCssTricks(rx.Component):
    library = "react-icons/di"
    tag = "DiCssTricks"


class DiCss3Full(rx.Component):
    library = "react-icons/di"
    tag = "DiCss3Full"


class DiCss3(rx.Component):
    library = "react-icons/di"
    tag = "DiCss3"


class DiCssdeck(rx.Component):
    library = "react-icons/di"
    tag = "DiCssdeck"


class DiDart(rx.Component):
    library = "react-icons/di"
    tag = "DiDart"


class DiDatabase(rx.Component):
    library = "react-icons/di"
    tag = "DiDatabase"


class DiDebian(rx.Component):
    library = "react-icons/di"
    tag = "DiDebian"


class DiDigitalOcean(rx.Component):
    library = "react-icons/di"
    tag = "DiDigitalOcean"


class DiDjango(rx.Component):
    library = "react-icons/di"
    tag = "DiDjango"


class DiDlang(rx.Component):
    library = "react-icons/di"
    tag = "DiDlang"


class DiDocker(rx.Component):
    library = "react-icons/di"
    tag = "DiDocker"


class DiDoctrine(rx.Component):
    library = "react-icons/di"
    tag = "DiDoctrine"


class DiDojo(rx.Component):
    library = "react-icons/di"
    tag = "DiDojo"


class DiDotnet(rx.Component):
    library = "react-icons/di"
    tag = "DiDotnet"


class DiDreamweaver(rx.Component):
    library = "react-icons/di"
    tag = "DiDreamweaver"


class DiDropbox(rx.Component):
    library = "react-icons/di"
    tag = "DiDropbox"


class DiDrupal(rx.Component):
    library = "react-icons/di"
    tag = "DiDrupal"


class DiEclipse(rx.Component):
    library = "react-icons/di"
    tag = "DiEclipse"


class DiEmber(rx.Component):
    library = "react-icons/di"
    tag = "DiEmber"


class DiEnvato(rx.Component):
    library = "react-icons/di"
    tag = "DiEnvato"


class DiErlang(rx.Component):
    library = "react-icons/di"
    tag = "DiErlang"


class DiExtjs(rx.Component):
    library = "react-icons/di"
    tag = "DiExtjs"


class DiFirebase(rx.Component):
    library = "react-icons/di"
    tag = "DiFirebase"


class DiFirefox(rx.Component):
    library = "react-icons/di"
    tag = "DiFirefox"


class DiFsharp(rx.Component):
    library = "react-icons/di"
    tag = "DiFsharp"


class DiGhostSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiGhostSmall"


class DiGhost(rx.Component):
    library = "react-icons/di"
    tag = "DiGhost"


class DiGitBranch(rx.Component):
    library = "react-icons/di"
    tag = "DiGitBranch"


class DiGitCommit(rx.Component):
    library = "react-icons/di"
    tag = "DiGitCommit"


class DiGitCompare(rx.Component):
    library = "react-icons/di"
    tag = "DiGitCompare"


class DiGitMerge(rx.Component):
    library = "react-icons/di"
    tag = "DiGitMerge"


class DiGitPullRequest(rx.Component):
    library = "react-icons/di"
    tag = "DiGitPullRequest"


class DiGit(rx.Component):
    library = "react-icons/di"
    tag = "DiGit"


class DiGithubAlt(rx.Component):
    library = "react-icons/di"
    tag = "DiGithubAlt"


class DiGithubBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiGithubBadge"


class DiGithubFull(rx.Component):
    library = "react-icons/di"
    tag = "DiGithubFull"


class DiGithub(rx.Component):
    library = "react-icons/di"
    tag = "DiGithub"


class DiGnu(rx.Component):
    library = "react-icons/di"
    tag = "DiGnu"


class DiGo(rx.Component):
    library = "react-icons/di"
    tag = "DiGo"


class DiGoogleAnalytics(rx.Component):
    library = "react-icons/di"
    tag = "DiGoogleAnalytics"


class DiGoogleDrive(rx.Component):
    library = "react-icons/di"
    tag = "DiGoogleDrive"


class DiGoogleCloudPlatform(rx.Component):
    library = "react-icons/di"
    tag = "DiGoogleCloudPlatform"


class DiGrails(rx.Component):
    library = "react-icons/di"
    tag = "DiGrails"


class DiGroovy(rx.Component):
    library = "react-icons/di"
    tag = "DiGroovy"


class DiGrunt(rx.Component):
    library = "react-icons/di"
    tag = "DiGrunt"


class DiGulp(rx.Component):
    library = "react-icons/di"
    tag = "DiGulp"


class DiHackernews(rx.Component):
    library = "react-icons/di"
    tag = "DiHackernews"


class DiHaskell(rx.Component):
    library = "react-icons/di"
    tag = "DiHaskell"


class DiHeroku(rx.Component):
    library = "react-icons/di"
    tag = "DiHeroku"


class DiHtml53DEffects(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml53DEffects"


class DiHtml5Connectivity(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml5Connectivity"


class DiHtml5DeviceAccess(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml5DeviceAccess"


class DiHtml5Multimedia(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml5Multimedia"


class DiHtml5(rx.Component):
    library = "react-icons/di"
    tag = "DiHtml5"


class DiIe(rx.Component):
    library = "react-icons/di"
    tag = "DiIe"


class DiIllustrator(rx.Component):
    library = "react-icons/di"
    tag = "DiIllustrator"


class DiIntellij(rx.Component):
    library = "react-icons/di"
    tag = "DiIntellij"


class DiIonic(rx.Component):
    library = "react-icons/di"
    tag = "DiIonic"


class DiJava(rx.Component):
    library = "react-icons/di"
    tag = "DiJava"


class DiJavascript1(rx.Component):
    library = "react-icons/di"
    tag = "DiJavascript1"


class DiJavascript(rx.Component):
    library = "react-icons/di"
    tag = "DiJavascript"


class DiJekyllSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiJekyllSmall"


class DiJenkins(rx.Component):
    library = "react-icons/di"
    tag = "DiJenkins"


class DiJira(rx.Component):
    library = "react-icons/di"
    tag = "DiJira"


class DiJoomla(rx.Component):
    library = "react-icons/di"
    tag = "DiJoomla"


class DiJqueryLogo(rx.Component):
    library = "react-icons/di"
    tag = "DiJqueryLogo"


class DiJqueryUiLogo(rx.Component):
    library = "react-icons/di"
    tag = "DiJqueryUiLogo"


class DiJsBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiJsBadge"


class DiKomodo(rx.Component):
    library = "react-icons/di"
    tag = "DiKomodo"


class DiKrakenjsBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiKrakenjsBadge"


class DiKrakenjs(rx.Component):
    library = "react-icons/di"
    tag = "DiKrakenjs"


class DiLaravel(rx.Component):
    library = "react-icons/di"
    tag = "DiLaravel"


class DiLess(rx.Component):
    library = "react-icons/di"
    tag = "DiLess"


class DiLinux(rx.Component):
    library = "react-icons/di"
    tag = "DiLinux"


class DiMagento(rx.Component):
    library = "react-icons/di"
    tag = "DiMagento"


class DiMailchimp(rx.Component):
    library = "react-icons/di"
    tag = "DiMailchimp"


class DiMarkdown(rx.Component):
    library = "react-icons/di"
    tag = "DiMarkdown"


class DiMaterializecss(rx.Component):
    library = "react-icons/di"
    tag = "DiMaterializecss"


class DiMeteor(rx.Component):
    library = "react-icons/di"
    tag = "DiMeteor"


class DiMeteorfull(rx.Component):
    library = "react-icons/di"
    tag = "DiMeteorfull"


class DiMitlicence(rx.Component):
    library = "react-icons/di"
    tag = "DiMitlicence"


class DiModernizr(rx.Component):
    library = "react-icons/di"
    tag = "DiModernizr"


class DiMongodb(rx.Component):
    library = "react-icons/di"
    tag = "DiMongodb"


class DiMootoolsBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiMootoolsBadge"


class DiMootools(rx.Component):
    library = "react-icons/di"
    tag = "DiMootools"


class DiMozilla(rx.Component):
    library = "react-icons/di"
    tag = "DiMozilla"


class DiMsqlServer(rx.Component):
    library = "react-icons/di"
    tag = "DiMsqlServer"


class DiMysql(rx.Component):
    library = "react-icons/di"
    tag = "DiMysql"


class DiNancy(rx.Component):
    library = "react-icons/di"
    tag = "DiNancy"


class DiNetbeans(rx.Component):
    library = "react-icons/di"
    tag = "DiNetbeans"


class DiNetmagazine(rx.Component):
    library = "react-icons/di"
    tag = "DiNetmagazine"


class DiNginx(rx.Component):
    library = "react-icons/di"
    tag = "DiNginx"


class DiNodejsSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiNodejsSmall"


class DiNodejs(rx.Component):
    library = "react-icons/di"
    tag = "DiNodejs"


class DiNpm(rx.Component):
    library = "react-icons/di"
    tag = "DiNpm"


class DiOnedrive(rx.Component):
    library = "react-icons/di"
    tag = "DiOnedrive"


class DiOpenshift(rx.Component):
    library = "react-icons/di"
    tag = "DiOpenshift"


class DiOpensource(rx.Component):
    library = "react-icons/di"
    tag = "DiOpensource"


class DiOpera(rx.Component):
    library = "react-icons/di"
    tag = "DiOpera"


class DiPerl(rx.Component):
    library = "react-icons/di"
    tag = "DiPerl"


class DiPhonegap(rx.Component):
    library = "react-icons/di"
    tag = "DiPhonegap"


class DiPhotoshop(rx.Component):
    library = "react-icons/di"
    tag = "DiPhotoshop"


class DiPhp(rx.Component):
    library = "react-icons/di"
    tag = "DiPhp"


class DiPostgresql(rx.Component):
    library = "react-icons/di"
    tag = "DiPostgresql"


class DiProlog(rx.Component):
    library = "react-icons/di"
    tag = "DiProlog"


class DiPython(rx.Component):
    library = "react-icons/di"
    tag = "DiPython"


class DiRackspace(rx.Component):
    library = "react-icons/di"
    tag = "DiRackspace"


class DiRaphael(rx.Component):
    library = "react-icons/di"
    tag = "DiRaphael"


class DiRasberryPi(rx.Component):
    library = "react-icons/di"
    tag = "DiRasberryPi"


class DiReact(rx.Component):
    library = "react-icons/di"
    tag = "DiReact"


class DiRedhat(rx.Component):
    library = "react-icons/di"
    tag = "DiRedhat"


class DiRedis(rx.Component):
    library = "react-icons/di"
    tag = "DiRedis"


class DiRequirejs(rx.Component):
    library = "react-icons/di"
    tag = "DiRequirejs"


class DiResponsive(rx.Component):
    library = "react-icons/di"
    tag = "DiResponsive"


class DiRor(rx.Component):
    library = "react-icons/di"
    tag = "DiRor"


class DiRubyRough(rx.Component):
    library = "react-icons/di"
    tag = "DiRubyRough"


class DiRuby(rx.Component):
    library = "react-icons/di"
    tag = "DiRuby"


class DiRust(rx.Component):
    library = "react-icons/di"
    tag = "DiRust"


class DiSafari(rx.Component):
    library = "react-icons/di"
    tag = "DiSafari"


class DiSass(rx.Component):
    library = "react-icons/di"
    tag = "DiSass"


class DiScala(rx.Component):
    library = "react-icons/di"
    tag = "DiScala"


class DiScriptcs(rx.Component):
    library = "react-icons/di"
    tag = "DiScriptcs"


class DiScrum(rx.Component):
    library = "react-icons/di"
    tag = "DiScrum"


class DiSenchatouch(rx.Component):
    library = "react-icons/di"
    tag = "DiSenchatouch"


class DiSizzlejs(rx.Component):
    library = "react-icons/di"
    tag = "DiSizzlejs"


class DiSmashingMagazine(rx.Component):
    library = "react-icons/di"
    tag = "DiSmashingMagazine"


class DiSnapSvg(rx.Component):
    library = "react-icons/di"
    tag = "DiSnapSvg"


class DiSpark(rx.Component):
    library = "react-icons/di"
    tag = "DiSpark"


class DiSqllite(rx.Component):
    library = "react-icons/di"
    tag = "DiSqllite"


class DiStackoverflow(rx.Component):
    library = "react-icons/di"
    tag = "DiStackoverflow"


class DiStreamline(rx.Component):
    library = "react-icons/di"
    tag = "DiStreamline"


class DiStylus(rx.Component):
    library = "react-icons/di"
    tag = "DiStylus"


class DiSublime(rx.Component):
    library = "react-icons/di"
    tag = "DiSublime"


class DiSwift(rx.Component):
    library = "react-icons/di"
    tag = "DiSwift"


class DiSymfonyBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiSymfonyBadge"


class DiSymfony(rx.Component):
    library = "react-icons/di"
    tag = "DiSymfony"


class DiTechcrunch(rx.Component):
    library = "react-icons/di"
    tag = "DiTechcrunch"


class DiTerminalBadge(rx.Component):
    library = "react-icons/di"
    tag = "DiTerminalBadge"


class DiTerminal(rx.Component):
    library = "react-icons/di"
    tag = "DiTerminal"


class DiTravis(rx.Component):
    library = "react-icons/di"
    tag = "DiTravis"


class DiTrello(rx.Component):
    library = "react-icons/di"
    tag = "DiTrello"


class DiTypo3(rx.Component):
    library = "react-icons/di"
    tag = "DiTypo3"


class DiUbuntu(rx.Component):
    library = "react-icons/di"
    tag = "DiUbuntu"


class DiUikit(rx.Component):
    library = "react-icons/di"
    tag = "DiUikit"


class DiUnitySmall(rx.Component):
    library = "react-icons/di"
    tag = "DiUnitySmall"


class DiVim(rx.Component):
    library = "react-icons/di"
    tag = "DiVim"


class DiVisualstudio(rx.Component):
    library = "react-icons/di"
    tag = "DiVisualstudio"


class DiW3C(rx.Component):
    library = "react-icons/di"
    tag = "DiW3C"


class DiWebplatform(rx.Component):
    library = "react-icons/di"
    tag = "DiWebplatform"


class DiWindows(rx.Component):
    library = "react-icons/di"
    tag = "DiWindows"


class DiWordpress(rx.Component):
    library = "react-icons/di"
    tag = "DiWordpress"


class DiYahooSmall(rx.Component):
    library = "react-icons/di"
    tag = "DiYahooSmall"


class DiYahoo(rx.Component):
    library = "react-icons/di"
    tag = "DiYahoo"


class DiYeoman(rx.Component):
    library = "react-icons/di"
    tag = "DiYeoman"


class DiYii(rx.Component):
    library = "react-icons/di"
    tag = "DiYii"


class DiZend(rx.Component):
    library = "react-icons/di"
    tag = "DiZend"


