import reflex as rx

class GrAccessibility(rx.Component):
    library = "react-icons/gr"
    tag = "GrAccessibility"


class GrAchievement(rx.Component):
    library = "react-icons/gr"
    tag = "GrAchievement"


class GrAction(rx.Component):
    library = "react-icons/gr"
    tag = "GrAction"


class GrActions(rx.Component):
    library = "react-icons/gr"
    tag = "GrActions"


class GrAd(rx.Component):
    library = "react-icons/gr"
    tag = "GrAd"


class GrAddCircle(rx.Component):
    library = "react-icons/gr"
    tag = "GrAddCircle"


class GrAdd(rx.Component):
    library = "react-icons/gr"
    tag = "GrAdd"


class GrAed(rx.Component):
    library = "react-icons/gr"
    tag = "GrAed"


class GrAggregate(rx.Component):
    library = "react-icons/gr"
    tag = "GrAggregate"


class GrAidOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrAidOption"


class GrAid(rx.Component):
    library = "react-icons/gr"
    tag = "GrAid"


class GrAlarm(rx.Component):
    library = "react-icons/gr"
    tag = "GrAlarm"


class GrAlert(rx.Component):
    library = "react-icons/gr"
    tag = "GrAlert"


class GrAmazon(rx.Component):
    library = "react-icons/gr"
    tag = "GrAmazon"


class GrAmex(rx.Component):
    library = "react-icons/gr"
    tag = "GrAmex"


class GrAnalytics(rx.Component):
    library = "react-icons/gr"
    tag = "GrAnalytics"


class GrAnchor(rx.Component):
    library = "react-icons/gr"
    tag = "GrAnchor"


class GrAndroid(rx.Component):
    library = "react-icons/gr"
    tag = "GrAndroid"


class GrAnnounce(rx.Component):
    library = "react-icons/gr"
    tag = "GrAnnounce"


class GrAppleAppStore(rx.Component):
    library = "react-icons/gr"
    tag = "GrAppleAppStore"


class GrApple(rx.Component):
    library = "react-icons/gr"
    tag = "GrApple"


class GrAppsRounded(rx.Component):
    library = "react-icons/gr"
    tag = "GrAppsRounded"


class GrApps(rx.Component):
    library = "react-icons/gr"
    tag = "GrApps"


class GrArchive(rx.Component):
    library = "react-icons/gr"
    tag = "GrArchive"


class GrArchlinux(rx.Component):
    library = "react-icons/gr"
    tag = "GrArchlinux"


class GrArticle(rx.Component):
    library = "react-icons/gr"
    tag = "GrArticle"


class GrAruba(rx.Component):
    library = "react-icons/gr"
    tag = "GrAruba"


class GrAscend(rx.Component):
    library = "react-icons/gr"
    tag = "GrAscend"


class GrAscending(rx.Component):
    library = "react-icons/gr"
    tag = "GrAscending"


class GrAssistListening(rx.Component):
    library = "react-icons/gr"
    tag = "GrAssistListening"


class GrAtm(rx.Component):
    library = "react-icons/gr"
    tag = "GrAtm"


class GrAttachment(rx.Component):
    library = "react-icons/gr"
    tag = "GrAttachment"


class GrAttraction(rx.Component):
    library = "react-icons/gr"
    tag = "GrAttraction"


class GrBaby(rx.Component):
    library = "react-icons/gr"
    tag = "GrBaby"


class GrBackTen(rx.Component):
    library = "react-icons/gr"
    tag = "GrBackTen"


class GrBarChart(rx.Component):
    library = "react-icons/gr"
    tag = "GrBarChart"


class GrBar(rx.Component):
    library = "react-icons/gr"
    tag = "GrBar"


class GrBasket(rx.Component):
    library = "react-icons/gr"
    tag = "GrBasket"


class GrBeacon(rx.Component):
    library = "react-icons/gr"
    tag = "GrBeacon"


class GrBike(rx.Component):
    library = "react-icons/gr"
    tag = "GrBike"


class GrBitcoin(rx.Component):
    library = "react-icons/gr"
    tag = "GrBitcoin"


class GrBladesHorizontal(rx.Component):
    library = "react-icons/gr"
    tag = "GrBladesHorizontal"


class GrBladesVertical(rx.Component):
    library = "react-icons/gr"
    tag = "GrBladesVertical"


class GrBlockQuote(rx.Component):
    library = "react-icons/gr"
    tag = "GrBlockQuote"


class GrBlog(rx.Component):
    library = "react-icons/gr"
    tag = "GrBlog"


class GrBluetooth(rx.Component):
    library = "react-icons/gr"
    tag = "GrBluetooth"


class GrBold(rx.Component):
    library = "react-icons/gr"
    tag = "GrBold"


class GrBook(rx.Component):
    library = "react-icons/gr"
    tag = "GrBook"


class GrBookmark(rx.Component):
    library = "react-icons/gr"
    tag = "GrBookmark"


class GrBottomCorner(rx.Component):
    library = "react-icons/gr"
    tag = "GrBottomCorner"


class GrBraille(rx.Component):
    library = "react-icons/gr"
    tag = "GrBraille"


class GrBriefcase(rx.Component):
    library = "react-icons/gr"
    tag = "GrBriefcase"


class GrBrush(rx.Component):
    library = "react-icons/gr"
    tag = "GrBrush"


class GrBucket(rx.Component):
    library = "react-icons/gr"
    tag = "GrBucket"


class GrBug(rx.Component):
    library = "react-icons/gr"
    tag = "GrBug"


class GrBundle(rx.Component):
    library = "react-icons/gr"
    tag = "GrBundle"


class GrBus(rx.Component):
    library = "react-icons/gr"
    tag = "GrBus"


class GrBusinessService(rx.Component):
    library = "react-icons/gr"
    tag = "GrBusinessService"


class GrCafeteria(rx.Component):
    library = "react-icons/gr"
    tag = "GrCafeteria"


class GrCalculator(rx.Component):
    library = "react-icons/gr"
    tag = "GrCalculator"


class GrCalendar(rx.Component):
    library = "react-icons/gr"
    tag = "GrCalendar"


class GrCamera(rx.Component):
    library = "react-icons/gr"
    tag = "GrCamera"


class GrCapacity(rx.Component):
    library = "react-icons/gr"
    tag = "GrCapacity"


class GrCar(rx.Component):
    library = "react-icons/gr"
    tag = "GrCar"


class GrCaretDownFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrCaretDownFill"


class GrCaretDown(rx.Component):
    library = "react-icons/gr"
    tag = "GrCaretDown"


class GrCaretLeftFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrCaretLeftFill"


class GrCaretNext(rx.Component):
    library = "react-icons/gr"
    tag = "GrCaretNext"


class GrCaretPrevious(rx.Component):
    library = "react-icons/gr"
    tag = "GrCaretPrevious"


class GrCaretRightFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrCaretRightFill"


class GrCaretUpFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrCaretUpFill"


class GrCaretUp(rx.Component):
    library = "react-icons/gr"
    tag = "GrCaretUp"


class GrCart(rx.Component):
    library = "react-icons/gr"
    tag = "GrCart"


class GrCatalogOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrCatalogOption"


class GrCatalog(rx.Component):
    library = "react-icons/gr"
    tag = "GrCatalog"


class GrCentos(rx.Component):
    library = "react-icons/gr"
    tag = "GrCentos"


class GrCertificate(rx.Component):
    library = "react-icons/gr"
    tag = "GrCertificate"


class GrChannel(rx.Component):
    library = "react-icons/gr"
    tag = "GrChannel"


class GrChapterAdd(rx.Component):
    library = "react-icons/gr"
    tag = "GrChapterAdd"


class GrChapterNext(rx.Component):
    library = "react-icons/gr"
    tag = "GrChapterNext"


class GrChapterPrevious(rx.Component):
    library = "react-icons/gr"
    tag = "GrChapterPrevious"


class GrChatOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrChatOption"


class GrChat(rx.Component):
    library = "react-icons/gr"
    tag = "GrChat"


class GrCheckboxSelected(rx.Component):
    library = "react-icons/gr"
    tag = "GrCheckboxSelected"


class GrCheckbox(rx.Component):
    library = "react-icons/gr"
    tag = "GrCheckbox"


class GrCheckmark(rx.Component):
    library = "react-icons/gr"
    tag = "GrCheckmark"


class GrChrome(rx.Component):
    library = "react-icons/gr"
    tag = "GrChrome"


class GrCircleAlert(rx.Component):
    library = "react-icons/gr"
    tag = "GrCircleAlert"


class GrCircleInformation(rx.Component):
    library = "react-icons/gr"
    tag = "GrCircleInformation"


class GrCirclePlay(rx.Component):
    library = "react-icons/gr"
    tag = "GrCirclePlay"


class GrCircleQuestion(rx.Component):
    library = "react-icons/gr"
    tag = "GrCircleQuestion"


class GrClearOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrClearOption"


class GrClear(rx.Component):
    library = "react-icons/gr"
    tag = "GrClear"


class GrCli(rx.Component):
    library = "react-icons/gr"
    tag = "GrCli"


class GrClipboard(rx.Component):
    library = "react-icons/gr"
    tag = "GrClipboard"


class GrClock(rx.Component):
    library = "react-icons/gr"
    tag = "GrClock"


class GrClone(rx.Component):
    library = "react-icons/gr"
    tag = "GrClone"


class GrClose(rx.Component):
    library = "react-icons/gr"
    tag = "GrClose"


class GrClosedCaption(rx.Component):
    library = "react-icons/gr"
    tag = "GrClosedCaption"


class GrCloudComputer(rx.Component):
    library = "react-icons/gr"
    tag = "GrCloudComputer"


class GrCloudDownload(rx.Component):
    library = "react-icons/gr"
    tag = "GrCloudDownload"


class GrCloudSoftware(rx.Component):
    library = "react-icons/gr"
    tag = "GrCloudSoftware"


class GrCloudUpload(rx.Component):
    library = "react-icons/gr"
    tag = "GrCloudUpload"


class GrCloud(rx.Component):
    library = "react-icons/gr"
    tag = "GrCloud"


class GrCloudlinux(rx.Component):
    library = "react-icons/gr"
    tag = "GrCloudlinux"


class GrCluster(rx.Component):
    library = "react-icons/gr"
    tag = "GrCluster"


class GrCoatCheck(rx.Component):
    library = "react-icons/gr"
    tag = "GrCoatCheck"


class GrCodeSandbox(rx.Component):
    library = "react-icons/gr"
    tag = "GrCodeSandbox"


class GrCode(rx.Component):
    library = "react-icons/gr"
    tag = "GrCode"


class GrCodepen(rx.Component):
    library = "react-icons/gr"
    tag = "GrCodepen"


class GrCoffee(rx.Component):
    library = "react-icons/gr"
    tag = "GrCoffee"


class GrColumns(rx.Component):
    library = "react-icons/gr"
    tag = "GrColumns"


class GrCommand(rx.Component):
    library = "react-icons/gr"
    tag = "GrCommand"


class GrCompare(rx.Component):
    library = "react-icons/gr"
    tag = "GrCompare"


class GrCompass(rx.Component):
    library = "react-icons/gr"
    tag = "GrCompass"


class GrCompliance(rx.Component):
    library = "react-icons/gr"
    tag = "GrCompliance"


class GrConfigure(rx.Component):
    library = "react-icons/gr"
    tag = "GrConfigure"


class GrConnect(rx.Component):
    library = "react-icons/gr"
    tag = "GrConnect"


class GrConnectivity(rx.Component):
    library = "react-icons/gr"
    tag = "GrConnectivity"


class GrConsole(rx.Component):
    library = "react-icons/gr"
    tag = "GrConsole"


class GrContactInfo(rx.Component):
    library = "react-icons/gr"
    tag = "GrContactInfo"


class GrContact(rx.Component):
    library = "react-icons/gr"
    tag = "GrContact"


class GrContract(rx.Component):
    library = "react-icons/gr"
    tag = "GrContract"


class GrCopy(rx.Component):
    library = "react-icons/gr"
    tag = "GrCopy"


class GrCpu(rx.Component):
    library = "react-icons/gr"
    tag = "GrCpu"


class GrCreativeCommons(rx.Component):
    library = "react-icons/gr"
    tag = "GrCreativeCommons"


class GrCreditCard(rx.Component):
    library = "react-icons/gr"
    tag = "GrCreditCard"


class GrCss3(rx.Component):
    library = "react-icons/gr"
    tag = "GrCss3"


class GrCube(rx.Component):
    library = "react-icons/gr"
    tag = "GrCube"


class GrCubes(rx.Component):
    library = "react-icons/gr"
    tag = "GrCubes"


class GrCurrency(rx.Component):
    library = "react-icons/gr"
    tag = "GrCurrency"


class GrCursor(rx.Component):
    library = "react-icons/gr"
    tag = "GrCursor"


class GrCut(rx.Component):
    library = "react-icons/gr"
    tag = "GrCut"


class GrCycle(rx.Component):
    library = "react-icons/gr"
    tag = "GrCycle"


class GrDashboard(rx.Component):
    library = "react-icons/gr"
    tag = "GrDashboard"


class GrDatabase(rx.Component):
    library = "react-icons/gr"
    tag = "GrDatabase"


class GrDebian(rx.Component):
    library = "react-icons/gr"
    tag = "GrDebian"


class GrDeliver(rx.Component):
    library = "react-icons/gr"
    tag = "GrDeliver"


class GrDeploy(rx.Component):
    library = "react-icons/gr"
    tag = "GrDeploy"


class GrDescend(rx.Component):
    library = "react-icons/gr"
    tag = "GrDescend"


class GrDescending(rx.Component):
    library = "react-icons/gr"
    tag = "GrDescending"


class GrDesktop(rx.Component):
    library = "react-icons/gr"
    tag = "GrDesktop"


class GrDetach(rx.Component):
    library = "react-icons/gr"
    tag = "GrDetach"


class GrDevice(rx.Component):
    library = "react-icons/gr"
    tag = "GrDevice"


class GrDiamond(rx.Component):
    library = "react-icons/gr"
    tag = "GrDiamond"


class GrDirections(rx.Component):
    library = "react-icons/gr"
    tag = "GrDirections"


class GrDisabledOutline(rx.Component):
    library = "react-icons/gr"
    tag = "GrDisabledOutline"


class GrDisc(rx.Component):
    library = "react-icons/gr"
    tag = "GrDisc"


class GrDislikeFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrDislikeFill"


class GrDislike(rx.Component):
    library = "react-icons/gr"
    tag = "GrDislike"


class GrDocker(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocker"


class GrDocumentCloud(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentCloud"


class GrDocumentConfig(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentConfig"


class GrDocumentCsv(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentCsv"


class GrDocumentDownload(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentDownload"


class GrDocumentExcel(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentExcel"


class GrDocumentImage(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentImage"


class GrDocumentLocked(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentLocked"


class GrDocumentMissing(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentMissing"


class GrDocumentNotes(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentNotes"


class GrDocumentOutlook(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentOutlook"


class GrDocumentPdf(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentPdf"


class GrDocumentPerformance(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentPerformance"


class GrDocumentPpt(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentPpt"


class GrDocumentRtf(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentRtf"


class GrDocumentSound(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentSound"


class GrDocumentStore(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentStore"


class GrDocumentTest(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentTest"


class GrDocumentText(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentText"


class GrDocumentThreat(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentThreat"


class GrDocumentTime(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentTime"


class GrDocumentTransfer(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentTransfer"


class GrDocumentTxt(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentTxt"


class GrDocumentUpdate(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentUpdate"


class GrDocumentUpload(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentUpload"


class GrDocumentUser(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentUser"


class GrDocumentVerified(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentVerified"


class GrDocumentVideo(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentVideo"


class GrDocumentWindows(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentWindows"


class GrDocumentWord(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentWord"


class GrDocumentZip(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocumentZip"


class GrDocument(rx.Component):
    library = "react-icons/gr"
    tag = "GrDocument"


class GrDomain(rx.Component):
    library = "react-icons/gr"
    tag = "GrDomain"


class GrDos(rx.Component):
    library = "react-icons/gr"
    tag = "GrDos"


class GrDown(rx.Component):
    library = "react-icons/gr"
    tag = "GrDown"


class GrDownloadOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrDownloadOption"


class GrDownload(rx.Component):
    library = "react-icons/gr"
    tag = "GrDownload"


class GrDrag(rx.Component):
    library = "react-icons/gr"
    tag = "GrDrag"


class GrDrawer(rx.Component):
    library = "react-icons/gr"
    tag = "GrDrawer"


class GrDribbble(rx.Component):
    library = "react-icons/gr"
    tag = "GrDribbble"


class GrDriveCage(rx.Component):
    library = "react-icons/gr"
    tag = "GrDriveCage"


class GrDropbox(rx.Component):
    library = "react-icons/gr"
    tag = "GrDropbox"


class GrDuplicate(rx.Component):
    library = "react-icons/gr"
    tag = "GrDuplicate"


class GrDxc(rx.Component):
    library = "react-icons/gr"
    tag = "GrDxc"


class GrEbay(rx.Component):
    library = "react-icons/gr"
    tag = "GrEbay"


class GrEdge(rx.Component):
    library = "react-icons/gr"
    tag = "GrEdge"


class GrEdit(rx.Component):
    library = "react-icons/gr"
    tag = "GrEdit"


class GrEject(rx.Component):
    library = "react-icons/gr"
    tag = "GrEject"


class GrElevator(rx.Component):
    library = "react-icons/gr"
    tag = "GrElevator"


class GrEmergency(rx.Component):
    library = "react-icons/gr"
    tag = "GrEmergency"


class GrEmoji(rx.Component):
    library = "react-icons/gr"
    tag = "GrEmoji"


class GrEmptyCircle(rx.Component):
    library = "react-icons/gr"
    tag = "GrEmptyCircle"


class GrErase(rx.Component):
    library = "react-icons/gr"
    tag = "GrErase"


class GrEscalator(rx.Component):
    library = "react-icons/gr"
    tag = "GrEscalator"


class GrExpand(rx.Component):
    library = "react-icons/gr"
    tag = "GrExpand"


class GrEzmeral(rx.Component):
    library = "react-icons/gr"
    tag = "GrEzmeral"


class GrFacebookOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrFacebookOption"


class GrFacebook(rx.Component):
    library = "react-icons/gr"
    tag = "GrFacebook"


class GrFanOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrFanOption"


class GrFan(rx.Component):
    library = "react-icons/gr"
    tag = "GrFan"


class GrFastForward(rx.Component):
    library = "react-icons/gr"
    tag = "GrFastForward"


class GrFavorite(rx.Component):
    library = "react-icons/gr"
    tag = "GrFavorite"


class GrFedora(rx.Component):
    library = "react-icons/gr"
    tag = "GrFedora"


class GrFigma(rx.Component):
    library = "react-icons/gr"
    tag = "GrFigma"


class GrFilter(rx.Component):
    library = "react-icons/gr"
    tag = "GrFilter"


class GrFingerPrint(rx.Component):
    library = "react-icons/gr"
    tag = "GrFingerPrint"


class GrFireball(rx.Component):
    library = "react-icons/gr"
    tag = "GrFireball"


class GrFirefox(rx.Component):
    library = "react-icons/gr"
    tag = "GrFirefox"


class GrFirewall(rx.Component):
    library = "react-icons/gr"
    tag = "GrFirewall"


class GrFlagFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrFlagFill"


class GrFlag(rx.Component):
    library = "react-icons/gr"
    tag = "GrFlag"


class GrFlows(rx.Component):
    library = "react-icons/gr"
    tag = "GrFlows"


class GrFolderCycle(rx.Component):
    library = "react-icons/gr"
    tag = "GrFolderCycle"


class GrFolderOpen(rx.Component):
    library = "react-icons/gr"
    tag = "GrFolderOpen"


class GrFolder(rx.Component):
    library = "react-icons/gr"
    tag = "GrFolder"


class GrFormAdd(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormAdd"


class GrFormAttachment(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormAttachment"


class GrFormCalendar(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormCalendar"


class GrFormCheckmark(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormCheckmark"


class GrFormClock(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormClock"


class GrFormClose(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormClose"


class GrFormCut(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormCut"


class GrFormDown(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormDown"


class GrFormEdit(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormEdit"


class GrFormFilter(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormFilter"


class GrFormFolder(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormFolder"


class GrFormLocation(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormLocation"


class GrFormLock(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormLock"


class GrFormNextLink(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormNextLink"


class GrFormNext(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormNext"


class GrFormPin(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormPin"


class GrFormPreviousLink(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormPreviousLink"


class GrFormPrevious(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormPrevious"


class GrFormRefresh(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormRefresh"


class GrFormSchedule(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormSchedule"


class GrFormSearch(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormSearch"


class GrFormSubtract(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormSubtract"


class GrFormTrash(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormTrash"


class GrFormUp(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormUp"


class GrFormUpload(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormUpload"


class GrFormViewHide(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormViewHide"


class GrFormView(rx.Component):
    library = "react-icons/gr"
    tag = "GrFormView"


class GrForwardTen(rx.Component):
    library = "react-icons/gr"
    tag = "GrForwardTen"


class GrFreebsd(rx.Component):
    library = "react-icons/gr"
    tag = "GrFreebsd"


class GrGallery(rx.Component):
    library = "react-icons/gr"
    tag = "GrGallery"


class GrGamepad(rx.Component):
    library = "react-icons/gr"
    tag = "GrGamepad"


class GrGateway(rx.Component):
    library = "react-icons/gr"
    tag = "GrGateway"


class GrGatsbyjs(rx.Component):
    library = "react-icons/gr"
    tag = "GrGatsbyjs"


class GrGem(rx.Component):
    library = "react-icons/gr"
    tag = "GrGem"


class GrGift(rx.Component):
    library = "react-icons/gr"
    tag = "GrGift"


class GrGithub(rx.Component):
    library = "react-icons/gr"
    tag = "GrGithub"


class GrGlobe(rx.Component):
    library = "react-icons/gr"
    tag = "GrGlobe"


class GrGolang(rx.Component):
    library = "react-icons/gr"
    tag = "GrGolang"


class GrGooglePlay(rx.Component):
    library = "react-icons/gr"
    tag = "GrGooglePlay"


class GrGooglePlus(rx.Component):
    library = "react-icons/gr"
    tag = "GrGooglePlus"


class GrGoogleWallet(rx.Component):
    library = "react-icons/gr"
    tag = "GrGoogleWallet"


class GrGoogle(rx.Component):
    library = "react-icons/gr"
    tag = "GrGoogle"


class GrGraphQl(rx.Component):
    library = "react-icons/gr"
    tag = "GrGraphQl"


class GrGremlin(rx.Component):
    library = "react-icons/gr"
    tag = "GrGremlin"


class GrGrid(rx.Component):
    library = "react-icons/gr"
    tag = "GrGrid"


class GrGrommet(rx.Component):
    library = "react-icons/gr"
    tag = "GrGrommet"


class GrGroup(rx.Component):
    library = "react-icons/gr"
    tag = "GrGroup"


class GrGrow(rx.Component):
    library = "react-icons/gr"
    tag = "GrGrow"


class GrHadoop(rx.Component):
    library = "react-icons/gr"
    tag = "GrHadoop"


class GrHalt(rx.Component):
    library = "react-icons/gr"
    tag = "GrHalt"


class GrHelpOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrHelpOption"


class GrHelp(rx.Component):
    library = "react-icons/gr"
    tag = "GrHelp"


class GrHeroku(rx.Component):
    library = "react-icons/gr"
    tag = "GrHeroku"


class GrHide(rx.Component):
    library = "react-icons/gr"
    tag = "GrHide"


class GrHistory(rx.Component):
    library = "react-icons/gr"
    tag = "GrHistory"


class GrHomeOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrHomeOption"


class GrHomeRounded(rx.Component):
    library = "react-icons/gr"
    tag = "GrHomeRounded"


class GrHome(rx.Component):
    library = "react-icons/gr"
    tag = "GrHome"


class GrHorton(rx.Component):
    library = "react-icons/gr"
    tag = "GrHorton"


class GrHostMaintenance(rx.Component):
    library = "react-icons/gr"
    tag = "GrHostMaintenance"


class GrHost(rx.Component):
    library = "react-icons/gr"
    tag = "GrHost"


class GrHp(rx.Component):
    library = "react-icons/gr"
    tag = "GrHp"


class GrHpeLabs(rx.Component):
    library = "react-icons/gr"
    tag = "GrHpeLabs"


class GrHpe(rx.Component):
    library = "react-icons/gr"
    tag = "GrHpe"


class GrHpi(rx.Component):
    library = "react-icons/gr"
    tag = "GrHpi"


class GrHtml5(rx.Component):
    library = "react-icons/gr"
    tag = "GrHtml5"


class GrIceCream(rx.Component):
    library = "react-icons/gr"
    tag = "GrIceCream"


class GrImage(rx.Component):
    library = "react-icons/gr"
    tag = "GrImage"


class GrImpact(rx.Component):
    library = "react-icons/gr"
    tag = "GrImpact"


class GrInProgress(rx.Component):
    library = "react-icons/gr"
    tag = "GrInProgress"


class GrInbox(rx.Component):
    library = "react-icons/gr"
    tag = "GrInbox"


class GrIndicator(rx.Component):
    library = "react-icons/gr"
    tag = "GrIndicator"


class GrInfo(rx.Component):
    library = "react-icons/gr"
    tag = "GrInfo"


class GrInherit(rx.Component):
    library = "react-icons/gr"
    tag = "GrInherit"


class GrInsecure(rx.Component):
    library = "react-icons/gr"
    tag = "GrInsecure"


class GrInspect(rx.Component):
    library = "react-icons/gr"
    tag = "GrInspect"


class GrInstagram(rx.Component):
    library = "react-icons/gr"
    tag = "GrInstagram"


class GrInstallOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrInstallOption"


class GrInstall(rx.Component):
    library = "react-icons/gr"
    tag = "GrInstall"


class GrIntegration(rx.Component):
    library = "react-icons/gr"
    tag = "GrIntegration"


class GrInternetExplorer(rx.Component):
    library = "react-icons/gr"
    tag = "GrInternetExplorer"


class GrItalic(rx.Component):
    library = "react-icons/gr"
    tag = "GrItalic"


class GrIteration(rx.Component):
    library = "react-icons/gr"
    tag = "GrIteration"


class GrJava(rx.Component):
    library = "react-icons/gr"
    tag = "GrJava"


class GrJs(rx.Component):
    library = "react-icons/gr"
    tag = "GrJs"


class GrKey(rx.Component):
    library = "react-icons/gr"
    tag = "GrKey"


class GrKeyboard(rx.Component):
    library = "react-icons/gr"
    tag = "GrKeyboard"


class GrLanguage(rx.Component):
    library = "react-icons/gr"
    tag = "GrLanguage"


class GrLastfm(rx.Component):
    library = "react-icons/gr"
    tag = "GrLastfm"


class GrLaunch(rx.Component):
    library = "react-icons/gr"
    tag = "GrLaunch"


class GrLayer(rx.Component):
    library = "react-icons/gr"
    tag = "GrLayer"


class GrLicense(rx.Component):
    library = "react-icons/gr"
    tag = "GrLicense"


class GrLikeFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrLikeFill"


class GrLike(rx.Component):
    library = "react-icons/gr"
    tag = "GrLike"


class GrLineChart(rx.Component):
    library = "react-icons/gr"
    tag = "GrLineChart"


class GrLinkBottom(rx.Component):
    library = "react-icons/gr"
    tag = "GrLinkBottom"


class GrLinkDown(rx.Component):
    library = "react-icons/gr"
    tag = "GrLinkDown"


class GrLinkNext(rx.Component):
    library = "react-icons/gr"
    tag = "GrLinkNext"


class GrLinkPrevious(rx.Component):
    library = "react-icons/gr"
    tag = "GrLinkPrevious"


class GrLinkTop(rx.Component):
    library = "react-icons/gr"
    tag = "GrLinkTop"


class GrLinkUp(rx.Component):
    library = "react-icons/gr"
    tag = "GrLinkUp"


class GrLink(rx.Component):
    library = "react-icons/gr"
    tag = "GrLink"


class GrLinkedinOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrLinkedinOption"


class GrLinkedin(rx.Component):
    library = "react-icons/gr"
    tag = "GrLinkedin"


class GrList(rx.Component):
    library = "react-icons/gr"
    tag = "GrList"


class GrLocal(rx.Component):
    library = "react-icons/gr"
    tag = "GrLocal"


class GrLocationPin(rx.Component):
    library = "react-icons/gr"
    tag = "GrLocationPin"


class GrLocation(rx.Component):
    library = "react-icons/gr"
    tag = "GrLocation"


class GrLock(rx.Component):
    library = "react-icons/gr"
    tag = "GrLock"


class GrLogin(rx.Component):
    library = "react-icons/gr"
    tag = "GrLogin"


class GrLogout(rx.Component):
    library = "react-icons/gr"
    tag = "GrLogout"


class GrLounge(rx.Component):
    library = "react-icons/gr"
    tag = "GrLounge"


class GrMagic(rx.Component):
    library = "react-icons/gr"
    tag = "GrMagic"


class GrMailOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrMailOption"


class GrMail(rx.Component):
    library = "react-icons/gr"
    tag = "GrMail"


class GrMandriva(rx.Component):
    library = "react-icons/gr"
    tag = "GrMandriva"


class GrManual(rx.Component):
    library = "react-icons/gr"
    tag = "GrManual"


class GrMapLocation(rx.Component):
    library = "react-icons/gr"
    tag = "GrMapLocation"


class GrMap(rx.Component):
    library = "react-icons/gr"
    tag = "GrMap"


class GrMastercard(rx.Component):
    library = "react-icons/gr"
    tag = "GrMastercard"


class GrMedium(rx.Component):
    library = "react-icons/gr"
    tag = "GrMedium"


class GrMemory(rx.Component):
    library = "react-icons/gr"
    tag = "GrMemory"


class GrMenu(rx.Component):
    library = "react-icons/gr"
    tag = "GrMenu"


class GrMicrofocus(rx.Component):
    library = "react-icons/gr"
    tag = "GrMicrofocus"


class GrMicrophone(rx.Component):
    library = "react-icons/gr"
    tag = "GrMicrophone"


class GrMoney(rx.Component):
    library = "react-icons/gr"
    tag = "GrMoney"


class GrMonitor(rx.Component):
    library = "react-icons/gr"
    tag = "GrMonitor"


class GrMonospace(rx.Component):
    library = "react-icons/gr"
    tag = "GrMonospace"


class GrMoon(rx.Component):
    library = "react-icons/gr"
    tag = "GrMoon"


class GrMoreVertical(rx.Component):
    library = "react-icons/gr"
    tag = "GrMoreVertical"


class GrMore(rx.Component):
    library = "react-icons/gr"
    tag = "GrMore"


class GrMouse(rx.Component):
    library = "react-icons/gr"
    tag = "GrMouse"


class GrMultimedia(rx.Component):
    library = "react-icons/gr"
    tag = "GrMultimedia"


class GrMultiple(rx.Component):
    library = "react-icons/gr"
    tag = "GrMultiple"


class GrMusic(rx.Component):
    library = "react-icons/gr"
    tag = "GrMusic"


class GrMysql(rx.Component):
    library = "react-icons/gr"
    tag = "GrMysql"


class GrNavigate(rx.Component):
    library = "react-icons/gr"
    tag = "GrNavigate"


class GrNetworkDrive(rx.Component):
    library = "react-icons/gr"
    tag = "GrNetworkDrive"


class GrNetwork(rx.Component):
    library = "react-icons/gr"
    tag = "GrNetwork"


class GrNewWindow(rx.Component):
    library = "react-icons/gr"
    tag = "GrNewWindow"


class GrNew(rx.Component):
    library = "react-icons/gr"
    tag = "GrNew"


class GrNext(rx.Component):
    library = "react-icons/gr"
    tag = "GrNext"


class GrNode(rx.Component):
    library = "react-icons/gr"
    tag = "GrNode"


class GrNodes(rx.Component):
    library = "react-icons/gr"
    tag = "GrNodes"


class GrNorton(rx.Component):
    library = "react-icons/gr"
    tag = "GrNorton"


class GrNote(rx.Component):
    library = "react-icons/gr"
    tag = "GrNote"


class GrNotes(rx.Component):
    library = "react-icons/gr"
    tag = "GrNotes"


class GrNotification(rx.Component):
    library = "react-icons/gr"
    tag = "GrNotification"


class GrNpm(rx.Component):
    library = "react-icons/gr"
    tag = "GrNpm"


class GrObjectGroup(rx.Component):
    library = "react-icons/gr"
    tag = "GrObjectGroup"


class GrObjectUngroup(rx.Component):
    library = "react-icons/gr"
    tag = "GrObjectUngroup"


class GrOfflineStorage(rx.Component):
    library = "react-icons/gr"
    tag = "GrOfflineStorage"


class GrOnedrive(rx.Component):
    library = "react-icons/gr"
    tag = "GrOnedrive"


class GrOpera(rx.Component):
    library = "react-icons/gr"
    tag = "GrOpera"


class GrOptimize(rx.Component):
    library = "react-icons/gr"
    tag = "GrOptimize"


class GrOracle(rx.Component):
    library = "react-icons/gr"
    tag = "GrOracle"


class GrOrderedList(rx.Component):
    library = "react-icons/gr"
    tag = "GrOrderedList"


class GrOrganization(rx.Component):
    library = "react-icons/gr"
    tag = "GrOrganization"


class GrOverview(rx.Component):
    library = "react-icons/gr"
    tag = "GrOverview"


class GrPackage(rx.Component):
    library = "react-icons/gr"
    tag = "GrPackage"


class GrPaint(rx.Component):
    library = "react-icons/gr"
    tag = "GrPaint"


class GrPan(rx.Component):
    library = "react-icons/gr"
    tag = "GrPan"


class GrPauseFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrPauseFill"


class GrPause(rx.Component):
    library = "react-icons/gr"
    tag = "GrPause"


class GrPaypal(rx.Component):
    library = "react-icons/gr"
    tag = "GrPaypal"


class GrPerformance(rx.Component):
    library = "react-icons/gr"
    tag = "GrPerformance"


class GrPersonalComputer(rx.Component):
    library = "react-icons/gr"
    tag = "GrPersonalComputer"


class GrPhoneFlip(rx.Component):
    library = "react-icons/gr"
    tag = "GrPhoneFlip"


class GrPhoneHorizontal(rx.Component):
    library = "react-icons/gr"
    tag = "GrPhoneHorizontal"


class GrPhoneVertical(rx.Component):
    library = "react-icons/gr"
    tag = "GrPhoneVertical"


class GrPhone(rx.Component):
    library = "react-icons/gr"
    tag = "GrPhone"


class GrPieChart(rx.Component):
    library = "react-icons/gr"
    tag = "GrPieChart"


class GrPiedPiper(rx.Component):
    library = "react-icons/gr"
    tag = "GrPiedPiper"


class GrPin(rx.Component):
    library = "react-icons/gr"
    tag = "GrPin"


class GrPinterest(rx.Component):
    library = "react-icons/gr"
    tag = "GrPinterest"


class GrPlan(rx.Component):
    library = "react-icons/gr"
    tag = "GrPlan"


class GrPlayFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrPlayFill"


class GrPlay(rx.Component):
    library = "react-icons/gr"
    tag = "GrPlay"


class GrPlug(rx.Component):
    library = "react-icons/gr"
    tag = "GrPlug"


class GrPocket(rx.Component):
    library = "react-icons/gr"
    tag = "GrPocket"


class GrPowerCycle(rx.Component):
    library = "react-icons/gr"
    tag = "GrPowerCycle"


class GrPowerForceShutdown(rx.Component):
    library = "react-icons/gr"
    tag = "GrPowerForceShutdown"


class GrPowerReset(rx.Component):
    library = "react-icons/gr"
    tag = "GrPowerReset"


class GrPowerShutdown(rx.Component):
    library = "react-icons/gr"
    tag = "GrPowerShutdown"


class GrPower(rx.Component):
    library = "react-icons/gr"
    tag = "GrPower"


class GrPrevious(rx.Component):
    library = "react-icons/gr"
    tag = "GrPrevious"


class GrPrint(rx.Component):
    library = "react-icons/gr"
    tag = "GrPrint"


class GrProductHunt(rx.Component):
    library = "react-icons/gr"
    tag = "GrProductHunt"


class GrProjects(rx.Component):
    library = "react-icons/gr"
    tag = "GrProjects"


class GrQr(rx.Component):
    library = "react-icons/gr"
    tag = "GrQr"


class GrRadialSelected(rx.Component):
    library = "react-icons/gr"
    tag = "GrRadialSelected"


class GrRadial(rx.Component):
    library = "react-icons/gr"
    tag = "GrRadial"


class GrRaspberry(rx.Component):
    library = "react-icons/gr"
    tag = "GrRaspberry"


class GrReactjs(rx.Component):
    library = "react-icons/gr"
    tag = "GrReactjs"


class GrReddit(rx.Component):
    library = "react-icons/gr"
    tag = "GrReddit"


class GrRedhat(rx.Component):
    library = "react-icons/gr"
    tag = "GrRedhat"


class GrRedo(rx.Component):
    library = "react-icons/gr"
    tag = "GrRedo"


class GrRefresh(rx.Component):
    library = "react-icons/gr"
    tag = "GrRefresh"


class GrResources(rx.Component):
    library = "react-icons/gr"
    tag = "GrResources"


class GrRestaurant(rx.Component):
    library = "react-icons/gr"
    tag = "GrRestaurant"


class GrRestroomMen(rx.Component):
    library = "react-icons/gr"
    tag = "GrRestroomMen"


class GrRestroomWomen(rx.Component):
    library = "react-icons/gr"
    tag = "GrRestroomWomen"


class GrRestroom(rx.Component):
    library = "react-icons/gr"
    tag = "GrRestroom"


class GrResume(rx.Component):
    library = "react-icons/gr"
    tag = "GrResume"


class GrReturn(rx.Component):
    library = "react-icons/gr"
    tag = "GrReturn"


class GrRevert(rx.Component):
    library = "react-icons/gr"
    tag = "GrRevert"


class GrRewind(rx.Component):
    library = "react-icons/gr"
    tag = "GrRewind"


class GrRisk(rx.Component):
    library = "react-icons/gr"
    tag = "GrRisk"


class GrRobot(rx.Component):
    library = "react-icons/gr"
    tag = "GrRobot"


class GrRotateLeft(rx.Component):
    library = "react-icons/gr"
    tag = "GrRotateLeft"


class GrRotateRight(rx.Component):
    library = "react-icons/gr"
    tag = "GrRotateRight"


class GrRss(rx.Component):
    library = "react-icons/gr"
    tag = "GrRss"


class GrRun(rx.Component):
    library = "react-icons/gr"
    tag = "GrRun"


class GrSafariOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrSafariOption"


class GrSans(rx.Component):
    library = "react-icons/gr"
    tag = "GrSans"


class GrSatellite(rx.Component):
    library = "react-icons/gr"
    tag = "GrSatellite"


class GrSave(rx.Component):
    library = "react-icons/gr"
    tag = "GrSave"


class GrScan(rx.Component):
    library = "react-icons/gr"
    tag = "GrScan"


class GrScheduleNew(rx.Component):
    library = "react-icons/gr"
    tag = "GrScheduleNew"


class GrSchedulePlay(rx.Component):
    library = "react-icons/gr"
    tag = "GrSchedulePlay"


class GrSchedule(rx.Component):
    library = "react-icons/gr"
    tag = "GrSchedule"


class GrSchedules(rx.Component):
    library = "react-icons/gr"
    tag = "GrSchedules"


class GrSco(rx.Component):
    library = "react-icons/gr"
    tag = "GrSco"


class GrScorecard(rx.Component):
    library = "react-icons/gr"
    tag = "GrScorecard"


class GrScript(rx.Component):
    library = "react-icons/gr"
    tag = "GrScript"


class GrSd(rx.Component):
    library = "react-icons/gr"
    tag = "GrSd"


class GrSearchAdvanced(rx.Component):
    library = "react-icons/gr"
    tag = "GrSearchAdvanced"


class GrSearch(rx.Component):
    library = "react-icons/gr"
    tag = "GrSearch"


class GrSecure(rx.Component):
    library = "react-icons/gr"
    tag = "GrSecure"


class GrSelect(rx.Component):
    library = "react-icons/gr"
    tag = "GrSelect"


class GrSelection(rx.Component):
    library = "react-icons/gr"
    tag = "GrSelection"


class GrSemantics(rx.Component):
    library = "react-icons/gr"
    tag = "GrSemantics"


class GrSend(rx.Component):
    library = "react-icons/gr"
    tag = "GrSend"


class GrServerCluster(rx.Component):
    library = "react-icons/gr"
    tag = "GrServerCluster"


class GrServer(rx.Component):
    library = "react-icons/gr"
    tag = "GrServer"


class GrServers(rx.Component):
    library = "react-icons/gr"
    tag = "GrServers"


class GrServicePlay(rx.Component):
    library = "react-icons/gr"
    tag = "GrServicePlay"


class GrServices(rx.Component):
    library = "react-icons/gr"
    tag = "GrServices"


class GrSettingsOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrSettingsOption"


class GrShareOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrShareOption"


class GrShareRounded(rx.Component):
    library = "react-icons/gr"
    tag = "GrShareRounded"


class GrShare(rx.Component):
    library = "react-icons/gr"
    tag = "GrShare"


class GrShieldSecurity(rx.Component):
    library = "react-icons/gr"
    tag = "GrShieldSecurity"


class GrShield(rx.Component):
    library = "react-icons/gr"
    tag = "GrShield"


class GrShift(rx.Component):
    library = "react-icons/gr"
    tag = "GrShift"


class GrShop(rx.Component):
    library = "react-icons/gr"
    tag = "GrShop"


class GrSidebar(rx.Component):
    library = "react-icons/gr"
    tag = "GrSidebar"


class GrSign(rx.Component):
    library = "react-icons/gr"
    tag = "GrSign"


class GrSkype(rx.Component):
    library = "react-icons/gr"
    tag = "GrSkype"


class GrSlack(rx.Component):
    library = "react-icons/gr"
    tag = "GrSlack"


class GrSnapchat(rx.Component):
    library = "react-icons/gr"
    tag = "GrSnapchat"


class GrSolaris(rx.Component):
    library = "react-icons/gr"
    tag = "GrSolaris"


class GrSort(rx.Component):
    library = "react-icons/gr"
    tag = "GrSort"


class GrSoundcloud(rx.Component):
    library = "react-icons/gr"
    tag = "GrSoundcloud"


class GrSpa(rx.Component):
    library = "react-icons/gr"
    tag = "GrSpa"


class GrSpectrum(rx.Component):
    library = "react-icons/gr"
    tag = "GrSpectrum"


class GrSplit(rx.Component):
    library = "react-icons/gr"
    tag = "GrSplit"


class GrSplits(rx.Component):
    library = "react-icons/gr"
    tag = "GrSplits"


class GrSpotify(rx.Component):
    library = "react-icons/gr"
    tag = "GrSpotify"


class GrSquare(rx.Component):
    library = "react-icons/gr"
    tag = "GrSquare"


class GrStackOverflow(rx.Component):
    library = "react-icons/gr"
    tag = "GrStackOverflow"


class GrStakeholder(rx.Component):
    library = "react-icons/gr"
    tag = "GrStakeholder"


class GrStarHalf(rx.Component):
    library = "react-icons/gr"
    tag = "GrStarHalf"


class GrStarOutline(rx.Component):
    library = "react-icons/gr"
    tag = "GrStarOutline"


class GrStar(rx.Component):
    library = "react-icons/gr"
    tag = "GrStar"


class GrStatusCriticalSmall(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusCriticalSmall"


class GrStatusCritical(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusCritical"


class GrStatusDisabledSmall(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusDisabledSmall"


class GrStatusDisabled(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusDisabled"


class GrStatusGoodSmall(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusGoodSmall"


class GrStatusGood(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusGood"


class GrStatusInfoSmall(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusInfoSmall"


class GrStatusInfo(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusInfo"


class GrStatusPlaceholderSmall(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusPlaceholderSmall"


class GrStatusPlaceholder(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusPlaceholder"


class GrStatusUnknownSmall(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusUnknownSmall"


class GrStatusUnknown(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusUnknown"


class GrStatusWarningSmall(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusWarningSmall"


class GrStatusWarning(rx.Component):
    library = "react-icons/gr"
    tag = "GrStatusWarning"


class GrStepsOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrStepsOption"


class GrSteps(rx.Component):
    library = "react-icons/gr"
    tag = "GrSteps"


class GrStopFill(rx.Component):
    library = "react-icons/gr"
    tag = "GrStopFill"


class GrStop(rx.Component):
    library = "react-icons/gr"
    tag = "GrStop"


class GrStorage(rx.Component):
    library = "react-icons/gr"
    tag = "GrStorage"


class GrStreetView(rx.Component):
    library = "react-icons/gr"
    tag = "GrStreetView"


class GrStrikeThrough(rx.Component):
    library = "react-icons/gr"
    tag = "GrStrikeThrough"


class GrStripe(rx.Component):
    library = "react-icons/gr"
    tag = "GrStripe"


class GrSubscript(rx.Component):
    library = "react-icons/gr"
    tag = "GrSubscript"


class GrSubtractCircle(rx.Component):
    library = "react-icons/gr"
    tag = "GrSubtractCircle"


class GrSubtract(rx.Component):
    library = "react-icons/gr"
    tag = "GrSubtract"


class GrSun(rx.Component):
    library = "react-icons/gr"
    tag = "GrSun"


class GrSuperscript(rx.Component):
    library = "react-icons/gr"
    tag = "GrSuperscript"


class GrSupport(rx.Component):
    library = "react-icons/gr"
    tag = "GrSupport"


class GrSuse(rx.Component):
    library = "react-icons/gr"
    tag = "GrSuse"


class GrSwift(rx.Component):
    library = "react-icons/gr"
    tag = "GrSwift"


class GrSwim(rx.Component):
    library = "react-icons/gr"
    tag = "GrSwim"


class GrSwitch(rx.Component):
    library = "react-icons/gr"
    tag = "GrSwitch"


class GrSync(rx.Component):
    library = "react-icons/gr"
    tag = "GrSync"


class GrSystem(rx.Component):
    library = "react-icons/gr"
    tag = "GrSystem"


class GrTableAdd(rx.Component):
    library = "react-icons/gr"
    tag = "GrTableAdd"


class GrTable(rx.Component):
    library = "react-icons/gr"
    tag = "GrTable"


class GrTag(rx.Component):
    library = "react-icons/gr"
    tag = "GrTag"


class GrTapeOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrTapeOption"


class GrTape(rx.Component):
    library = "react-icons/gr"
    tag = "GrTape"


class GrTarget(rx.Component):
    library = "react-icons/gr"
    tag = "GrTarget"


class GrTask(rx.Component):
    library = "react-icons/gr"
    tag = "GrTask"


class GrTasks(rx.Component):
    library = "react-icons/gr"
    tag = "GrTasks"


class GrTechnology(rx.Component):
    library = "react-icons/gr"
    tag = "GrTechnology"


class GrTemplate(rx.Component):
    library = "react-icons/gr"
    tag = "GrTemplate"


class GrTerminal(rx.Component):
    library = "react-icons/gr"
    tag = "GrTerminal"


class GrTestDesktop(rx.Component):
    library = "react-icons/gr"
    tag = "GrTestDesktop"


class GrTest(rx.Component):
    library = "react-icons/gr"
    tag = "GrTest"


class GrTextAlignCenter(rx.Component):
    library = "react-icons/gr"
    tag = "GrTextAlignCenter"


class GrTextAlignFull(rx.Component):
    library = "react-icons/gr"
    tag = "GrTextAlignFull"


class GrTextAlignLeft(rx.Component):
    library = "react-icons/gr"
    tag = "GrTextAlignLeft"


class GrTextAlignRight(rx.Component):
    library = "react-icons/gr"
    tag = "GrTextAlignRight"


class GrTextWrap(rx.Component):
    library = "react-icons/gr"
    tag = "GrTextWrap"


class GrThreats(rx.Component):
    library = "react-icons/gr"
    tag = "GrThreats"


class GrThreeDEffects(rx.Component):
    library = "react-icons/gr"
    tag = "GrThreeDEffects"


class GrThreeD(rx.Component):
    library = "react-icons/gr"
    tag = "GrThreeD"


class GrTicket(rx.Component):
    library = "react-icons/gr"
    tag = "GrTicket"


class GrTiktok(rx.Component):
    library = "react-icons/gr"
    tag = "GrTiktok"


class GrTime(rx.Component):
    library = "react-icons/gr"
    tag = "GrTime"


class GrTip(rx.Component):
    library = "react-icons/gr"
    tag = "GrTip"


class GrToast(rx.Component):
    library = "react-icons/gr"
    tag = "GrToast"


class GrTools(rx.Component):
    library = "react-icons/gr"
    tag = "GrTools"


class GrTooltip(rx.Component):
    library = "react-icons/gr"
    tag = "GrTooltip"


class GrTopCorner(rx.Component):
    library = "react-icons/gr"
    tag = "GrTopCorner"


class GrTrain(rx.Component):
    library = "react-icons/gr"
    tag = "GrTrain"


class GrTransaction(rx.Component):
    library = "react-icons/gr"
    tag = "GrTransaction"


class GrTrash(rx.Component):
    library = "react-icons/gr"
    tag = "GrTrash"


class GrTreeOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrTreeOption"


class GrTree(rx.Component):
    library = "react-icons/gr"
    tag = "GrTree"


class GrTrigger(rx.Component):
    library = "react-icons/gr"
    tag = "GrTrigger"


class GrTrophy(rx.Component):
    library = "react-icons/gr"
    tag = "GrTrophy"


class GrTroubleshoot(rx.Component):
    library = "react-icons/gr"
    tag = "GrTroubleshoot"


class GrTty(rx.Component):
    library = "react-icons/gr"
    tag = "GrTty"


class GrTumblr(rx.Component):
    library = "react-icons/gr"
    tag = "GrTumblr"


class GrTurbolinux(rx.Component):
    library = "react-icons/gr"
    tag = "GrTurbolinux"


class GrTwitter(rx.Component):
    library = "react-icons/gr"
    tag = "GrTwitter"


class GrUbuntu(rx.Component):
    library = "react-icons/gr"
    tag = "GrUbuntu"


class GrUnderline(rx.Component):
    library = "react-icons/gr"
    tag = "GrUnderline"


class GrUndo(rx.Component):
    library = "react-icons/gr"
    tag = "GrUndo"


class GrUnlink(rx.Component):
    library = "react-icons/gr"
    tag = "GrUnlink"


class GrUnlock(rx.Component):
    library = "react-icons/gr"
    tag = "GrUnlock"


class GrUnorderedList(rx.Component):
    library = "react-icons/gr"
    tag = "GrUnorderedList"


class GrUnsorted(rx.Component):
    library = "react-icons/gr"
    tag = "GrUnsorted"


class GrUp(rx.Component):
    library = "react-icons/gr"
    tag = "GrUp"


class GrUpdate(rx.Component):
    library = "react-icons/gr"
    tag = "GrUpdate"


class GrUpgrade(rx.Component):
    library = "react-icons/gr"
    tag = "GrUpgrade"


class GrUploadOption(rx.Component):
    library = "react-icons/gr"
    tag = "GrUploadOption"


class GrUpload(rx.Component):
    library = "react-icons/gr"
    tag = "GrUpload"


class GrUsbKey(rx.Component):
    library = "react-icons/gr"
    tag = "GrUsbKey"


class GrUserAdd(rx.Component):
    library = "react-icons/gr"
    tag = "GrUserAdd"


class GrUserAdmin(rx.Component):
    library = "react-icons/gr"
    tag = "GrUserAdmin"


class GrUserExpert(rx.Component):
    library = "react-icons/gr"
    tag = "GrUserExpert"


class GrUserFemale(rx.Component):
    library = "react-icons/gr"
    tag = "GrUserFemale"


class GrUserManager(rx.Component):
    library = "react-icons/gr"
    tag = "GrUserManager"


class GrUserNew(rx.Component):
    library = "react-icons/gr"
    tag = "GrUserNew"


class GrUserPolice(rx.Component):
    library = "react-icons/gr"
    tag = "GrUserPolice"


class GrUserSettings(rx.Component):
    library = "react-icons/gr"
    tag = "GrUserSettings"


class GrUserWorker(rx.Component):
    library = "react-icons/gr"
    tag = "GrUserWorker"


class GrUser(rx.Component):
    library = "react-icons/gr"
    tag = "GrUser"


class GrValidate(rx.Component):
    library = "react-icons/gr"
    tag = "GrValidate"


class GrVend(rx.Component):
    library = "react-icons/gr"
    tag = "GrVend"


class GrVideo(rx.Component):
    library = "react-icons/gr"
    tag = "GrVideo"


class GrView(rx.Component):
    library = "react-icons/gr"
    tag = "GrView"


class GrVimeo(rx.Component):
    library = "react-icons/gr"
    tag = "GrVimeo"


class GrVirtualMachine(rx.Component):
    library = "react-icons/gr"
    tag = "GrVirtualMachine"


class GrVirtualStorage(rx.Component):
    library = "react-icons/gr"
    tag = "GrVirtualStorage"


class GrVisa(rx.Component):
    library = "react-icons/gr"
    tag = "GrVisa"


class GrVmMaintenance(rx.Component):
    library = "react-icons/gr"
    tag = "GrVmMaintenance"


class GrVmware(rx.Component):
    library = "react-icons/gr"
    tag = "GrVmware"


class GrVolumeControl(rx.Component):
    library = "react-icons/gr"
    tag = "GrVolumeControl"


class GrVolumeLow(rx.Component):
    library = "react-icons/gr"
    tag = "GrVolumeLow"


class GrVolumeMute(rx.Component):
    library = "react-icons/gr"
    tag = "GrVolumeMute"


class GrVolume(rx.Component):
    library = "react-icons/gr"
    tag = "GrVolume"


class GrVulnerability(rx.Component):
    library = "react-icons/gr"
    tag = "GrVulnerability"


class GrWaypoint(rx.Component):
    library = "react-icons/gr"
    tag = "GrWaypoint"


class GrWebcam(rx.Component):
    library = "react-icons/gr"
    tag = "GrWebcam"


class GrWheelchairActive(rx.Component):
    library = "react-icons/gr"
    tag = "GrWheelchairActive"


class GrWheelchair(rx.Component):
    library = "react-icons/gr"
    tag = "GrWheelchair"


class GrWifiLow(rx.Component):
    library = "react-icons/gr"
    tag = "GrWifiLow"


class GrWifiMedium(rx.Component):
    library = "react-icons/gr"
    tag = "GrWifiMedium"


class GrWifiNone(rx.Component):
    library = "react-icons/gr"
    tag = "GrWifiNone"


class GrWifi(rx.Component):
    library = "react-icons/gr"
    tag = "GrWifi"


class GrWindowsLegacy(rx.Component):
    library = "react-icons/gr"
    tag = "GrWindowsLegacy"


class GrWindows(rx.Component):
    library = "react-icons/gr"
    tag = "GrWindows"


class GrWordpress(rx.Component):
    library = "react-icons/gr"
    tag = "GrWordpress"


class GrWorkshop(rx.Component):
    library = "react-icons/gr"
    tag = "GrWorkshop"


class GrYoga(rx.Component):
    library = "react-icons/gr"
    tag = "GrYoga"


class GrYoutube(rx.Component):
    library = "react-icons/gr"
    tag = "GrYoutube"


class GrZoomIn(rx.Component):
    library = "react-icons/gr"
    tag = "GrZoomIn"


class GrZoomOut(rx.Component):
    library = "react-icons/gr"
    tag = "GrZoomOut"


class GrZoom(rx.Component):
    library = "react-icons/gr"
    tag = "GrZoom"


