import reflex as rx

class RxAccessibility(rx.Component):
    library = "react-icons/rx"
    tag = "RxAccessibility"


class RxActivityLog(rx.Component):
    library = "react-icons/rx"
    tag = "RxActivityLog"


class RxAlignBaseline(rx.Component):
    library = "react-icons/rx"
    tag = "RxAlignBaseline"


class RxAlignBottom(rx.Component):
    library = "react-icons/rx"
    tag = "RxAlignBottom"


class RxAlignCenterHorizontally(rx.Component):
    library = "react-icons/rx"
    tag = "RxAlignCenterHorizontally"


class RxAlignCenterVertically(rx.Component):
    library = "react-icons/rx"
    tag = "RxAlignCenterVertically"


class RxAlignLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxAlignLeft"


class RxAlignRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxAlignRight"


class RxAlignTop(rx.Component):
    library = "react-icons/rx"
    tag = "RxAlignTop"


class RxAllSides(rx.Component):
    library = "react-icons/rx"
    tag = "RxAllSides"


class RxAngle(rx.Component):
    library = "react-icons/rx"
    tag = "RxAngle"


class RxArchive(rx.Component):
    library = "react-icons/rx"
    tag = "RxArchive"


class RxArrowBottomLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxArrowBottomLeft"


class RxArrowBottomRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxArrowBottomRight"


class RxArrowDown(rx.Component):
    library = "react-icons/rx"
    tag = "RxArrowDown"


class RxArrowLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxArrowLeft"


class RxArrowRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxArrowRight"


class RxArrowTopLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxArrowTopLeft"


class RxArrowTopRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxArrowTopRight"


class RxArrowUp(rx.Component):
    library = "react-icons/rx"
    tag = "RxArrowUp"


class RxAspectRatio(rx.Component):
    library = "react-icons/rx"
    tag = "RxAspectRatio"


class RxAvatar(rx.Component):
    library = "react-icons/rx"
    tag = "RxAvatar"


class RxBackpack(rx.Component):
    library = "react-icons/rx"
    tag = "RxBackpack"


class RxBadge(rx.Component):
    library = "react-icons/rx"
    tag = "RxBadge"


class RxBarChart(rx.Component):
    library = "react-icons/rx"
    tag = "RxBarChart"


class RxBell(rx.Component):
    library = "react-icons/rx"
    tag = "RxBell"


class RxBlendingMode(rx.Component):
    library = "react-icons/rx"
    tag = "RxBlendingMode"


class RxBookmarkFilled(rx.Component):
    library = "react-icons/rx"
    tag = "RxBookmarkFilled"


class RxBookmark(rx.Component):
    library = "react-icons/rx"
    tag = "RxBookmark"


class RxBorderAll(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderAll"


class RxBorderBottom(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderBottom"


class RxBorderDashed(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderDashed"


class RxBorderDotted(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderDotted"


class RxBorderLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderLeft"


class RxBorderNone(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderNone"


class RxBorderRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderRight"


class RxBorderSolid(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderSolid"


class RxBorderSplit(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderSplit"


class RxBorderStyle(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderStyle"


class RxBorderTop(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderTop"


class RxBorderWidth(rx.Component):
    library = "react-icons/rx"
    tag = "RxBorderWidth"


class RxBoxModel(rx.Component):
    library = "react-icons/rx"
    tag = "RxBoxModel"


class RxBox(rx.Component):
    library = "react-icons/rx"
    tag = "RxBox"


class RxButton(rx.Component):
    library = "react-icons/rx"
    tag = "RxButton"


class RxCalendar(rx.Component):
    library = "react-icons/rx"
    tag = "RxCalendar"


class RxCamera(rx.Component):
    library = "react-icons/rx"
    tag = "RxCamera"


class RxCardStackMinus(rx.Component):
    library = "react-icons/rx"
    tag = "RxCardStackMinus"


class RxCardStackPlus(rx.Component):
    library = "react-icons/rx"
    tag = "RxCardStackPlus"


class RxCardStack(rx.Component):
    library = "react-icons/rx"
    tag = "RxCardStack"


class RxCaretDown(rx.Component):
    library = "react-icons/rx"
    tag = "RxCaretDown"


class RxCaretLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxCaretLeft"


class RxCaretRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxCaretRight"


class RxCaretSort(rx.Component):
    library = "react-icons/rx"
    tag = "RxCaretSort"


class RxCaretUp(rx.Component):
    library = "react-icons/rx"
    tag = "RxCaretUp"


class RxChatBubble(rx.Component):
    library = "react-icons/rx"
    tag = "RxChatBubble"


class RxCheckCircled(rx.Component):
    library = "react-icons/rx"
    tag = "RxCheckCircled"


class RxCheck(rx.Component):
    library = "react-icons/rx"
    tag = "RxCheck"


class RxCheckbox(rx.Component):
    library = "react-icons/rx"
    tag = "RxCheckbox"


class RxChevronDown(rx.Component):
    library = "react-icons/rx"
    tag = "RxChevronDown"


class RxChevronLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxChevronLeft"


class RxChevronRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxChevronRight"


class RxChevronUp(rx.Component):
    library = "react-icons/rx"
    tag = "RxChevronUp"


class RxCircleBackslash(rx.Component):
    library = "react-icons/rx"
    tag = "RxCircleBackslash"


class RxCircle(rx.Component):
    library = "react-icons/rx"
    tag = "RxCircle"


class RxClipboardCopy(rx.Component):
    library = "react-icons/rx"
    tag = "RxClipboardCopy"


class RxClipboard(rx.Component):
    library = "react-icons/rx"
    tag = "RxClipboard"


class RxClock(rx.Component):
    library = "react-icons/rx"
    tag = "RxClock"


class RxCode(rx.Component):
    library = "react-icons/rx"
    tag = "RxCode"


class RxCodesandboxLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxCodesandboxLogo"


class RxColorWheel(rx.Component):
    library = "react-icons/rx"
    tag = "RxColorWheel"


class RxColumnSpacing(rx.Component):
    library = "react-icons/rx"
    tag = "RxColumnSpacing"


class RxColumns(rx.Component):
    library = "react-icons/rx"
    tag = "RxColumns"


class RxCommit(rx.Component):
    library = "react-icons/rx"
    tag = "RxCommit"


class RxComponent1(rx.Component):
    library = "react-icons/rx"
    tag = "RxComponent1"


class RxComponent2(rx.Component):
    library = "react-icons/rx"
    tag = "RxComponent2"


class RxComponentBoolean(rx.Component):
    library = "react-icons/rx"
    tag = "RxComponentBoolean"


class RxComponentInstance(rx.Component):
    library = "react-icons/rx"
    tag = "RxComponentInstance"


class RxComponentNone(rx.Component):
    library = "react-icons/rx"
    tag = "RxComponentNone"


class RxComponentPlaceholder(rx.Component):
    library = "react-icons/rx"
    tag = "RxComponentPlaceholder"


class RxContainer(rx.Component):
    library = "react-icons/rx"
    tag = "RxContainer"


class RxCookie(rx.Component):
    library = "react-icons/rx"
    tag = "RxCookie"


class RxCopy(rx.Component):
    library = "react-icons/rx"
    tag = "RxCopy"


class RxCornerBottomLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxCornerBottomLeft"


class RxCornerBottomRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxCornerBottomRight"


class RxCornerTopLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxCornerTopLeft"


class RxCornerTopRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxCornerTopRight"


class RxCorners(rx.Component):
    library = "react-icons/rx"
    tag = "RxCorners"


class RxCountdownTimer(rx.Component):
    library = "react-icons/rx"
    tag = "RxCountdownTimer"


class RxCounterClockwiseClock(rx.Component):
    library = "react-icons/rx"
    tag = "RxCounterClockwiseClock"


class RxCrop(rx.Component):
    library = "react-icons/rx"
    tag = "RxCrop"


class RxCross1(rx.Component):
    library = "react-icons/rx"
    tag = "RxCross1"


class RxCross2(rx.Component):
    library = "react-icons/rx"
    tag = "RxCross2"


class RxCrossCircled(rx.Component):
    library = "react-icons/rx"
    tag = "RxCrossCircled"


class RxCrosshair1(rx.Component):
    library = "react-icons/rx"
    tag = "RxCrosshair1"


class RxCrosshair2(rx.Component):
    library = "react-icons/rx"
    tag = "RxCrosshair2"


class RxCrumpledPaper(rx.Component):
    library = "react-icons/rx"
    tag = "RxCrumpledPaper"


class RxCube(rx.Component):
    library = "react-icons/rx"
    tag = "RxCube"


class RxCursorArrow(rx.Component):
    library = "react-icons/rx"
    tag = "RxCursorArrow"


class RxCursorText(rx.Component):
    library = "react-icons/rx"
    tag = "RxCursorText"


class RxDash(rx.Component):
    library = "react-icons/rx"
    tag = "RxDash"


class RxDashboard(rx.Component):
    library = "react-icons/rx"
    tag = "RxDashboard"


class RxDesktop(rx.Component):
    library = "react-icons/rx"
    tag = "RxDesktop"


class RxDimensions(rx.Component):
    library = "react-icons/rx"
    tag = "RxDimensions"


class RxDisc(rx.Component):
    library = "react-icons/rx"
    tag = "RxDisc"


class RxDiscordLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxDiscordLogo"


class RxDividerHorizontal(rx.Component):
    library = "react-icons/rx"
    tag = "RxDividerHorizontal"


class RxDividerVertical(rx.Component):
    library = "react-icons/rx"
    tag = "RxDividerVertical"


class RxDotFilled(rx.Component):
    library = "react-icons/rx"
    tag = "RxDotFilled"


class RxDot(rx.Component):
    library = "react-icons/rx"
    tag = "RxDot"


class RxDotsHorizontal(rx.Component):
    library = "react-icons/rx"
    tag = "RxDotsHorizontal"


class RxDotsVertical(rx.Component):
    library = "react-icons/rx"
    tag = "RxDotsVertical"


class RxDoubleArrowDown(rx.Component):
    library = "react-icons/rx"
    tag = "RxDoubleArrowDown"


class RxDoubleArrowLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxDoubleArrowLeft"


class RxDoubleArrowRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxDoubleArrowRight"


class RxDoubleArrowUp(rx.Component):
    library = "react-icons/rx"
    tag = "RxDoubleArrowUp"


class RxDownload(rx.Component):
    library = "react-icons/rx"
    tag = "RxDownload"


class RxDragHandleDots1(rx.Component):
    library = "react-icons/rx"
    tag = "RxDragHandleDots1"


class RxDragHandleDots2(rx.Component):
    library = "react-icons/rx"
    tag = "RxDragHandleDots2"


class RxDragHandleHorizontal(rx.Component):
    library = "react-icons/rx"
    tag = "RxDragHandleHorizontal"


class RxDragHandleVertical(rx.Component):
    library = "react-icons/rx"
    tag = "RxDragHandleVertical"


class RxDrawingPinFilled(rx.Component):
    library = "react-icons/rx"
    tag = "RxDrawingPinFilled"


class RxDrawingPin(rx.Component):
    library = "react-icons/rx"
    tag = "RxDrawingPin"


class RxDropdownMenu(rx.Component):
    library = "react-icons/rx"
    tag = "RxDropdownMenu"


class RxEnterFullScreen(rx.Component):
    library = "react-icons/rx"
    tag = "RxEnterFullScreen"


class RxEnter(rx.Component):
    library = "react-icons/rx"
    tag = "RxEnter"


class RxEnvelopeClosed(rx.Component):
    library = "react-icons/rx"
    tag = "RxEnvelopeClosed"


class RxEnvelopeOpen(rx.Component):
    library = "react-icons/rx"
    tag = "RxEnvelopeOpen"


class RxEraser(rx.Component):
    library = "react-icons/rx"
    tag = "RxEraser"


class RxExclamationTriangle(rx.Component):
    library = "react-icons/rx"
    tag = "RxExclamationTriangle"


class RxExitFullScreen(rx.Component):
    library = "react-icons/rx"
    tag = "RxExitFullScreen"


class RxExit(rx.Component):
    library = "react-icons/rx"
    tag = "RxExit"


class RxExternalLink(rx.Component):
    library = "react-icons/rx"
    tag = "RxExternalLink"


class RxEyeClosed(rx.Component):
    library = "react-icons/rx"
    tag = "RxEyeClosed"


class RxEyeNone(rx.Component):
    library = "react-icons/rx"
    tag = "RxEyeNone"


class RxEyeOpen(rx.Component):
    library = "react-icons/rx"
    tag = "RxEyeOpen"


class RxFace(rx.Component):
    library = "react-icons/rx"
    tag = "RxFace"


class RxFigmaLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxFigmaLogo"


class RxFileMinus(rx.Component):
    library = "react-icons/rx"
    tag = "RxFileMinus"


class RxFilePlus(rx.Component):
    library = "react-icons/rx"
    tag = "RxFilePlus"


class RxFileText(rx.Component):
    library = "react-icons/rx"
    tag = "RxFileText"


class RxFile(rx.Component):
    library = "react-icons/rx"
    tag = "RxFile"


class RxFontBold(rx.Component):
    library = "react-icons/rx"
    tag = "RxFontBold"


class RxFontFamily(rx.Component):
    library = "react-icons/rx"
    tag = "RxFontFamily"


class RxFontItalic(rx.Component):
    library = "react-icons/rx"
    tag = "RxFontItalic"


class RxFontRoman(rx.Component):
    library = "react-icons/rx"
    tag = "RxFontRoman"


class RxFontSize(rx.Component):
    library = "react-icons/rx"
    tag = "RxFontSize"


class RxFontStyle(rx.Component):
    library = "react-icons/rx"
    tag = "RxFontStyle"


class RxFrame(rx.Component):
    library = "react-icons/rx"
    tag = "RxFrame"


class RxFramerLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxFramerLogo"


class RxGear(rx.Component):
    library = "react-icons/rx"
    tag = "RxGear"


class RxGithubLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxGithubLogo"


class RxGlobe(rx.Component):
    library = "react-icons/rx"
    tag = "RxGlobe"


class RxGrid(rx.Component):
    library = "react-icons/rx"
    tag = "RxGrid"


class RxGroup(rx.Component):
    library = "react-icons/rx"
    tag = "RxGroup"


class RxHalf1(rx.Component):
    library = "react-icons/rx"
    tag = "RxHalf1"


class RxHalf2(rx.Component):
    library = "react-icons/rx"
    tag = "RxHalf2"


class RxHamburgerMenu(rx.Component):
    library = "react-icons/rx"
    tag = "RxHamburgerMenu"


class RxHand(rx.Component):
    library = "react-icons/rx"
    tag = "RxHand"


class RxHeading(rx.Component):
    library = "react-icons/rx"
    tag = "RxHeading"


class RxHeartFilled(rx.Component):
    library = "react-icons/rx"
    tag = "RxHeartFilled"


class RxHeart(rx.Component):
    library = "react-icons/rx"
    tag = "RxHeart"


class RxHeight(rx.Component):
    library = "react-icons/rx"
    tag = "RxHeight"


class RxHobbyKnife(rx.Component):
    library = "react-icons/rx"
    tag = "RxHobbyKnife"


class RxHome(rx.Component):
    library = "react-icons/rx"
    tag = "RxHome"


class RxIconjarLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxIconjarLogo"


class RxIdCard(rx.Component):
    library = "react-icons/rx"
    tag = "RxIdCard"


class RxImage(rx.Component):
    library = "react-icons/rx"
    tag = "RxImage"


class RxInfoCircled(rx.Component):
    library = "react-icons/rx"
    tag = "RxInfoCircled"


class RxInput(rx.Component):
    library = "react-icons/rx"
    tag = "RxInput"


class RxInstagramLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxInstagramLogo"


class RxKeyboard(rx.Component):
    library = "react-icons/rx"
    tag = "RxKeyboard"


class RxLapTimer(rx.Component):
    library = "react-icons/rx"
    tag = "RxLapTimer"


class RxLaptop(rx.Component):
    library = "react-icons/rx"
    tag = "RxLaptop"


class RxLayers(rx.Component):
    library = "react-icons/rx"
    tag = "RxLayers"


class RxLayout(rx.Component):
    library = "react-icons/rx"
    tag = "RxLayout"


class RxLetterCaseCapitalize(rx.Component):
    library = "react-icons/rx"
    tag = "RxLetterCaseCapitalize"


class RxLetterCaseLowercase(rx.Component):
    library = "react-icons/rx"
    tag = "RxLetterCaseLowercase"


class RxLetterCaseToggle(rx.Component):
    library = "react-icons/rx"
    tag = "RxLetterCaseToggle"


class RxLetterCaseUppercase(rx.Component):
    library = "react-icons/rx"
    tag = "RxLetterCaseUppercase"


class RxLetterSpacing(rx.Component):
    library = "react-icons/rx"
    tag = "RxLetterSpacing"


class RxLightningBolt(rx.Component):
    library = "react-icons/rx"
    tag = "RxLightningBolt"


class RxLineHeight(rx.Component):
    library = "react-icons/rx"
    tag = "RxLineHeight"


class RxLink1(rx.Component):
    library = "react-icons/rx"
    tag = "RxLink1"


class RxLink2(rx.Component):
    library = "react-icons/rx"
    tag = "RxLink2"


class RxLinkBreak1(rx.Component):
    library = "react-icons/rx"
    tag = "RxLinkBreak1"


class RxLinkBreak2(rx.Component):
    library = "react-icons/rx"
    tag = "RxLinkBreak2"


class RxLinkNone1(rx.Component):
    library = "react-icons/rx"
    tag = "RxLinkNone1"


class RxLinkNone2(rx.Component):
    library = "react-icons/rx"
    tag = "RxLinkNone2"


class RxLinkedinLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxLinkedinLogo"


class RxListBullet(rx.Component):
    library = "react-icons/rx"
    tag = "RxListBullet"


class RxLockClosed(rx.Component):
    library = "react-icons/rx"
    tag = "RxLockClosed"


class RxLockOpen1(rx.Component):
    library = "react-icons/rx"
    tag = "RxLockOpen1"


class RxLockOpen2(rx.Component):
    library = "react-icons/rx"
    tag = "RxLockOpen2"


class RxLoop(rx.Component):
    library = "react-icons/rx"
    tag = "RxLoop"


class RxMagicWand(rx.Component):
    library = "react-icons/rx"
    tag = "RxMagicWand"


class RxMagnifyingGlass(rx.Component):
    library = "react-icons/rx"
    tag = "RxMagnifyingGlass"


class RxMargin(rx.Component):
    library = "react-icons/rx"
    tag = "RxMargin"


class RxMaskOff(rx.Component):
    library = "react-icons/rx"
    tag = "RxMaskOff"


class RxMaskOn(rx.Component):
    library = "react-icons/rx"
    tag = "RxMaskOn"


class RxMinusCircled(rx.Component):
    library = "react-icons/rx"
    tag = "RxMinusCircled"


class RxMinus(rx.Component):
    library = "react-icons/rx"
    tag = "RxMinus"


class RxMix(rx.Component):
    library = "react-icons/rx"
    tag = "RxMix"


class RxMixerHorizontal(rx.Component):
    library = "react-icons/rx"
    tag = "RxMixerHorizontal"


class RxMixerVertical(rx.Component):
    library = "react-icons/rx"
    tag = "RxMixerVertical"


class RxMobile(rx.Component):
    library = "react-icons/rx"
    tag = "RxMobile"


class RxModulzLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxModulzLogo"


class RxMoon(rx.Component):
    library = "react-icons/rx"
    tag = "RxMoon"


class RxMove(rx.Component):
    library = "react-icons/rx"
    tag = "RxMove"


class RxNotionLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxNotionLogo"


class RxOpacity(rx.Component):
    library = "react-icons/rx"
    tag = "RxOpacity"


class RxOpenInNewWindow(rx.Component):
    library = "react-icons/rx"
    tag = "RxOpenInNewWindow"


class RxOverline(rx.Component):
    library = "react-icons/rx"
    tag = "RxOverline"


class RxPadding(rx.Component):
    library = "react-icons/rx"
    tag = "RxPadding"


class RxPaperPlane(rx.Component):
    library = "react-icons/rx"
    tag = "RxPaperPlane"


class RxPause(rx.Component):
    library = "react-icons/rx"
    tag = "RxPause"


class RxPencil1(rx.Component):
    library = "react-icons/rx"
    tag = "RxPencil1"


class RxPencil2(rx.Component):
    library = "react-icons/rx"
    tag = "RxPencil2"


class RxPerson(rx.Component):
    library = "react-icons/rx"
    tag = "RxPerson"


class RxPieChart(rx.Component):
    library = "react-icons/rx"
    tag = "RxPieChart"


class RxPilcrow(rx.Component):
    library = "react-icons/rx"
    tag = "RxPilcrow"


class RxPinBottom(rx.Component):
    library = "react-icons/rx"
    tag = "RxPinBottom"


class RxPinLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxPinLeft"


class RxPinRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxPinRight"


class RxPinTop(rx.Component):
    library = "react-icons/rx"
    tag = "RxPinTop"


class RxPlay(rx.Component):
    library = "react-icons/rx"
    tag = "RxPlay"


class RxPlusCircled(rx.Component):
    library = "react-icons/rx"
    tag = "RxPlusCircled"


class RxPlus(rx.Component):
    library = "react-icons/rx"
    tag = "RxPlus"


class RxQuestionMarkCircled(rx.Component):
    library = "react-icons/rx"
    tag = "RxQuestionMarkCircled"


class RxQuestionMark(rx.Component):
    library = "react-icons/rx"
    tag = "RxQuestionMark"


class RxQuote(rx.Component):
    library = "react-icons/rx"
    tag = "RxQuote"


class RxRadiobutton(rx.Component):
    library = "react-icons/rx"
    tag = "RxRadiobutton"


class RxReader(rx.Component):
    library = "react-icons/rx"
    tag = "RxReader"


class RxReload(rx.Component):
    library = "react-icons/rx"
    tag = "RxReload"


class RxReset(rx.Component):
    library = "react-icons/rx"
    tag = "RxReset"


class RxResume(rx.Component):
    library = "react-icons/rx"
    tag = "RxResume"


class RxRocket(rx.Component):
    library = "react-icons/rx"
    tag = "RxRocket"


class RxRotateCounterClockwise(rx.Component):
    library = "react-icons/rx"
    tag = "RxRotateCounterClockwise"


class RxRowSpacing(rx.Component):
    library = "react-icons/rx"
    tag = "RxRowSpacing"


class RxRows(rx.Component):
    library = "react-icons/rx"
    tag = "RxRows"


class RxRulerHorizontal(rx.Component):
    library = "react-icons/rx"
    tag = "RxRulerHorizontal"


class RxRulerSquare(rx.Component):
    library = "react-icons/rx"
    tag = "RxRulerSquare"


class RxScissors(rx.Component):
    library = "react-icons/rx"
    tag = "RxScissors"


class RxSection(rx.Component):
    library = "react-icons/rx"
    tag = "RxSection"


class RxSewingPinFilled(rx.Component):
    library = "react-icons/rx"
    tag = "RxSewingPinFilled"


class RxSewingPin(rx.Component):
    library = "react-icons/rx"
    tag = "RxSewingPin"


class RxShadowInner(rx.Component):
    library = "react-icons/rx"
    tag = "RxShadowInner"


class RxShadowNone(rx.Component):
    library = "react-icons/rx"
    tag = "RxShadowNone"


class RxShadowOuter(rx.Component):
    library = "react-icons/rx"
    tag = "RxShadowOuter"


class RxShadow(rx.Component):
    library = "react-icons/rx"
    tag = "RxShadow"


class RxShare1(rx.Component):
    library = "react-icons/rx"
    tag = "RxShare1"


class RxShare2(rx.Component):
    library = "react-icons/rx"
    tag = "RxShare2"


class RxShuffle(rx.Component):
    library = "react-icons/rx"
    tag = "RxShuffle"


class RxSize(rx.Component):
    library = "react-icons/rx"
    tag = "RxSize"


class RxSketchLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxSketchLogo"


class RxSlash(rx.Component):
    library = "react-icons/rx"
    tag = "RxSlash"


class RxSlider(rx.Component):
    library = "react-icons/rx"
    tag = "RxSlider"


class RxSpaceBetweenHorizontally(rx.Component):
    library = "react-icons/rx"
    tag = "RxSpaceBetweenHorizontally"


class RxSpaceBetweenVertically(rx.Component):
    library = "react-icons/rx"
    tag = "RxSpaceBetweenVertically"


class RxSpaceEvenlyHorizontally(rx.Component):
    library = "react-icons/rx"
    tag = "RxSpaceEvenlyHorizontally"


class RxSpaceEvenlyVertically(rx.Component):
    library = "react-icons/rx"
    tag = "RxSpaceEvenlyVertically"


class RxSpeakerLoud(rx.Component):
    library = "react-icons/rx"
    tag = "RxSpeakerLoud"


class RxSpeakerModerate(rx.Component):
    library = "react-icons/rx"
    tag = "RxSpeakerModerate"


class RxSpeakerOff(rx.Component):
    library = "react-icons/rx"
    tag = "RxSpeakerOff"


class RxSpeakerQuiet(rx.Component):
    library = "react-icons/rx"
    tag = "RxSpeakerQuiet"


class RxSquare(rx.Component):
    library = "react-icons/rx"
    tag = "RxSquare"


class RxStack(rx.Component):
    library = "react-icons/rx"
    tag = "RxStack"


class RxStarFilled(rx.Component):
    library = "react-icons/rx"
    tag = "RxStarFilled"


class RxStar(rx.Component):
    library = "react-icons/rx"
    tag = "RxStar"


class RxStitchesLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxStitchesLogo"


class RxStop(rx.Component):
    library = "react-icons/rx"
    tag = "RxStop"


class RxStopwatch(rx.Component):
    library = "react-icons/rx"
    tag = "RxStopwatch"


class RxStretchHorizontally(rx.Component):
    library = "react-icons/rx"
    tag = "RxStretchHorizontally"


class RxStretchVertically(rx.Component):
    library = "react-icons/rx"
    tag = "RxStretchVertically"


class RxStrikethrough(rx.Component):
    library = "react-icons/rx"
    tag = "RxStrikethrough"


class RxSun(rx.Component):
    library = "react-icons/rx"
    tag = "RxSun"


class RxSwitch(rx.Component):
    library = "react-icons/rx"
    tag = "RxSwitch"


class RxSymbol(rx.Component):
    library = "react-icons/rx"
    tag = "RxSymbol"


class RxTable(rx.Component):
    library = "react-icons/rx"
    tag = "RxTable"


class RxTarget(rx.Component):
    library = "react-icons/rx"
    tag = "RxTarget"


class RxTextAlignBottom(rx.Component):
    library = "react-icons/rx"
    tag = "RxTextAlignBottom"


class RxTextAlignCenter(rx.Component):
    library = "react-icons/rx"
    tag = "RxTextAlignCenter"


class RxTextAlignJustify(rx.Component):
    library = "react-icons/rx"
    tag = "RxTextAlignJustify"


class RxTextAlignLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxTextAlignLeft"


class RxTextAlignMiddle(rx.Component):
    library = "react-icons/rx"
    tag = "RxTextAlignMiddle"


class RxTextAlignRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxTextAlignRight"


class RxTextAlignTop(rx.Component):
    library = "react-icons/rx"
    tag = "RxTextAlignTop"


class RxTextNone(rx.Component):
    library = "react-icons/rx"
    tag = "RxTextNone"


class RxText(rx.Component):
    library = "react-icons/rx"
    tag = "RxText"


class RxThickArrowDown(rx.Component):
    library = "react-icons/rx"
    tag = "RxThickArrowDown"


class RxThickArrowLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxThickArrowLeft"


class RxThickArrowRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxThickArrowRight"


class RxThickArrowUp(rx.Component):
    library = "react-icons/rx"
    tag = "RxThickArrowUp"


class RxTimer(rx.Component):
    library = "react-icons/rx"
    tag = "RxTimer"


class RxTokens(rx.Component):
    library = "react-icons/rx"
    tag = "RxTokens"


class RxTrackNext(rx.Component):
    library = "react-icons/rx"
    tag = "RxTrackNext"


class RxTrackPrevious(rx.Component):
    library = "react-icons/rx"
    tag = "RxTrackPrevious"


class RxTransform(rx.Component):
    library = "react-icons/rx"
    tag = "RxTransform"


class RxTransparencyGrid(rx.Component):
    library = "react-icons/rx"
    tag = "RxTransparencyGrid"


class RxTrash(rx.Component):
    library = "react-icons/rx"
    tag = "RxTrash"


class RxTriangleDown(rx.Component):
    library = "react-icons/rx"
    tag = "RxTriangleDown"


class RxTriangleLeft(rx.Component):
    library = "react-icons/rx"
    tag = "RxTriangleLeft"


class RxTriangleRight(rx.Component):
    library = "react-icons/rx"
    tag = "RxTriangleRight"


class RxTriangleUp(rx.Component):
    library = "react-icons/rx"
    tag = "RxTriangleUp"


class RxTwitterLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxTwitterLogo"


class RxUnderline(rx.Component):
    library = "react-icons/rx"
    tag = "RxUnderline"


class RxUpdate(rx.Component):
    library = "react-icons/rx"
    tag = "RxUpdate"


class RxUpload(rx.Component):
    library = "react-icons/rx"
    tag = "RxUpload"


class RxValueNone(rx.Component):
    library = "react-icons/rx"
    tag = "RxValueNone"


class RxValue(rx.Component):
    library = "react-icons/rx"
    tag = "RxValue"


class RxVercelLogo(rx.Component):
    library = "react-icons/rx"
    tag = "RxVercelLogo"


class RxVideo(rx.Component):
    library = "react-icons/rx"
    tag = "RxVideo"


class RxViewGrid(rx.Component):
    library = "react-icons/rx"
    tag = "RxViewGrid"


class RxViewHorizontal(rx.Component):
    library = "react-icons/rx"
    tag = "RxViewHorizontal"


class RxViewNone(rx.Component):
    library = "react-icons/rx"
    tag = "RxViewNone"


class RxViewVertical(rx.Component):
    library = "react-icons/rx"
    tag = "RxViewVertical"


class RxWidth(rx.Component):
    library = "react-icons/rx"
    tag = "RxWidth"


class RxZoomIn(rx.Component):
    library = "react-icons/rx"
    tag = "RxZoomIn"


class RxZoomOut(rx.Component):
    library = "react-icons/rx"
    tag = "RxZoomOut"


