import reflex as rx

class HiAcademicCap(rx.Component):
    library = "react-icons/hi"
    tag = "HiAcademicCap"


class HiAdjustments(rx.Component):
    library = "react-icons/hi"
    tag = "HiAdjustments"


class HiAnnotation(rx.Component):
    library = "react-icons/hi"
    tag = "HiAnnotation"


class HiArchive(rx.Component):
    library = "react-icons/hi"
    tag = "HiArchive"


class HiArrowCircleDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowCircleDown"


class HiArrowCircleLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowCircleLeft"


class HiArrowCircleRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowCircleRight"


class HiArrowCircleUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowCircleUp"


class HiArrowDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowDown"


class HiArrowLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowLeft"


class HiArrowNarrowDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowNarrowDown"


class HiArrowNarrowLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowNarrowLeft"


class HiArrowNarrowRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowNarrowRight"


class HiArrowNarrowUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowNarrowUp"


class HiArrowRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowRight"


class HiArrowSmDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowSmDown"


class HiArrowSmLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowSmLeft"


class HiArrowSmRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowSmRight"


class HiArrowSmUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowSmUp"


class HiArrowUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowUp"


class HiArrowsExpand(rx.Component):
    library = "react-icons/hi"
    tag = "HiArrowsExpand"


class HiAtSymbol(rx.Component):
    library = "react-icons/hi"
    tag = "HiAtSymbol"


class HiBackspace(rx.Component):
    library = "react-icons/hi"
    tag = "HiBackspace"


class HiBadgeCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiBadgeCheck"


class HiBan(rx.Component):
    library = "react-icons/hi"
    tag = "HiBan"


class HiBeaker(rx.Component):
    library = "react-icons/hi"
    tag = "HiBeaker"


class HiBell(rx.Component):
    library = "react-icons/hi"
    tag = "HiBell"


class HiBookOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiBookOpen"


class HiBookmarkAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiBookmarkAlt"


class HiBookmark(rx.Component):
    library = "react-icons/hi"
    tag = "HiBookmark"


class HiBriefcase(rx.Component):
    library = "react-icons/hi"
    tag = "HiBriefcase"


class HiCake(rx.Component):
    library = "react-icons/hi"
    tag = "HiCake"


class HiCalculator(rx.Component):
    library = "react-icons/hi"
    tag = "HiCalculator"


class HiCalendar(rx.Component):
    library = "react-icons/hi"
    tag = "HiCalendar"


class HiCamera(rx.Component):
    library = "react-icons/hi"
    tag = "HiCamera"


class HiCash(rx.Component):
    library = "react-icons/hi"
    tag = "HiCash"


class HiChartBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiChartBar"


class HiChartPie(rx.Component):
    library = "react-icons/hi"
    tag = "HiChartPie"


class HiChartSquareBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiChartSquareBar"


class HiChatAlt2(rx.Component):
    library = "react-icons/hi"
    tag = "HiChatAlt2"


class HiChatAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiChatAlt"


class HiChat(rx.Component):
    library = "react-icons/hi"
    tag = "HiChat"


class HiCheckCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiCheckCircle"


class HiCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiCheck"


class HiChevronDoubleDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDoubleDown"


class HiChevronDoubleLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDoubleLeft"


class HiChevronDoubleRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDoubleRight"


class HiChevronDoubleUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDoubleUp"


class HiChevronDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronDown"


class HiChevronLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronLeft"


class HiChevronRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronRight"


class HiChevronUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiChevronUp"


class HiChip(rx.Component):
    library = "react-icons/hi"
    tag = "HiChip"


class HiClipboardCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiClipboardCheck"


class HiClipboardCopy(rx.Component):
    library = "react-icons/hi"
    tag = "HiClipboardCopy"


class HiClipboardList(rx.Component):
    library = "react-icons/hi"
    tag = "HiClipboardList"


class HiClipboard(rx.Component):
    library = "react-icons/hi"
    tag = "HiClipboard"


class HiClock(rx.Component):
    library = "react-icons/hi"
    tag = "HiClock"


class HiCloudDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiCloudDownload"


class HiCloudUpload(rx.Component):
    library = "react-icons/hi"
    tag = "HiCloudUpload"


class HiCloud(rx.Component):
    library = "react-icons/hi"
    tag = "HiCloud"


class HiCode(rx.Component):
    library = "react-icons/hi"
    tag = "HiCode"


class HiCog(rx.Component):
    library = "react-icons/hi"
    tag = "HiCog"


class HiCollection(rx.Component):
    library = "react-icons/hi"
    tag = "HiCollection"


class HiColorSwatch(rx.Component):
    library = "react-icons/hi"
    tag = "HiColorSwatch"


class HiCreditCard(rx.Component):
    library = "react-icons/hi"
    tag = "HiCreditCard"


class HiCubeTransparent(rx.Component):
    library = "react-icons/hi"
    tag = "HiCubeTransparent"


class HiCube(rx.Component):
    library = "react-icons/hi"
    tag = "HiCube"


class HiCurrencyBangladeshi(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyBangladeshi"


class HiCurrencyDollar(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyDollar"


class HiCurrencyEuro(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyEuro"


class HiCurrencyPound(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyPound"


class HiCurrencyRupee(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyRupee"


class HiCurrencyYen(rx.Component):
    library = "react-icons/hi"
    tag = "HiCurrencyYen"


class HiCursorClick(rx.Component):
    library = "react-icons/hi"
    tag = "HiCursorClick"


class HiDatabase(rx.Component):
    library = "react-icons/hi"
    tag = "HiDatabase"


class HiDesktopComputer(rx.Component):
    library = "react-icons/hi"
    tag = "HiDesktopComputer"


class HiDeviceMobile(rx.Component):
    library = "react-icons/hi"
    tag = "HiDeviceMobile"


class HiDeviceTablet(rx.Component):
    library = "react-icons/hi"
    tag = "HiDeviceTablet"


class HiDocumentAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentAdd"


class HiDocumentDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentDownload"


class HiDocumentDuplicate(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentDuplicate"


class HiDocumentRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentRemove"


class HiDocumentReport(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentReport"


class HiDocumentSearch(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentSearch"


class HiDocumentText(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocumentText"


class HiDocument(rx.Component):
    library = "react-icons/hi"
    tag = "HiDocument"


class HiDotsCircleHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiDotsCircleHorizontal"


class HiDotsHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiDotsHorizontal"


class HiDotsVertical(rx.Component):
    library = "react-icons/hi"
    tag = "HiDotsVertical"


class HiDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiDownload"


class HiDuplicate(rx.Component):
    library = "react-icons/hi"
    tag = "HiDuplicate"


class HiEmojiHappy(rx.Component):
    library = "react-icons/hi"
    tag = "HiEmojiHappy"


class HiEmojiSad(rx.Component):
    library = "react-icons/hi"
    tag = "HiEmojiSad"


class HiExclamationCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiExclamationCircle"


class HiExclamation(rx.Component):
    library = "react-icons/hi"
    tag = "HiExclamation"


class HiExternalLink(rx.Component):
    library = "react-icons/hi"
    tag = "HiExternalLink"


class HiEyeOff(rx.Component):
    library = "react-icons/hi"
    tag = "HiEyeOff"


class HiEye(rx.Component):
    library = "react-icons/hi"
    tag = "HiEye"


class HiFastForward(rx.Component):
    library = "react-icons/hi"
    tag = "HiFastForward"


class HiFilm(rx.Component):
    library = "react-icons/hi"
    tag = "HiFilm"


class HiFilter(rx.Component):
    library = "react-icons/hi"
    tag = "HiFilter"


class HiFingerPrint(rx.Component):
    library = "react-icons/hi"
    tag = "HiFingerPrint"


class HiFire(rx.Component):
    library = "react-icons/hi"
    tag = "HiFire"


class HiFlag(rx.Component):
    library = "react-icons/hi"
    tag = "HiFlag"


class HiFolderAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolderAdd"


class HiFolderDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolderDownload"


class HiFolderOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolderOpen"


class HiFolderRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolderRemove"


class HiFolder(rx.Component):
    library = "react-icons/hi"
    tag = "HiFolder"


class HiGift(rx.Component):
    library = "react-icons/hi"
    tag = "HiGift"


class HiGlobeAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiGlobeAlt"


class HiGlobe(rx.Component):
    library = "react-icons/hi"
    tag = "HiGlobe"


class HiHand(rx.Component):
    library = "react-icons/hi"
    tag = "HiHand"


class HiHashtag(rx.Component):
    library = "react-icons/hi"
    tag = "HiHashtag"


class HiHeart(rx.Component):
    library = "react-icons/hi"
    tag = "HiHeart"


class HiHome(rx.Component):
    library = "react-icons/hi"
    tag = "HiHome"


class HiIdentification(rx.Component):
    library = "react-icons/hi"
    tag = "HiIdentification"


class HiInboxIn(rx.Component):
    library = "react-icons/hi"
    tag = "HiInboxIn"


class HiInbox(rx.Component):
    library = "react-icons/hi"
    tag = "HiInbox"


class HiInformationCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiInformationCircle"


class HiKey(rx.Component):
    library = "react-icons/hi"
    tag = "HiKey"


class HiLibrary(rx.Component):
    library = "react-icons/hi"
    tag = "HiLibrary"


class HiLightBulb(rx.Component):
    library = "react-icons/hi"
    tag = "HiLightBulb"


class HiLightningBolt(rx.Component):
    library = "react-icons/hi"
    tag = "HiLightningBolt"


class HiLink(rx.Component):
    library = "react-icons/hi"
    tag = "HiLink"


class HiLocationMarker(rx.Component):
    library = "react-icons/hi"
    tag = "HiLocationMarker"


class HiLockClosed(rx.Component):
    library = "react-icons/hi"
    tag = "HiLockClosed"


class HiLockOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiLockOpen"


class HiLogin(rx.Component):
    library = "react-icons/hi"
    tag = "HiLogin"


class HiLogout(rx.Component):
    library = "react-icons/hi"
    tag = "HiLogout"


class HiMailOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiMailOpen"


class HiMail(rx.Component):
    library = "react-icons/hi"
    tag = "HiMail"


class HiMap(rx.Component):
    library = "react-icons/hi"
    tag = "HiMap"


class HiMenuAlt1(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenuAlt1"


class HiMenuAlt2(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenuAlt2"


class HiMenuAlt3(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenuAlt3"


class HiMenuAlt4(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenuAlt4"


class HiMenu(rx.Component):
    library = "react-icons/hi"
    tag = "HiMenu"


class HiMicrophone(rx.Component):
    library = "react-icons/hi"
    tag = "HiMicrophone"


class HiMinusCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiMinusCircle"


class HiMinusSm(rx.Component):
    library = "react-icons/hi"
    tag = "HiMinusSm"


class HiMinus(rx.Component):
    library = "react-icons/hi"
    tag = "HiMinus"


class HiMoon(rx.Component):
    library = "react-icons/hi"
    tag = "HiMoon"


class HiMusicNote(rx.Component):
    library = "react-icons/hi"
    tag = "HiMusicNote"


class HiNewspaper(rx.Component):
    library = "react-icons/hi"
    tag = "HiNewspaper"


class HiOfficeBuilding(rx.Component):
    library = "react-icons/hi"
    tag = "HiOfficeBuilding"


class HiPaperAirplane(rx.Component):
    library = "react-icons/hi"
    tag = "HiPaperAirplane"


class HiPaperClip(rx.Component):
    library = "react-icons/hi"
    tag = "HiPaperClip"


class HiPause(rx.Component):
    library = "react-icons/hi"
    tag = "HiPause"


class HiPencilAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiPencilAlt"


class HiPencil(rx.Component):
    library = "react-icons/hi"
    tag = "HiPencil"


class HiPhoneIncoming(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhoneIncoming"


class HiPhoneMissedCall(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhoneMissedCall"


class HiPhoneOutgoing(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhoneOutgoing"


class HiPhone(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhone"


class HiPhotograph(rx.Component):
    library = "react-icons/hi"
    tag = "HiPhotograph"


class HiPlay(rx.Component):
    library = "react-icons/hi"
    tag = "HiPlay"


class HiPlusCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiPlusCircle"


class HiPlusSm(rx.Component):
    library = "react-icons/hi"
    tag = "HiPlusSm"


class HiPlus(rx.Component):
    library = "react-icons/hi"
    tag = "HiPlus"


class HiPresentationChartBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiPresentationChartBar"


class HiPresentationChartLine(rx.Component):
    library = "react-icons/hi"
    tag = "HiPresentationChartLine"


class HiPrinter(rx.Component):
    library = "react-icons/hi"
    tag = "HiPrinter"


class HiPuzzle(rx.Component):
    library = "react-icons/hi"
    tag = "HiPuzzle"


class HiQrcode(rx.Component):
    library = "react-icons/hi"
    tag = "HiQrcode"


class HiQuestionMarkCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiQuestionMarkCircle"


class HiReceiptRefund(rx.Component):
    library = "react-icons/hi"
    tag = "HiReceiptRefund"


class HiReceiptTax(rx.Component):
    library = "react-icons/hi"
    tag = "HiReceiptTax"


class HiRefresh(rx.Component):
    library = "react-icons/hi"
    tag = "HiRefresh"


class HiReply(rx.Component):
    library = "react-icons/hi"
    tag = "HiReply"


class HiRewind(rx.Component):
    library = "react-icons/hi"
    tag = "HiRewind"


class HiRss(rx.Component):
    library = "react-icons/hi"
    tag = "HiRss"


class HiSaveAs(rx.Component):
    library = "react-icons/hi"
    tag = "HiSaveAs"


class HiSave(rx.Component):
    library = "react-icons/hi"
    tag = "HiSave"


class HiScale(rx.Component):
    library = "react-icons/hi"
    tag = "HiScale"


class HiScissors(rx.Component):
    library = "react-icons/hi"
    tag = "HiScissors"


class HiSearchCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiSearchCircle"


class HiSearch(rx.Component):
    library = "react-icons/hi"
    tag = "HiSearch"


class HiSelector(rx.Component):
    library = "react-icons/hi"
    tag = "HiSelector"


class HiServer(rx.Component):
    library = "react-icons/hi"
    tag = "HiServer"


class HiShare(rx.Component):
    library = "react-icons/hi"
    tag = "HiShare"


class HiShieldCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiShieldCheck"


class HiShieldExclamation(rx.Component):
    library = "react-icons/hi"
    tag = "HiShieldExclamation"


class HiShoppingBag(rx.Component):
    library = "react-icons/hi"
    tag = "HiShoppingBag"


class HiShoppingCart(rx.Component):
    library = "react-icons/hi"
    tag = "HiShoppingCart"


class HiSortAscending(rx.Component):
    library = "react-icons/hi"
    tag = "HiSortAscending"


class HiSortDescending(rx.Component):
    library = "react-icons/hi"
    tag = "HiSortDescending"


class HiSparkles(rx.Component):
    library = "react-icons/hi"
    tag = "HiSparkles"


class HiSpeakerphone(rx.Component):
    library = "react-icons/hi"
    tag = "HiSpeakerphone"


class HiStar(rx.Component):
    library = "react-icons/hi"
    tag = "HiStar"


class HiStatusOffline(rx.Component):
    library = "react-icons/hi"
    tag = "HiStatusOffline"


class HiStatusOnline(rx.Component):
    library = "react-icons/hi"
    tag = "HiStatusOnline"


class HiStop(rx.Component):
    library = "react-icons/hi"
    tag = "HiStop"


class HiSun(rx.Component):
    library = "react-icons/hi"
    tag = "HiSun"


class HiSupport(rx.Component):
    library = "react-icons/hi"
    tag = "HiSupport"


class HiSwitchHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiSwitchHorizontal"


class HiSwitchVertical(rx.Component):
    library = "react-icons/hi"
    tag = "HiSwitchVertical"


class HiTable(rx.Component):
    library = "react-icons/hi"
    tag = "HiTable"


class HiTag(rx.Component):
    library = "react-icons/hi"
    tag = "HiTag"


class HiTemplate(rx.Component):
    library = "react-icons/hi"
    tag = "HiTemplate"


class HiTerminal(rx.Component):
    library = "react-icons/hi"
    tag = "HiTerminal"


class HiThumbDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiThumbDown"


class HiThumbUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiThumbUp"


class HiTicket(rx.Component):
    library = "react-icons/hi"
    tag = "HiTicket"


class HiTranslate(rx.Component):
    library = "react-icons/hi"
    tag = "HiTranslate"


class HiTrash(rx.Component):
    library = "react-icons/hi"
    tag = "HiTrash"


class HiTrendingDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiTrendingDown"


class HiTrendingUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiTrendingUp"


class HiTruck(rx.Component):
    library = "react-icons/hi"
    tag = "HiTruck"


class HiUpload(rx.Component):
    library = "react-icons/hi"
    tag = "HiUpload"


class HiUserAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiUserAdd"


class HiUserCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiUserCircle"


class HiUserGroup(rx.Component):
    library = "react-icons/hi"
    tag = "HiUserGroup"


class HiUserRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiUserRemove"


class HiUser(rx.Component):
    library = "react-icons/hi"
    tag = "HiUser"


class HiUsers(rx.Component):
    library = "react-icons/hi"
    tag = "HiUsers"


class HiVariable(rx.Component):
    library = "react-icons/hi"
    tag = "HiVariable"


class HiVideoCamera(rx.Component):
    library = "react-icons/hi"
    tag = "HiVideoCamera"


class HiViewBoards(rx.Component):
    library = "react-icons/hi"
    tag = "HiViewBoards"


class HiViewGridAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiViewGridAdd"


class HiViewGrid(rx.Component):
    library = "react-icons/hi"
    tag = "HiViewGrid"


class HiViewList(rx.Component):
    library = "react-icons/hi"
    tag = "HiViewList"


class HiVolumeOff(rx.Component):
    library = "react-icons/hi"
    tag = "HiVolumeOff"


class HiVolumeUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiVolumeUp"


class HiWifi(rx.Component):
    library = "react-icons/hi"
    tag = "HiWifi"


class HiXCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiXCircle"


class HiX(rx.Component):
    library = "react-icons/hi"
    tag = "HiX"


class HiZoomIn(rx.Component):
    library = "react-icons/hi"
    tag = "HiZoomIn"


class HiZoomOut(rx.Component):
    library = "react-icons/hi"
    tag = "HiZoomOut"


class HiOutlineAcademicCap(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineAcademicCap"


class HiOutlineAdjustments(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineAdjustments"


class HiOutlineAnnotation(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineAnnotation"


class HiOutlineArchive(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArchive"


class HiOutlineArrowCircleDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowCircleDown"


class HiOutlineArrowCircleLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowCircleLeft"


class HiOutlineArrowCircleRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowCircleRight"


class HiOutlineArrowCircleUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowCircleUp"


class HiOutlineArrowDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowDown"


class HiOutlineArrowLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowLeft"


class HiOutlineArrowNarrowDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowNarrowDown"


class HiOutlineArrowNarrowLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowNarrowLeft"


class HiOutlineArrowNarrowRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowNarrowRight"


class HiOutlineArrowNarrowUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowNarrowUp"


class HiOutlineArrowRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowRight"


class HiOutlineArrowSmDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowSmDown"


class HiOutlineArrowSmLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowSmLeft"


class HiOutlineArrowSmRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowSmRight"


class HiOutlineArrowSmUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowSmUp"


class HiOutlineArrowUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowUp"


class HiOutlineArrowsExpand(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineArrowsExpand"


class HiOutlineAtSymbol(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineAtSymbol"


class HiOutlineBackspace(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBackspace"


class HiOutlineBadgeCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBadgeCheck"


class HiOutlineBan(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBan"


class HiOutlineBeaker(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBeaker"


class HiOutlineBell(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBell"


class HiOutlineBookOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBookOpen"


class HiOutlineBookmarkAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBookmarkAlt"


class HiOutlineBookmark(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBookmark"


class HiOutlineBriefcase(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineBriefcase"


class HiOutlineCake(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCake"


class HiOutlineCalculator(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCalculator"


class HiOutlineCalendar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCalendar"


class HiOutlineCamera(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCamera"


class HiOutlineCash(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCash"


class HiOutlineChartBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChartBar"


class HiOutlineChartPie(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChartPie"


class HiOutlineChartSquareBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChartSquareBar"


class HiOutlineChatAlt2(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChatAlt2"


class HiOutlineChatAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChatAlt"


class HiOutlineChat(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChat"


class HiOutlineCheckCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCheckCircle"


class HiOutlineCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCheck"


class HiOutlineChevronDoubleDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDoubleDown"


class HiOutlineChevronDoubleLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDoubleLeft"


class HiOutlineChevronDoubleRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDoubleRight"


class HiOutlineChevronDoubleUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDoubleUp"


class HiOutlineChevronDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronDown"


class HiOutlineChevronLeft(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronLeft"


class HiOutlineChevronRight(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronRight"


class HiOutlineChevronUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChevronUp"


class HiOutlineChip(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineChip"


class HiOutlineClipboardCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClipboardCheck"


class HiOutlineClipboardCopy(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClipboardCopy"


class HiOutlineClipboardList(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClipboardList"


class HiOutlineClipboard(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClipboard"


class HiOutlineClock(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineClock"


class HiOutlineCloudDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCloudDownload"


class HiOutlineCloudUpload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCloudUpload"


class HiOutlineCloud(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCloud"


class HiOutlineCode(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCode"


class HiOutlineCog(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCog"


class HiOutlineCollection(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCollection"


class HiOutlineColorSwatch(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineColorSwatch"


class HiOutlineCreditCard(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCreditCard"


class HiOutlineCubeTransparent(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCubeTransparent"


class HiOutlineCube(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCube"


class HiOutlineCurrencyBangladeshi(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyBangladeshi"


class HiOutlineCurrencyDollar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyDollar"


class HiOutlineCurrencyEuro(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyEuro"


class HiOutlineCurrencyPound(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyPound"


class HiOutlineCurrencyRupee(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyRupee"


class HiOutlineCurrencyYen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCurrencyYen"


class HiOutlineCursorClick(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineCursorClick"


class HiOutlineDatabase(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDatabase"


class HiOutlineDesktopComputer(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDesktopComputer"


class HiOutlineDeviceMobile(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDeviceMobile"


class HiOutlineDeviceTablet(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDeviceTablet"


class HiOutlineDocumentAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentAdd"


class HiOutlineDocumentDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentDownload"


class HiOutlineDocumentDuplicate(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentDuplicate"


class HiOutlineDocumentRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentRemove"


class HiOutlineDocumentReport(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentReport"


class HiOutlineDocumentSearch(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentSearch"


class HiOutlineDocumentText(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocumentText"


class HiOutlineDocument(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDocument"


class HiOutlineDotsCircleHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDotsCircleHorizontal"


class HiOutlineDotsHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDotsHorizontal"


class HiOutlineDotsVertical(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDotsVertical"


class HiOutlineDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDownload"


class HiOutlineDuplicate(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineDuplicate"


class HiOutlineEmojiHappy(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineEmojiHappy"


class HiOutlineEmojiSad(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineEmojiSad"


class HiOutlineExclamationCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineExclamationCircle"


class HiOutlineExclamation(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineExclamation"


class HiOutlineExternalLink(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineExternalLink"


class HiOutlineEyeOff(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineEyeOff"


class HiOutlineEye(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineEye"


class HiOutlineFastForward(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFastForward"


class HiOutlineFilm(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFilm"


class HiOutlineFilter(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFilter"


class HiOutlineFingerPrint(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFingerPrint"


class HiOutlineFire(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFire"


class HiOutlineFlag(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFlag"


class HiOutlineFolderAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolderAdd"


class HiOutlineFolderDownload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolderDownload"


class HiOutlineFolderOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolderOpen"


class HiOutlineFolderRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolderRemove"


class HiOutlineFolder(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineFolder"


class HiOutlineGift(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineGift"


class HiOutlineGlobeAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineGlobeAlt"


class HiOutlineGlobe(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineGlobe"


class HiOutlineHand(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineHand"


class HiOutlineHashtag(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineHashtag"


class HiOutlineHeart(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineHeart"


class HiOutlineHome(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineHome"


class HiOutlineIdentification(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineIdentification"


class HiOutlineInboxIn(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineInboxIn"


class HiOutlineInbox(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineInbox"


class HiOutlineInformationCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineInformationCircle"


class HiOutlineKey(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineKey"


class HiOutlineLibrary(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLibrary"


class HiOutlineLightBulb(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLightBulb"


class HiOutlineLightningBolt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLightningBolt"


class HiOutlineLink(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLink"


class HiOutlineLocationMarker(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLocationMarker"


class HiOutlineLockClosed(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLockClosed"


class HiOutlineLockOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLockOpen"


class HiOutlineLogin(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLogin"


class HiOutlineLogout(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineLogout"


class HiOutlineMailOpen(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMailOpen"


class HiOutlineMail(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMail"


class HiOutlineMap(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMap"


class HiOutlineMenuAlt1(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenuAlt1"


class HiOutlineMenuAlt2(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenuAlt2"


class HiOutlineMenuAlt3(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenuAlt3"


class HiOutlineMenuAlt4(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenuAlt4"


class HiOutlineMenu(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMenu"


class HiOutlineMicrophone(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMicrophone"


class HiOutlineMinusCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMinusCircle"


class HiOutlineMinusSm(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMinusSm"


class HiOutlineMinus(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMinus"


class HiOutlineMoon(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMoon"


class HiOutlineMusicNote(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineMusicNote"


class HiOutlineNewspaper(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineNewspaper"


class HiOutlineOfficeBuilding(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineOfficeBuilding"


class HiOutlinePaperAirplane(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePaperAirplane"


class HiOutlinePaperClip(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePaperClip"


class HiOutlinePause(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePause"


class HiOutlinePencilAlt(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePencilAlt"


class HiOutlinePencil(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePencil"


class HiOutlinePhoneIncoming(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhoneIncoming"


class HiOutlinePhoneMissedCall(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhoneMissedCall"


class HiOutlinePhoneOutgoing(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhoneOutgoing"


class HiOutlinePhone(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhone"


class HiOutlinePhotograph(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePhotograph"


class HiOutlinePlay(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePlay"


class HiOutlinePlusCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePlusCircle"


class HiOutlinePlusSm(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePlusSm"


class HiOutlinePlus(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePlus"


class HiOutlinePresentationChartBar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePresentationChartBar"


class HiOutlinePresentationChartLine(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePresentationChartLine"


class HiOutlinePrinter(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePrinter"


class HiOutlinePuzzle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlinePuzzle"


class HiOutlineQrcode(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineQrcode"


class HiOutlineQuestionMarkCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineQuestionMarkCircle"


class HiOutlineReceiptRefund(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineReceiptRefund"


class HiOutlineReceiptTax(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineReceiptTax"


class HiOutlineRefresh(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineRefresh"


class HiOutlineReply(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineReply"


class HiOutlineRewind(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineRewind"


class HiOutlineRss(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineRss"


class HiOutlineSaveAs(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSaveAs"


class HiOutlineSave(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSave"


class HiOutlineScale(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineScale"


class HiOutlineScissors(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineScissors"


class HiOutlineSearchCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSearchCircle"


class HiOutlineSearch(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSearch"


class HiOutlineSelector(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSelector"


class HiOutlineServer(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineServer"


class HiOutlineShare(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShare"


class HiOutlineShieldCheck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShieldCheck"


class HiOutlineShieldExclamation(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShieldExclamation"


class HiOutlineShoppingBag(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShoppingBag"


class HiOutlineShoppingCart(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineShoppingCart"


class HiOutlineSortAscending(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSortAscending"


class HiOutlineSortDescending(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSortDescending"


class HiOutlineSparkles(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSparkles"


class HiOutlineSpeakerphone(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSpeakerphone"


class HiOutlineStar(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineStar"


class HiOutlineStatusOffline(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineStatusOffline"


class HiOutlineStatusOnline(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineStatusOnline"


class HiOutlineStop(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineStop"


class HiOutlineSun(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSun"


class HiOutlineSupport(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSupport"


class HiOutlineSwitchHorizontal(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSwitchHorizontal"


class HiOutlineSwitchVertical(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineSwitchVertical"


class HiOutlineTable(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTable"


class HiOutlineTag(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTag"


class HiOutlineTemplate(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTemplate"


class HiOutlineTerminal(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTerminal"


class HiOutlineThumbDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineThumbDown"


class HiOutlineThumbUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineThumbUp"


class HiOutlineTicket(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTicket"


class HiOutlineTranslate(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTranslate"


class HiOutlineTrash(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTrash"


class HiOutlineTrendingDown(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTrendingDown"


class HiOutlineTrendingUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTrendingUp"


class HiOutlineTruck(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineTruck"


class HiOutlineUpload(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUpload"


class HiOutlineUserAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUserAdd"


class HiOutlineUserCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUserCircle"


class HiOutlineUserGroup(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUserGroup"


class HiOutlineUserRemove(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUserRemove"


class HiOutlineUser(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUser"


class HiOutlineUsers(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineUsers"


class HiOutlineVariable(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineVariable"


class HiOutlineVideoCamera(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineVideoCamera"


class HiOutlineViewBoards(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineViewBoards"


class HiOutlineViewGridAdd(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineViewGridAdd"


class HiOutlineViewGrid(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineViewGrid"


class HiOutlineViewList(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineViewList"


class HiOutlineVolumeOff(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineVolumeOff"


class HiOutlineVolumeUp(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineVolumeUp"


class HiOutlineWifi(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineWifi"


class HiOutlineXCircle(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineXCircle"


class HiOutlineX(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineX"


class HiOutlineZoomIn(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineZoomIn"


class HiOutlineZoomOut(rx.Component):
    library = "react-icons/hi"
    tag = "HiOutlineZoomOut"


