import reflex as rx

class ImHome(rx.Component):
    library = "react-icons/im"
    tag = "ImHome"


class ImHome2(rx.Component):
    library = "react-icons/im"
    tag = "ImHome2"


class ImHome3(rx.Component):
    library = "react-icons/im"
    tag = "ImHome3"


class ImOffice(rx.Component):
    library = "react-icons/im"
    tag = "ImOffice"


class ImNewspaper(rx.Component):
    library = "react-icons/im"
    tag = "ImNewspaper"


class ImPencil(rx.Component):
    library = "react-icons/im"
    tag = "ImPencil"


class ImPencil2(rx.Component):
    library = "react-icons/im"
    tag = "ImPencil2"


class ImQuill(rx.Component):
    library = "react-icons/im"
    tag = "ImQuill"


class ImPen(rx.Component):
    library = "react-icons/im"
    tag = "ImPen"


class ImBlog(rx.Component):
    library = "react-icons/im"
    tag = "ImBlog"


class ImEyedropper(rx.Component):
    library = "react-icons/im"
    tag = "ImEyedropper"


class ImDroplet(rx.Component):
    library = "react-icons/im"
    tag = "ImDroplet"


class ImPaintFormat(rx.Component):
    library = "react-icons/im"
    tag = "ImPaintFormat"


class ImImage(rx.Component):
    library = "react-icons/im"
    tag = "ImImage"


class ImImages(rx.Component):
    library = "react-icons/im"
    tag = "ImImages"


class ImCamera(rx.Component):
    library = "react-icons/im"
    tag = "ImCamera"


class ImHeadphones(rx.Component):
    library = "react-icons/im"
    tag = "ImHeadphones"


class ImMusic(rx.Component):
    library = "react-icons/im"
    tag = "ImMusic"


class ImPlay(rx.Component):
    library = "react-icons/im"
    tag = "ImPlay"


class ImFilm(rx.Component):
    library = "react-icons/im"
    tag = "ImFilm"


class ImVideoCamera(rx.Component):
    library = "react-icons/im"
    tag = "ImVideoCamera"


class ImDice(rx.Component):
    library = "react-icons/im"
    tag = "ImDice"


class ImPacman(rx.Component):
    library = "react-icons/im"
    tag = "ImPacman"


class ImSpades(rx.Component):
    library = "react-icons/im"
    tag = "ImSpades"


class ImClubs(rx.Component):
    library = "react-icons/im"
    tag = "ImClubs"


class ImDiamonds(rx.Component):
    library = "react-icons/im"
    tag = "ImDiamonds"


class ImBullhorn(rx.Component):
    library = "react-icons/im"
    tag = "ImBullhorn"


class ImConnection(rx.Component):
    library = "react-icons/im"
    tag = "ImConnection"


class ImPodcast(rx.Component):
    library = "react-icons/im"
    tag = "ImPodcast"


class ImFeed(rx.Component):
    library = "react-icons/im"
    tag = "ImFeed"


class ImMic(rx.Component):
    library = "react-icons/im"
    tag = "ImMic"


class ImBook(rx.Component):
    library = "react-icons/im"
    tag = "ImBook"


class ImBooks(rx.Component):
    library = "react-icons/im"
    tag = "ImBooks"


class ImLibrary(rx.Component):
    library = "react-icons/im"
    tag = "ImLibrary"


class ImFileText(rx.Component):
    library = "react-icons/im"
    tag = "ImFileText"


class ImProfile(rx.Component):
    library = "react-icons/im"
    tag = "ImProfile"


class ImFileEmpty(rx.Component):
    library = "react-icons/im"
    tag = "ImFileEmpty"


class ImFilesEmpty(rx.Component):
    library = "react-icons/im"
    tag = "ImFilesEmpty"


class ImFileText2(rx.Component):
    library = "react-icons/im"
    tag = "ImFileText2"


class ImFilePicture(rx.Component):
    library = "react-icons/im"
    tag = "ImFilePicture"


class ImFileMusic(rx.Component):
    library = "react-icons/im"
    tag = "ImFileMusic"


class ImFilePlay(rx.Component):
    library = "react-icons/im"
    tag = "ImFilePlay"


class ImFileVideo(rx.Component):
    library = "react-icons/im"
    tag = "ImFileVideo"


class ImFileZip(rx.Component):
    library = "react-icons/im"
    tag = "ImFileZip"


class ImCopy(rx.Component):
    library = "react-icons/im"
    tag = "ImCopy"


class ImPaste(rx.Component):
    library = "react-icons/im"
    tag = "ImPaste"


class ImStack(rx.Component):
    library = "react-icons/im"
    tag = "ImStack"


class ImFolder(rx.Component):
    library = "react-icons/im"
    tag = "ImFolder"


class ImFolderOpen(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderOpen"


class ImFolderPlus(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderPlus"


class ImFolderMinus(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderMinus"


class ImFolderDownload(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderDownload"


class ImFolderUpload(rx.Component):
    library = "react-icons/im"
    tag = "ImFolderUpload"


class ImPriceTag(rx.Component):
    library = "react-icons/im"
    tag = "ImPriceTag"


class ImPriceTags(rx.Component):
    library = "react-icons/im"
    tag = "ImPriceTags"


class ImBarcode(rx.Component):
    library = "react-icons/im"
    tag = "ImBarcode"


class ImQrcode(rx.Component):
    library = "react-icons/im"
    tag = "ImQrcode"


class ImTicket(rx.Component):
    library = "react-icons/im"
    tag = "ImTicket"


class ImCart(rx.Component):
    library = "react-icons/im"
    tag = "ImCart"


class ImCoinDollar(rx.Component):
    library = "react-icons/im"
    tag = "ImCoinDollar"


class ImCoinEuro(rx.Component):
    library = "react-icons/im"
    tag = "ImCoinEuro"


class ImCoinPound(rx.Component):
    library = "react-icons/im"
    tag = "ImCoinPound"


class ImCoinYen(rx.Component):
    library = "react-icons/im"
    tag = "ImCoinYen"


class ImCreditCard(rx.Component):
    library = "react-icons/im"
    tag = "ImCreditCard"


class ImCalculator(rx.Component):
    library = "react-icons/im"
    tag = "ImCalculator"


class ImLifebuoy(rx.Component):
    library = "react-icons/im"
    tag = "ImLifebuoy"


class ImPhone(rx.Component):
    library = "react-icons/im"
    tag = "ImPhone"


class ImPhoneHangUp(rx.Component):
    library = "react-icons/im"
    tag = "ImPhoneHangUp"


class ImAddressBook(rx.Component):
    library = "react-icons/im"
    tag = "ImAddressBook"


class ImEnvelop(rx.Component):
    library = "react-icons/im"
    tag = "ImEnvelop"


class ImPushpin(rx.Component):
    library = "react-icons/im"
    tag = "ImPushpin"


class ImLocation(rx.Component):
    library = "react-icons/im"
    tag = "ImLocation"


class ImLocation2(rx.Component):
    library = "react-icons/im"
    tag = "ImLocation2"


class ImCompass(rx.Component):
    library = "react-icons/im"
    tag = "ImCompass"


class ImCompass2(rx.Component):
    library = "react-icons/im"
    tag = "ImCompass2"


class ImMap(rx.Component):
    library = "react-icons/im"
    tag = "ImMap"


class ImMap2(rx.Component):
    library = "react-icons/im"
    tag = "ImMap2"


class ImHistory(rx.Component):
    library = "react-icons/im"
    tag = "ImHistory"


class ImClock(rx.Component):
    library = "react-icons/im"
    tag = "ImClock"


class ImClock2(rx.Component):
    library = "react-icons/im"
    tag = "ImClock2"


class ImAlarm(rx.Component):
    library = "react-icons/im"
    tag = "ImAlarm"


class ImBell(rx.Component):
    library = "react-icons/im"
    tag = "ImBell"


class ImStopwatch(rx.Component):
    library = "react-icons/im"
    tag = "ImStopwatch"


class ImCalendar(rx.Component):
    library = "react-icons/im"
    tag = "ImCalendar"


class ImPrinter(rx.Component):
    library = "react-icons/im"
    tag = "ImPrinter"


class ImKeyboard(rx.Component):
    library = "react-icons/im"
    tag = "ImKeyboard"


class ImDisplay(rx.Component):
    library = "react-icons/im"
    tag = "ImDisplay"


class ImLaptop(rx.Component):
    library = "react-icons/im"
    tag = "ImLaptop"


class ImMobile(rx.Component):
    library = "react-icons/im"
    tag = "ImMobile"


class ImMobile2(rx.Component):
    library = "react-icons/im"
    tag = "ImMobile2"


class ImTablet(rx.Component):
    library = "react-icons/im"
    tag = "ImTablet"


class ImTv(rx.Component):
    library = "react-icons/im"
    tag = "ImTv"


class ImDrawer(rx.Component):
    library = "react-icons/im"
    tag = "ImDrawer"


class ImDrawer2(rx.Component):
    library = "react-icons/im"
    tag = "ImDrawer2"


class ImBoxAdd(rx.Component):
    library = "react-icons/im"
    tag = "ImBoxAdd"


class ImBoxRemove(rx.Component):
    library = "react-icons/im"
    tag = "ImBoxRemove"


class ImDownload(rx.Component):
    library = "react-icons/im"
    tag = "ImDownload"


class ImUpload(rx.Component):
    library = "react-icons/im"
    tag = "ImUpload"


class ImFloppyDisk(rx.Component):
    library = "react-icons/im"
    tag = "ImFloppyDisk"


class ImDrive(rx.Component):
    library = "react-icons/im"
    tag = "ImDrive"


class ImDatabase(rx.Component):
    library = "react-icons/im"
    tag = "ImDatabase"


class ImUndo(rx.Component):
    library = "react-icons/im"
    tag = "ImUndo"


class ImRedo(rx.Component):
    library = "react-icons/im"
    tag = "ImRedo"


class ImUndo2(rx.Component):
    library = "react-icons/im"
    tag = "ImUndo2"


class ImRedo2(rx.Component):
    library = "react-icons/im"
    tag = "ImRedo2"


class ImForward(rx.Component):
    library = "react-icons/im"
    tag = "ImForward"


class ImReply(rx.Component):
    library = "react-icons/im"
    tag = "ImReply"


class ImBubble(rx.Component):
    library = "react-icons/im"
    tag = "ImBubble"


class ImBubbles(rx.Component):
    library = "react-icons/im"
    tag = "ImBubbles"


class ImBubbles2(rx.Component):
    library = "react-icons/im"
    tag = "ImBubbles2"


class ImBubble2(rx.Component):
    library = "react-icons/im"
    tag = "ImBubble2"


class ImBubbles3(rx.Component):
    library = "react-icons/im"
    tag = "ImBubbles3"


class ImBubbles4(rx.Component):
    library = "react-icons/im"
    tag = "ImBubbles4"


class ImUser(rx.Component):
    library = "react-icons/im"
    tag = "ImUser"


class ImUsers(rx.Component):
    library = "react-icons/im"
    tag = "ImUsers"


class ImUserPlus(rx.Component):
    library = "react-icons/im"
    tag = "ImUserPlus"


class ImUserMinus(rx.Component):
    library = "react-icons/im"
    tag = "ImUserMinus"


class ImUserCheck(rx.Component):
    library = "react-icons/im"
    tag = "ImUserCheck"


class ImUserTie(rx.Component):
    library = "react-icons/im"
    tag = "ImUserTie"


class ImQuotesLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImQuotesLeft"


class ImQuotesRight(rx.Component):
    library = "react-icons/im"
    tag = "ImQuotesRight"


class ImHourGlass(rx.Component):
    library = "react-icons/im"
    tag = "ImHourGlass"


class ImSpinner(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner"


class ImSpinner2(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner2"


class ImSpinner3(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner3"


class ImSpinner4(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner4"


class ImSpinner5(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner5"


class ImSpinner6(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner6"


class ImSpinner7(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner7"


class ImSpinner8(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner8"


class ImSpinner9(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner9"


class ImSpinner10(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner10"


class ImSpinner11(rx.Component):
    library = "react-icons/im"
    tag = "ImSpinner11"


class ImBinoculars(rx.Component):
    library = "react-icons/im"
    tag = "ImBinoculars"


class ImSearch(rx.Component):
    library = "react-icons/im"
    tag = "ImSearch"


class ImZoomIn(rx.Component):
    library = "react-icons/im"
    tag = "ImZoomIn"


class ImZoomOut(rx.Component):
    library = "react-icons/im"
    tag = "ImZoomOut"


class ImEnlarge(rx.Component):
    library = "react-icons/im"
    tag = "ImEnlarge"


class ImShrink(rx.Component):
    library = "react-icons/im"
    tag = "ImShrink"


class ImEnlarge2(rx.Component):
    library = "react-icons/im"
    tag = "ImEnlarge2"


class ImShrink2(rx.Component):
    library = "react-icons/im"
    tag = "ImShrink2"


class ImKey(rx.Component):
    library = "react-icons/im"
    tag = "ImKey"


class ImKey2(rx.Component):
    library = "react-icons/im"
    tag = "ImKey2"


class ImLock(rx.Component):
    library = "react-icons/im"
    tag = "ImLock"


class ImUnlocked(rx.Component):
    library = "react-icons/im"
    tag = "ImUnlocked"


class ImWrench(rx.Component):
    library = "react-icons/im"
    tag = "ImWrench"


class ImEqualizer(rx.Component):
    library = "react-icons/im"
    tag = "ImEqualizer"


class ImEqualizer2(rx.Component):
    library = "react-icons/im"
    tag = "ImEqualizer2"


class ImCog(rx.Component):
    library = "react-icons/im"
    tag = "ImCog"


class ImCogs(rx.Component):
    library = "react-icons/im"
    tag = "ImCogs"


class ImHammer(rx.Component):
    library = "react-icons/im"
    tag = "ImHammer"


class ImMagicWand(rx.Component):
    library = "react-icons/im"
    tag = "ImMagicWand"


class ImAidKit(rx.Component):
    library = "react-icons/im"
    tag = "ImAidKit"


class ImBug(rx.Component):
    library = "react-icons/im"
    tag = "ImBug"


class ImPieChart(rx.Component):
    library = "react-icons/im"
    tag = "ImPieChart"


class ImStatsDots(rx.Component):
    library = "react-icons/im"
    tag = "ImStatsDots"


class ImStatsBars(rx.Component):
    library = "react-icons/im"
    tag = "ImStatsBars"


class ImStatsBars2(rx.Component):
    library = "react-icons/im"
    tag = "ImStatsBars2"


class ImTrophy(rx.Component):
    library = "react-icons/im"
    tag = "ImTrophy"


class ImGift(rx.Component):
    library = "react-icons/im"
    tag = "ImGift"


class ImGlass(rx.Component):
    library = "react-icons/im"
    tag = "ImGlass"


class ImGlass2(rx.Component):
    library = "react-icons/im"
    tag = "ImGlass2"


class ImMug(rx.Component):
    library = "react-icons/im"
    tag = "ImMug"


class ImSpoonKnife(rx.Component):
    library = "react-icons/im"
    tag = "ImSpoonKnife"


class ImLeaf(rx.Component):
    library = "react-icons/im"
    tag = "ImLeaf"


class ImRocket(rx.Component):
    library = "react-icons/im"
    tag = "ImRocket"


class ImMeter(rx.Component):
    library = "react-icons/im"
    tag = "ImMeter"


class ImMeter2(rx.Component):
    library = "react-icons/im"
    tag = "ImMeter2"


class ImHammer2(rx.Component):
    library = "react-icons/im"
    tag = "ImHammer2"


class ImFire(rx.Component):
    library = "react-icons/im"
    tag = "ImFire"


class ImLab(rx.Component):
    library = "react-icons/im"
    tag = "ImLab"


class ImMagnet(rx.Component):
    library = "react-icons/im"
    tag = "ImMagnet"


class ImBin(rx.Component):
    library = "react-icons/im"
    tag = "ImBin"


class ImBin2(rx.Component):
    library = "react-icons/im"
    tag = "ImBin2"


class ImBriefcase(rx.Component):
    library = "react-icons/im"
    tag = "ImBriefcase"


class ImAirplane(rx.Component):
    library = "react-icons/im"
    tag = "ImAirplane"


class ImTruck(rx.Component):
    library = "react-icons/im"
    tag = "ImTruck"


class ImRoad(rx.Component):
    library = "react-icons/im"
    tag = "ImRoad"


class ImAccessibility(rx.Component):
    library = "react-icons/im"
    tag = "ImAccessibility"


class ImTarget(rx.Component):
    library = "react-icons/im"
    tag = "ImTarget"


class ImShield(rx.Component):
    library = "react-icons/im"
    tag = "ImShield"


class ImPower(rx.Component):
    library = "react-icons/im"
    tag = "ImPower"


class ImSwitch(rx.Component):
    library = "react-icons/im"
    tag = "ImSwitch"


class ImPowerCord(rx.Component):
    library = "react-icons/im"
    tag = "ImPowerCord"


class ImClipboard(rx.Component):
    library = "react-icons/im"
    tag = "ImClipboard"


class ImListNumbered(rx.Component):
    library = "react-icons/im"
    tag = "ImListNumbered"


class ImList(rx.Component):
    library = "react-icons/im"
    tag = "ImList"


class ImList2(rx.Component):
    library = "react-icons/im"
    tag = "ImList2"


class ImTree(rx.Component):
    library = "react-icons/im"
    tag = "ImTree"


class ImMenu(rx.Component):
    library = "react-icons/im"
    tag = "ImMenu"


class ImMenu2(rx.Component):
    library = "react-icons/im"
    tag = "ImMenu2"


class ImMenu3(rx.Component):
    library = "react-icons/im"
    tag = "ImMenu3"


class ImMenu4(rx.Component):
    library = "react-icons/im"
    tag = "ImMenu4"


class ImCloud(rx.Component):
    library = "react-icons/im"
    tag = "ImCloud"


class ImCloudDownload(rx.Component):
    library = "react-icons/im"
    tag = "ImCloudDownload"


class ImCloudUpload(rx.Component):
    library = "react-icons/im"
    tag = "ImCloudUpload"


class ImCloudCheck(rx.Component):
    library = "react-icons/im"
    tag = "ImCloudCheck"


class ImDownload2(rx.Component):
    library = "react-icons/im"
    tag = "ImDownload2"


class ImUpload2(rx.Component):
    library = "react-icons/im"
    tag = "ImUpload2"


class ImDownload3(rx.Component):
    library = "react-icons/im"
    tag = "ImDownload3"


class ImUpload3(rx.Component):
    library = "react-icons/im"
    tag = "ImUpload3"


class ImSphere(rx.Component):
    library = "react-icons/im"
    tag = "ImSphere"


class ImEarth(rx.Component):
    library = "react-icons/im"
    tag = "ImEarth"


class ImLink(rx.Component):
    library = "react-icons/im"
    tag = "ImLink"


class ImFlag(rx.Component):
    library = "react-icons/im"
    tag = "ImFlag"


class ImAttachment(rx.Component):
    library = "react-icons/im"
    tag = "ImAttachment"


class ImEye(rx.Component):
    library = "react-icons/im"
    tag = "ImEye"


class ImEyePlus(rx.Component):
    library = "react-icons/im"
    tag = "ImEyePlus"


class ImEyeMinus(rx.Component):
    library = "react-icons/im"
    tag = "ImEyeMinus"


class ImEyeBlocked(rx.Component):
    library = "react-icons/im"
    tag = "ImEyeBlocked"


class ImBookmark(rx.Component):
    library = "react-icons/im"
    tag = "ImBookmark"


class ImBookmarks(rx.Component):
    library = "react-icons/im"
    tag = "ImBookmarks"


class ImSun(rx.Component):
    library = "react-icons/im"
    tag = "ImSun"


class ImContrast(rx.Component):
    library = "react-icons/im"
    tag = "ImContrast"


class ImBrightnessContrast(rx.Component):
    library = "react-icons/im"
    tag = "ImBrightnessContrast"


class ImStarEmpty(rx.Component):
    library = "react-icons/im"
    tag = "ImStarEmpty"


class ImStarHalf(rx.Component):
    library = "react-icons/im"
    tag = "ImStarHalf"


class ImStarFull(rx.Component):
    library = "react-icons/im"
    tag = "ImStarFull"


class ImHeart(rx.Component):
    library = "react-icons/im"
    tag = "ImHeart"


class ImHeartBroken(rx.Component):
    library = "react-icons/im"
    tag = "ImHeartBroken"


class ImMan(rx.Component):
    library = "react-icons/im"
    tag = "ImMan"


class ImWoman(rx.Component):
    library = "react-icons/im"
    tag = "ImWoman"


class ImManWoman(rx.Component):
    library = "react-icons/im"
    tag = "ImManWoman"


class ImHappy(rx.Component):
    library = "react-icons/im"
    tag = "ImHappy"


class ImHappy2(rx.Component):
    library = "react-icons/im"
    tag = "ImHappy2"


class ImSmile(rx.Component):
    library = "react-icons/im"
    tag = "ImSmile"


class ImSmile2(rx.Component):
    library = "react-icons/im"
    tag = "ImSmile2"


class ImTongue(rx.Component):
    library = "react-icons/im"
    tag = "ImTongue"


class ImTongue2(rx.Component):
    library = "react-icons/im"
    tag = "ImTongue2"


class ImSad(rx.Component):
    library = "react-icons/im"
    tag = "ImSad"


class ImSad2(rx.Component):
    library = "react-icons/im"
    tag = "ImSad2"


class ImWink(rx.Component):
    library = "react-icons/im"
    tag = "ImWink"


class ImWink2(rx.Component):
    library = "react-icons/im"
    tag = "ImWink2"


class ImGrin(rx.Component):
    library = "react-icons/im"
    tag = "ImGrin"


class ImGrin2(rx.Component):
    library = "react-icons/im"
    tag = "ImGrin2"


class ImCool(rx.Component):
    library = "react-icons/im"
    tag = "ImCool"


class ImCool2(rx.Component):
    library = "react-icons/im"
    tag = "ImCool2"


class ImAngry(rx.Component):
    library = "react-icons/im"
    tag = "ImAngry"


class ImAngry2(rx.Component):
    library = "react-icons/im"
    tag = "ImAngry2"


class ImEvil(rx.Component):
    library = "react-icons/im"
    tag = "ImEvil"


class ImEvil2(rx.Component):
    library = "react-icons/im"
    tag = "ImEvil2"


class ImShocked(rx.Component):
    library = "react-icons/im"
    tag = "ImShocked"


class ImShocked2(rx.Component):
    library = "react-icons/im"
    tag = "ImShocked2"


class ImBaffled(rx.Component):
    library = "react-icons/im"
    tag = "ImBaffled"


class ImBaffled2(rx.Component):
    library = "react-icons/im"
    tag = "ImBaffled2"


class ImConfused(rx.Component):
    library = "react-icons/im"
    tag = "ImConfused"


class ImConfused2(rx.Component):
    library = "react-icons/im"
    tag = "ImConfused2"


class ImNeutral(rx.Component):
    library = "react-icons/im"
    tag = "ImNeutral"


class ImNeutral2(rx.Component):
    library = "react-icons/im"
    tag = "ImNeutral2"


class ImHipster(rx.Component):
    library = "react-icons/im"
    tag = "ImHipster"


class ImHipster2(rx.Component):
    library = "react-icons/im"
    tag = "ImHipster2"


class ImWondering(rx.Component):
    library = "react-icons/im"
    tag = "ImWondering"


class ImWondering2(rx.Component):
    library = "react-icons/im"
    tag = "ImWondering2"


class ImSleepy(rx.Component):
    library = "react-icons/im"
    tag = "ImSleepy"


class ImSleepy2(rx.Component):
    library = "react-icons/im"
    tag = "ImSleepy2"


class ImFrustrated(rx.Component):
    library = "react-icons/im"
    tag = "ImFrustrated"


class ImFrustrated2(rx.Component):
    library = "react-icons/im"
    tag = "ImFrustrated2"


class ImCrying(rx.Component):
    library = "react-icons/im"
    tag = "ImCrying"


class ImCrying2(rx.Component):
    library = "react-icons/im"
    tag = "ImCrying2"


class ImPointUp(rx.Component):
    library = "react-icons/im"
    tag = "ImPointUp"


class ImPointRight(rx.Component):
    library = "react-icons/im"
    tag = "ImPointRight"


class ImPointDown(rx.Component):
    library = "react-icons/im"
    tag = "ImPointDown"


class ImPointLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImPointLeft"


class ImWarning(rx.Component):
    library = "react-icons/im"
    tag = "ImWarning"


class ImNotification(rx.Component):
    library = "react-icons/im"
    tag = "ImNotification"


class ImQuestion(rx.Component):
    library = "react-icons/im"
    tag = "ImQuestion"


class ImPlus(rx.Component):
    library = "react-icons/im"
    tag = "ImPlus"


class ImMinus(rx.Component):
    library = "react-icons/im"
    tag = "ImMinus"


class ImInfo(rx.Component):
    library = "react-icons/im"
    tag = "ImInfo"


class ImCancelCircle(rx.Component):
    library = "react-icons/im"
    tag = "ImCancelCircle"


class ImBlocked(rx.Component):
    library = "react-icons/im"
    tag = "ImBlocked"


class ImCross(rx.Component):
    library = "react-icons/im"
    tag = "ImCross"


class ImCheckmark(rx.Component):
    library = "react-icons/im"
    tag = "ImCheckmark"


class ImCheckmark2(rx.Component):
    library = "react-icons/im"
    tag = "ImCheckmark2"


class ImSpellCheck(rx.Component):
    library = "react-icons/im"
    tag = "ImSpellCheck"


class ImEnter(rx.Component):
    library = "react-icons/im"
    tag = "ImEnter"


class ImExit(rx.Component):
    library = "react-icons/im"
    tag = "ImExit"


class ImPlay2(rx.Component):
    library = "react-icons/im"
    tag = "ImPlay2"


class ImPause(rx.Component):
    library = "react-icons/im"
    tag = "ImPause"


class ImStop(rx.Component):
    library = "react-icons/im"
    tag = "ImStop"


class ImPrevious(rx.Component):
    library = "react-icons/im"
    tag = "ImPrevious"


class ImNext(rx.Component):
    library = "react-icons/im"
    tag = "ImNext"


class ImBackward(rx.Component):
    library = "react-icons/im"
    tag = "ImBackward"


class ImForward2(rx.Component):
    library = "react-icons/im"
    tag = "ImForward2"


class ImPlay3(rx.Component):
    library = "react-icons/im"
    tag = "ImPlay3"


class ImPause2(rx.Component):
    library = "react-icons/im"
    tag = "ImPause2"


class ImStop2(rx.Component):
    library = "react-icons/im"
    tag = "ImStop2"


class ImBackward2(rx.Component):
    library = "react-icons/im"
    tag = "ImBackward2"


class ImForward3(rx.Component):
    library = "react-icons/im"
    tag = "ImForward3"


class ImFirst(rx.Component):
    library = "react-icons/im"
    tag = "ImFirst"


class ImLast(rx.Component):
    library = "react-icons/im"
    tag = "ImLast"


class ImPrevious2(rx.Component):
    library = "react-icons/im"
    tag = "ImPrevious2"


class ImNext2(rx.Component):
    library = "react-icons/im"
    tag = "ImNext2"


class ImEject(rx.Component):
    library = "react-icons/im"
    tag = "ImEject"


class ImVolumeHigh(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeHigh"


class ImVolumeMedium(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeMedium"


class ImVolumeLow(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeLow"


class ImVolumeMute(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeMute"


class ImVolumeMute2(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeMute2"


class ImVolumeIncrease(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeIncrease"


class ImVolumeDecrease(rx.Component):
    library = "react-icons/im"
    tag = "ImVolumeDecrease"


class ImLoop(rx.Component):
    library = "react-icons/im"
    tag = "ImLoop"


class ImLoop2(rx.Component):
    library = "react-icons/im"
    tag = "ImLoop2"


class ImInfinite(rx.Component):
    library = "react-icons/im"
    tag = "ImInfinite"


class ImShuffle(rx.Component):
    library = "react-icons/im"
    tag = "ImShuffle"


class ImArrowUpLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUpLeft"


class ImArrowUp(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUp"


class ImArrowUpRight(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUpRight"


class ImArrowRight(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowRight"


class ImArrowDownRight(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDownRight"


class ImArrowDown(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDown"


class ImArrowDownLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDownLeft"


class ImArrowLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowLeft"


class ImArrowUpLeft2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUpLeft2"


class ImArrowUp2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUp2"


class ImArrowUpRight2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowUpRight2"


class ImArrowRight2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowRight2"


class ImArrowDownRight2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDownRight2"


class ImArrowDown2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDown2"


class ImArrowDownLeft2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowDownLeft2"


class ImArrowLeft2(rx.Component):
    library = "react-icons/im"
    tag = "ImArrowLeft2"


class ImCircleUp(rx.Component):
    library = "react-icons/im"
    tag = "ImCircleUp"


class ImCircleRight(rx.Component):
    library = "react-icons/im"
    tag = "ImCircleRight"


class ImCircleDown(rx.Component):
    library = "react-icons/im"
    tag = "ImCircleDown"


class ImCircleLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImCircleLeft"


class ImTab(rx.Component):
    library = "react-icons/im"
    tag = "ImTab"


class ImMoveUp(rx.Component):
    library = "react-icons/im"
    tag = "ImMoveUp"


class ImMoveDown(rx.Component):
    library = "react-icons/im"
    tag = "ImMoveDown"


class ImSortAlphaAsc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortAlphaAsc"


class ImSortAlphaDesc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortAlphaDesc"


class ImSortNumericAsc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortNumericAsc"


class ImSortNumbericDesc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortNumbericDesc"


class ImSortAmountAsc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortAmountAsc"


class ImSortAmountDesc(rx.Component):
    library = "react-icons/im"
    tag = "ImSortAmountDesc"


class ImCommand(rx.Component):
    library = "react-icons/im"
    tag = "ImCommand"


class ImShift(rx.Component):
    library = "react-icons/im"
    tag = "ImShift"


class ImCtrl(rx.Component):
    library = "react-icons/im"
    tag = "ImCtrl"


class ImOpt(rx.Component):
    library = "react-icons/im"
    tag = "ImOpt"


class ImCheckboxChecked(rx.Component):
    library = "react-icons/im"
    tag = "ImCheckboxChecked"


class ImCheckboxUnchecked(rx.Component):
    library = "react-icons/im"
    tag = "ImCheckboxUnchecked"


class ImRadioChecked(rx.Component):
    library = "react-icons/im"
    tag = "ImRadioChecked"


class ImRadioChecked2(rx.Component):
    library = "react-icons/im"
    tag = "ImRadioChecked2"


class ImRadioUnchecked(rx.Component):
    library = "react-icons/im"
    tag = "ImRadioUnchecked"


class ImCrop(rx.Component):
    library = "react-icons/im"
    tag = "ImCrop"


class ImMakeGroup(rx.Component):
    library = "react-icons/im"
    tag = "ImMakeGroup"


class ImUngroup(rx.Component):
    library = "react-icons/im"
    tag = "ImUngroup"


class ImScissors(rx.Component):
    library = "react-icons/im"
    tag = "ImScissors"


class ImFilter(rx.Component):
    library = "react-icons/im"
    tag = "ImFilter"


class ImFont(rx.Component):
    library = "react-icons/im"
    tag = "ImFont"


class ImLigature(rx.Component):
    library = "react-icons/im"
    tag = "ImLigature"


class ImLigature2(rx.Component):
    library = "react-icons/im"
    tag = "ImLigature2"


class ImTextHeight(rx.Component):
    library = "react-icons/im"
    tag = "ImTextHeight"


class ImTextWidth(rx.Component):
    library = "react-icons/im"
    tag = "ImTextWidth"


class ImFontSize(rx.Component):
    library = "react-icons/im"
    tag = "ImFontSize"


class ImBold(rx.Component):
    library = "react-icons/im"
    tag = "ImBold"


class ImUnderline(rx.Component):
    library = "react-icons/im"
    tag = "ImUnderline"


class ImItalic(rx.Component):
    library = "react-icons/im"
    tag = "ImItalic"


class ImStrikethrough(rx.Component):
    library = "react-icons/im"
    tag = "ImStrikethrough"


class ImOmega(rx.Component):
    library = "react-icons/im"
    tag = "ImOmega"


class ImSigma(rx.Component):
    library = "react-icons/im"
    tag = "ImSigma"


class ImPageBreak(rx.Component):
    library = "react-icons/im"
    tag = "ImPageBreak"


class ImSuperscript(rx.Component):
    library = "react-icons/im"
    tag = "ImSuperscript"


class ImSubscript(rx.Component):
    library = "react-icons/im"
    tag = "ImSubscript"


class ImSuperscript2(rx.Component):
    library = "react-icons/im"
    tag = "ImSuperscript2"


class ImSubscript2(rx.Component):
    library = "react-icons/im"
    tag = "ImSubscript2"


class ImTextColor(rx.Component):
    library = "react-icons/im"
    tag = "ImTextColor"


class ImPagebreak(rx.Component):
    library = "react-icons/im"
    tag = "ImPagebreak"


class ImClearFormatting(rx.Component):
    library = "react-icons/im"
    tag = "ImClearFormatting"


class ImTable(rx.Component):
    library = "react-icons/im"
    tag = "ImTable"


class ImTable2(rx.Component):
    library = "react-icons/im"
    tag = "ImTable2"


class ImInsertTemplate(rx.Component):
    library = "react-icons/im"
    tag = "ImInsertTemplate"


class ImPilcrow(rx.Component):
    library = "react-icons/im"
    tag = "ImPilcrow"


class ImLtr(rx.Component):
    library = "react-icons/im"
    tag = "ImLtr"


class ImRtl(rx.Component):
    library = "react-icons/im"
    tag = "ImRtl"


class ImSection(rx.Component):
    library = "react-icons/im"
    tag = "ImSection"


class ImParagraphLeft(rx.Component):
    library = "react-icons/im"
    tag = "ImParagraphLeft"


class ImParagraphCenter(rx.Component):
    library = "react-icons/im"
    tag = "ImParagraphCenter"


class ImParagraphRight(rx.Component):
    library = "react-icons/im"
    tag = "ImParagraphRight"


class ImParagraphJustify(rx.Component):
    library = "react-icons/im"
    tag = "ImParagraphJustify"


class ImIndentIncrease(rx.Component):
    library = "react-icons/im"
    tag = "ImIndentIncrease"


class ImIndentDecrease(rx.Component):
    library = "react-icons/im"
    tag = "ImIndentDecrease"


class ImShare(rx.Component):
    library = "react-icons/im"
    tag = "ImShare"


class ImNewTab(rx.Component):
    library = "react-icons/im"
    tag = "ImNewTab"


class ImEmbed(rx.Component):
    library = "react-icons/im"
    tag = "ImEmbed"


class ImEmbed2(rx.Component):
    library = "react-icons/im"
    tag = "ImEmbed2"


class ImTerminal(rx.Component):
    library = "react-icons/im"
    tag = "ImTerminal"


class ImShare2(rx.Component):
    library = "react-icons/im"
    tag = "ImShare2"


class ImMail(rx.Component):
    library = "react-icons/im"
    tag = "ImMail"


class ImMail2(rx.Component):
    library = "react-icons/im"
    tag = "ImMail2"


class ImMail3(rx.Component):
    library = "react-icons/im"
    tag = "ImMail3"


class ImMail4(rx.Component):
    library = "react-icons/im"
    tag = "ImMail4"


class ImAmazon(rx.Component):
    library = "react-icons/im"
    tag = "ImAmazon"


class ImGoogle(rx.Component):
    library = "react-icons/im"
    tag = "ImGoogle"


class ImGoogle2(rx.Component):
    library = "react-icons/im"
    tag = "ImGoogle2"


class ImGoogle3(rx.Component):
    library = "react-icons/im"
    tag = "ImGoogle3"


class ImGooglePlus(rx.Component):
    library = "react-icons/im"
    tag = "ImGooglePlus"


class ImGooglePlus2(rx.Component):
    library = "react-icons/im"
    tag = "ImGooglePlus2"


class ImGooglePlus3(rx.Component):
    library = "react-icons/im"
    tag = "ImGooglePlus3"


class ImHangouts(rx.Component):
    library = "react-icons/im"
    tag = "ImHangouts"


class ImGoogleDrive(rx.Component):
    library = "react-icons/im"
    tag = "ImGoogleDrive"


class ImFacebook(rx.Component):
    library = "react-icons/im"
    tag = "ImFacebook"


class ImFacebook2(rx.Component):
    library = "react-icons/im"
    tag = "ImFacebook2"


class ImInstagram(rx.Component):
    library = "react-icons/im"
    tag = "ImInstagram"


class ImWhatsapp(rx.Component):
    library = "react-icons/im"
    tag = "ImWhatsapp"


class ImSpotify(rx.Component):
    library = "react-icons/im"
    tag = "ImSpotify"


class ImTelegram(rx.Component):
    library = "react-icons/im"
    tag = "ImTelegram"


class ImTwitter(rx.Component):
    library = "react-icons/im"
    tag = "ImTwitter"


class ImVine(rx.Component):
    library = "react-icons/im"
    tag = "ImVine"


class ImVk(rx.Component):
    library = "react-icons/im"
    tag = "ImVk"


class ImRenren(rx.Component):
    library = "react-icons/im"
    tag = "ImRenren"


class ImSinaWeibo(rx.Component):
    library = "react-icons/im"
    tag = "ImSinaWeibo"


class ImRss(rx.Component):
    library = "react-icons/im"
    tag = "ImRss"


class ImRss2(rx.Component):
    library = "react-icons/im"
    tag = "ImRss2"


class ImYoutube(rx.Component):
    library = "react-icons/im"
    tag = "ImYoutube"


class ImYoutube2(rx.Component):
    library = "react-icons/im"
    tag = "ImYoutube2"


class ImTwitch(rx.Component):
    library = "react-icons/im"
    tag = "ImTwitch"


class ImVimeo(rx.Component):
    library = "react-icons/im"
    tag = "ImVimeo"


class ImVimeo2(rx.Component):
    library = "react-icons/im"
    tag = "ImVimeo2"


class ImLanyrd(rx.Component):
    library = "react-icons/im"
    tag = "ImLanyrd"


class ImFlickr(rx.Component):
    library = "react-icons/im"
    tag = "ImFlickr"


class ImFlickr2(rx.Component):
    library = "react-icons/im"
    tag = "ImFlickr2"


class ImFlickr3(rx.Component):
    library = "react-icons/im"
    tag = "ImFlickr3"


class ImFlickr4(rx.Component):
    library = "react-icons/im"
    tag = "ImFlickr4"


class ImDribbble(rx.Component):
    library = "react-icons/im"
    tag = "ImDribbble"


class ImBehance(rx.Component):
    library = "react-icons/im"
    tag = "ImBehance"


class ImBehance2(rx.Component):
    library = "react-icons/im"
    tag = "ImBehance2"


class ImDeviantart(rx.Component):
    library = "react-icons/im"
    tag = "ImDeviantart"


class Im500Px(rx.Component):
    library = "react-icons/im"
    tag = "Im500Px"


class ImSteam(rx.Component):
    library = "react-icons/im"
    tag = "ImSteam"


class ImSteam2(rx.Component):
    library = "react-icons/im"
    tag = "ImSteam2"


class ImDropbox(rx.Component):
    library = "react-icons/im"
    tag = "ImDropbox"


class ImOnedrive(rx.Component):
    library = "react-icons/im"
    tag = "ImOnedrive"


class ImGithub(rx.Component):
    library = "react-icons/im"
    tag = "ImGithub"


class ImNpm(rx.Component):
    library = "react-icons/im"
    tag = "ImNpm"


class ImBasecamp(rx.Component):
    library = "react-icons/im"
    tag = "ImBasecamp"


class ImTrello(rx.Component):
    library = "react-icons/im"
    tag = "ImTrello"


class ImWordpress(rx.Component):
    library = "react-icons/im"
    tag = "ImWordpress"


class ImJoomla(rx.Component):
    library = "react-icons/im"
    tag = "ImJoomla"


class ImEllo(rx.Component):
    library = "react-icons/im"
    tag = "ImEllo"


class ImBlogger(rx.Component):
    library = "react-icons/im"
    tag = "ImBlogger"


class ImBlogger2(rx.Component):
    library = "react-icons/im"
    tag = "ImBlogger2"


class ImTumblr(rx.Component):
    library = "react-icons/im"
    tag = "ImTumblr"


class ImTumblr2(rx.Component):
    library = "react-icons/im"
    tag = "ImTumblr2"


class ImYahoo(rx.Component):
    library = "react-icons/im"
    tag = "ImYahoo"


class ImYahoo2(rx.Component):
    library = "react-icons/im"
    tag = "ImYahoo2"


class ImTux(rx.Component):
    library = "react-icons/im"
    tag = "ImTux"


class ImAppleinc(rx.Component):
    library = "react-icons/im"
    tag = "ImAppleinc"


class ImFinder(rx.Component):
    library = "react-icons/im"
    tag = "ImFinder"


class ImAndroid(rx.Component):
    library = "react-icons/im"
    tag = "ImAndroid"


class ImWindows(rx.Component):
    library = "react-icons/im"
    tag = "ImWindows"


class ImWindows8(rx.Component):
    library = "react-icons/im"
    tag = "ImWindows8"


class ImSoundcloud(rx.Component):
    library = "react-icons/im"
    tag = "ImSoundcloud"


class ImSoundcloud2(rx.Component):
    library = "react-icons/im"
    tag = "ImSoundcloud2"


class ImSkype(rx.Component):
    library = "react-icons/im"
    tag = "ImSkype"


class ImReddit(rx.Component):
    library = "react-icons/im"
    tag = "ImReddit"


class ImHackernews(rx.Component):
    library = "react-icons/im"
    tag = "ImHackernews"


class ImWikipedia(rx.Component):
    library = "react-icons/im"
    tag = "ImWikipedia"


class ImLinkedin(rx.Component):
    library = "react-icons/im"
    tag = "ImLinkedin"


class ImLinkedin2(rx.Component):
    library = "react-icons/im"
    tag = "ImLinkedin2"


class ImLastfm(rx.Component):
    library = "react-icons/im"
    tag = "ImLastfm"


class ImLastfm2(rx.Component):
    library = "react-icons/im"
    tag = "ImLastfm2"


class ImDelicious(rx.Component):
    library = "react-icons/im"
    tag = "ImDelicious"


class ImStumbleupon(rx.Component):
    library = "react-icons/im"
    tag = "ImStumbleupon"


class ImStumbleupon2(rx.Component):
    library = "react-icons/im"
    tag = "ImStumbleupon2"


class ImStackoverflow(rx.Component):
    library = "react-icons/im"
    tag = "ImStackoverflow"


class ImPinterest(rx.Component):
    library = "react-icons/im"
    tag = "ImPinterest"


class ImPinterest2(rx.Component):
    library = "react-icons/im"
    tag = "ImPinterest2"


class ImXing(rx.Component):
    library = "react-icons/im"
    tag = "ImXing"


class ImXing2(rx.Component):
    library = "react-icons/im"
    tag = "ImXing2"


class ImFlattr(rx.Component):
    library = "react-icons/im"
    tag = "ImFlattr"


class ImFoursquare(rx.Component):
    library = "react-icons/im"
    tag = "ImFoursquare"


class ImYelp(rx.Component):
    library = "react-icons/im"
    tag = "ImYelp"


class ImPaypal(rx.Component):
    library = "react-icons/im"
    tag = "ImPaypal"


class ImChrome(rx.Component):
    library = "react-icons/im"
    tag = "ImChrome"


class ImFirefox(rx.Component):
    library = "react-icons/im"
    tag = "ImFirefox"


class ImIe(rx.Component):
    library = "react-icons/im"
    tag = "ImIe"


class ImEdge(rx.Component):
    library = "react-icons/im"
    tag = "ImEdge"


class ImSafari(rx.Component):
    library = "react-icons/im"
    tag = "ImSafari"


class ImOpera(rx.Component):
    library = "react-icons/im"
    tag = "ImOpera"


class ImFilePdf(rx.Component):
    library = "react-icons/im"
    tag = "ImFilePdf"


class ImFileOpenoffice(rx.Component):
    library = "react-icons/im"
    tag = "ImFileOpenoffice"


class ImFileWord(rx.Component):
    library = "react-icons/im"
    tag = "ImFileWord"


class ImFileExcel(rx.Component):
    library = "react-icons/im"
    tag = "ImFileExcel"


class ImLibreoffice(rx.Component):
    library = "react-icons/im"
    tag = "ImLibreoffice"


class ImHtmlFive(rx.Component):
    library = "react-icons/im"
    tag = "ImHtmlFive"


class ImHtmlFive2(rx.Component):
    library = "react-icons/im"
    tag = "ImHtmlFive2"


class ImCss3(rx.Component):
    library = "react-icons/im"
    tag = "ImCss3"


class ImGit(rx.Component):
    library = "react-icons/im"
    tag = "ImGit"


class ImCodepen(rx.Component):
    library = "react-icons/im"
    tag = "ImCodepen"


class ImSvg(rx.Component):
    library = "react-icons/im"
    tag = "ImSvg"


class ImIcoMoon(rx.Component):
    library = "react-icons/im"
    tag = "ImIcoMoon"


