import reflex as rx

class TiAdjustBrightness(rx.Component):
    library = "react-icons/ti"
    tag = "TiAdjustBrightness"


class TiAdjustContrast(rx.Component):
    library = "react-icons/ti"
    tag = "TiAdjustContrast"


class TiAnchorOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiAnchorOutline"


class TiAnchor(rx.Component):
    library = "react-icons/ti"
    tag = "TiAnchor"


class TiArchive(rx.Component):
    library = "react-icons/ti"
    tag = "TiArchive"


class TiArrowBackOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowBackOutline"


class TiArrowBack(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowBack"


class TiArrowDownOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowDownOutline"


class TiArrowDownThick(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowDownThick"


class TiArrowDown(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowDown"


class TiArrowForwardOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowForwardOutline"


class TiArrowForward(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowForward"


class TiArrowLeftOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLeftOutline"


class TiArrowLeftThick(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLeftThick"


class TiArrowLeft(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLeft"


class TiArrowLoopOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLoopOutline"


class TiArrowLoop(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowLoop"


class TiArrowMaximiseOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMaximiseOutline"


class TiArrowMaximise(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMaximise"


class TiArrowMinimiseOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMinimiseOutline"


class TiArrowMinimise(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMinimise"


class TiArrowMoveOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMoveOutline"


class TiArrowMove(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowMove"


class TiArrowRepeatOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRepeatOutline"


class TiArrowRepeat(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRepeat"


class TiArrowRightOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRightOutline"


class TiArrowRightThick(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRightThick"


class TiArrowRight(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowRight"


class TiArrowShuffle(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowShuffle"


class TiArrowSortedDown(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowSortedDown"


class TiArrowSortedUp(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowSortedUp"


class TiArrowSyncOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowSyncOutline"


class TiArrowSync(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowSync"


class TiArrowUnsorted(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowUnsorted"


class TiArrowUpOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowUpOutline"


class TiArrowUpThick(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowUpThick"


class TiArrowUp(rx.Component):
    library = "react-icons/ti"
    tag = "TiArrowUp"


class TiAt(rx.Component):
    library = "react-icons/ti"
    tag = "TiAt"


class TiAttachmentOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiAttachmentOutline"


class TiAttachment(rx.Component):
    library = "react-icons/ti"
    tag = "TiAttachment"


class TiBackspaceOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiBackspaceOutline"


class TiBackspace(rx.Component):
    library = "react-icons/ti"
    tag = "TiBackspace"


class TiBatteryCharge(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryCharge"


class TiBatteryFull(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryFull"


class TiBatteryHigh(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryHigh"


class TiBatteryLow(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryLow"


class TiBatteryMid(rx.Component):
    library = "react-icons/ti"
    tag = "TiBatteryMid"


class TiBeaker(rx.Component):
    library = "react-icons/ti"
    tag = "TiBeaker"


class TiBeer(rx.Component):
    library = "react-icons/ti"
    tag = "TiBeer"


class TiBell(rx.Component):
    library = "react-icons/ti"
    tag = "TiBell"


class TiBook(rx.Component):
    library = "react-icons/ti"
    tag = "TiBook"


class TiBookmark(rx.Component):
    library = "react-icons/ti"
    tag = "TiBookmark"


class TiBriefcase(rx.Component):
    library = "react-icons/ti"
    tag = "TiBriefcase"


class TiBrush(rx.Component):
    library = "react-icons/ti"
    tag = "TiBrush"


class TiBusinessCard(rx.Component):
    library = "react-icons/ti"
    tag = "TiBusinessCard"


class TiCalculator(rx.Component):
    library = "react-icons/ti"
    tag = "TiCalculator"


class TiCalendarOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCalendarOutline"


class TiCalendar(rx.Component):
    library = "react-icons/ti"
    tag = "TiCalendar"


class TiCameraOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCameraOutline"


class TiCamera(rx.Component):
    library = "react-icons/ti"
    tag = "TiCamera"


class TiCancelOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCancelOutline"


class TiCancel(rx.Component):
    library = "react-icons/ti"
    tag = "TiCancel"


class TiChartAreaOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartAreaOutline"


class TiChartArea(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartArea"


class TiChartBarOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartBarOutline"


class TiChartBar(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartBar"


class TiChartLineOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartLineOutline"


class TiChartLine(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartLine"


class TiChartPieOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartPieOutline"


class TiChartPie(rx.Component):
    library = "react-icons/ti"
    tag = "TiChartPie"


class TiChevronLeftOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChevronLeftOutline"


class TiChevronLeft(rx.Component):
    library = "react-icons/ti"
    tag = "TiChevronLeft"


class TiChevronRightOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiChevronRightOutline"


class TiChevronRight(rx.Component):
    library = "react-icons/ti"
    tag = "TiChevronRight"


class TiClipboard(rx.Component):
    library = "react-icons/ti"
    tag = "TiClipboard"


class TiCloudStorageOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCloudStorageOutline"


class TiCloudStorage(rx.Component):
    library = "react-icons/ti"
    tag = "TiCloudStorage"


class TiCodeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCodeOutline"


class TiCode(rx.Component):
    library = "react-icons/ti"
    tag = "TiCode"


class TiCoffee(rx.Component):
    library = "react-icons/ti"
    tag = "TiCoffee"


class TiCogOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiCogOutline"


class TiCog(rx.Component):
    library = "react-icons/ti"
    tag = "TiCog"


class TiCompass(rx.Component):
    library = "react-icons/ti"
    tag = "TiCompass"


class TiContacts(rx.Component):
    library = "react-icons/ti"
    tag = "TiContacts"


class TiCreditCard(rx.Component):
    library = "react-icons/ti"
    tag = "TiCreditCard"


class TiCss3(rx.Component):
    library = "react-icons/ti"
    tag = "TiCss3"


class TiDatabase(rx.Component):
    library = "react-icons/ti"
    tag = "TiDatabase"


class TiDeleteOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiDeleteOutline"


class TiDelete(rx.Component):
    library = "react-icons/ti"
    tag = "TiDelete"


class TiDeviceDesktop(rx.Component):
    library = "react-icons/ti"
    tag = "TiDeviceDesktop"


class TiDeviceLaptop(rx.Component):
    library = "react-icons/ti"
    tag = "TiDeviceLaptop"


class TiDevicePhone(rx.Component):
    library = "react-icons/ti"
    tag = "TiDevicePhone"


class TiDeviceTablet(rx.Component):
    library = "react-icons/ti"
    tag = "TiDeviceTablet"


class TiDirections(rx.Component):
    library = "react-icons/ti"
    tag = "TiDirections"


class TiDivideOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiDivideOutline"


class TiDivide(rx.Component):
    library = "react-icons/ti"
    tag = "TiDivide"


class TiDocumentAdd(rx.Component):
    library = "react-icons/ti"
    tag = "TiDocumentAdd"


class TiDocumentDelete(rx.Component):
    library = "react-icons/ti"
    tag = "TiDocumentDelete"


class TiDocumentText(rx.Component):
    library = "react-icons/ti"
    tag = "TiDocumentText"


class TiDocument(rx.Component):
    library = "react-icons/ti"
    tag = "TiDocument"


class TiDownloadOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiDownloadOutline"


class TiDownload(rx.Component):
    library = "react-icons/ti"
    tag = "TiDownload"


class TiDropbox(rx.Component):
    library = "react-icons/ti"
    tag = "TiDropbox"


class TiEdit(rx.Component):
    library = "react-icons/ti"
    tag = "TiEdit"


class TiEjectOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiEjectOutline"


class TiEject(rx.Component):
    library = "react-icons/ti"
    tag = "TiEject"


class TiEqualsOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiEqualsOutline"


class TiEquals(rx.Component):
    library = "react-icons/ti"
    tag = "TiEquals"


class TiExportOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiExportOutline"


class TiExport(rx.Component):
    library = "react-icons/ti"
    tag = "TiExport"


class TiEyeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiEyeOutline"


class TiEye(rx.Component):
    library = "react-icons/ti"
    tag = "TiEye"


class TiFeather(rx.Component):
    library = "react-icons/ti"
    tag = "TiFeather"


class TiFilm(rx.Component):
    library = "react-icons/ti"
    tag = "TiFilm"


class TiFilter(rx.Component):
    library = "react-icons/ti"
    tag = "TiFilter"


class TiFlagOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlagOutline"


class TiFlag(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlag"


class TiFlashOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlashOutline"


class TiFlash(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlash"


class TiFlowChildren(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlowChildren"


class TiFlowMerge(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlowMerge"


class TiFlowParallel(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlowParallel"


class TiFlowSwitch(rx.Component):
    library = "react-icons/ti"
    tag = "TiFlowSwitch"


class TiFolderAdd(rx.Component):
    library = "react-icons/ti"
    tag = "TiFolderAdd"


class TiFolderDelete(rx.Component):
    library = "react-icons/ti"
    tag = "TiFolderDelete"


class TiFolderOpen(rx.Component):
    library = "react-icons/ti"
    tag = "TiFolderOpen"


class TiFolder(rx.Component):
    library = "react-icons/ti"
    tag = "TiFolder"


class TiGift(rx.Component):
    library = "react-icons/ti"
    tag = "TiGift"


class TiGlobeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiGlobeOutline"


class TiGlobe(rx.Component):
    library = "react-icons/ti"
    tag = "TiGlobe"


class TiGroupOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiGroupOutline"


class TiGroup(rx.Component):
    library = "react-icons/ti"
    tag = "TiGroup"


class TiHeadphones(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeadphones"


class TiHeartFullOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeartFullOutline"


class TiHeartHalfOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeartHalfOutline"


class TiHeartOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeartOutline"


class TiHeart(rx.Component):
    library = "react-icons/ti"
    tag = "TiHeart"


class TiHomeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiHomeOutline"


class TiHome(rx.Component):
    library = "react-icons/ti"
    tag = "TiHome"


class TiHtml5(rx.Component):
    library = "react-icons/ti"
    tag = "TiHtml5"


class TiImageOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiImageOutline"


class TiImage(rx.Component):
    library = "react-icons/ti"
    tag = "TiImage"


class TiInfinityOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfinityOutline"


class TiInfinity(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfinity"


class TiInfoLargeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfoLargeOutline"


class TiInfoLarge(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfoLarge"


class TiInfoOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfoOutline"


class TiInfo(rx.Component):
    library = "react-icons/ti"
    tag = "TiInfo"


class TiInputCheckedOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiInputCheckedOutline"


class TiInputChecked(rx.Component):
    library = "react-icons/ti"
    tag = "TiInputChecked"


class TiKeyOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiKeyOutline"


class TiKey(rx.Component):
    library = "react-icons/ti"
    tag = "TiKey"


class TiKeyboard(rx.Component):
    library = "react-icons/ti"
    tag = "TiKeyboard"


class TiLeaf(rx.Component):
    library = "react-icons/ti"
    tag = "TiLeaf"


class TiLightbulb(rx.Component):
    library = "react-icons/ti"
    tag = "TiLightbulb"


class TiLinkOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLinkOutline"


class TiLink(rx.Component):
    library = "react-icons/ti"
    tag = "TiLink"


class TiLocationArrowOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLocationArrowOutline"


class TiLocationArrow(rx.Component):
    library = "react-icons/ti"
    tag = "TiLocationArrow"


class TiLocationOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLocationOutline"


class TiLocation(rx.Component):
    library = "react-icons/ti"
    tag = "TiLocation"


class TiLockClosedOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLockClosedOutline"


class TiLockClosed(rx.Component):
    library = "react-icons/ti"
    tag = "TiLockClosed"


class TiLockOpenOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiLockOpenOutline"


class TiLockOpen(rx.Component):
    library = "react-icons/ti"
    tag = "TiLockOpen"


class TiMail(rx.Component):
    library = "react-icons/ti"
    tag = "TiMail"


class TiMap(rx.Component):
    library = "react-icons/ti"
    tag = "TiMap"


class TiMediaEjectOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaEjectOutline"


class TiMediaEject(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaEject"


class TiMediaFastForwardOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaFastForwardOutline"


class TiMediaFastForward(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaFastForward"


class TiMediaPauseOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPauseOutline"


class TiMediaPause(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPause"


class TiMediaPlayOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPlayOutline"


class TiMediaPlayReverseOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPlayReverseOutline"


class TiMediaPlayReverse(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPlayReverse"


class TiMediaPlay(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaPlay"


class TiMediaRecordOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaRecordOutline"


class TiMediaRecord(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaRecord"


class TiMediaRewindOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaRewindOutline"


class TiMediaRewind(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaRewind"


class TiMediaStopOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaStopOutline"


class TiMediaStop(rx.Component):
    library = "react-icons/ti"
    tag = "TiMediaStop"


class TiMessageTyping(rx.Component):
    library = "react-icons/ti"
    tag = "TiMessageTyping"


class TiMessage(rx.Component):
    library = "react-icons/ti"
    tag = "TiMessage"


class TiMessages(rx.Component):
    library = "react-icons/ti"
    tag = "TiMessages"


class TiMicrophoneOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMicrophoneOutline"


class TiMicrophone(rx.Component):
    library = "react-icons/ti"
    tag = "TiMicrophone"


class TiMinusOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiMinusOutline"


class TiMinus(rx.Component):
    library = "react-icons/ti"
    tag = "TiMinus"


class TiMortarBoard(rx.Component):
    library = "react-icons/ti"
    tag = "TiMortarBoard"


class TiNews(rx.Component):
    library = "react-icons/ti"
    tag = "TiNews"


class TiNotesOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiNotesOutline"


class TiNotes(rx.Component):
    library = "react-icons/ti"
    tag = "TiNotes"


class TiPen(rx.Component):
    library = "react-icons/ti"
    tag = "TiPen"


class TiPencil(rx.Component):
    library = "react-icons/ti"
    tag = "TiPencil"


class TiPhoneOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPhoneOutline"


class TiPhone(rx.Component):
    library = "react-icons/ti"
    tag = "TiPhone"


class TiPiOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPiOutline"


class TiPi(rx.Component):
    library = "react-icons/ti"
    tag = "TiPi"


class TiPinOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPinOutline"


class TiPin(rx.Component):
    library = "react-icons/ti"
    tag = "TiPin"


class TiPipette(rx.Component):
    library = "react-icons/ti"
    tag = "TiPipette"


class TiPlaneOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlaneOutline"


class TiPlane(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlane"


class TiPlug(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlug"


class TiPlusOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlusOutline"


class TiPlus(rx.Component):
    library = "react-icons/ti"
    tag = "TiPlus"


class TiPointOfInterestOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPointOfInterestOutline"


class TiPointOfInterest(rx.Component):
    library = "react-icons/ti"
    tag = "TiPointOfInterest"


class TiPowerOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPowerOutline"


class TiPower(rx.Component):
    library = "react-icons/ti"
    tag = "TiPower"


class TiPrinter(rx.Component):
    library = "react-icons/ti"
    tag = "TiPrinter"


class TiPuzzleOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiPuzzleOutline"


class TiPuzzle(rx.Component):
    library = "react-icons/ti"
    tag = "TiPuzzle"


class TiRadarOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiRadarOutline"


class TiRadar(rx.Component):
    library = "react-icons/ti"
    tag = "TiRadar"


class TiRefreshOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiRefreshOutline"


class TiRefresh(rx.Component):
    library = "react-icons/ti"
    tag = "TiRefresh"


class TiRssOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiRssOutline"


class TiRss(rx.Component):
    library = "react-icons/ti"
    tag = "TiRss"


class TiScissorsOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiScissorsOutline"


class TiScissors(rx.Component):
    library = "react-icons/ti"
    tag = "TiScissors"


class TiShoppingBag(rx.Component):
    library = "react-icons/ti"
    tag = "TiShoppingBag"


class TiShoppingCart(rx.Component):
    library = "react-icons/ti"
    tag = "TiShoppingCart"


class TiSocialAtCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialAtCircular"


class TiSocialDribbbleCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialDribbbleCircular"


class TiSocialDribbble(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialDribbble"


class TiSocialFacebookCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialFacebookCircular"


class TiSocialFacebook(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialFacebook"


class TiSocialFlickrCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialFlickrCircular"


class TiSocialFlickr(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialFlickr"


class TiSocialGithubCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialGithubCircular"


class TiSocialGithub(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialGithub"


class TiSocialGooglePlusCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialGooglePlusCircular"


class TiSocialGooglePlus(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialGooglePlus"


class TiSocialInstagramCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialInstagramCircular"


class TiSocialInstagram(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialInstagram"


class TiSocialLastFmCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialLastFmCircular"


class TiSocialLastFm(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialLastFm"


class TiSocialLinkedinCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialLinkedinCircular"


class TiSocialLinkedin(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialLinkedin"


class TiSocialPinterestCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialPinterestCircular"


class TiSocialPinterest(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialPinterest"


class TiSocialSkypeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialSkypeOutline"


class TiSocialSkype(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialSkype"


class TiSocialTumblerCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialTumblerCircular"


class TiSocialTumbler(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialTumbler"


class TiSocialTwitterCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialTwitterCircular"


class TiSocialTwitter(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialTwitter"


class TiSocialVimeoCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialVimeoCircular"


class TiSocialVimeo(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialVimeo"


class TiSocialYoutubeCircular(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialYoutubeCircular"


class TiSocialYoutube(rx.Component):
    library = "react-icons/ti"
    tag = "TiSocialYoutube"


class TiSortAlphabeticallyOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiSortAlphabeticallyOutline"


class TiSortAlphabetically(rx.Component):
    library = "react-icons/ti"
    tag = "TiSortAlphabetically"


class TiSortNumericallyOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiSortNumericallyOutline"


class TiSortNumerically(rx.Component):
    library = "react-icons/ti"
    tag = "TiSortNumerically"


class TiSpannerOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiSpannerOutline"


class TiSpanner(rx.Component):
    library = "react-icons/ti"
    tag = "TiSpanner"


class TiSpiral(rx.Component):
    library = "react-icons/ti"
    tag = "TiSpiral"


class TiStarFullOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarFullOutline"


class TiStarHalfOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarHalfOutline"


class TiStarHalf(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarHalf"


class TiStarOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarOutline"


class TiStar(rx.Component):
    library = "react-icons/ti"
    tag = "TiStar"


class TiStarburstOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarburstOutline"


class TiStarburst(rx.Component):
    library = "react-icons/ti"
    tag = "TiStarburst"


class TiStopwatch(rx.Component):
    library = "react-icons/ti"
    tag = "TiStopwatch"


class TiSupport(rx.Component):
    library = "react-icons/ti"
    tag = "TiSupport"


class TiTabsOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiTabsOutline"


class TiTag(rx.Component):
    library = "react-icons/ti"
    tag = "TiTag"


class TiTags(rx.Component):
    library = "react-icons/ti"
    tag = "TiTags"


class TiThLargeOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiThLargeOutline"


class TiThLarge(rx.Component):
    library = "react-icons/ti"
    tag = "TiThLarge"


class TiThListOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiThListOutline"


class TiThList(rx.Component):
    library = "react-icons/ti"
    tag = "TiThList"


class TiThMenuOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiThMenuOutline"


class TiThMenu(rx.Component):
    library = "react-icons/ti"
    tag = "TiThMenu"


class TiThSmallOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiThSmallOutline"


class TiThSmall(rx.Component):
    library = "react-icons/ti"
    tag = "TiThSmall"


class TiThermometer(rx.Component):
    library = "react-icons/ti"
    tag = "TiThermometer"


class TiThumbsDown(rx.Component):
    library = "react-icons/ti"
    tag = "TiThumbsDown"


class TiThumbsOk(rx.Component):
    library = "react-icons/ti"
    tag = "TiThumbsOk"


class TiThumbsUp(rx.Component):
    library = "react-icons/ti"
    tag = "TiThumbsUp"


class TiTickOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiTickOutline"


class TiTick(rx.Component):
    library = "react-icons/ti"
    tag = "TiTick"


class TiTicket(rx.Component):
    library = "react-icons/ti"
    tag = "TiTicket"


class TiTime(rx.Component):
    library = "react-icons/ti"
    tag = "TiTime"


class TiTimesOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiTimesOutline"


class TiTimes(rx.Component):
    library = "react-icons/ti"
    tag = "TiTimes"


class TiTrash(rx.Component):
    library = "react-icons/ti"
    tag = "TiTrash"


class TiTree(rx.Component):
    library = "react-icons/ti"
    tag = "TiTree"


class TiUploadOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiUploadOutline"


class TiUpload(rx.Component):
    library = "react-icons/ti"
    tag = "TiUpload"


class TiUserAddOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserAddOutline"


class TiUserAdd(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserAdd"


class TiUserDeleteOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserDeleteOutline"


class TiUserDelete(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserDelete"


class TiUserOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiUserOutline"


class TiUser(rx.Component):
    library = "react-icons/ti"
    tag = "TiUser"


class TiVendorAndroid(rx.Component):
    library = "react-icons/ti"
    tag = "TiVendorAndroid"


class TiVendorApple(rx.Component):
    library = "react-icons/ti"
    tag = "TiVendorApple"


class TiVendorMicrosoft(rx.Component):
    library = "react-icons/ti"
    tag = "TiVendorMicrosoft"


class TiVideoOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiVideoOutline"


class TiVideo(rx.Component):
    library = "react-icons/ti"
    tag = "TiVideo"


class TiVolumeDown(rx.Component):
    library = "react-icons/ti"
    tag = "TiVolumeDown"


class TiVolumeMute(rx.Component):
    library = "react-icons/ti"
    tag = "TiVolumeMute"


class TiVolumeUp(rx.Component):
    library = "react-icons/ti"
    tag = "TiVolumeUp"


class TiVolume(rx.Component):
    library = "react-icons/ti"
    tag = "TiVolume"


class TiWarningOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiWarningOutline"


class TiWarning(rx.Component):
    library = "react-icons/ti"
    tag = "TiWarning"


class TiWatch(rx.Component):
    library = "react-icons/ti"
    tag = "TiWatch"


class TiWavesOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiWavesOutline"


class TiWaves(rx.Component):
    library = "react-icons/ti"
    tag = "TiWaves"


class TiWeatherCloudy(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherCloudy"


class TiWeatherDownpour(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherDownpour"


class TiWeatherNight(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherNight"


class TiWeatherPartlySunny(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherPartlySunny"


class TiWeatherShower(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherShower"


class TiWeatherSnow(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherSnow"


class TiWeatherStormy(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherStormy"


class TiWeatherSunny(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherSunny"


class TiWeatherWindyCloudy(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherWindyCloudy"


class TiWeatherWindy(rx.Component):
    library = "react-icons/ti"
    tag = "TiWeatherWindy"


class TiWiFiOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiWiFiOutline"


class TiWiFi(rx.Component):
    library = "react-icons/ti"
    tag = "TiWiFi"


class TiWine(rx.Component):
    library = "react-icons/ti"
    tag = "TiWine"


class TiWorldOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiWorldOutline"


class TiWorld(rx.Component):
    library = "react-icons/ti"
    tag = "TiWorld"


class TiZoomInOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomInOutline"


class TiZoomIn(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomIn"


class TiZoomOutOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomOutOutline"


class TiZoomOut(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomOut"


class TiZoomOutline(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoomOutline"


class TiZoom(rx.Component):
    library = "react-icons/ti"
    tag = "TiZoom"


