import reflex as rx

class CgAbstract(rx.Component):
    library = "react-icons/cg"
    tag = "CgAbstract"


class CgAddR(rx.Component):
    library = "react-icons/cg"
    tag = "CgAddR"


class CgAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgAdd"


class CgAdidas(rx.Component):
    library = "react-icons/cg"
    tag = "CgAdidas"


class CgAirplane(rx.Component):
    library = "react-icons/cg"
    tag = "CgAirplane"


class CgAlarm(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlarm"


class CgAlbum(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlbum"


class CgAlignBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignBottom"


class CgAlignCenter(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignCenter"


class CgAlignLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignLeft"


class CgAlignMiddle(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignMiddle"


class CgAlignRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignRight"


class CgAlignTop(rx.Component):
    library = "react-icons/cg"
    tag = "CgAlignTop"


class CgAnchor(rx.Component):
    library = "react-icons/cg"
    tag = "CgAnchor"


class CgAppleWatch(rx.Component):
    library = "react-icons/cg"
    tag = "CgAppleWatch"


class CgArrangeBack(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrangeBack"


class CgArrangeFront(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrangeFront"


class CgArrowAlignH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowAlignH"


class CgArrowAlignV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowAlignV"


class CgArrowBottomLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomLeftO"


class CgArrowBottomLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomLeftR"


class CgArrowBottomLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomLeft"


class CgArrowBottomRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomRightO"


class CgArrowBottomRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomRightR"


class CgArrowBottomRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowBottomRight"


class CgArrowDownO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowDownO"


class CgArrowDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowDownR"


class CgArrowDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowDown"


class CgArrowLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLeftO"


class CgArrowLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLeftR"


class CgArrowLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLeft"


class CgArrowLongDownC(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDownC"


class CgArrowLongDownE(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDownE"


class CgArrowLongDownL(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDownL"


class CgArrowLongDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDownR"


class CgArrowLongDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongDown"


class CgArrowLongLeftC(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeftC"


class CgArrowLongLeftE(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeftE"


class CgArrowLongLeftL(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeftL"


class CgArrowLongLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeftR"


class CgArrowLongLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongLeft"


class CgArrowLongRightC(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRightC"


class CgArrowLongRightE(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRightE"


class CgArrowLongRightL(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRightL"


class CgArrowLongRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRightR"


class CgArrowLongRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongRight"


class CgArrowLongUpC(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUpC"


class CgArrowLongUpE(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUpE"


class CgArrowLongUpL(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUpL"


class CgArrowLongUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUpR"


class CgArrowLongUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowLongUp"


class CgArrowRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowRightO"


class CgArrowRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowRightR"


class CgArrowRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowRight"


class CgArrowTopLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopLeftO"


class CgArrowTopLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopLeftR"


class CgArrowTopLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopLeft"


class CgArrowTopRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopRightO"


class CgArrowTopRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopRightR"


class CgArrowTopRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowTopRight"


class CgArrowUpO(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowUpO"


class CgArrowUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowUpR"


class CgArrowUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowUp"


class CgArrowsBreakeH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsBreakeH"


class CgArrowsBreakeV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsBreakeV"


class CgArrowsExchangeAltV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExchangeAltV"


class CgArrowsExchangeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExchangeAlt"


class CgArrowsExchangeV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExchangeV"


class CgArrowsExchange(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExchange"


class CgArrowsExpandDownLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandDownLeft"


class CgArrowsExpandDownRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandDownRight"


class CgArrowsExpandLeftAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandLeftAlt"


class CgArrowsExpandLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandLeft"


class CgArrowsExpandRightAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandRightAlt"


class CgArrowsExpandRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandRight"


class CgArrowsExpandUpLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandUpLeft"


class CgArrowsExpandUpRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsExpandUpRight"


class CgArrowsHAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsHAlt"


class CgArrowsH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsH"


class CgArrowsMergeAltH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsMergeAltH"


class CgArrowsMergeAltV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsMergeAltV"


class CgArrowsScrollH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsScrollH"


class CgArrowsScrollV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsScrollV"


class CgArrowsShrinkH(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsShrinkH"


class CgArrowsShrinkV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsShrinkV"


class CgArrowsVAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsVAlt"


class CgArrowsV(rx.Component):
    library = "react-icons/cg"
    tag = "CgArrowsV"


class CgAssign(rx.Component):
    library = "react-icons/cg"
    tag = "CgAssign"


class CgAsterisk(rx.Component):
    library = "react-icons/cg"
    tag = "CgAsterisk"


class CgAtlasian(rx.Component):
    library = "react-icons/cg"
    tag = "CgAtlasian"


class CgAttachment(rx.Component):
    library = "react-icons/cg"
    tag = "CgAttachment"


class CgAttribution(rx.Component):
    library = "react-icons/cg"
    tag = "CgAttribution"


class CgAwards(rx.Component):
    library = "react-icons/cg"
    tag = "CgAwards"


class CgBackspace(rx.Component):
    library = "react-icons/cg"
    tag = "CgBackspace"


class CgBandAid(rx.Component):
    library = "react-icons/cg"
    tag = "CgBandAid"


class CgBatteryEmpty(rx.Component):
    library = "react-icons/cg"
    tag = "CgBatteryEmpty"


class CgBatteryFull(rx.Component):
    library = "react-icons/cg"
    tag = "CgBatteryFull"


class CgBattery(rx.Component):
    library = "react-icons/cg"
    tag = "CgBattery"


class CgBee(rx.Component):
    library = "react-icons/cg"
    tag = "CgBee"


class CgBell(rx.Component):
    library = "react-icons/cg"
    tag = "CgBell"


class CgBitbucket(rx.Component):
    library = "react-icons/cg"
    tag = "CgBitbucket"


class CgBlock(rx.Component):
    library = "react-icons/cg"
    tag = "CgBlock"


class CgBmw(rx.Component):
    library = "react-icons/cg"
    tag = "CgBmw"


class CgBoard(rx.Component):
    library = "react-icons/cg"
    tag = "CgBoard"


class CgBolt(rx.Component):
    library = "react-icons/cg"
    tag = "CgBolt"


class CgBookmark(rx.Component):
    library = "react-icons/cg"
    tag = "CgBookmark"


class CgBorderAll(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderAll"


class CgBorderBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderBottom"


class CgBorderLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderLeft"


class CgBorderRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderRight"


class CgBorderStyleDashed(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderStyleDashed"


class CgBorderStyleDotted(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderStyleDotted"


class CgBorderStyleSolid(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderStyleSolid"


class CgBorderTop(rx.Component):
    library = "react-icons/cg"
    tag = "CgBorderTop"


class CgBot(rx.Component):
    library = "react-icons/cg"
    tag = "CgBot"


class CgBowl(rx.Component):
    library = "react-icons/cg"
    tag = "CgBowl"


class CgBox(rx.Component):
    library = "react-icons/cg"
    tag = "CgBox"


class CgBoy(rx.Component):
    library = "react-icons/cg"
    tag = "CgBoy"


class CgBrackets(rx.Component):
    library = "react-icons/cg"
    tag = "CgBrackets"


class CgBriefcase(rx.Component):
    library = "react-icons/cg"
    tag = "CgBriefcase"


class CgBrowse(rx.Component):
    library = "react-icons/cg"
    tag = "CgBrowse"


class CgBrowser(rx.Component):
    library = "react-icons/cg"
    tag = "CgBrowser"


class CgBrush(rx.Component):
    library = "react-icons/cg"
    tag = "CgBrush"


class CgBulb(rx.Component):
    library = "react-icons/cg"
    tag = "CgBulb"


class CgCPlusPlus(rx.Component):
    library = "react-icons/cg"
    tag = "CgCPlusPlus"


class CgCalculator(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalculator"


class CgCalendarDates(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarDates"


class CgCalendarDue(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarDue"


class CgCalendarNext(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarNext"


class CgCalendarToday(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarToday"


class CgCalendarTwo(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendarTwo"


class CgCalendar(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalendar"


class CgCalibrate(rx.Component):
    library = "react-icons/cg"
    tag = "CgCalibrate"


class CgCamera(rx.Component):
    library = "react-icons/cg"
    tag = "CgCamera"


class CgCap(rx.Component):
    library = "react-icons/cg"
    tag = "CgCap"


class CgCaptions(rx.Component):
    library = "react-icons/cg"
    tag = "CgCaptions"


class CgCardClubs(rx.Component):
    library = "react-icons/cg"
    tag = "CgCardClubs"


class CgCardDiamonds(rx.Component):
    library = "react-icons/cg"
    tag = "CgCardDiamonds"


class CgCardHearts(rx.Component):
    library = "react-icons/cg"
    tag = "CgCardHearts"


class CgCardSpades(rx.Component):
    library = "react-icons/cg"
    tag = "CgCardSpades"


class CgCarousel(rx.Component):
    library = "react-icons/cg"
    tag = "CgCarousel"


class CgCast(rx.Component):
    library = "react-icons/cg"
    tag = "CgCast"


class CgChanel(rx.Component):
    library = "react-icons/cg"
    tag = "CgChanel"


class CgChart(rx.Component):
    library = "react-icons/cg"
    tag = "CgChart"


class CgCheckO(rx.Component):
    library = "react-icons/cg"
    tag = "CgCheckO"


class CgCheckR(rx.Component):
    library = "react-icons/cg"
    tag = "CgCheckR"


class CgCheck(rx.Component):
    library = "react-icons/cg"
    tag = "CgCheck"


class CgChevronDoubleDownO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleDownO"


class CgChevronDoubleDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleDownR"


class CgChevronDoubleDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleDown"


class CgChevronDoubleLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleLeftO"


class CgChevronDoubleLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleLeftR"


class CgChevronDoubleLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleLeft"


class CgChevronDoubleRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleRightO"


class CgChevronDoubleRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleRightR"


class CgChevronDoubleRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleRight"


class CgChevronDoubleUpO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleUpO"


class CgChevronDoubleUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleUpR"


class CgChevronDoubleUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDoubleUp"


class CgChevronDownO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDownO"


class CgChevronDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDownR"


class CgChevronDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronDown"


class CgChevronLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronLeftO"


class CgChevronLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronLeftR"


class CgChevronLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronLeft"


class CgChevronRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronRightO"


class CgChevronRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronRightR"


class CgChevronRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronRight"


class CgChevronUpO(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronUpO"


class CgChevronUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronUpR"


class CgChevronUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgChevronUp"


class CgCircleci(rx.Component):
    library = "react-icons/cg"
    tag = "CgCircleci"


class CgClapperBoard(rx.Component):
    library = "react-icons/cg"
    tag = "CgClapperBoard"


class CgClipboard(rx.Component):
    library = "react-icons/cg"
    tag = "CgClipboard"


class CgCloseO(rx.Component):
    library = "react-icons/cg"
    tag = "CgCloseO"


class CgCloseR(rx.Component):
    library = "react-icons/cg"
    tag = "CgCloseR"


class CgClose(rx.Component):
    library = "react-icons/cg"
    tag = "CgClose"


class CgCloud(rx.Component):
    library = "react-icons/cg"
    tag = "CgCloud"


class CgCodeClimate(rx.Component):
    library = "react-icons/cg"
    tag = "CgCodeClimate"


class CgCodeSlash(rx.Component):
    library = "react-icons/cg"
    tag = "CgCodeSlash"


class CgCode(rx.Component):
    library = "react-icons/cg"
    tag = "CgCode"


class CgCoffee(rx.Component):
    library = "react-icons/cg"
    tag = "CgCoffee"


class CgCollage(rx.Component):
    library = "react-icons/cg"
    tag = "CgCollage"


class CgColorBucket(rx.Component):
    library = "react-icons/cg"
    tag = "CgColorBucket"


class CgColorPicker(rx.Component):
    library = "react-icons/cg"
    tag = "CgColorPicker"


class CgComedyCentral(rx.Component):
    library = "react-icons/cg"
    tag = "CgComedyCentral"


class CgComment(rx.Component):
    library = "react-icons/cg"
    tag = "CgComment"


class CgCommunity(rx.Component):
    library = "react-icons/cg"
    tag = "CgCommunity"


class CgComponents(rx.Component):
    library = "react-icons/cg"
    tag = "CgComponents"


class CgCompressLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCompressLeft"


class CgCompressRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCompressRight"


class CgCompressV(rx.Component):
    library = "react-icons/cg"
    tag = "CgCompressV"


class CgCompress(rx.Component):
    library = "react-icons/cg"
    tag = "CgCompress"


class CgController(rx.Component):
    library = "react-icons/cg"
    tag = "CgController"


class CgCopy(rx.Component):
    library = "react-icons/cg"
    tag = "CgCopy"


class CgCopyright(rx.Component):
    library = "react-icons/cg"
    tag = "CgCopyright"


class CgCornerDoubleDownLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleDownLeft"


class CgCornerDoubleDownRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleDownRight"


class CgCornerDoubleLeftDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleLeftDown"


class CgCornerDoubleLeftUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleLeftUp"


class CgCornerDoubleRightDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleRightDown"


class CgCornerDoubleRightUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleRightUp"


class CgCornerDoubleUpLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleUpLeft"


class CgCornerDoubleUpRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDoubleUpRight"


class CgCornerDownLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDownLeft"


class CgCornerDownRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerDownRight"


class CgCornerLeftDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerLeftDown"


class CgCornerLeftUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerLeftUp"


class CgCornerRightDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerRightDown"


class CgCornerRightUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerRightUp"


class CgCornerUpLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerUpLeft"


class CgCornerUpRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgCornerUpRight"


class CgCreditCard(rx.Component):
    library = "react-icons/cg"
    tag = "CgCreditCard"


class CgCrop(rx.Component):
    library = "react-icons/cg"
    tag = "CgCrop"


class CgCross(rx.Component):
    library = "react-icons/cg"
    tag = "CgCross"


class CgCrowdfire(rx.Component):
    library = "react-icons/cg"
    tag = "CgCrowdfire"


class CgCrown(rx.Component):
    library = "react-icons/cg"
    tag = "CgCrown"


class CgDanger(rx.Component):
    library = "react-icons/cg"
    tag = "CgDanger"


class CgDarkMode(rx.Component):
    library = "react-icons/cg"
    tag = "CgDarkMode"


class CgData(rx.Component):
    library = "react-icons/cg"
    tag = "CgData"


class CgDatabase(rx.Component):
    library = "react-icons/cg"
    tag = "CgDatabase"


class CgDebug(rx.Component):
    library = "react-icons/cg"
    tag = "CgDebug"


class CgDesignmodo(rx.Component):
    library = "react-icons/cg"
    tag = "CgDesignmodo"


class CgDesktop(rx.Component):
    library = "react-icons/cg"
    tag = "CgDesktop"


class CgDetailsLess(rx.Component):
    library = "react-icons/cg"
    tag = "CgDetailsLess"


class CgDetailsMore(rx.Component):
    library = "react-icons/cg"
    tag = "CgDetailsMore"


class CgDialpad(rx.Component):
    library = "react-icons/cg"
    tag = "CgDialpad"


class CgDice1(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice1"


class CgDice2(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice2"


class CgDice3(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice3"


class CgDice4(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice4"


class CgDice5(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice5"


class CgDice6(rx.Component):
    library = "react-icons/cg"
    tag = "CgDice6"


class CgDigitalocean(rx.Component):
    library = "react-icons/cg"
    tag = "CgDigitalocean"


class CgDisc(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisc"


class CgDisplayFlex(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisplayFlex"


class CgDisplayFullwidth(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisplayFullwidth"


class CgDisplayGrid(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisplayGrid"


class CgDisplaySpacing(rx.Component):
    library = "react-icons/cg"
    tag = "CgDisplaySpacing"


class CgDistributeHorizontal(rx.Component):
    library = "react-icons/cg"
    tag = "CgDistributeHorizontal"


class CgDistributeVertical(rx.Component):
    library = "react-icons/cg"
    tag = "CgDistributeVertical"


class CgDockBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgDockBottom"


class CgDockLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgDockLeft"


class CgDockRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgDockRight"


class CgDockWindow(rx.Component):
    library = "react-icons/cg"
    tag = "CgDockWindow"


class CgDolby(rx.Component):
    library = "react-icons/cg"
    tag = "CgDolby"


class CgDollar(rx.Component):
    library = "react-icons/cg"
    tag = "CgDollar"


class CgDribbble(rx.Component):
    library = "react-icons/cg"
    tag = "CgDribbble"


class CgDrive(rx.Component):
    library = "react-icons/cg"
    tag = "CgDrive"


class CgDropInvert(rx.Component):
    library = "react-icons/cg"
    tag = "CgDropInvert"


class CgDropOpacity(rx.Component):
    library = "react-icons/cg"
    tag = "CgDropOpacity"


class CgDrop(rx.Component):
    library = "react-icons/cg"
    tag = "CgDrop"


class CgDuplicate(rx.Component):
    library = "react-icons/cg"
    tag = "CgDuplicate"


class CgEditBlackPoint(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditBlackPoint"


class CgEditContrast(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditContrast"


class CgEditExposure(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditExposure"


class CgEditFade(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditFade"


class CgEditFlipH(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditFlipH"


class CgEditFlipV(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditFlipV"


class CgEditHighlight(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditHighlight"


class CgEditMarkup(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditMarkup"


class CgEditMask(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditMask"


class CgEditNoise(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditNoise"


class CgEditShadows(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditShadows"


class CgEditStraight(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditStraight"


class CgEditUnmask(rx.Component):
    library = "react-icons/cg"
    tag = "CgEditUnmask"


class CgEject(rx.Component):
    library = "react-icons/cg"
    tag = "CgEject"


class CgEnter(rx.Component):
    library = "react-icons/cg"
    tag = "CgEnter"


class CgErase(rx.Component):
    library = "react-icons/cg"
    tag = "CgErase"


class CgEreader(rx.Component):
    library = "react-icons/cg"
    tag = "CgEreader"


class CgEricsson(rx.Component):
    library = "react-icons/cg"
    tag = "CgEricsson"


class CgEthernet(rx.Component):
    library = "react-icons/cg"
    tag = "CgEthernet"


class CgEuro(rx.Component):
    library = "react-icons/cg"
    tag = "CgEuro"


class CgEventbrite(rx.Component):
    library = "react-icons/cg"
    tag = "CgEventbrite"


class CgExpand(rx.Component):
    library = "react-icons/cg"
    tag = "CgExpand"


class CgExport(rx.Component):
    library = "react-icons/cg"
    tag = "CgExport"


class CgExtensionAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgExtensionAdd"


class CgExtensionAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgExtensionAlt"


class CgExtensionRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgExtensionRemove"


class CgExtension(rx.Component):
    library = "react-icons/cg"
    tag = "CgExtension"


class CgExternal(rx.Component):
    library = "react-icons/cg"
    tag = "CgExternal"


class CgEyeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgEyeAlt"


class CgEye(rx.Component):
    library = "react-icons/cg"
    tag = "CgEye"


class CgFacebook(rx.Component):
    library = "react-icons/cg"
    tag = "CgFacebook"


class CgFeed(rx.Component):
    library = "react-icons/cg"
    tag = "CgFeed"


class CgFigma(rx.Component):
    library = "react-icons/cg"
    tag = "CgFigma"


class CgFileAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgFileAdd"


class CgFileDocument(rx.Component):
    library = "react-icons/cg"
    tag = "CgFileDocument"


class CgFileRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgFileRemove"


class CgFile(rx.Component):
    library = "react-icons/cg"
    tag = "CgFile"


class CgFilm(rx.Component):
    library = "react-icons/cg"
    tag = "CgFilm"


class CgFilters(rx.Component):
    library = "react-icons/cg"
    tag = "CgFilters"


class CgFlagAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgFlagAlt"


class CgFlag(rx.Component):
    library = "react-icons/cg"
    tag = "CgFlag"


class CgFolderAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgFolderAdd"


class CgFolderRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgFolderRemove"


class CgFolder(rx.Component):
    library = "react-icons/cg"
    tag = "CgFolder"


class CgFontHeight(rx.Component):
    library = "react-icons/cg"
    tag = "CgFontHeight"


class CgFontSpacing(rx.Component):
    library = "react-icons/cg"
    tag = "CgFontSpacing"


class CgFormatBold(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatBold"


class CgFormatCenter(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatCenter"


class CgFormatColor(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatColor"


class CgFormatHeading(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatHeading"


class CgFormatIndentDecrease(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatIndentDecrease"


class CgFormatIndentIncrease(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatIndentIncrease"


class CgFormatItalic(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatItalic"


class CgFormatJustify(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatJustify"


class CgFormatLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatLeft"


class CgFormatLineHeight(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatLineHeight"


class CgFormatRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatRight"


class CgFormatSeparator(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatSeparator"


class CgFormatSlash(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatSlash"


class CgFormatStrike(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatStrike"


class CgFormatText(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatText"


class CgFormatUnderline(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatUnderline"


class CgFormatUppercase(rx.Component):
    library = "react-icons/cg"
    tag = "CgFormatUppercase"


class CgFramer(rx.Component):
    library = "react-icons/cg"
    tag = "CgFramer"


class CgGames(rx.Component):
    library = "react-icons/cg"
    tag = "CgGames"


class CgGenderFemale(rx.Component):
    library = "react-icons/cg"
    tag = "CgGenderFemale"


class CgGenderMale(rx.Component):
    library = "react-icons/cg"
    tag = "CgGenderMale"


class CgGhostCharacter(rx.Component):
    library = "react-icons/cg"
    tag = "CgGhostCharacter"


class CgGhost(rx.Component):
    library = "react-icons/cg"
    tag = "CgGhost"


class CgGift(rx.Component):
    library = "react-icons/cg"
    tag = "CgGift"


class CgGirl(rx.Component):
    library = "react-icons/cg"
    tag = "CgGirl"


class CgGitBranch(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitBranch"


class CgGitCommit(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitCommit"


class CgGitFork(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitFork"


class CgGitPull(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitPull"


class CgGitter(rx.Component):
    library = "react-icons/cg"
    tag = "CgGitter"


class CgGlassAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgGlassAlt"


class CgGlass(rx.Component):
    library = "react-icons/cg"
    tag = "CgGlass"


class CgGlobeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgGlobeAlt"


class CgGlobe(rx.Component):
    library = "react-icons/cg"
    tag = "CgGlobe"


class CgGoogleTasks(rx.Component):
    library = "react-icons/cg"
    tag = "CgGoogleTasks"


class CgGoogle(rx.Component):
    library = "react-icons/cg"
    tag = "CgGoogle"


class CgGym(rx.Component):
    library = "react-icons/cg"
    tag = "CgGym"


class CgHashtag(rx.Component):
    library = "react-icons/cg"
    tag = "CgHashtag"


class CgHeadset(rx.Component):
    library = "react-icons/cg"
    tag = "CgHeadset"


class CgHeart(rx.Component):
    library = "react-icons/cg"
    tag = "CgHeart"


class CgHello(rx.Component):
    library = "react-icons/cg"
    tag = "CgHello"


class CgHomeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgHomeAlt"


class CgHomeScreen(rx.Component):
    library = "react-icons/cg"
    tag = "CgHomeScreen"


class CgHome(rx.Component):
    library = "react-icons/cg"
    tag = "CgHome"


class CgIcecream(rx.Component):
    library = "react-icons/cg"
    tag = "CgIcecream"


class CgIfDesign(rx.Component):
    library = "react-icons/cg"
    tag = "CgIfDesign"


class CgImage(rx.Component):
    library = "react-icons/cg"
    tag = "CgImage"


class CgImport(rx.Component):
    library = "react-icons/cg"
    tag = "CgImport"


class CgInbox(rx.Component):
    library = "react-icons/cg"
    tag = "CgInbox"


class CgIndieHackers(rx.Component):
    library = "react-icons/cg"
    tag = "CgIndieHackers"


class CgInfinity(rx.Component):
    library = "react-icons/cg"
    tag = "CgInfinity"


class CgInfo(rx.Component):
    library = "react-icons/cg"
    tag = "CgInfo"


class CgInpicture(rx.Component):
    library = "react-icons/cg"
    tag = "CgInpicture"


class CgInsertAfterO(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertAfterO"


class CgInsertAfterR(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertAfterR"


class CgInsertAfter(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertAfter"


class CgInsertBeforeO(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertBeforeO"


class CgInsertBeforeR(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertBeforeR"


class CgInsertBefore(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsertBefore"


class CgInsights(rx.Component):
    library = "react-icons/cg"
    tag = "CgInsights"


class CgInstagram(rx.Component):
    library = "react-icons/cg"
    tag = "CgInstagram"


class CgInternal(rx.Component):
    library = "react-icons/cg"
    tag = "CgInternal"


class CgKey(rx.Component):
    library = "react-icons/cg"
    tag = "CgKey"


class CgKeyboard(rx.Component):
    library = "react-icons/cg"
    tag = "CgKeyboard"


class CgKeyhole(rx.Component):
    library = "react-icons/cg"
    tag = "CgKeyhole"


class CgLaptop(rx.Component):
    library = "react-icons/cg"
    tag = "CgLaptop"


class CgLastpass(rx.Component):
    library = "react-icons/cg"
    tag = "CgLastpass"


class CgLayoutGridSmall(rx.Component):
    library = "react-icons/cg"
    tag = "CgLayoutGridSmall"


class CgLayoutGrid(rx.Component):
    library = "react-icons/cg"
    tag = "CgLayoutGrid"


class CgLayoutList(rx.Component):
    library = "react-icons/cg"
    tag = "CgLayoutList"


class CgLayoutPin(rx.Component):
    library = "react-icons/cg"
    tag = "CgLayoutPin"


class CgLinear(rx.Component):
    library = "react-icons/cg"
    tag = "CgLinear"


class CgLink(rx.Component):
    library = "react-icons/cg"
    tag = "CgLink"


class CgListTree(rx.Component):
    library = "react-icons/cg"
    tag = "CgListTree"


class CgList(rx.Component):
    library = "react-icons/cg"
    tag = "CgList"


class CgLivePhoto(rx.Component):
    library = "react-icons/cg"
    tag = "CgLivePhoto"


class CgLoadbarAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoadbarAlt"


class CgLoadbarDoc(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoadbarDoc"


class CgLoadbarSound(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoadbarSound"


class CgLoadbar(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoadbar"


class CgLockUnlock(rx.Component):
    library = "react-icons/cg"
    tag = "CgLockUnlock"


class CgLock(rx.Component):
    library = "react-icons/cg"
    tag = "CgLock"


class CgLogIn(rx.Component):
    library = "react-icons/cg"
    tag = "CgLogIn"


class CgLogOff(rx.Component):
    library = "react-icons/cg"
    tag = "CgLogOff"


class CgLogOut(rx.Component):
    library = "react-icons/cg"
    tag = "CgLogOut"


class CgLoupe(rx.Component):
    library = "react-icons/cg"
    tag = "CgLoupe"


class CgMagnet(rx.Component):
    library = "react-icons/cg"
    tag = "CgMagnet"


class CgMailForward(rx.Component):
    library = "react-icons/cg"
    tag = "CgMailForward"


class CgMailOpen(rx.Component):
    library = "react-icons/cg"
    tag = "CgMailOpen"


class CgMailReply(rx.Component):
    library = "react-icons/cg"
    tag = "CgMailReply"


class CgMail(rx.Component):
    library = "react-icons/cg"
    tag = "CgMail"


class CgMathDivide(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathDivide"


class CgMathEqual(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathEqual"


class CgMathMinus(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathMinus"


class CgMathPercent(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathPercent"


class CgMathPlus(rx.Component):
    library = "react-icons/cg"
    tag = "CgMathPlus"


class CgMaximizeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMaximizeAlt"


class CgMaximize(rx.Component):
    library = "react-icons/cg"
    tag = "CgMaximize"


class CgMaze(rx.Component):
    library = "react-icons/cg"
    tag = "CgMaze"


class CgMediaLive(rx.Component):
    library = "react-icons/cg"
    tag = "CgMediaLive"


class CgMediaPodcast(rx.Component):
    library = "react-icons/cg"
    tag = "CgMediaPodcast"


class CgMenuBoxed(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuBoxed"


class CgMenuCake(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuCake"


class CgMenuCheese(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuCheese"


class CgMenuGridO(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuGridO"


class CgMenuGridR(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuGridR"


class CgMenuHotdog(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuHotdog"


class CgMenuLeftAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuLeftAlt"


class CgMenuLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuLeft"


class CgMenuMotion(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuMotion"


class CgMenuOreos(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuOreos"


class CgMenuRightAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuRightAlt"


class CgMenuRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuRight"


class CgMenuRound(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenuRound"


class CgMenu(rx.Component):
    library = "react-icons/cg"
    tag = "CgMenu"


class CgMergeHorizontal(rx.Component):
    library = "react-icons/cg"
    tag = "CgMergeHorizontal"


class CgMergeVertical(rx.Component):
    library = "react-icons/cg"
    tag = "CgMergeVertical"


class CgMic(rx.Component):
    library = "react-icons/cg"
    tag = "CgMic"


class CgMicrobit(rx.Component):
    library = "react-icons/cg"
    tag = "CgMicrobit"


class CgMicrosoft(rx.Component):
    library = "react-icons/cg"
    tag = "CgMicrosoft"


class CgMiniPlayer(rx.Component):
    library = "react-icons/cg"
    tag = "CgMiniPlayer"


class CgMinimizeAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMinimizeAlt"


class CgMinimize(rx.Component):
    library = "react-icons/cg"
    tag = "CgMinimize"


class CgModem(rx.Component):
    library = "react-icons/cg"
    tag = "CgModem"


class CgMonday(rx.Component):
    library = "react-icons/cg"
    tag = "CgMonday"


class CgMoon(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoon"


class CgMoreAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreAlt"


class CgMoreO(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreO"


class CgMoreR(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreR"


class CgMoreVerticalAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreVerticalAlt"


class CgMoreVerticalO(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreVerticalO"


class CgMoreVerticalR(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreVerticalR"


class CgMoreVertical(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoreVertical"


class CgMore(rx.Component):
    library = "react-icons/cg"
    tag = "CgMore"


class CgMouse(rx.Component):
    library = "react-icons/cg"
    tag = "CgMouse"


class CgMoveDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveDown"


class CgMoveLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveLeft"


class CgMoveRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveRight"


class CgMoveTask(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveTask"


class CgMoveUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgMoveUp"


class CgMusicNote(rx.Component):
    library = "react-icons/cg"
    tag = "CgMusicNote"


class CgMusicSpeaker(rx.Component):
    library = "react-icons/cg"
    tag = "CgMusicSpeaker"


class CgMusic(rx.Component):
    library = "react-icons/cg"
    tag = "CgMusic"


class CgNametag(rx.Component):
    library = "react-icons/cg"
    tag = "CgNametag"


class CgNotes(rx.Component):
    library = "react-icons/cg"
    tag = "CgNotes"


class CgNotifications(rx.Component):
    library = "react-icons/cg"
    tag = "CgNotifications"


class CgNpm(rx.Component):
    library = "react-icons/cg"
    tag = "CgNpm"


class CgOculus(rx.Component):
    library = "react-icons/cg"
    tag = "CgOculus"


class CgOpenCollective(rx.Component):
    library = "react-icons/cg"
    tag = "CgOpenCollective"


class CgOptions(rx.Component):
    library = "react-icons/cg"
    tag = "CgOptions"


class CgOrganisation(rx.Component):
    library = "react-icons/cg"
    tag = "CgOrganisation"


class CgOverflow(rx.Component):
    library = "react-icons/cg"
    tag = "CgOverflow"


class CgPacman(rx.Component):
    library = "react-icons/cg"
    tag = "CgPacman"


class CgPassword(rx.Component):
    library = "react-icons/cg"
    tag = "CgPassword"


class CgPathBack(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathBack"


class CgPathCrop(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathCrop"


class CgPathDivide(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathDivide"


class CgPathExclude(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathExclude"


class CgPathFront(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathFront"


class CgPathIntersect(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathIntersect"


class CgPathOutline(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathOutline"


class CgPathTrim(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathTrim"


class CgPathUnite(rx.Component):
    library = "react-icons/cg"
    tag = "CgPathUnite"


class CgPatreon(rx.Component):
    library = "react-icons/cg"
    tag = "CgPatreon"


class CgPaypal(rx.Component):
    library = "react-icons/cg"
    tag = "CgPaypal"


class CgPen(rx.Component):
    library = "react-icons/cg"
    tag = "CgPen"


class CgPentagonBottomLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonBottomLeft"


class CgPentagonBottomRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonBottomRight"


class CgPentagonDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonDown"


class CgPentagonLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonLeft"


class CgPentagonRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonRight"


class CgPentagonTopLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonTopLeft"


class CgPentagonTopRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonTopRight"


class CgPentagonUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgPentagonUp"


class CgPerformance(rx.Component):
    library = "react-icons/cg"
    tag = "CgPerformance"


class CgPexels(rx.Component):
    library = "react-icons/cg"
    tag = "CgPexels"


class CgPhone(rx.Component):
    library = "react-icons/cg"
    tag = "CgPhone"


class CgPhotoscan(rx.Component):
    library = "react-icons/cg"
    tag = "CgPhotoscan"


class CgPiano(rx.Component):
    library = "react-icons/cg"
    tag = "CgPiano"


class CgPill(rx.Component):
    library = "react-icons/cg"
    tag = "CgPill"


class CgPinAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgPinAlt"


class CgPinBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgPinBottom"


class CgPinTop(rx.Component):
    library = "react-icons/cg"
    tag = "CgPinTop"


class CgPin(rx.Component):
    library = "react-icons/cg"
    tag = "CgPin"


class CgPlayBackwards(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayBackwards"


class CgPlayButtonO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayButtonO"


class CgPlayButtonR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayButtonR"


class CgPlayButton(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayButton"


class CgPlayForwards(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayForwards"


class CgPlayListAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayListAdd"


class CgPlayListCheck(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayListCheck"


class CgPlayListRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayListRemove"


class CgPlayListSearch(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayListSearch"


class CgPlayList(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayList"


class CgPlayPauseO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayPauseO"


class CgPlayPauseR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayPauseR"


class CgPlayPause(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayPause"


class CgPlayStopO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayStopO"


class CgPlayStopR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayStopR"


class CgPlayStop(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayStop"


class CgPlayTrackNextO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackNextO"


class CgPlayTrackNextR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackNextR"


class CgPlayTrackNext(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackNext"


class CgPlayTrackPrevO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackPrevO"


class CgPlayTrackPrevR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackPrevR"


class CgPlayTrackPrev(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlayTrackPrev"


class CgPlug(rx.Component):
    library = "react-icons/cg"
    tag = "CgPlug"


class CgPocket(rx.Component):
    library = "react-icons/cg"
    tag = "CgPocket"


class CgPokemon(rx.Component):
    library = "react-icons/cg"
    tag = "CgPokemon"


class CgPolaroid(rx.Component):
    library = "react-icons/cg"
    tag = "CgPolaroid"


class CgPoll(rx.Component):
    library = "react-icons/cg"
    tag = "CgPoll"


class CgPresentation(rx.Component):
    library = "react-icons/cg"
    tag = "CgPresentation"


class CgPrinter(rx.Component):
    library = "react-icons/cg"
    tag = "CgPrinter"


class CgProductHunt(rx.Component):
    library = "react-icons/cg"
    tag = "CgProductHunt"


class CgProfile(rx.Component):
    library = "react-icons/cg"
    tag = "CgProfile"


class CgPullClear(rx.Component):
    library = "react-icons/cg"
    tag = "CgPullClear"


class CgPushChevronDownO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronDownO"


class CgPushChevronDownR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronDownR"


class CgPushChevronDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronDown"


class CgPushChevronLeftO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronLeftO"


class CgPushChevronLeftR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronLeftR"


class CgPushChevronLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronLeft"


class CgPushChevronRightO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronRightO"


class CgPushChevronRightR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronRightR"


class CgPushChevronRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronRight"


class CgPushChevronUpO(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronUpO"


class CgPushChevronUpR(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronUpR"


class CgPushChevronUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushChevronUp"


class CgPushDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushDown"


class CgPushLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushLeft"


class CgPushRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushRight"


class CgPushUp(rx.Component):
    library = "react-icons/cg"
    tag = "CgPushUp"


class CgQr(rx.Component):
    library = "react-icons/cg"
    tag = "CgQr"


class CgQuoteO(rx.Component):
    library = "react-icons/cg"
    tag = "CgQuoteO"


class CgQuote(rx.Component):
    library = "react-icons/cg"
    tag = "CgQuote"


class CgRadioCheck(rx.Component):
    library = "react-icons/cg"
    tag = "CgRadioCheck"


class CgRadioChecked(rx.Component):
    library = "react-icons/cg"
    tag = "CgRadioChecked"


class CgRatio(rx.Component):
    library = "react-icons/cg"
    tag = "CgRatio"


class CgRead(rx.Component):
    library = "react-icons/cg"
    tag = "CgRead"


class CgReadme(rx.Component):
    library = "react-icons/cg"
    tag = "CgReadme"


class CgRecord(rx.Component):
    library = "react-icons/cg"
    tag = "CgRecord"


class CgRedo(rx.Component):
    library = "react-icons/cg"
    tag = "CgRedo"


class CgRemote(rx.Component):
    library = "react-icons/cg"
    tag = "CgRemote"


class CgRemoveR(rx.Component):
    library = "react-icons/cg"
    tag = "CgRemoveR"


class CgRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgRemove"


class CgRename(rx.Component):
    library = "react-icons/cg"
    tag = "CgRename"


class CgReorder(rx.Component):
    library = "react-icons/cg"
    tag = "CgReorder"


class CgRepeat(rx.Component):
    library = "react-icons/cg"
    tag = "CgRepeat"


class CgRing(rx.Component):
    library = "react-icons/cg"
    tag = "CgRing"


class CgRowFirst(rx.Component):
    library = "react-icons/cg"
    tag = "CgRowFirst"


class CgRowLast(rx.Component):
    library = "react-icons/cg"
    tag = "CgRowLast"


class CgRuler(rx.Component):
    library = "react-icons/cg"
    tag = "CgRuler"


class CgSandClock(rx.Component):
    library = "react-icons/cg"
    tag = "CgSandClock"


class CgScan(rx.Component):
    library = "react-icons/cg"
    tag = "CgScan"


class CgScreenMirror(rx.Component):
    library = "react-icons/cg"
    tag = "CgScreenMirror"


class CgScreenShot(rx.Component):
    library = "react-icons/cg"
    tag = "CgScreenShot"


class CgScreenWide(rx.Component):
    library = "react-icons/cg"
    tag = "CgScreenWide"


class CgScreen(rx.Component):
    library = "react-icons/cg"
    tag = "CgScreen"


class CgScrollH(rx.Component):
    library = "react-icons/cg"
    tag = "CgScrollH"


class CgScrollV(rx.Component):
    library = "react-icons/cg"
    tag = "CgScrollV"


class CgSearchFound(rx.Component):
    library = "react-icons/cg"
    tag = "CgSearchFound"


class CgSearchLoading(rx.Component):
    library = "react-icons/cg"
    tag = "CgSearchLoading"


class CgSearch(rx.Component):
    library = "react-icons/cg"
    tag = "CgSearch"


class CgSelectO(rx.Component):
    library = "react-icons/cg"
    tag = "CgSelectO"


class CgSelectR(rx.Component):
    library = "react-icons/cg"
    tag = "CgSelectR"


class CgSelect(rx.Component):
    library = "react-icons/cg"
    tag = "CgSelect"


class CgServer(rx.Component):
    library = "react-icons/cg"
    tag = "CgServer"


class CgServerless(rx.Component):
    library = "react-icons/cg"
    tag = "CgServerless"


class CgShapeCircle(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeCircle"


class CgShapeHalfCircle(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeHalfCircle"


class CgShapeHexagon(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeHexagon"


class CgShapeRhombus(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeRhombus"


class CgShapeSquare(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeSquare"


class CgShapeTriangle(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeTriangle"


class CgShapeZigzag(rx.Component):
    library = "react-icons/cg"
    tag = "CgShapeZigzag"


class CgShare(rx.Component):
    library = "react-icons/cg"
    tag = "CgShare"


class CgShield(rx.Component):
    library = "react-icons/cg"
    tag = "CgShield"


class CgShoppingBag(rx.Component):
    library = "react-icons/cg"
    tag = "CgShoppingBag"


class CgShoppingCart(rx.Component):
    library = "react-icons/cg"
    tag = "CgShoppingCart"


class CgShortcut(rx.Component):
    library = "react-icons/cg"
    tag = "CgShortcut"


class CgShutterstock(rx.Component):
    library = "react-icons/cg"
    tag = "CgShutterstock"


class CgSidebarOpen(rx.Component):
    library = "react-icons/cg"
    tag = "CgSidebarOpen"


class CgSidebarRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgSidebarRight"


class CgSidebar(rx.Component):
    library = "react-icons/cg"
    tag = "CgSidebar"


class CgSignal(rx.Component):
    library = "react-icons/cg"
    tag = "CgSignal"


class CgSize(rx.Component):
    library = "react-icons/cg"
    tag = "CgSize"


class CgSketch(rx.Component):
    library = "react-icons/cg"
    tag = "CgSketch"


class CgSlack(rx.Component):
    library = "react-icons/cg"
    tag = "CgSlack"


class CgSleep(rx.Component):
    library = "react-icons/cg"
    tag = "CgSleep"


class CgSmartHomeBoiler(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeBoiler"


class CgSmartHomeCooker(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeCooker"


class CgSmartHomeHeat(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeHeat"


class CgSmartHomeLight(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeLight"


class CgSmartHomeRefrigerator(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeRefrigerator"


class CgSmartHomeWashMachine(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartHomeWashMachine"


class CgSmartphoneChip(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartphoneChip"


class CgSmartphoneRam(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartphoneRam"


class CgSmartphoneShake(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartphoneShake"


class CgSmartphone(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmartphone"


class CgSmileMouthOpen(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileMouthOpen"


class CgSmileNeutral(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileNeutral"


class CgSmileNoMouth(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileNoMouth"


class CgSmileNone(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileNone"


class CgSmileSad(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileSad"


class CgSmileUpside(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmileUpside"


class CgSmile(rx.Component):
    library = "react-icons/cg"
    tag = "CgSmile"


class CgSoftwareDownload(rx.Component):
    library = "react-icons/cg"
    tag = "CgSoftwareDownload"


class CgSoftwareUpload(rx.Component):
    library = "react-icons/cg"
    tag = "CgSoftwareUpload"


class CgSortAz(rx.Component):
    library = "react-icons/cg"
    tag = "CgSortAz"


class CgSortZa(rx.Component):
    library = "react-icons/cg"
    tag = "CgSortZa"


class CgSpaceBetweenV(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpaceBetweenV"


class CgSpaceBetween(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpaceBetween"


class CgSpectrum(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpectrum"


class CgSpinnerAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpinnerAlt"


class CgSpinnerTwoAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpinnerTwoAlt"


class CgSpinnerTwo(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpinnerTwo"


class CgSpinner(rx.Component):
    library = "react-icons/cg"
    tag = "CgSpinner"


class CgSquare(rx.Component):
    library = "react-icons/cg"
    tag = "CgSquare"


class CgStack(rx.Component):
    library = "react-icons/cg"
    tag = "CgStack"


class CgStark(rx.Component):
    library = "react-icons/cg"
    tag = "CgStark"


class CgStopwatch(rx.Component):
    library = "react-icons/cg"
    tag = "CgStopwatch"


class CgStories(rx.Component):
    library = "react-icons/cg"
    tag = "CgStories"


class CgStudio(rx.Component):
    library = "react-icons/cg"
    tag = "CgStudio"


class CgStyle(rx.Component):
    library = "react-icons/cg"
    tag = "CgStyle"


class CgSun(rx.Component):
    library = "react-icons/cg"
    tag = "CgSun"


class CgSupport(rx.Component):
    library = "react-icons/cg"
    tag = "CgSupport"


class CgSwapVertical(rx.Component):
    library = "react-icons/cg"
    tag = "CgSwapVertical"


class CgSwap(rx.Component):
    library = "react-icons/cg"
    tag = "CgSwap"


class CgSweden(rx.Component):
    library = "react-icons/cg"
    tag = "CgSweden"


class CgSwiss(rx.Component):
    library = "react-icons/cg"
    tag = "CgSwiss"


class CgSync(rx.Component):
    library = "react-icons/cg"
    tag = "CgSync"


class CgTab(rx.Component):
    library = "react-icons/cg"
    tag = "CgTab"


class CgTag(rx.Component):
    library = "react-icons/cg"
    tag = "CgTag"


class CgTally(rx.Component):
    library = "react-icons/cg"
    tag = "CgTally"


class CgTapDouble(rx.Component):
    library = "react-icons/cg"
    tag = "CgTapDouble"


class CgTapSingle(rx.Component):
    library = "react-icons/cg"
    tag = "CgTapSingle"


class CgTemplate(rx.Component):
    library = "react-icons/cg"
    tag = "CgTemplate"


class CgTennis(rx.Component):
    library = "react-icons/cg"
    tag = "CgTennis"


class CgTerminal(rx.Component):
    library = "react-icons/cg"
    tag = "CgTerminal"


class CgTerrain(rx.Component):
    library = "react-icons/cg"
    tag = "CgTerrain"


class CgThermometer(rx.Component):
    library = "react-icons/cg"
    tag = "CgThermometer"


class CgThermostat(rx.Component):
    library = "react-icons/cg"
    tag = "CgThermostat"


class CgTikcode(rx.Component):
    library = "react-icons/cg"
    tag = "CgTikcode"


class CgTime(rx.Component):
    library = "react-icons/cg"
    tag = "CgTime"


class CgTimelapse(rx.Component):
    library = "react-icons/cg"
    tag = "CgTimelapse"


class CgTimer(rx.Component):
    library = "react-icons/cg"
    tag = "CgTimer"


class CgToday(rx.Component):
    library = "react-icons/cg"
    tag = "CgToday"


class CgToggleOff(rx.Component):
    library = "react-icons/cg"
    tag = "CgToggleOff"


class CgToggleOn(rx.Component):
    library = "react-icons/cg"
    tag = "CgToggleOn"


class CgToggleSquareOff(rx.Component):
    library = "react-icons/cg"
    tag = "CgToggleSquareOff"


class CgToggleSquare(rx.Component):
    library = "react-icons/cg"
    tag = "CgToggleSquare"


class CgToolbarBottom(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbarBottom"


class CgToolbarLeft(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbarLeft"


class CgToolbarRight(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbarRight"


class CgToolbarTop(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbarTop"


class CgToolbox(rx.Component):
    library = "react-icons/cg"
    tag = "CgToolbox"


class CgTouchpad(rx.Component):
    library = "react-icons/cg"
    tag = "CgTouchpad"


class CgTrack(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrack"


class CgTranscript(rx.Component):
    library = "react-icons/cg"
    tag = "CgTranscript"


class CgTrashEmpty(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrashEmpty"


class CgTrash(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrash"


class CgTree(rx.Component):
    library = "react-icons/cg"
    tag = "CgTree"


class CgTrees(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrees"


class CgTrello(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrello"


class CgTrendingDown(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrendingDown"


class CgTrending(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrending"


class CgTrophy(rx.Component):
    library = "react-icons/cg"
    tag = "CgTrophy"


class CgTv(rx.Component):
    library = "react-icons/cg"
    tag = "CgTv"


class CgTwilio(rx.Component):
    library = "react-icons/cg"
    tag = "CgTwilio"


class CgTwitter(rx.Component):
    library = "react-icons/cg"
    tag = "CgTwitter"


class CgUiKit(rx.Component):
    library = "react-icons/cg"
    tag = "CgUiKit"


class CgUmbrella(rx.Component):
    library = "react-icons/cg"
    tag = "CgUmbrella"


class CgUnavailable(rx.Component):
    library = "react-icons/cg"
    tag = "CgUnavailable"


class CgUnblock(rx.Component):
    library = "react-icons/cg"
    tag = "CgUnblock"


class CgUndo(rx.Component):
    library = "react-icons/cg"
    tag = "CgUndo"


class CgUnfold(rx.Component):
    library = "react-icons/cg"
    tag = "CgUnfold"


class CgUnsplash(rx.Component):
    library = "react-icons/cg"
    tag = "CgUnsplash"


class CgUsbC(rx.Component):
    library = "react-icons/cg"
    tag = "CgUsbC"


class CgUsb(rx.Component):
    library = "react-icons/cg"
    tag = "CgUsb"


class CgUserAdd(rx.Component):
    library = "react-icons/cg"
    tag = "CgUserAdd"


class CgUserList(rx.Component):
    library = "react-icons/cg"
    tag = "CgUserList"


class CgUserRemove(rx.Component):
    library = "react-icons/cg"
    tag = "CgUserRemove"


class CgUser(rx.Component):
    library = "react-icons/cg"
    tag = "CgUser"


class CgUserlane(rx.Component):
    library = "react-icons/cg"
    tag = "CgUserlane"


class CgViewCols(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewCols"


class CgViewComfortable(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewComfortable"


class CgViewDay(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewDay"


class CgViewGrid(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewGrid"


class CgViewList(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewList"


class CgViewMonth(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewMonth"


class CgViewSplit(rx.Component):
    library = "react-icons/cg"
    tag = "CgViewSplit"


class CgVinyl(rx.Component):
    library = "react-icons/cg"
    tag = "CgVinyl"


class CgVoicemailO(rx.Component):
    library = "react-icons/cg"
    tag = "CgVoicemailO"


class CgVoicemailR(rx.Component):
    library = "react-icons/cg"
    tag = "CgVoicemailR"


class CgVoicemail(rx.Component):
    library = "react-icons/cg"
    tag = "CgVoicemail"


class CgVolume(rx.Component):
    library = "react-icons/cg"
    tag = "CgVolume"


class CgWebcam(rx.Component):
    library = "react-icons/cg"
    tag = "CgWebcam"


class CgWebsite(rx.Component):
    library = "react-icons/cg"
    tag = "CgWebsite"


class CgWindows(rx.Component):
    library = "react-icons/cg"
    tag = "CgWindows"


class CgWorkAlt(rx.Component):
    library = "react-icons/cg"
    tag = "CgWorkAlt"


class CgYinyang(rx.Component):
    library = "react-icons/cg"
    tag = "CgYinyang"


class CgYoutube(rx.Component):
    library = "react-icons/cg"
    tag = "CgYoutube"


class CgZeit(rx.Component):
    library = "react-icons/cg"
    tag = "CgZeit"


class CgZoomIn(rx.Component):
    library = "react-icons/cg"
    tag = "CgZoomIn"


class CgZoomOut(rx.Component):
    library = "react-icons/cg"
    tag = "CgZoomOut"


