import reflex as rx

class WiAlien(rx.Component):
    library = "react-icons/wi"
    tag = "WiAlien"


class WiBarometer(rx.Component):
    library = "react-icons/wi"
    tag = "WiBarometer"


class WiCelsius(rx.Component):
    library = "react-icons/wi"
    tag = "WiCelsius"


class WiCloudDown(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudDown"


class WiCloudRefresh(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudRefresh"


class WiCloudUp(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudUp"


class WiCloud(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloud"


class WiCloudyGusts(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudyGusts"


class WiCloudyWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudyWindy"


class WiCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiCloudy"


class WiDayCloudyGusts(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayCloudyGusts"


class WiDayCloudyHigh(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayCloudyHigh"


class WiDayCloudyWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayCloudyWindy"


class WiDayCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayCloudy"


class WiDayFog(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayFog"


class WiDayHail(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayHail"


class WiDayHaze(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayHaze"


class WiDayLightWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayLightWind"


class WiDayLightning(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayLightning"


class WiDayRainMix(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayRainMix"


class WiDayRainWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayRainWind"


class WiDayRain(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayRain"


class WiDayShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayShowers"


class WiDaySleetStorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySleetStorm"


class WiDaySleet(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySleet"


class WiDaySnowThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySnowThunderstorm"


class WiDaySnowWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySnowWind"


class WiDaySnow(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySnow"


class WiDaySprinkle(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySprinkle"


class WiDayStormShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayStormShowers"


class WiDaySunnyOvercast(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySunnyOvercast"


class WiDaySunny(rx.Component):
    library = "react-icons/wi"
    tag = "WiDaySunny"


class WiDayThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayThunderstorm"


class WiDayWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiDayWindy"


class WiDegrees(rx.Component):
    library = "react-icons/wi"
    tag = "WiDegrees"


class WiDirectionDownLeft(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionDownLeft"


class WiDirectionDownRight(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionDownRight"


class WiDirectionDown(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionDown"


class WiDirectionLeft(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionLeft"


class WiDirectionRight(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionRight"


class WiDirectionUpLeft(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionUpLeft"


class WiDirectionUpRight(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionUpRight"


class WiDirectionUp(rx.Component):
    library = "react-icons/wi"
    tag = "WiDirectionUp"


class WiDust(rx.Component):
    library = "react-icons/wi"
    tag = "WiDust"


class WiEarthquake(rx.Component):
    library = "react-icons/wi"
    tag = "WiEarthquake"


class WiFahrenheit(rx.Component):
    library = "react-icons/wi"
    tag = "WiFahrenheit"


class WiFire(rx.Component):
    library = "react-icons/wi"
    tag = "WiFire"


class WiFlood(rx.Component):
    library = "react-icons/wi"
    tag = "WiFlood"


class WiFog(rx.Component):
    library = "react-icons/wi"
    tag = "WiFog"


class WiGaleWarning(rx.Component):
    library = "react-icons/wi"
    tag = "WiGaleWarning"


class WiHail(rx.Component):
    library = "react-icons/wi"
    tag = "WiHail"


class WiHorizonAlt(rx.Component):
    library = "react-icons/wi"
    tag = "WiHorizonAlt"


class WiHorizon(rx.Component):
    library = "react-icons/wi"
    tag = "WiHorizon"


class WiHot(rx.Component):
    library = "react-icons/wi"
    tag = "WiHot"


class WiHumidity(rx.Component):
    library = "react-icons/wi"
    tag = "WiHumidity"


class WiHurricaneWarning(rx.Component):
    library = "react-icons/wi"
    tag = "WiHurricaneWarning"


class WiHurricane(rx.Component):
    library = "react-icons/wi"
    tag = "WiHurricane"


class WiLightning(rx.Component):
    library = "react-icons/wi"
    tag = "WiLightning"


class WiLunarEclipse(rx.Component):
    library = "react-icons/wi"
    tag = "WiLunarEclipse"


class WiMeteor(rx.Component):
    library = "react-icons/wi"
    tag = "WiMeteor"


class WiMoonAltFirstQuarter(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltFirstQuarter"


class WiMoonAltFull(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltFull"


class WiMoonAltNew(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltNew"


class WiMoonAltThirdQuarter(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltThirdQuarter"


class WiMoonAltWaningCrescent1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent1"


class WiMoonAltWaningCrescent2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent2"


class WiMoonAltWaningCrescent3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent3"


class WiMoonAltWaningCrescent4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent4"


class WiMoonAltWaningCrescent5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent5"


class WiMoonAltWaningCrescent6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningCrescent6"


class WiMoonAltWaningGibbous1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous1"


class WiMoonAltWaningGibbous2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous2"


class WiMoonAltWaningGibbous3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous3"


class WiMoonAltWaningGibbous4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous4"


class WiMoonAltWaningGibbous5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous5"


class WiMoonAltWaningGibbous6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaningGibbous6"


class WiMoonAltWaxingCrescent1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent1"


class WiMoonAltWaxingCrescent2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent2"


class WiMoonAltWaxingCrescent3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent3"


class WiMoonAltWaxingCrescent4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent4"


class WiMoonAltWaxingCrescent5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent5"


class WiMoonAltWaxingCrescent6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingCrescent6"


class WiMoonAltWaxingGibbous1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous1"


class WiMoonAltWaxingGibbous2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous2"


class WiMoonAltWaxingGibbous3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous3"


class WiMoonAltWaxingGibbous4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous4"


class WiMoonAltWaxingGibbous5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous5"


class WiMoonAltWaxingGibbous6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonAltWaxingGibbous6"


class WiMoonFirstQuarter(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonFirstQuarter"


class WiMoonFull(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonFull"


class WiMoonNew(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonNew"


class WiMoonThirdQuarter(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonThirdQuarter"


class WiMoonWaningCrescent1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent1"


class WiMoonWaningCrescent2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent2"


class WiMoonWaningCrescent3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent3"


class WiMoonWaningCrescent4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent4"


class WiMoonWaningCrescent5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent5"


class WiMoonWaningCrescent6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningCrescent6"


class WiMoonWaningGibbous1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous1"


class WiMoonWaningGibbous2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous2"


class WiMoonWaningGibbous3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous3"


class WiMoonWaningGibbous4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous4"


class WiMoonWaningGibbous5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous5"


class WiMoonWaningGibbous6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaningGibbous6"


class WiMoonWaxing6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxing6"


class WiMoonWaxingCrescent1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent1"


class WiMoonWaxingCrescent2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent2"


class WiMoonWaxingCrescent3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent3"


class WiMoonWaxingCrescent4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent4"


class WiMoonWaxingCrescent5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingCrescent5"


class WiMoonWaxingGibbous1(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous1"


class WiMoonWaxingGibbous2(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous2"


class WiMoonWaxingGibbous3(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous3"


class WiMoonWaxingGibbous4(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous4"


class WiMoonWaxingGibbous5(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous5"


class WiMoonWaxingGibbous6(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonWaxingGibbous6"


class WiMoonrise(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonrise"


class WiMoonset(rx.Component):
    library = "react-icons/wi"
    tag = "WiMoonset"


class WiNa(rx.Component):
    library = "react-icons/wi"
    tag = "WiNa"


class WiNightAltCloudyGusts(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltCloudyGusts"


class WiNightAltCloudyHigh(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltCloudyHigh"


class WiNightAltCloudyWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltCloudyWindy"


class WiNightAltCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltCloudy"


class WiNightAltHail(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltHail"


class WiNightAltLightning(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltLightning"


class WiNightAltPartlyCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltPartlyCloudy"


class WiNightAltRainMix(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltRainMix"


class WiNightAltRainWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltRainWind"


class WiNightAltRain(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltRain"


class WiNightAltShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltShowers"


class WiNightAltSleetStorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSleetStorm"


class WiNightAltSleet(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSleet"


class WiNightAltSnowThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSnowThunderstorm"


class WiNightAltSnowWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSnowWind"


class WiNightAltSnow(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSnow"


class WiNightAltSprinkle(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltSprinkle"


class WiNightAltStormShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltStormShowers"


class WiNightAltThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightAltThunderstorm"


class WiNightClear(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightClear"


class WiNightCloudyGusts(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightCloudyGusts"


class WiNightCloudyHigh(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightCloudyHigh"


class WiNightCloudyWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightCloudyWindy"


class WiNightCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightCloudy"


class WiNightFog(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightFog"


class WiNightHail(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightHail"


class WiNightLightning(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightLightning"


class WiNightPartlyCloudy(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightPartlyCloudy"


class WiNightRainMix(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightRainMix"


class WiNightRainWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightRainWind"


class WiNightRain(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightRain"


class WiNightShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightShowers"


class WiNightSleetStorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSleetStorm"


class WiNightSleet(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSleet"


class WiNightSnowThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSnowThunderstorm"


class WiNightSnowWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSnowWind"


class WiNightSnow(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSnow"


class WiNightSprinkle(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightSprinkle"


class WiNightStormShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightStormShowers"


class WiNightThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiNightThunderstorm"


class WiRainMix(rx.Component):
    library = "react-icons/wi"
    tag = "WiRainMix"


class WiRainWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiRainWind"


class WiRain(rx.Component):
    library = "react-icons/wi"
    tag = "WiRain"


class WiRaindrop(rx.Component):
    library = "react-icons/wi"
    tag = "WiRaindrop"


class WiRaindrops(rx.Component):
    library = "react-icons/wi"
    tag = "WiRaindrops"


class WiRefreshAlt(rx.Component):
    library = "react-icons/wi"
    tag = "WiRefreshAlt"


class WiRefresh(rx.Component):
    library = "react-icons/wi"
    tag = "WiRefresh"


class WiSandstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiSandstorm"


class WiShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiShowers"


class WiSleet(rx.Component):
    library = "react-icons/wi"
    tag = "WiSleet"


class WiSmallCraftAdvisory(rx.Component):
    library = "react-icons/wi"
    tag = "WiSmallCraftAdvisory"


class WiSmog(rx.Component):
    library = "react-icons/wi"
    tag = "WiSmog"


class WiSmoke(rx.Component):
    library = "react-icons/wi"
    tag = "WiSmoke"


class WiSnowWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiSnowWind"


class WiSnow(rx.Component):
    library = "react-icons/wi"
    tag = "WiSnow"


class WiSnowflakeCold(rx.Component):
    library = "react-icons/wi"
    tag = "WiSnowflakeCold"


class WiSolarEclipse(rx.Component):
    library = "react-icons/wi"
    tag = "WiSolarEclipse"


class WiSprinkle(rx.Component):
    library = "react-icons/wi"
    tag = "WiSprinkle"


class WiStars(rx.Component):
    library = "react-icons/wi"
    tag = "WiStars"


class WiStormShowers(rx.Component):
    library = "react-icons/wi"
    tag = "WiStormShowers"


class WiStormWarning(rx.Component):
    library = "react-icons/wi"
    tag = "WiStormWarning"


class WiStrongWind(rx.Component):
    library = "react-icons/wi"
    tag = "WiStrongWind"


class WiSunrise(rx.Component):
    library = "react-icons/wi"
    tag = "WiSunrise"


class WiSunset(rx.Component):
    library = "react-icons/wi"
    tag = "WiSunset"


class WiThermometerExterior(rx.Component):
    library = "react-icons/wi"
    tag = "WiThermometerExterior"


class WiThermometerInternal(rx.Component):
    library = "react-icons/wi"
    tag = "WiThermometerInternal"


class WiThermometer(rx.Component):
    library = "react-icons/wi"
    tag = "WiThermometer"


class WiThunderstorm(rx.Component):
    library = "react-icons/wi"
    tag = "WiThunderstorm"


class WiTime1(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime1"


class WiTime10(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime10"


class WiTime11(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime11"


class WiTime12(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime12"


class WiTime2(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime2"


class WiTime3(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime3"


class WiTime4(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime4"


class WiTime5(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime5"


class WiTime6(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime6"


class WiTime7(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime7"


class WiTime8(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime8"


class WiTime9(rx.Component):
    library = "react-icons/wi"
    tag = "WiTime9"


class WiTornado(rx.Component):
    library = "react-icons/wi"
    tag = "WiTornado"


class WiTrain(rx.Component):
    library = "react-icons/wi"
    tag = "WiTrain"


class WiTsunami(rx.Component):
    library = "react-icons/wi"
    tag = "WiTsunami"


class WiUmbrella(rx.Component):
    library = "react-icons/wi"
    tag = "WiUmbrella"


class WiVolcano(rx.Component):
    library = "react-icons/wi"
    tag = "WiVolcano"


class WiWindBeaufort0(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort0"


class WiWindBeaufort1(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort1"


class WiWindBeaufort10(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort10"


class WiWindBeaufort11(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort11"


class WiWindBeaufort12(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort12"


class WiWindBeaufort2(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort2"


class WiWindBeaufort3(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort3"


class WiWindBeaufort4(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort4"


class WiWindBeaufort5(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort5"


class WiWindBeaufort6(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort6"


class WiWindBeaufort7(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort7"


class WiWindBeaufort8(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort8"


class WiWindBeaufort9(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindBeaufort9"


class WiWindDeg(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindDeg"


class WiWindy(rx.Component):
    library = "react-icons/wi"
    tag = "WiWindy"


