import reflex as rx

class TfiAgenda(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAgenda"


class TfiAlarmClock(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlarmClock"


class TfiAlert(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlert"


class TfiAlignCenter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlignCenter"


class TfiAlignJustify(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlignJustify"


class TfiAlignLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlignLeft"


class TfiAlignRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAlignRight"


class TfiAnchor(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAnchor"


class TfiAndroid(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAndroid"


class TfiAngleDoubleDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDoubleDown"


class TfiAngleDoubleLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDoubleLeft"


class TfiAngleDoubleRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDoubleRight"


class TfiAngleDoubleUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDoubleUp"


class TfiAngleDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleDown"


class TfiAngleLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleLeft"


class TfiAngleRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleRight"


class TfiAngleUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAngleUp"


class TfiAnnouncement(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiAnnouncement"


class TfiApple(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiApple"


class TfiArchive(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArchive"


class TfiArrowCircleDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowCircleDown"


class TfiArrowCircleLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowCircleLeft"


class TfiArrowCircleRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowCircleRight"


class TfiArrowCircleUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowCircleUp"


class TfiArrowDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowDown"


class TfiArrowLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowLeft"


class TfiArrowRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowRight"


class TfiArrowTopLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowTopLeft"


class TfiArrowTopRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowTopRight"


class TfiArrowUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowUp"


class TfiArrow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrow"


class TfiArrowsCorner(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowsCorner"


class TfiArrowsHorizontal(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowsHorizontal"


class TfiArrowsVertical(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiArrowsVertical"


class TfiBackLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBackLeft"


class TfiBackRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBackRight"


class TfiBag(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBag"


class TfiBarChartAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBarChartAlt"


class TfiBarChart(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBarChart"


class TfiBasketball(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBasketball"


class TfiBell(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBell"


class TfiBlackboard(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBlackboard"


class TfiBoltAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBoltAlt"


class TfiBolt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBolt"


class TfiBook(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBook"


class TfiBookmarkAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBookmarkAlt"


class TfiBookmark(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBookmark"


class TfiBriefcase(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBriefcase"


class TfiBrushAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBrushAlt"


class TfiBrush(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiBrush"


class TfiCalendar(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCalendar"


class TfiCamera(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCamera"


class TfiCar(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCar"


class TfiCheckBox(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCheckBox"


class TfiCheck(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCheck"


class TfiClip(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiClip"


class TfiClipboard(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiClipboard"


class TfiClose(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiClose"


class TfiCloudDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCloudDown"


class TfiCloudUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCloudUp"


class TfiCloud(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCloud"


class TfiCommentAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCommentAlt"


class TfiComment(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiComment"


class TfiCommentsSmiley(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCommentsSmiley"


class TfiComments(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiComments"


class TfiControlBackward(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlBackward"


class TfiControlEject(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlEject"


class TfiControlForward(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlForward"


class TfiControlPause(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlPause"


class TfiControlPlay(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlPlay"


class TfiControlRecord(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlRecord"


class TfiControlShuffle(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlShuffle"


class TfiControlSkipBackward(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlSkipBackward"


class TfiControlSkipForward(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlSkipForward"


class TfiControlStop(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiControlStop"


class TfiCreditCard(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCreditCard"


class TfiCrown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCrown"


class TfiCss3(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCss3"


class TfiCup(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCup"


class TfiCut(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiCut"


class TfiDashboard(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDashboard"


class TfiDesktop(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDesktop"


class TfiDirectionAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDirectionAlt"


class TfiDirection(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDirection"


class TfiDownload(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDownload"


class TfiDribbble(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDribbble"


class TfiDropboxAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDropboxAlt"


class TfiDropbox(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDropbox"


class TfiDrupal(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiDrupal"


class TfiEmail(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiEmail"


class TfiEnvelope(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiEnvelope"


class TfiEraser(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiEraser"


class TfiExchangeVertical(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiExchangeVertical"


class TfiExport(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiExport"


class TfiEye(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiEye"


class TfiFaceSad(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFaceSad"


class TfiFaceSmile(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFaceSmile"


class TfiFacebook(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFacebook"


class TfiFile(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFile"


class TfiFiles(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFiles"


class TfiFilter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFilter"


class TfiFlagAlt2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlagAlt2"


class TfiFlagAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlagAlt"


class TfiFlag(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlag"


class TfiFlickrAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlickrAlt"


class TfiFlickr(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFlickr"


class TfiFolder(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFolder"


class TfiFullscreen(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiFullscreen"


class TfiGallery(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGallery"


class TfiGame(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGame"


class TfiGift(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGift"


class TfiGithub(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGithub"


class TfiGoogle(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiGoogle"


class TfiHandDrag(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandDrag"


class TfiHandOpen(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandOpen"


class TfiHandPointDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandPointDown"


class TfiHandPointLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandPointLeft"


class TfiHandPointRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandPointRight"


class TfiHandPointUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandPointUp"


class TfiHandStop(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHandStop"


class TfiHarddrive(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHarddrive"


class TfiHarddrives(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHarddrives"


class TfiHeadphoneAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHeadphoneAlt"


class TfiHeadphone(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHeadphone"


class TfiHeartBroken(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHeartBroken"


class TfiHeart(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHeart"


class TfiHelpAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHelpAlt"


class TfiHelp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHelp"


class TfiHome(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHome"


class TfiHtml5(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHtml5"


class TfiHummer(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiHummer"


class TfiIdBadge(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiIdBadge"


class TfiImage(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiImage"


class TfiImport(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiImport"


class TfiInfinite(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInfinite"


class TfiInfoAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInfoAlt"


class TfiInfo(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInfo"


class TfiInkPen(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInkPen"


class TfiInstagram(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiInstagram"


class TfiItalic(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiItalic"


class TfiJoomla(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiJoomla"


class TfiJsfiddle(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiJsfiddle"


class TfiKey(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiKey"


class TfiLayersAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayersAlt"


class TfiLayers(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayers"


class TfiLayoutAccordionList(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutAccordionList"


class TfiLayoutAccordionMerged(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutAccordionMerged"


class TfiLayoutAccordionSeparated(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutAccordionSeparated"


class TfiLayoutColumn2Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn2Alt"


class TfiLayoutColumn2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn2"


class TfiLayoutColumn3Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn3Alt"


class TfiLayoutColumn3(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn3"


class TfiLayoutColumn4Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn4Alt"


class TfiLayoutColumn4(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutColumn4"


class TfiLayoutCtaBtnLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaBtnLeft"


class TfiLayoutCtaBtnRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaBtnRight"


class TfiLayoutCtaCenter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaCenter"


class TfiLayoutCtaLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaLeft"


class TfiLayoutCtaRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutCtaRight"


class TfiLayoutGrid2Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid2Alt"


class TfiLayoutGrid2Thumb(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid2Thumb"


class TfiLayoutGrid2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid2"


class TfiLayoutGrid3Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid3Alt"


class TfiLayoutGrid3(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid3"


class TfiLayoutGrid4Alt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid4Alt"


class TfiLayoutGrid4(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutGrid4"


class TfiLayoutLineSolid(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutLineSolid"


class TfiLayoutListLargeImage(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutListLargeImage"


class TfiLayoutListPost(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutListPost"


class TfiLayoutListThumbAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutListThumbAlt"


class TfiLayoutListThumb(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutListThumb"


class TfiLayoutMediaCenterAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaCenterAlt"


class TfiLayoutMediaCenter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaCenter"


class TfiLayoutMediaLeftAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaLeftAlt"


class TfiLayoutMediaLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaLeft"


class TfiLayoutMediaOverlayAlt2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaOverlayAlt2"


class TfiLayoutMediaOverlayAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaOverlayAlt"


class TfiLayoutMediaOverlay(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaOverlay"


class TfiLayoutMediaRightAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaRightAlt"


class TfiLayoutMediaRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMediaRight"


class TfiLayoutMenuFull(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMenuFull"


class TfiLayoutMenuSeparated(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMenuSeparated"


class TfiLayoutMenuV(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMenuV"


class TfiLayoutMenu(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutMenu"


class TfiLayoutPlaceholder(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutPlaceholder"


class TfiLayoutSidebar2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSidebar2"


class TfiLayoutSidebarLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSidebarLeft"


class TfiLayoutSidebarNone(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSidebarNone"


class TfiLayoutSidebarRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSidebarRight"


class TfiLayoutSliderAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSliderAlt"


class TfiLayoutSlider(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutSlider"


class TfiLayoutTabMin(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutTabMin"


class TfiLayoutTabV(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutTabV"


class TfiLayoutTabWindow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutTabWindow"


class TfiLayoutTab(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutTab"


class TfiLayoutWidthDefaultAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutWidthDefaultAlt"


class TfiLayoutWidthDefault(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutWidthDefault"


class TfiLayoutWidthFull(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayoutWidthFull"


class TfiLayout(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLayout"


class TfiLightBulb(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLightBulb"


class TfiLineDashed(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLineDashed"


class TfiLineDotted(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLineDotted"


class TfiLineDouble(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLineDouble"


class TfiLink(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLink"


class TfiLinkedin(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLinkedin"


class TfiLinux(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLinux"


class TfiListOl(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiListOl"


class TfiList(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiList"


class TfiLocationArrow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLocationArrow"


class TfiLocationPin(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLocationPin"


class TfiLock(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLock"


class TfiLoop(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiLoop"


class TfiMagnet(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMagnet"


class TfiMapAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMapAlt"


class TfiMap(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMap"


class TfiMarkerAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMarkerAlt"


class TfiMarker(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMarker"


class TfiMedallAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMedallAlt"


class TfiMedall(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMedall"


class TfiMenuAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMenuAlt"


class TfiMenu(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMenu"


class TfiMicrophoneAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMicrophoneAlt"


class TfiMicrophone(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMicrophone"


class TfiMicrosoftAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMicrosoftAlt"


class TfiMicrosoft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMicrosoft"


class TfiMinus(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMinus"


class TfiMobile(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMobile"


class TfiMoney(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMoney"


class TfiMoreAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMoreAlt"


class TfiMore(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMore"


class TfiMouseAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMouseAlt"


class TfiMouse(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMouse"


class TfiMusicAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMusicAlt"


class TfiMusic(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiMusic"


class TfiNa(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiNa"


class TfiNewWindow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiNewWindow"


class TfiNotepad(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiNotepad"


class TfiPackage(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPackage"


class TfiPaintBucket(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPaintBucket"


class TfiPaintRoller(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPaintRoller"


class TfiPalette(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPalette"


class TfiPanel(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPanel"


class TfiParagraph(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiParagraph"


class TfiPencilAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPencilAlt"


class TfiPencilAlt2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPencilAlt2"


class TfiPencil(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPencil"


class TfiPieChart(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPieChart"


class TfiPinAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPinAlt"


class TfiPin(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPin"


class TfiPin2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPin2"


class TfiPinterestAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPinterestAlt"


class TfiPinterest(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPinterest"


class TfiPlug(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPlug"


class TfiPlus(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPlus"


class TfiPowerOff(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPowerOff"


class TfiPrinter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPrinter"


class TfiPulse(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiPulse"


class TfiQuoteLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiQuoteLeft"


class TfiQuoteRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiQuoteRight"


class TfiReceipt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiReceipt"


class TfiReddit(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiReddit"


class TfiReload(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiReload"


class TfiRocket(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRocket"


class TfiRssAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRssAlt"


class TfiRss(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRss"


class TfiRulerAlt2(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRulerAlt2"


class TfiRulerAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRulerAlt"


class TfiRulerPencil(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRulerPencil"


class TfiRuler(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiRuler"


class TfiSaveAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSaveAlt"


class TfiSave(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSave"


class TfiSearch(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSearch"


class TfiServer(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiServer"


class TfiSettings(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSettings"


class TfiShareAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShareAlt"


class TfiShare(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShare"


class TfiSharethisAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSharethisAlt"


class TfiSharethis(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSharethis"


class TfiShield(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShield"


class TfiShiftLeftAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShiftLeftAlt"


class TfiShiftLeft(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShiftLeft"


class TfiShiftRightAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShiftRightAlt"


class TfiShiftRight(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShiftRight"


class TfiShine(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShine"


class TfiShoppingCartFull(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShoppingCartFull"


class TfiShoppingCart(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShoppingCart"


class TfiShortcode(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiShortcode"


class TfiSignal(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSignal"


class TfiSkype(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSkype"


class TfiSlice(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSlice"


class TfiSmallcap(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSmallcap"


class TfiSoundcloud(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSoundcloud"


class TfiSplitH(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSplitH"


class TfiSplitVAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSplitVAlt"


class TfiSplitV(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSplitV"


class TfiSpray(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSpray"


class TfiStackOverflow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStackOverflow"


class TfiStamp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStamp"


class TfiStar(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStar"


class TfiStatsDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStatsDown"


class TfiStatsUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiStatsUp"


class TfiSupport(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiSupport"


class TfiTablet(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTablet"


class TfiTag(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTag"


class TfiTarget(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTarget"


class TfiText(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiText"


class TfiThemifyFaviconAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThemifyFaviconAlt"


class TfiThemifyFavicon(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThemifyFavicon"


class TfiThemifyLogo(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThemifyLogo"


class TfiThought(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThought"


class TfiThumbDown(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThumbDown"


class TfiThumbUp(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiThumbUp"


class TfiTicket(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTicket"


class TfiTime(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTime"


class TfiTimer(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTimer"


class TfiTrash(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTrash"


class TfiTrello(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTrello"


class TfiTruck(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTruck"


class TfiTumblrAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTumblrAlt"


class TfiTumblr(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTumblr"


class TfiTwitterAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTwitterAlt"


class TfiTwitter(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiTwitter"


class TfiUnderline(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUnderline"


class TfiUnlink(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUnlink"


class TfiUnlock(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUnlock"


class TfiUpload(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUpload"


class TfiUppercase(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUppercase"


class TfiUser(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiUser"


class TfiVector(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVector"


class TfiVideoCamera(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVideoCamera"


class TfiVideoClapper(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVideoClapper"


class TfiViewGrid(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiViewGrid"


class TfiViewListAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiViewListAlt"


class TfiViewList(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiViewList"


class TfiVimeoAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVimeoAlt"


class TfiVimeo(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVimeo"


class TfiVolume(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiVolume"


class TfiWallet(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWallet"


class TfiWand(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWand"


class TfiWheelchair(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWheelchair"


class TfiWidgetAlt(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWidgetAlt"


class TfiWidget(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWidget"


class TfiWidgetized(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWidgetized"


class TfiWindow(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWindow"


class TfiWordpress(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWordpress"


class TfiWorld(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWorld"


class TfiWrite(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiWrite"


class TfiYahoo(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiYahoo"


class TfiYoutube(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiYoutube"


class TfiZip(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiZip"


class TfiZoomIn(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiZoomIn"


class TfiZoomOut(rx.Component):
    library = "react-icons/tfi"
    tag = "TfiZoomOut"


