import reflex as rx

class FiActivity(rx.Component):
    library = "react-icons/fi"
    tag = "FiActivity"


class FiAirplay(rx.Component):
    library = "react-icons/fi"
    tag = "FiAirplay"


class FiAlertCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlertCircle"


class FiAlertOctagon(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlertOctagon"


class FiAlertTriangle(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlertTriangle"


class FiAlignCenter(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlignCenter"


class FiAlignJustify(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlignJustify"


class FiAlignLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlignLeft"


class FiAlignRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiAlignRight"


class FiAnchor(rx.Component):
    library = "react-icons/fi"
    tag = "FiAnchor"


class FiAperture(rx.Component):
    library = "react-icons/fi"
    tag = "FiAperture"


class FiArchive(rx.Component):
    library = "react-icons/fi"
    tag = "FiArchive"


class FiArrowDownCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowDownCircle"


class FiArrowDownLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowDownLeft"


class FiArrowDownRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowDownRight"


class FiArrowDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowDown"


class FiArrowLeftCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowLeftCircle"


class FiArrowLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowLeft"


class FiArrowRightCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowRightCircle"


class FiArrowRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowRight"


class FiArrowUpCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowUpCircle"


class FiArrowUpLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowUpLeft"


class FiArrowUpRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowUpRight"


class FiArrowUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiArrowUp"


class FiAtSign(rx.Component):
    library = "react-icons/fi"
    tag = "FiAtSign"


class FiAward(rx.Component):
    library = "react-icons/fi"
    tag = "FiAward"


class FiBarChart2(rx.Component):
    library = "react-icons/fi"
    tag = "FiBarChart2"


class FiBarChart(rx.Component):
    library = "react-icons/fi"
    tag = "FiBarChart"


class FiBatteryCharging(rx.Component):
    library = "react-icons/fi"
    tag = "FiBatteryCharging"


class FiBattery(rx.Component):
    library = "react-icons/fi"
    tag = "FiBattery"


class FiBellOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiBellOff"


class FiBell(rx.Component):
    library = "react-icons/fi"
    tag = "FiBell"


class FiBluetooth(rx.Component):
    library = "react-icons/fi"
    tag = "FiBluetooth"


class FiBold(rx.Component):
    library = "react-icons/fi"
    tag = "FiBold"


class FiBookOpen(rx.Component):
    library = "react-icons/fi"
    tag = "FiBookOpen"


class FiBook(rx.Component):
    library = "react-icons/fi"
    tag = "FiBook"


class FiBookmark(rx.Component):
    library = "react-icons/fi"
    tag = "FiBookmark"


class FiBox(rx.Component):
    library = "react-icons/fi"
    tag = "FiBox"


class FiBriefcase(rx.Component):
    library = "react-icons/fi"
    tag = "FiBriefcase"


class FiCalendar(rx.Component):
    library = "react-icons/fi"
    tag = "FiCalendar"


class FiCameraOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiCameraOff"


class FiCamera(rx.Component):
    library = "react-icons/fi"
    tag = "FiCamera"


class FiCast(rx.Component):
    library = "react-icons/fi"
    tag = "FiCast"


class FiCheckCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiCheckCircle"


class FiCheckSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiCheckSquare"


class FiCheck(rx.Component):
    library = "react-icons/fi"
    tag = "FiCheck"


class FiChevronDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronDown"


class FiChevronLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronLeft"


class FiChevronRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronRight"


class FiChevronUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronUp"


class FiChevronsDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronsDown"


class FiChevronsLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronsLeft"


class FiChevronsRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronsRight"


class FiChevronsUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiChevronsUp"


class FiChrome(rx.Component):
    library = "react-icons/fi"
    tag = "FiChrome"


class FiCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiCircle"


class FiClipboard(rx.Component):
    library = "react-icons/fi"
    tag = "FiClipboard"


class FiClock(rx.Component):
    library = "react-icons/fi"
    tag = "FiClock"


class FiCloudDrizzle(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudDrizzle"


class FiCloudLightning(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudLightning"


class FiCloudOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudOff"


class FiCloudRain(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudRain"


class FiCloudSnow(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloudSnow"


class FiCloud(rx.Component):
    library = "react-icons/fi"
    tag = "FiCloud"


class FiCode(rx.Component):
    library = "react-icons/fi"
    tag = "FiCode"


class FiCodepen(rx.Component):
    library = "react-icons/fi"
    tag = "FiCodepen"


class FiCodesandbox(rx.Component):
    library = "react-icons/fi"
    tag = "FiCodesandbox"


class FiCoffee(rx.Component):
    library = "react-icons/fi"
    tag = "FiCoffee"


class FiColumns(rx.Component):
    library = "react-icons/fi"
    tag = "FiColumns"


class FiCommand(rx.Component):
    library = "react-icons/fi"
    tag = "FiCommand"


class FiCompass(rx.Component):
    library = "react-icons/fi"
    tag = "FiCompass"


class FiCopy(rx.Component):
    library = "react-icons/fi"
    tag = "FiCopy"


class FiCornerDownLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerDownLeft"


class FiCornerDownRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerDownRight"


class FiCornerLeftDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerLeftDown"


class FiCornerLeftUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerLeftUp"


class FiCornerRightDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerRightDown"


class FiCornerRightUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerRightUp"


class FiCornerUpLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerUpLeft"


class FiCornerUpRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiCornerUpRight"


class FiCpu(rx.Component):
    library = "react-icons/fi"
    tag = "FiCpu"


class FiCreditCard(rx.Component):
    library = "react-icons/fi"
    tag = "FiCreditCard"


class FiCrop(rx.Component):
    library = "react-icons/fi"
    tag = "FiCrop"


class FiCrosshair(rx.Component):
    library = "react-icons/fi"
    tag = "FiCrosshair"


class FiDatabase(rx.Component):
    library = "react-icons/fi"
    tag = "FiDatabase"


class FiDelete(rx.Component):
    library = "react-icons/fi"
    tag = "FiDelete"


class FiDisc(rx.Component):
    library = "react-icons/fi"
    tag = "FiDisc"


class FiDivideCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiDivideCircle"


class FiDivideSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiDivideSquare"


class FiDivide(rx.Component):
    library = "react-icons/fi"
    tag = "FiDivide"


class FiDollarSign(rx.Component):
    library = "react-icons/fi"
    tag = "FiDollarSign"


class FiDownloadCloud(rx.Component):
    library = "react-icons/fi"
    tag = "FiDownloadCloud"


class FiDownload(rx.Component):
    library = "react-icons/fi"
    tag = "FiDownload"


class FiDribbble(rx.Component):
    library = "react-icons/fi"
    tag = "FiDribbble"


class FiDroplet(rx.Component):
    library = "react-icons/fi"
    tag = "FiDroplet"


class FiEdit2(rx.Component):
    library = "react-icons/fi"
    tag = "FiEdit2"


class FiEdit3(rx.Component):
    library = "react-icons/fi"
    tag = "FiEdit3"


class FiEdit(rx.Component):
    library = "react-icons/fi"
    tag = "FiEdit"


class FiExternalLink(rx.Component):
    library = "react-icons/fi"
    tag = "FiExternalLink"


class FiEyeOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiEyeOff"


class FiEye(rx.Component):
    library = "react-icons/fi"
    tag = "FiEye"


class FiFacebook(rx.Component):
    library = "react-icons/fi"
    tag = "FiFacebook"


class FiFastForward(rx.Component):
    library = "react-icons/fi"
    tag = "FiFastForward"


class FiFeather(rx.Component):
    library = "react-icons/fi"
    tag = "FiFeather"


class FiFigma(rx.Component):
    library = "react-icons/fi"
    tag = "FiFigma"


class FiFileMinus(rx.Component):
    library = "react-icons/fi"
    tag = "FiFileMinus"


class FiFilePlus(rx.Component):
    library = "react-icons/fi"
    tag = "FiFilePlus"


class FiFileText(rx.Component):
    library = "react-icons/fi"
    tag = "FiFileText"


class FiFile(rx.Component):
    library = "react-icons/fi"
    tag = "FiFile"


class FiFilm(rx.Component):
    library = "react-icons/fi"
    tag = "FiFilm"


class FiFilter(rx.Component):
    library = "react-icons/fi"
    tag = "FiFilter"


class FiFlag(rx.Component):
    library = "react-icons/fi"
    tag = "FiFlag"


class FiFolderMinus(rx.Component):
    library = "react-icons/fi"
    tag = "FiFolderMinus"


class FiFolderPlus(rx.Component):
    library = "react-icons/fi"
    tag = "FiFolderPlus"


class FiFolder(rx.Component):
    library = "react-icons/fi"
    tag = "FiFolder"


class FiFramer(rx.Component):
    library = "react-icons/fi"
    tag = "FiFramer"


class FiFrown(rx.Component):
    library = "react-icons/fi"
    tag = "FiFrown"


class FiGift(rx.Component):
    library = "react-icons/fi"
    tag = "FiGift"


class FiGitBranch(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitBranch"


class FiGitCommit(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitCommit"


class FiGitMerge(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitMerge"


class FiGitPullRequest(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitPullRequest"


class FiGithub(rx.Component):
    library = "react-icons/fi"
    tag = "FiGithub"


class FiGitlab(rx.Component):
    library = "react-icons/fi"
    tag = "FiGitlab"


class FiGlobe(rx.Component):
    library = "react-icons/fi"
    tag = "FiGlobe"


class FiGrid(rx.Component):
    library = "react-icons/fi"
    tag = "FiGrid"


class FiHardDrive(rx.Component):
    library = "react-icons/fi"
    tag = "FiHardDrive"


class FiHash(rx.Component):
    library = "react-icons/fi"
    tag = "FiHash"


class FiHeadphones(rx.Component):
    library = "react-icons/fi"
    tag = "FiHeadphones"


class FiHeart(rx.Component):
    library = "react-icons/fi"
    tag = "FiHeart"


class FiHelpCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiHelpCircle"


class FiHexagon(rx.Component):
    library = "react-icons/fi"
    tag = "FiHexagon"


class FiHome(rx.Component):
    library = "react-icons/fi"
    tag = "FiHome"


class FiImage(rx.Component):
    library = "react-icons/fi"
    tag = "FiImage"


class FiInbox(rx.Component):
    library = "react-icons/fi"
    tag = "FiInbox"


class FiInfo(rx.Component):
    library = "react-icons/fi"
    tag = "FiInfo"


class FiInstagram(rx.Component):
    library = "react-icons/fi"
    tag = "FiInstagram"


class FiItalic(rx.Component):
    library = "react-icons/fi"
    tag = "FiItalic"


class FiKey(rx.Component):
    library = "react-icons/fi"
    tag = "FiKey"


class FiLayers(rx.Component):
    library = "react-icons/fi"
    tag = "FiLayers"


class FiLayout(rx.Component):
    library = "react-icons/fi"
    tag = "FiLayout"


class FiLifeBuoy(rx.Component):
    library = "react-icons/fi"
    tag = "FiLifeBuoy"


class FiLink2(rx.Component):
    library = "react-icons/fi"
    tag = "FiLink2"


class FiLink(rx.Component):
    library = "react-icons/fi"
    tag = "FiLink"


class FiLinkedin(rx.Component):
    library = "react-icons/fi"
    tag = "FiLinkedin"


class FiList(rx.Component):
    library = "react-icons/fi"
    tag = "FiList"


class FiLoader(rx.Component):
    library = "react-icons/fi"
    tag = "FiLoader"


class FiLock(rx.Component):
    library = "react-icons/fi"
    tag = "FiLock"


class FiLogIn(rx.Component):
    library = "react-icons/fi"
    tag = "FiLogIn"


class FiLogOut(rx.Component):
    library = "react-icons/fi"
    tag = "FiLogOut"


class FiMail(rx.Component):
    library = "react-icons/fi"
    tag = "FiMail"


class FiMapPin(rx.Component):
    library = "react-icons/fi"
    tag = "FiMapPin"


class FiMap(rx.Component):
    library = "react-icons/fi"
    tag = "FiMap"


class FiMaximize2(rx.Component):
    library = "react-icons/fi"
    tag = "FiMaximize2"


class FiMaximize(rx.Component):
    library = "react-icons/fi"
    tag = "FiMaximize"


class FiMeh(rx.Component):
    library = "react-icons/fi"
    tag = "FiMeh"


class FiMenu(rx.Component):
    library = "react-icons/fi"
    tag = "FiMenu"


class FiMessageCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiMessageCircle"


class FiMessageSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiMessageSquare"


class FiMicOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiMicOff"


class FiMic(rx.Component):
    library = "react-icons/fi"
    tag = "FiMic"


class FiMinimize2(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinimize2"


class FiMinimize(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinimize"


class FiMinusCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinusCircle"


class FiMinusSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinusSquare"


class FiMinus(rx.Component):
    library = "react-icons/fi"
    tag = "FiMinus"


class FiMonitor(rx.Component):
    library = "react-icons/fi"
    tag = "FiMonitor"


class FiMoon(rx.Component):
    library = "react-icons/fi"
    tag = "FiMoon"


class FiMoreHorizontal(rx.Component):
    library = "react-icons/fi"
    tag = "FiMoreHorizontal"


class FiMoreVertical(rx.Component):
    library = "react-icons/fi"
    tag = "FiMoreVertical"


class FiMousePointer(rx.Component):
    library = "react-icons/fi"
    tag = "FiMousePointer"


class FiMove(rx.Component):
    library = "react-icons/fi"
    tag = "FiMove"


class FiMusic(rx.Component):
    library = "react-icons/fi"
    tag = "FiMusic"


class FiNavigation2(rx.Component):
    library = "react-icons/fi"
    tag = "FiNavigation2"


class FiNavigation(rx.Component):
    library = "react-icons/fi"
    tag = "FiNavigation"


class FiOctagon(rx.Component):
    library = "react-icons/fi"
    tag = "FiOctagon"


class FiPackage(rx.Component):
    library = "react-icons/fi"
    tag = "FiPackage"


class FiPaperclip(rx.Component):
    library = "react-icons/fi"
    tag = "FiPaperclip"


class FiPauseCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiPauseCircle"


class FiPause(rx.Component):
    library = "react-icons/fi"
    tag = "FiPause"


class FiPenTool(rx.Component):
    library = "react-icons/fi"
    tag = "FiPenTool"


class FiPercent(rx.Component):
    library = "react-icons/fi"
    tag = "FiPercent"


class FiPhoneCall(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneCall"


class FiPhoneForwarded(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneForwarded"


class FiPhoneIncoming(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneIncoming"


class FiPhoneMissed(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneMissed"


class FiPhoneOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneOff"


class FiPhoneOutgoing(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhoneOutgoing"


class FiPhone(rx.Component):
    library = "react-icons/fi"
    tag = "FiPhone"


class FiPieChart(rx.Component):
    library = "react-icons/fi"
    tag = "FiPieChart"


class FiPlayCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlayCircle"


class FiPlay(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlay"


class FiPlusCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlusCircle"


class FiPlusSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlusSquare"


class FiPlus(rx.Component):
    library = "react-icons/fi"
    tag = "FiPlus"


class FiPocket(rx.Component):
    library = "react-icons/fi"
    tag = "FiPocket"


class FiPower(rx.Component):
    library = "react-icons/fi"
    tag = "FiPower"


class FiPrinter(rx.Component):
    library = "react-icons/fi"
    tag = "FiPrinter"


class FiRadio(rx.Component):
    library = "react-icons/fi"
    tag = "FiRadio"


class FiRefreshCcw(rx.Component):
    library = "react-icons/fi"
    tag = "FiRefreshCcw"


class FiRefreshCw(rx.Component):
    library = "react-icons/fi"
    tag = "FiRefreshCw"


class FiRepeat(rx.Component):
    library = "react-icons/fi"
    tag = "FiRepeat"


class FiRewind(rx.Component):
    library = "react-icons/fi"
    tag = "FiRewind"


class FiRotateCcw(rx.Component):
    library = "react-icons/fi"
    tag = "FiRotateCcw"


class FiRotateCw(rx.Component):
    library = "react-icons/fi"
    tag = "FiRotateCw"


class FiRss(rx.Component):
    library = "react-icons/fi"
    tag = "FiRss"


class FiSave(rx.Component):
    library = "react-icons/fi"
    tag = "FiSave"


class FiScissors(rx.Component):
    library = "react-icons/fi"
    tag = "FiScissors"


class FiSearch(rx.Component):
    library = "react-icons/fi"
    tag = "FiSearch"


class FiSend(rx.Component):
    library = "react-icons/fi"
    tag = "FiSend"


class FiServer(rx.Component):
    library = "react-icons/fi"
    tag = "FiServer"


class FiSettings(rx.Component):
    library = "react-icons/fi"
    tag = "FiSettings"


class FiShare2(rx.Component):
    library = "react-icons/fi"
    tag = "FiShare2"


class FiShare(rx.Component):
    library = "react-icons/fi"
    tag = "FiShare"


class FiShieldOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiShieldOff"


class FiShield(rx.Component):
    library = "react-icons/fi"
    tag = "FiShield"


class FiShoppingBag(rx.Component):
    library = "react-icons/fi"
    tag = "FiShoppingBag"


class FiShoppingCart(rx.Component):
    library = "react-icons/fi"
    tag = "FiShoppingCart"


class FiShuffle(rx.Component):
    library = "react-icons/fi"
    tag = "FiShuffle"


class FiSidebar(rx.Component):
    library = "react-icons/fi"
    tag = "FiSidebar"


class FiSkipBack(rx.Component):
    library = "react-icons/fi"
    tag = "FiSkipBack"


class FiSkipForward(rx.Component):
    library = "react-icons/fi"
    tag = "FiSkipForward"


class FiSlack(rx.Component):
    library = "react-icons/fi"
    tag = "FiSlack"


class FiSlash(rx.Component):
    library = "react-icons/fi"
    tag = "FiSlash"


class FiSliders(rx.Component):
    library = "react-icons/fi"
    tag = "FiSliders"


class FiSmartphone(rx.Component):
    library = "react-icons/fi"
    tag = "FiSmartphone"


class FiSmile(rx.Component):
    library = "react-icons/fi"
    tag = "FiSmile"


class FiSpeaker(rx.Component):
    library = "react-icons/fi"
    tag = "FiSpeaker"


class FiSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiSquare"


class FiStar(rx.Component):
    library = "react-icons/fi"
    tag = "FiStar"


class FiStopCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiStopCircle"


class FiSun(rx.Component):
    library = "react-icons/fi"
    tag = "FiSun"


class FiSunrise(rx.Component):
    library = "react-icons/fi"
    tag = "FiSunrise"


class FiSunset(rx.Component):
    library = "react-icons/fi"
    tag = "FiSunset"


class FiTablet(rx.Component):
    library = "react-icons/fi"
    tag = "FiTablet"


class FiTag(rx.Component):
    library = "react-icons/fi"
    tag = "FiTag"


class FiTarget(rx.Component):
    library = "react-icons/fi"
    tag = "FiTarget"


class FiTerminal(rx.Component):
    library = "react-icons/fi"
    tag = "FiTerminal"


class FiThermometer(rx.Component):
    library = "react-icons/fi"
    tag = "FiThermometer"


class FiThumbsDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiThumbsDown"


class FiThumbsUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiThumbsUp"


class FiToggleLeft(rx.Component):
    library = "react-icons/fi"
    tag = "FiToggleLeft"


class FiToggleRight(rx.Component):
    library = "react-icons/fi"
    tag = "FiToggleRight"


class FiTool(rx.Component):
    library = "react-icons/fi"
    tag = "FiTool"


class FiTrash2(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrash2"


class FiTrash(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrash"


class FiTrello(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrello"


class FiTrendingDown(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrendingDown"


class FiTrendingUp(rx.Component):
    library = "react-icons/fi"
    tag = "FiTrendingUp"


class FiTriangle(rx.Component):
    library = "react-icons/fi"
    tag = "FiTriangle"


class FiTruck(rx.Component):
    library = "react-icons/fi"
    tag = "FiTruck"


class FiTv(rx.Component):
    library = "react-icons/fi"
    tag = "FiTv"


class FiTwitch(rx.Component):
    library = "react-icons/fi"
    tag = "FiTwitch"


class FiTwitter(rx.Component):
    library = "react-icons/fi"
    tag = "FiTwitter"


class FiType(rx.Component):
    library = "react-icons/fi"
    tag = "FiType"


class FiUmbrella(rx.Component):
    library = "react-icons/fi"
    tag = "FiUmbrella"


class FiUnderline(rx.Component):
    library = "react-icons/fi"
    tag = "FiUnderline"


class FiUnlock(rx.Component):
    library = "react-icons/fi"
    tag = "FiUnlock"


class FiUploadCloud(rx.Component):
    library = "react-icons/fi"
    tag = "FiUploadCloud"


class FiUpload(rx.Component):
    library = "react-icons/fi"
    tag = "FiUpload"


class FiUserCheck(rx.Component):
    library = "react-icons/fi"
    tag = "FiUserCheck"


class FiUserMinus(rx.Component):
    library = "react-icons/fi"
    tag = "FiUserMinus"


class FiUserPlus(rx.Component):
    library = "react-icons/fi"
    tag = "FiUserPlus"


class FiUserX(rx.Component):
    library = "react-icons/fi"
    tag = "FiUserX"


class FiUser(rx.Component):
    library = "react-icons/fi"
    tag = "FiUser"


class FiUsers(rx.Component):
    library = "react-icons/fi"
    tag = "FiUsers"


class FiVideoOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiVideoOff"


class FiVideo(rx.Component):
    library = "react-icons/fi"
    tag = "FiVideo"


class FiVoicemail(rx.Component):
    library = "react-icons/fi"
    tag = "FiVoicemail"


class FiVolume1(rx.Component):
    library = "react-icons/fi"
    tag = "FiVolume1"


class FiVolume2(rx.Component):
    library = "react-icons/fi"
    tag = "FiVolume2"


class FiVolumeX(rx.Component):
    library = "react-icons/fi"
    tag = "FiVolumeX"


class FiVolume(rx.Component):
    library = "react-icons/fi"
    tag = "FiVolume"


class FiWatch(rx.Component):
    library = "react-icons/fi"
    tag = "FiWatch"


class FiWifiOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiWifiOff"


class FiWifi(rx.Component):
    library = "react-icons/fi"
    tag = "FiWifi"


class FiWind(rx.Component):
    library = "react-icons/fi"
    tag = "FiWind"


class FiXCircle(rx.Component):
    library = "react-icons/fi"
    tag = "FiXCircle"


class FiXOctagon(rx.Component):
    library = "react-icons/fi"
    tag = "FiXOctagon"


class FiXSquare(rx.Component):
    library = "react-icons/fi"
    tag = "FiXSquare"


class FiX(rx.Component):
    library = "react-icons/fi"
    tag = "FiX"


class FiYoutube(rx.Component):
    library = "react-icons/fi"
    tag = "FiYoutube"


class FiZapOff(rx.Component):
    library = "react-icons/fi"
    tag = "FiZapOff"


class FiZap(rx.Component):
    library = "react-icons/fi"
    tag = "FiZap"


class FiZoomIn(rx.Component):
    library = "react-icons/fi"
    tag = "FiZoomIn"


class FiZoomOut(rx.Component):
    library = "react-icons/fi"
    tag = "FiZoomOut"


