import reflex as rx

class FcAbout(rx.Component):
    library = "react-icons/fc"
    tag = "FcAbout"


class FcAcceptDatabase(rx.Component):
    library = "react-icons/fc"
    tag = "FcAcceptDatabase"


class FcAddColumn(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddColumn"


class FcAddDatabase(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddDatabase"


class FcAddImage(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddImage"


class FcAddRow(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddRow"


class FcAddressBook(rx.Component):
    library = "react-icons/fc"
    tag = "FcAddressBook"


class FcAdvance(rx.Component):
    library = "react-icons/fc"
    tag = "FcAdvance"


class FcAdvertising(rx.Component):
    library = "react-icons/fc"
    tag = "FcAdvertising"


class FcAlarmClock(rx.Component):
    library = "react-icons/fc"
    tag = "FcAlarmClock"


class FcAlphabeticalSortingAz(rx.Component):
    library = "react-icons/fc"
    tag = "FcAlphabeticalSortingAz"


class FcAlphabeticalSortingZa(rx.Component):
    library = "react-icons/fc"
    tag = "FcAlphabeticalSortingZa"


class FcAndroidOs(rx.Component):
    library = "react-icons/fc"
    tag = "FcAndroidOs"


class FcAnswers(rx.Component):
    library = "react-icons/fc"
    tag = "FcAnswers"


class FcApproval(rx.Component):
    library = "react-icons/fc"
    tag = "FcApproval"


class FcApprove(rx.Component):
    library = "react-icons/fc"
    tag = "FcApprove"


class FcAreaChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcAreaChart"


class FcAssistant(rx.Component):
    library = "react-icons/fc"
    tag = "FcAssistant"


class FcAudioFile(rx.Component):
    library = "react-icons/fc"
    tag = "FcAudioFile"


class FcAutomatic(rx.Component):
    library = "react-icons/fc"
    tag = "FcAutomatic"


class FcAutomotive(rx.Component):
    library = "react-icons/fc"
    tag = "FcAutomotive"


class FcBadDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcBadDecision"


class FcBarChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcBarChart"


class FcBbc(rx.Component):
    library = "react-icons/fc"
    tag = "FcBbc"


class FcBearish(rx.Component):
    library = "react-icons/fc"
    tag = "FcBearish"


class FcBinoculars(rx.Component):
    library = "react-icons/fc"
    tag = "FcBinoculars"


class FcBiohazard(rx.Component):
    library = "react-icons/fc"
    tag = "FcBiohazard"


class FcBiomass(rx.Component):
    library = "react-icons/fc"
    tag = "FcBiomass"


class FcBiotech(rx.Component):
    library = "react-icons/fc"
    tag = "FcBiotech"


class FcBookmark(rx.Component):
    library = "react-icons/fc"
    tag = "FcBookmark"


class FcBriefcase(rx.Component):
    library = "react-icons/fc"
    tag = "FcBriefcase"


class FcBrokenLink(rx.Component):
    library = "react-icons/fc"
    tag = "FcBrokenLink"


class FcBullish(rx.Component):
    library = "react-icons/fc"
    tag = "FcBullish"


class FcBusinessContact(rx.Component):
    library = "react-icons/fc"
    tag = "FcBusinessContact"


class FcBusiness(rx.Component):
    library = "react-icons/fc"
    tag = "FcBusiness"


class FcBusinessman(rx.Component):
    library = "react-icons/fc"
    tag = "FcBusinessman"


class FcBusinesswoman(rx.Component):
    library = "react-icons/fc"
    tag = "FcBusinesswoman"


class FcButtingIn(rx.Component):
    library = "react-icons/fc"
    tag = "FcButtingIn"


class FcCableRelease(rx.Component):
    library = "react-icons/fc"
    tag = "FcCableRelease"


class FcCalculator(rx.Component):
    library = "react-icons/fc"
    tag = "FcCalculator"


class FcCalendar(rx.Component):
    library = "react-icons/fc"
    tag = "FcCalendar"


class FcCallTransfer(rx.Component):
    library = "react-icons/fc"
    tag = "FcCallTransfer"


class FcCallback(rx.Component):
    library = "react-icons/fc"
    tag = "FcCallback"


class FcCamcorderPro(rx.Component):
    library = "react-icons/fc"
    tag = "FcCamcorderPro"


class FcCamcorder(rx.Component):
    library = "react-icons/fc"
    tag = "FcCamcorder"


class FcCameraAddon(rx.Component):
    library = "react-icons/fc"
    tag = "FcCameraAddon"


class FcCameraIdentification(rx.Component):
    library = "react-icons/fc"
    tag = "FcCameraIdentification"


class FcCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcCamera"


class FcCancel(rx.Component):
    library = "react-icons/fc"
    tag = "FcCancel"


class FcCandleSticks(rx.Component):
    library = "react-icons/fc"
    tag = "FcCandleSticks"


class FcCapacitor(rx.Component):
    library = "react-icons/fc"
    tag = "FcCapacitor"


class FcCdLogo(rx.Component):
    library = "react-icons/fc"
    tag = "FcCdLogo"


class FcCellPhone(rx.Component):
    library = "react-icons/fc"
    tag = "FcCellPhone"


class FcChargeBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcChargeBattery"


class FcCheckmark(rx.Component):
    library = "react-icons/fc"
    tag = "FcCheckmark"


class FcCircuit(rx.Component):
    library = "react-icons/fc"
    tag = "FcCircuit"


class FcClapperboard(rx.Component):
    library = "react-icons/fc"
    tag = "FcClapperboard"


class FcClearFilters(rx.Component):
    library = "react-icons/fc"
    tag = "FcClearFilters"


class FcClock(rx.Component):
    library = "react-icons/fc"
    tag = "FcClock"


class FcCloseUpMode(rx.Component):
    library = "react-icons/fc"
    tag = "FcCloseUpMode"


class FcCloth(rx.Component):
    library = "react-icons/fc"
    tag = "FcCloth"


class FcCollaboration(rx.Component):
    library = "react-icons/fc"
    tag = "FcCollaboration"


class FcCollapse(rx.Component):
    library = "react-icons/fc"
    tag = "FcCollapse"


class FcCollect(rx.Component):
    library = "react-icons/fc"
    tag = "FcCollect"


class FcComboChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcComboChart"


class FcCommandLine(rx.Component):
    library = "react-icons/fc"
    tag = "FcCommandLine"


class FcComments(rx.Component):
    library = "react-icons/fc"
    tag = "FcComments"


class FcCompactCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcCompactCamera"


class FcConferenceCall(rx.Component):
    library = "react-icons/fc"
    tag = "FcConferenceCall"


class FcContacts(rx.Component):
    library = "react-icons/fc"
    tag = "FcContacts"


class FcCopyleft(rx.Component):
    library = "react-icons/fc"
    tag = "FcCopyleft"


class FcCopyright(rx.Component):
    library = "react-icons/fc"
    tag = "FcCopyright"


class FcCrystalOscillator(rx.Component):
    library = "react-icons/fc"
    tag = "FcCrystalOscillator"


class FcCurrencyExchange(rx.Component):
    library = "react-icons/fc"
    tag = "FcCurrencyExchange"


class FcCursor(rx.Component):
    library = "react-icons/fc"
    tag = "FcCursor"


class FcCustomerSupport(rx.Component):
    library = "react-icons/fc"
    tag = "FcCustomerSupport"


class FcDam(rx.Component):
    library = "react-icons/fc"
    tag = "FcDam"


class FcDataBackup(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataBackup"


class FcDataConfiguration(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataConfiguration"


class FcDataEncryption(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataEncryption"


class FcDataProtection(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataProtection"


class FcDataRecovery(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataRecovery"


class FcDataSheet(rx.Component):
    library = "react-icons/fc"
    tag = "FcDataSheet"


class FcDatabase(rx.Component):
    library = "react-icons/fc"
    tag = "FcDatabase"


class FcDebian(rx.Component):
    library = "react-icons/fc"
    tag = "FcDebian"


class FcDebt(rx.Component):
    library = "react-icons/fc"
    tag = "FcDebt"


class FcDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcDecision"


class FcDeleteColumn(rx.Component):
    library = "react-icons/fc"
    tag = "FcDeleteColumn"


class FcDeleteDatabase(rx.Component):
    library = "react-icons/fc"
    tag = "FcDeleteDatabase"


class FcDeleteRow(rx.Component):
    library = "react-icons/fc"
    tag = "FcDeleteRow"


class FcDepartment(rx.Component):
    library = "react-icons/fc"
    tag = "FcDepartment"


class FcDeployment(rx.Component):
    library = "react-icons/fc"
    tag = "FcDeployment"


class FcDiploma1(rx.Component):
    library = "react-icons/fc"
    tag = "FcDiploma1"


class FcDiploma2(rx.Component):
    library = "react-icons/fc"
    tag = "FcDiploma2"


class FcDisapprove(rx.Component):
    library = "react-icons/fc"
    tag = "FcDisapprove"


class FcDisclaimer(rx.Component):
    library = "react-icons/fc"
    tag = "FcDisclaimer"


class FcDislike(rx.Component):
    library = "react-icons/fc"
    tag = "FcDislike"


class FcDisplay(rx.Component):
    library = "react-icons/fc"
    tag = "FcDisplay"


class FcDoNotInhale(rx.Component):
    library = "react-icons/fc"
    tag = "FcDoNotInhale"


class FcDoNotInsert(rx.Component):
    library = "react-icons/fc"
    tag = "FcDoNotInsert"


class FcDoNotMix(rx.Component):
    library = "react-icons/fc"
    tag = "FcDoNotMix"


class FcDocument(rx.Component):
    library = "react-icons/fc"
    tag = "FcDocument"


class FcDonate(rx.Component):
    library = "react-icons/fc"
    tag = "FcDonate"


class FcDoughnutChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcDoughnutChart"


class FcDownLeft(rx.Component):
    library = "react-icons/fc"
    tag = "FcDownLeft"


class FcDownRight(rx.Component):
    library = "react-icons/fc"
    tag = "FcDownRight"


class FcDown(rx.Component):
    library = "react-icons/fc"
    tag = "FcDown"


class FcDownload(rx.Component):
    library = "react-icons/fc"
    tag = "FcDownload"


class FcDribbble(rx.Component):
    library = "react-icons/fc"
    tag = "FcDribbble"


class FcDvdLogo(rx.Component):
    library = "react-icons/fc"
    tag = "FcDvdLogo"


class FcEditImage(rx.Component):
    library = "react-icons/fc"
    tag = "FcEditImage"


class FcElectricalSensor(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectricalSensor"


class FcElectricalThreshold(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectricalThreshold"


class FcElectricity(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectricity"


class FcElectroDevices(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectroDevices"


class FcElectronics(rx.Component):
    library = "react-icons/fc"
    tag = "FcElectronics"


class FcEmptyBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcEmptyBattery"


class FcEmptyFilter(rx.Component):
    library = "react-icons/fc"
    tag = "FcEmptyFilter"


class FcEmptyTrash(rx.Component):
    library = "react-icons/fc"
    tag = "FcEmptyTrash"


class FcEndCall(rx.Component):
    library = "react-icons/fc"
    tag = "FcEndCall"


class FcEngineering(rx.Component):
    library = "react-icons/fc"
    tag = "FcEngineering"


class FcEnteringHeavenAlive(rx.Component):
    library = "react-icons/fc"
    tag = "FcEnteringHeavenAlive"


class FcExpand(rx.Component):
    library = "react-icons/fc"
    tag = "FcExpand"


class FcExpired(rx.Component):
    library = "react-icons/fc"
    tag = "FcExpired"


class FcExport(rx.Component):
    library = "react-icons/fc"
    tag = "FcExport"


class FcExternal(rx.Component):
    library = "react-icons/fc"
    tag = "FcExternal"


class FcFactoryBreakdown(rx.Component):
    library = "react-icons/fc"
    tag = "FcFactoryBreakdown"


class FcFactory(rx.Component):
    library = "react-icons/fc"
    tag = "FcFactory"


class FcFaq(rx.Component):
    library = "react-icons/fc"
    tag = "FcFaq"


class FcFeedIn(rx.Component):
    library = "react-icons/fc"
    tag = "FcFeedIn"


class FcFeedback(rx.Component):
    library = "react-icons/fc"
    tag = "FcFeedback"


class FcFile(rx.Component):
    library = "react-icons/fc"
    tag = "FcFile"


class FcFilingCabinet(rx.Component):
    library = "react-icons/fc"
    tag = "FcFilingCabinet"


class FcFilledFilter(rx.Component):
    library = "react-icons/fc"
    tag = "FcFilledFilter"


class FcFilmReel(rx.Component):
    library = "react-icons/fc"
    tag = "FcFilmReel"


class FcFilm(rx.Component):
    library = "react-icons/fc"
    tag = "FcFilm"


class FcFinePrint(rx.Component):
    library = "react-icons/fc"
    tag = "FcFinePrint"


class FcFlashAuto(rx.Component):
    library = "react-icons/fc"
    tag = "FcFlashAuto"


class FcFlashOff(rx.Component):
    library = "react-icons/fc"
    tag = "FcFlashOff"


class FcFlashOn(rx.Component):
    library = "react-icons/fc"
    tag = "FcFlashOn"


class FcFlowChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcFlowChart"


class FcFolder(rx.Component):
    library = "react-icons/fc"
    tag = "FcFolder"


class FcFrame(rx.Component):
    library = "react-icons/fc"
    tag = "FcFrame"


class FcFullBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcFullBattery"


class FcFullTrash(rx.Component):
    library = "react-icons/fc"
    tag = "FcFullTrash"


class FcGallery(rx.Component):
    library = "react-icons/fc"
    tag = "FcGallery"


class FcGenealogy(rx.Component):
    library = "react-icons/fc"
    tag = "FcGenealogy"


class FcGenericSortingAsc(rx.Component):
    library = "react-icons/fc"
    tag = "FcGenericSortingAsc"


class FcGenericSortingDesc(rx.Component):
    library = "react-icons/fc"
    tag = "FcGenericSortingDesc"


class FcGlobe(rx.Component):
    library = "react-icons/fc"
    tag = "FcGlobe"


class FcGoodDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcGoodDecision"


class FcGoogle(rx.Component):
    library = "react-icons/fc"
    tag = "FcGoogle"


class FcGraduationCap(rx.Component):
    library = "react-icons/fc"
    tag = "FcGraduationCap"


class FcGrid(rx.Component):
    library = "react-icons/fc"
    tag = "FcGrid"


class FcHeadset(rx.Component):
    library = "react-icons/fc"
    tag = "FcHeadset"


class FcHeatMap(rx.Component):
    library = "react-icons/fc"
    tag = "FcHeatMap"


class FcHighBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcHighBattery"


class FcHighPriority(rx.Component):
    library = "react-icons/fc"
    tag = "FcHighPriority"


class FcHome(rx.Component):
    library = "react-icons/fc"
    tag = "FcHome"


class FcIcons8Cup(rx.Component):
    library = "react-icons/fc"
    tag = "FcIcons8Cup"


class FcIdea(rx.Component):
    library = "react-icons/fc"
    tag = "FcIdea"


class FcImageFile(rx.Component):
    library = "react-icons/fc"
    tag = "FcImageFile"


class FcImport(rx.Component):
    library = "react-icons/fc"
    tag = "FcImport"


class FcInTransit(rx.Component):
    library = "react-icons/fc"
    tag = "FcInTransit"


class FcInfo(rx.Component):
    library = "react-icons/fc"
    tag = "FcInfo"


class FcInspection(rx.Component):
    library = "react-icons/fc"
    tag = "FcInspection"


class FcIntegratedWebcam(rx.Component):
    library = "react-icons/fc"
    tag = "FcIntegratedWebcam"


class FcInternal(rx.Component):
    library = "react-icons/fc"
    tag = "FcInternal"


class FcInvite(rx.Component):
    library = "react-icons/fc"
    tag = "FcInvite"


class FcIpad(rx.Component):
    library = "react-icons/fc"
    tag = "FcIpad"


class FcIphone(rx.Component):
    library = "react-icons/fc"
    tag = "FcIphone"


class FcKey(rx.Component):
    library = "react-icons/fc"
    tag = "FcKey"


class FcKindle(rx.Component):
    library = "react-icons/fc"
    tag = "FcKindle"


class FcLandscape(rx.Component):
    library = "react-icons/fc"
    tag = "FcLandscape"


class FcLeave(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeave"


class FcLeftDown(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeftDown"


class FcLeftDown2(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeftDown2"


class FcLeftUp(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeftUp"


class FcLeftUp2(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeftUp2"


class FcLeft(rx.Component):
    library = "react-icons/fc"
    tag = "FcLeft"


class FcLibrary(rx.Component):
    library = "react-icons/fc"
    tag = "FcLibrary"


class FcLightAtTheEndOfTunnel(rx.Component):
    library = "react-icons/fc"
    tag = "FcLightAtTheEndOfTunnel"


class FcLikePlaceholder(rx.Component):
    library = "react-icons/fc"
    tag = "FcLikePlaceholder"


class FcLike(rx.Component):
    library = "react-icons/fc"
    tag = "FcLike"


class FcLineChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcLineChart"


class FcLink(rx.Component):
    library = "react-icons/fc"
    tag = "FcLink"


class FcLinux(rx.Component):
    library = "react-icons/fc"
    tag = "FcLinux"


class FcList(rx.Component):
    library = "react-icons/fc"
    tag = "FcList"


class FcLockLandscape(rx.Component):
    library = "react-icons/fc"
    tag = "FcLockLandscape"


class FcLockPortrait(rx.Component):
    library = "react-icons/fc"
    tag = "FcLockPortrait"


class FcLock(rx.Component):
    library = "react-icons/fc"
    tag = "FcLock"


class FcLowBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcLowBattery"


class FcLowPriority(rx.Component):
    library = "react-icons/fc"
    tag = "FcLowPriority"


class FcMakeDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcMakeDecision"


class FcManager(rx.Component):
    library = "react-icons/fc"
    tag = "FcManager"


class FcMediumPriority(rx.Component):
    library = "react-icons/fc"
    tag = "FcMediumPriority"


class FcMenu(rx.Component):
    library = "react-icons/fc"
    tag = "FcMenu"


class FcMiddleBattery(rx.Component):
    library = "react-icons/fc"
    tag = "FcMiddleBattery"


class FcMindMap(rx.Component):
    library = "react-icons/fc"
    tag = "FcMindMap"


class FcMinus(rx.Component):
    library = "react-icons/fc"
    tag = "FcMinus"


class FcMissedCall(rx.Component):
    library = "react-icons/fc"
    tag = "FcMissedCall"


class FcMms(rx.Component):
    library = "react-icons/fc"
    tag = "FcMms"


class FcMoneyTransfer(rx.Component):
    library = "react-icons/fc"
    tag = "FcMoneyTransfer"


class FcMultipleCameras(rx.Component):
    library = "react-icons/fc"
    tag = "FcMultipleCameras"


class FcMultipleDevices(rx.Component):
    library = "react-icons/fc"
    tag = "FcMultipleDevices"


class FcMultipleInputs(rx.Component):
    library = "react-icons/fc"
    tag = "FcMultipleInputs"


class FcMultipleSmartphones(rx.Component):
    library = "react-icons/fc"
    tag = "FcMultipleSmartphones"


class FcMusic(rx.Component):
    library = "react-icons/fc"
    tag = "FcMusic"


class FcNegativeDynamic(rx.Component):
    library = "react-icons/fc"
    tag = "FcNegativeDynamic"


class FcNeutralDecision(rx.Component):
    library = "react-icons/fc"
    tag = "FcNeutralDecision"


class FcNeutralTrading(rx.Component):
    library = "react-icons/fc"
    tag = "FcNeutralTrading"


class FcNews(rx.Component):
    library = "react-icons/fc"
    tag = "FcNews"


class FcNext(rx.Component):
    library = "react-icons/fc"
    tag = "FcNext"


class FcNfcSign(rx.Component):
    library = "react-icons/fc"
    tag = "FcNfcSign"


class FcNightLandscape(rx.Component):
    library = "react-icons/fc"
    tag = "FcNightLandscape"


class FcNightPortrait(rx.Component):
    library = "react-icons/fc"
    tag = "FcNightPortrait"


class FcNoIdea(rx.Component):
    library = "react-icons/fc"
    tag = "FcNoIdea"


class FcNoVideo(rx.Component):
    library = "react-icons/fc"
    tag = "FcNoVideo"


class FcNook(rx.Component):
    library = "react-icons/fc"
    tag = "FcNook"


class FcNumericalSorting12(rx.Component):
    library = "react-icons/fc"
    tag = "FcNumericalSorting12"


class FcNumericalSorting21(rx.Component):
    library = "react-icons/fc"
    tag = "FcNumericalSorting21"


class FcOk(rx.Component):
    library = "react-icons/fc"
    tag = "FcOk"


class FcOldTimeCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcOldTimeCamera"


class FcOnlineSupport(rx.Component):
    library = "react-icons/fc"
    tag = "FcOnlineSupport"


class FcOpenedFolder(rx.Component):
    library = "react-icons/fc"
    tag = "FcOpenedFolder"


class FcOrgUnit(rx.Component):
    library = "react-icons/fc"
    tag = "FcOrgUnit"


class FcOrganization(rx.Component):
    library = "react-icons/fc"
    tag = "FcOrganization"


class FcOvertime(rx.Component):
    library = "react-icons/fc"
    tag = "FcOvertime"


class FcPackage(rx.Component):
    library = "react-icons/fc"
    tag = "FcPackage"


class FcPaid(rx.Component):
    library = "react-icons/fc"
    tag = "FcPaid"


class FcPanorama(rx.Component):
    library = "react-icons/fc"
    tag = "FcPanorama"


class FcParallelTasks(rx.Component):
    library = "react-icons/fc"
    tag = "FcParallelTasks"


class FcPhoneAndroid(rx.Component):
    library = "react-icons/fc"
    tag = "FcPhoneAndroid"


class FcPhone(rx.Component):
    library = "react-icons/fc"
    tag = "FcPhone"


class FcPhotoReel(rx.Component):
    library = "react-icons/fc"
    tag = "FcPhotoReel"


class FcPicture(rx.Component):
    library = "react-icons/fc"
    tag = "FcPicture"


class FcPieChart(rx.Component):
    library = "react-icons/fc"
    tag = "FcPieChart"


class FcPlanner(rx.Component):
    library = "react-icons/fc"
    tag = "FcPlanner"


class FcPlus(rx.Component):
    library = "react-icons/fc"
    tag = "FcPlus"


class FcPodiumWithAudience(rx.Component):
    library = "react-icons/fc"
    tag = "FcPodiumWithAudience"


class FcPodiumWithSpeaker(rx.Component):
    library = "react-icons/fc"
    tag = "FcPodiumWithSpeaker"


class FcPodiumWithoutSpeaker(rx.Component):
    library = "react-icons/fc"
    tag = "FcPodiumWithoutSpeaker"


class FcPortraitMode(rx.Component):
    library = "react-icons/fc"
    tag = "FcPortraitMode"


class FcPositiveDynamic(rx.Component):
    library = "react-icons/fc"
    tag = "FcPositiveDynamic"


class FcPrevious(rx.Component):
    library = "react-icons/fc"
    tag = "FcPrevious"


class FcPrint(rx.Component):
    library = "react-icons/fc"
    tag = "FcPrint"


class FcPrivacy(rx.Component):
    library = "react-icons/fc"
    tag = "FcPrivacy"


class FcProcess(rx.Component):
    library = "react-icons/fc"
    tag = "FcProcess"


class FcPuzzle(rx.Component):
    library = "react-icons/fc"
    tag = "FcPuzzle"


class FcQuestions(rx.Component):
    library = "react-icons/fc"
    tag = "FcQuestions"


class FcRadarPlot(rx.Component):
    library = "react-icons/fc"
    tag = "FcRadarPlot"


class FcRating(rx.Component):
    library = "react-icons/fc"
    tag = "FcRating"


class FcRatings(rx.Component):
    library = "react-icons/fc"
    tag = "FcRatings"


class FcReadingEbook(rx.Component):
    library = "react-icons/fc"
    tag = "FcReadingEbook"


class FcReading(rx.Component):
    library = "react-icons/fc"
    tag = "FcReading"


class FcReddit(rx.Component):
    library = "react-icons/fc"
    tag = "FcReddit"


class FcRedo(rx.Component):
    library = "react-icons/fc"
    tag = "FcRedo"


class FcRefresh(rx.Component):
    library = "react-icons/fc"
    tag = "FcRefresh"


class FcRegisteredTrademark(rx.Component):
    library = "react-icons/fc"
    tag = "FcRegisteredTrademark"


class FcRemoveImage(rx.Component):
    library = "react-icons/fc"
    tag = "FcRemoveImage"


class FcReuse(rx.Component):
    library = "react-icons/fc"
    tag = "FcReuse"


class FcRightDown(rx.Component):
    library = "react-icons/fc"
    tag = "FcRightDown"


class FcRightDown2(rx.Component):
    library = "react-icons/fc"
    tag = "FcRightDown2"


class FcRightUp(rx.Component):
    library = "react-icons/fc"
    tag = "FcRightUp"


class FcRightUp2(rx.Component):
    library = "react-icons/fc"
    tag = "FcRightUp2"


class FcRight(rx.Component):
    library = "react-icons/fc"
    tag = "FcRight"


class FcRotateCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcRotateCamera"


class FcRotateToLandscape(rx.Component):
    library = "react-icons/fc"
    tag = "FcRotateToLandscape"


class FcRotateToPortrait(rx.Component):
    library = "react-icons/fc"
    tag = "FcRotateToPortrait"


class FcRuler(rx.Component):
    library = "react-icons/fc"
    tag = "FcRuler"


class FcRules(rx.Component):
    library = "react-icons/fc"
    tag = "FcRules"


class FcSafe(rx.Component):
    library = "react-icons/fc"
    tag = "FcSafe"


class FcSalesPerformance(rx.Component):
    library = "react-icons/fc"
    tag = "FcSalesPerformance"


class FcScatterPlot(rx.Component):
    library = "react-icons/fc"
    tag = "FcScatterPlot"


class FcSearch(rx.Component):
    library = "react-icons/fc"
    tag = "FcSearch"


class FcSelfServiceKiosk(rx.Component):
    library = "react-icons/fc"
    tag = "FcSelfServiceKiosk"


class FcSelfie(rx.Component):
    library = "react-icons/fc"
    tag = "FcSelfie"


class FcSerialTasks(rx.Component):
    library = "react-icons/fc"
    tag = "FcSerialTasks"


class FcServiceMark(rx.Component):
    library = "react-icons/fc"
    tag = "FcServiceMark"


class FcServices(rx.Component):
    library = "react-icons/fc"
    tag = "FcServices"


class FcSettings(rx.Component):
    library = "react-icons/fc"
    tag = "FcSettings"


class FcShare(rx.Component):
    library = "react-icons/fc"
    tag = "FcShare"


class FcShipped(rx.Component):
    library = "react-icons/fc"
    tag = "FcShipped"


class FcShop(rx.Component):
    library = "react-icons/fc"
    tag = "FcShop"


class FcSignature(rx.Component):
    library = "react-icons/fc"
    tag = "FcSignature"


class FcSimCardChip(rx.Component):
    library = "react-icons/fc"
    tag = "FcSimCardChip"


class FcSimCard(rx.Component):
    library = "react-icons/fc"
    tag = "FcSimCard"


class FcSlrBackSide(rx.Component):
    library = "react-icons/fc"
    tag = "FcSlrBackSide"


class FcSmartphoneTablet(rx.Component):
    library = "react-icons/fc"
    tag = "FcSmartphoneTablet"


class FcSms(rx.Component):
    library = "react-icons/fc"
    tag = "FcSms"


class FcSoundRecordingCopyright(rx.Component):
    library = "react-icons/fc"
    tag = "FcSoundRecordingCopyright"


class FcSpeaker(rx.Component):
    library = "react-icons/fc"
    tag = "FcSpeaker"


class FcSportsMode(rx.Component):
    library = "react-icons/fc"
    tag = "FcSportsMode"


class FcStackOfPhotos(rx.Component):
    library = "react-icons/fc"
    tag = "FcStackOfPhotos"


class FcStart(rx.Component):
    library = "react-icons/fc"
    tag = "FcStart"


class FcStatistics(rx.Component):
    library = "react-icons/fc"
    tag = "FcStatistics"


class FcSteam(rx.Component):
    library = "react-icons/fc"
    tag = "FcSteam"


class FcStumbleupon(rx.Component):
    library = "react-icons/fc"
    tag = "FcStumbleupon"


class FcSupport(rx.Component):
    library = "react-icons/fc"
    tag = "FcSupport"


class FcSurvey(rx.Component):
    library = "react-icons/fc"
    tag = "FcSurvey"


class FcSwitchCamera(rx.Component):
    library = "react-icons/fc"
    tag = "FcSwitchCamera"


class FcSynchronize(rx.Component):
    library = "react-icons/fc"
    tag = "FcSynchronize"


class FcTabletAndroid(rx.Component):
    library = "react-icons/fc"
    tag = "FcTabletAndroid"


class FcTemplate(rx.Component):
    library = "react-icons/fc"
    tag = "FcTemplate"


class FcTimeline(rx.Component):
    library = "react-icons/fc"
    tag = "FcTimeline"


class FcTodoList(rx.Component):
    library = "react-icons/fc"
    tag = "FcTodoList"


class FcTouchscreenSmartphone(rx.Component):
    library = "react-icons/fc"
    tag = "FcTouchscreenSmartphone"


class FcTrademark(rx.Component):
    library = "react-icons/fc"
    tag = "FcTrademark"


class FcTreeStructure(rx.Component):
    library = "react-icons/fc"
    tag = "FcTreeStructure"


class FcTwoSmartphones(rx.Component):
    library = "react-icons/fc"
    tag = "FcTwoSmartphones"


class FcUndo(rx.Component):
    library = "react-icons/fc"
    tag = "FcUndo"


class FcUnlock(rx.Component):
    library = "react-icons/fc"
    tag = "FcUnlock"


class FcUpLeft(rx.Component):
    library = "react-icons/fc"
    tag = "FcUpLeft"


class FcUpRight(rx.Component):
    library = "react-icons/fc"
    tag = "FcUpRight"


class FcUp(rx.Component):
    library = "react-icons/fc"
    tag = "FcUp"


class FcUpload(rx.Component):
    library = "react-icons/fc"
    tag = "FcUpload"


class FcUsb(rx.Component):
    library = "react-icons/fc"
    tag = "FcUsb"


class FcVideoCall(rx.Component):
    library = "react-icons/fc"
    tag = "FcVideoCall"


class FcVideoFile(rx.Component):
    library = "react-icons/fc"
    tag = "FcVideoFile"


class FcVideoProjector(rx.Component):
    library = "react-icons/fc"
    tag = "FcVideoProjector"


class FcViewDetails(rx.Component):
    library = "react-icons/fc"
    tag = "FcViewDetails"


class FcVip(rx.Component):
    library = "react-icons/fc"
    tag = "FcVip"


class FcVlc(rx.Component):
    library = "react-icons/fc"
    tag = "FcVlc"


class FcVoicePresentation(rx.Component):
    library = "react-icons/fc"
    tag = "FcVoicePresentation"


class FcVoicemail(rx.Component):
    library = "react-icons/fc"
    tag = "FcVoicemail"


class FcWebcam(rx.Component):
    library = "react-icons/fc"
    tag = "FcWebcam"


class FcWiFiLogo(rx.Component):
    library = "react-icons/fc"
    tag = "FcWiFiLogo"


class FcWikipedia(rx.Component):
    library = "react-icons/fc"
    tag = "FcWikipedia"


class FcWorkflow(rx.Component):
    library = "react-icons/fc"
    tag = "FcWorkflow"


