import reflex as rx

class CiAirportSign1(rx.Component):
    library = "react-icons/ci"
    tag = "CiAirportSign1"


class CiAlarmOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlarmOff"


class CiAlarmOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlarmOn"


class CiAlignBottom(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignBottom"


class CiAlignCenterH(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignCenterH"


class CiAlignCenterV(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignCenterV"


class CiAlignLeft(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignLeft"


class CiAlignRight(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignRight"


class CiAlignTop(rx.Component):
    library = "react-icons/ci"
    tag = "CiAlignTop"


class CiApple(rx.Component):
    library = "react-icons/ci"
    tag = "CiApple"


class CiAt(rx.Component):
    library = "react-icons/ci"
    tag = "CiAt"


class CiAvocado(rx.Component):
    library = "react-icons/ci"
    tag = "CiAvocado"


class CiBacon(rx.Component):
    library = "react-icons/ci"
    tag = "CiBacon"


class CiBadgeDollar(rx.Component):
    library = "react-icons/ci"
    tag = "CiBadgeDollar"


class CiBag1(rx.Component):
    library = "react-icons/ci"
    tag = "CiBag1"


class CiBandage(rx.Component):
    library = "react-icons/ci"
    tag = "CiBandage"


class CiBank(rx.Component):
    library = "react-icons/ci"
    tag = "CiBank"


class CiBarcode(rx.Component):
    library = "react-icons/ci"
    tag = "CiBarcode"


class CiBaseball(rx.Component):
    library = "react-icons/ci"
    tag = "CiBaseball"


class CiBasketball(rx.Component):
    library = "react-icons/ci"
    tag = "CiBasketball"


class CiBatteryCharging(rx.Component):
    library = "react-icons/ci"
    tag = "CiBatteryCharging"


class CiBatteryEmpty(rx.Component):
    library = "react-icons/ci"
    tag = "CiBatteryEmpty"


class CiBatteryFull(rx.Component):
    library = "react-icons/ci"
    tag = "CiBatteryFull"


class CiBeaker1(rx.Component):
    library = "react-icons/ci"
    tag = "CiBeaker1"


class CiBeerMugFull(rx.Component):
    library = "react-icons/ci"
    tag = "CiBeerMugFull"


class CiBellOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiBellOff"


class CiBellOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiBellOn"


class CiBezier(rx.Component):
    library = "react-icons/ci"
    tag = "CiBezier"


class CiBitcoin(rx.Component):
    library = "react-icons/ci"
    tag = "CiBitcoin"


class CiBluetooth(rx.Component):
    library = "react-icons/ci"
    tag = "CiBluetooth"


class CiBookmarkCheck(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmarkCheck"


class CiBookmarkMinus(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmarkMinus"


class CiBookmarkPlus(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmarkPlus"


class CiBookmarkRemove(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmarkRemove"


class CiBookmark(rx.Component):
    library = "react-icons/ci"
    tag = "CiBookmark"


class CiBowlNoodles(rx.Component):
    library = "react-icons/ci"
    tag = "CiBowlNoodles"


class CiBoxList(rx.Component):
    library = "react-icons/ci"
    tag = "CiBoxList"


class CiBoxes(rx.Component):
    library = "react-icons/ci"
    tag = "CiBoxes"


class CiBrightnessDown(rx.Component):
    library = "react-icons/ci"
    tag = "CiBrightnessDown"


class CiBrightnessUp(rx.Component):
    library = "react-icons/ci"
    tag = "CiBrightnessUp"


class CiBullhorn(rx.Component):
    library = "react-icons/ci"
    tag = "CiBullhorn"


class CiBurger(rx.Component):
    library = "react-icons/ci"
    tag = "CiBurger"


class CiCalculator1(rx.Component):
    library = "react-icons/ci"
    tag = "CiCalculator1"


class CiCalculator2(rx.Component):
    library = "react-icons/ci"
    tag = "CiCalculator2"


class CiCalendarDate(rx.Component):
    library = "react-icons/ci"
    tag = "CiCalendarDate"


class CiCalendar(rx.Component):
    library = "react-icons/ci"
    tag = "CiCalendar"


class CiCamera(rx.Component):
    library = "react-icons/ci"
    tag = "CiCamera"


class CiChat1(rx.Component):
    library = "react-icons/ci"
    tag = "CiChat1"


class CiChat2(rx.Component):
    library = "react-icons/ci"
    tag = "CiChat2"


class CiCircleAlert(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleAlert"


class CiCircleCheck(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleCheck"


class CiCircleChevDown(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleChevDown"


class CiCircleChevLeft(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleChevLeft"


class CiCircleChevRight(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleChevRight"


class CiCircleChevUp(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleChevUp"


class CiCircleInfo(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleInfo"


class CiCircleList(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleList"


class CiCircleMinus(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleMinus"


class CiCircleMore(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleMore"


class CiCirclePlus(rx.Component):
    library = "react-icons/ci"
    tag = "CiCirclePlus"


class CiCircleQuestion(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleQuestion"


class CiCircleRemove(rx.Component):
    library = "react-icons/ci"
    tag = "CiCircleRemove"


class CiClock1(rx.Component):
    library = "react-icons/ci"
    tag = "CiClock1"


class CiClock2(rx.Component):
    library = "react-icons/ci"
    tag = "CiClock2"


class CiCloudDrizzle(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudDrizzle"


class CiCloudMoon(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudMoon"


class CiCloudOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudOff"


class CiCloudOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudOn"


class CiCloudRainbow(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudRainbow"


class CiCloudSun(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloudSun"


class CiCloud(rx.Component):
    library = "react-icons/ci"
    tag = "CiCloud"


class CiCoffeeBean(rx.Component):
    library = "react-icons/ci"
    tag = "CiCoffeeBean"


class CiCoffeeCup(rx.Component):
    library = "react-icons/ci"
    tag = "CiCoffeeCup"


class CiCoinInsert(rx.Component):
    library = "react-icons/ci"
    tag = "CiCoinInsert"


class CiCoins1(rx.Component):
    library = "react-icons/ci"
    tag = "CiCoins1"


class CiCompass1(rx.Component):
    library = "react-icons/ci"
    tag = "CiCompass1"


class CiCreditCard1(rx.Component):
    library = "react-icons/ci"
    tag = "CiCreditCard1"


class CiCreditCard2(rx.Component):
    library = "react-icons/ci"
    tag = "CiCreditCard2"


class CiCreditCardOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiCreditCardOff"


class CiCrop(rx.Component):
    library = "react-icons/ci"
    tag = "CiCrop"


class CiDark(rx.Component):
    library = "react-icons/ci"
    tag = "CiDark"


class CiDatabase(rx.Component):
    library = "react-icons/ci"
    tag = "CiDatabase"


class CiDeliveryTruck(rx.Component):
    library = "react-icons/ci"
    tag = "CiDeliveryTruck"


class CiDesktopMouse1(rx.Component):
    library = "react-icons/ci"
    tag = "CiDesktopMouse1"


class CiDesktopMouse2(rx.Component):
    library = "react-icons/ci"
    tag = "CiDesktopMouse2"


class CiDesktop(rx.Component):
    library = "react-icons/ci"
    tag = "CiDesktop"


class CiDiscount1(rx.Component):
    library = "react-icons/ci"
    tag = "CiDiscount1"


class CiDollar(rx.Component):
    library = "react-icons/ci"
    tag = "CiDollar"


class CiDroplet(rx.Component):
    library = "react-icons/ci"
    tag = "CiDroplet"


class CiDumbbell(rx.Component):
    library = "react-icons/ci"
    tag = "CiDumbbell"


class CiEdit(rx.Component):
    library = "react-icons/ci"
    tag = "CiEdit"


class CiEraser(rx.Component):
    library = "react-icons/ci"
    tag = "CiEraser"


class CiExport(rx.Component):
    library = "react-icons/ci"
    tag = "CiExport"


class CiFaceFrown(rx.Component):
    library = "react-icons/ci"
    tag = "CiFaceFrown"


class CiFaceMeh(rx.Component):
    library = "react-icons/ci"
    tag = "CiFaceMeh"


class CiFaceSmile(rx.Component):
    library = "react-icons/ci"
    tag = "CiFaceSmile"


class CiFacebook(rx.Component):
    library = "react-icons/ci"
    tag = "CiFacebook"


class CiFileOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiFileOff"


class CiFileOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiFileOn"


class CiFilter(rx.Component):
    library = "react-icons/ci"
    tag = "CiFilter"


class CiFlag1(rx.Component):
    library = "react-icons/ci"
    tag = "CiFlag1"


class CiFloppyDisk(rx.Component):
    library = "react-icons/ci"
    tag = "CiFloppyDisk"


class CiFolderOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiFolderOff"


class CiFolderOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiFolderOn"


class CiFootball(rx.Component):
    library = "react-icons/ci"
    tag = "CiFootball"


class CiForkAndKnife(rx.Component):
    library = "react-icons/ci"
    tag = "CiForkAndKnife"


class CiFries(rx.Component):
    library = "react-icons/ci"
    tag = "CiFries"


class CiGift(rx.Component):
    library = "react-icons/ci"
    tag = "CiGift"


class CiGlass(rx.Component):
    library = "react-icons/ci"
    tag = "CiGlass"


class CiGlobe(rx.Component):
    library = "react-icons/ci"
    tag = "CiGlobe"


class CiGps(rx.Component):
    library = "react-icons/ci"
    tag = "CiGps"


class CiGrid2H(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid2H"


class CiGrid2V(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid2V"


class CiGrid31(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid31"


class CiGrid32(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid32"


class CiGrid41(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid41"


class CiGrid42(rx.Component):
    library = "react-icons/ci"
    tag = "CiGrid42"


class CiHardDrive(rx.Component):
    library = "react-icons/ci"
    tag = "CiHardDrive"


class CiHashtag(rx.Component):
    library = "react-icons/ci"
    tag = "CiHashtag"


class CiHeadphones(rx.Component):
    library = "react-icons/ci"
    tag = "CiHeadphones"


class CiHeart(rx.Component):
    library = "react-icons/ci"
    tag = "CiHeart"


class CiHome(rx.Component):
    library = "react-icons/ci"
    tag = "CiHome"


class CiHospital1(rx.Component):
    library = "react-icons/ci"
    tag = "CiHospital1"


class CiHotdog(rx.Component):
    library = "react-icons/ci"
    tag = "CiHotdog"


class CiIceCream(rx.Component):
    library = "react-icons/ci"
    tag = "CiIceCream"


class CiImageOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiImageOff"


class CiImageOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiImageOn"


class CiImport(rx.Component):
    library = "react-icons/ci"
    tag = "CiImport"


class CiInboxIn(rx.Component):
    library = "react-icons/ci"
    tag = "CiInboxIn"


class CiInboxOut(rx.Component):
    library = "react-icons/ci"
    tag = "CiInboxOut"


class CiIndent(rx.Component):
    library = "react-icons/ci"
    tag = "CiIndent"


class CiInstagram(rx.Component):
    library = "react-icons/ci"
    tag = "CiInstagram"


class CiKeyboard(rx.Component):
    library = "react-icons/ci"
    tag = "CiKeyboard"


class CiLaptop(rx.Component):
    library = "react-icons/ci"
    tag = "CiLaptop"


class CiLemon(rx.Component):
    library = "react-icons/ci"
    tag = "CiLemon"


class CiLight(rx.Component):
    library = "react-icons/ci"
    tag = "CiLight"


class CiLineHeight(rx.Component):
    library = "react-icons/ci"
    tag = "CiLineHeight"


class CiLink(rx.Component):
    library = "react-icons/ci"
    tag = "CiLink"


class CiLinkedin(rx.Component):
    library = "react-icons/ci"
    tag = "CiLinkedin"


class CiLocationArrow1(rx.Component):
    library = "react-icons/ci"
    tag = "CiLocationArrow1"


class CiLocationOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiLocationOff"


class CiLocationOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiLocationOn"


class CiLock(rx.Component):
    library = "react-icons/ci"
    tag = "CiLock"


class CiLogin(rx.Component):
    library = "react-icons/ci"
    tag = "CiLogin"


class CiLogout(rx.Component):
    library = "react-icons/ci"
    tag = "CiLogout"


class CiLollipop(rx.Component):
    library = "react-icons/ci"
    tag = "CiLollipop"


class CiMail(rx.Component):
    library = "react-icons/ci"
    tag = "CiMail"


class CiMapPin(rx.Component):
    library = "react-icons/ci"
    tag = "CiMapPin"


class CiMap(rx.Component):
    library = "react-icons/ci"
    tag = "CiMap"


class CiMaximize1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMaximize1"


class CiMaximize2(rx.Component):
    library = "react-icons/ci"
    tag = "CiMaximize2"


class CiMedal(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedal"


class CiMedicalCase(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedicalCase"


class CiMedicalClipboard(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedicalClipboard"


class CiMedicalCross(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedicalCross"


class CiMedicalMask(rx.Component):
    library = "react-icons/ci"
    tag = "CiMedicalMask"


class CiMemoPad(rx.Component):
    library = "react-icons/ci"
    tag = "CiMemoPad"


class CiMenuBurger(rx.Component):
    library = "react-icons/ci"
    tag = "CiMenuBurger"


class CiMenuFries(rx.Component):
    library = "react-icons/ci"
    tag = "CiMenuFries"


class CiMenuKebab(rx.Component):
    library = "react-icons/ci"
    tag = "CiMenuKebab"


class CiMicrochip(rx.Component):
    library = "react-icons/ci"
    tag = "CiMicrochip"


class CiMicrophoneOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiMicrophoneOff"


class CiMicrophoneOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiMicrophoneOn"


class CiMinimize1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMinimize1"


class CiMinimize2(rx.Component):
    library = "react-icons/ci"
    tag = "CiMinimize2"


class CiMobile1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMobile1"


class CiMobile2(rx.Component):
    library = "react-icons/ci"
    tag = "CiMobile2"


class CiMobile3(rx.Component):
    library = "react-icons/ci"
    tag = "CiMobile3"


class CiMobile4(rx.Component):
    library = "react-icons/ci"
    tag = "CiMobile4"


class CiMoneyBill(rx.Component):
    library = "react-icons/ci"
    tag = "CiMoneyBill"


class CiMoneyCheck1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMoneyCheck1"


class CiMonitor(rx.Component):
    library = "react-icons/ci"
    tag = "CiMonitor"


class CiMountain1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMountain1"


class CiMug1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMug1"


class CiMusicNote1(rx.Component):
    library = "react-icons/ci"
    tag = "CiMusicNote1"


class CiNoWaitingSign(rx.Component):
    library = "react-icons/ci"
    tag = "CiNoWaitingSign"


class CiPalette(rx.Component):
    library = "react-icons/ci"
    tag = "CiPalette"


class CiPaperplane(rx.Component):
    library = "react-icons/ci"
    tag = "CiPaperplane"


class CiParking1(rx.Component):
    library = "react-icons/ci"
    tag = "CiParking1"


class CiPassport1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPassport1"


class CiPause1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPause1"


class CiPen(rx.Component):
    library = "react-icons/ci"
    tag = "CiPen"


class CiPenpot(rx.Component):
    library = "react-icons/ci"
    tag = "CiPenpot"


class CiPercent(rx.Component):
    library = "react-icons/ci"
    tag = "CiPercent"


class CiPhone(rx.Component):
    library = "react-icons/ci"
    tag = "CiPhone"


class CiPickerEmpty(rx.Component):
    library = "react-icons/ci"
    tag = "CiPickerEmpty"


class CiPickerHalf(rx.Component):
    library = "react-icons/ci"
    tag = "CiPickerHalf"


class CiPill(rx.Component):
    library = "react-icons/ci"
    tag = "CiPill"


class CiPillsBottle1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPillsBottle1"


class CiPizza(rx.Component):
    library = "react-icons/ci"
    tag = "CiPizza"


class CiPlane(rx.Component):
    library = "react-icons/ci"
    tag = "CiPlane"


class CiPlay1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPlay1"


class CiPlug1(rx.Component):
    library = "react-icons/ci"
    tag = "CiPlug1"


class CiPower(rx.Component):
    library = "react-icons/ci"
    tag = "CiPower"


class CiRainbow(rx.Component):
    library = "react-icons/ci"
    tag = "CiRainbow"


class CiRead(rx.Component):
    library = "react-icons/ci"
    tag = "CiRead"


class CiReceipt(rx.Component):
    library = "react-icons/ci"
    tag = "CiReceipt"


class CiRedo(rx.Component):
    library = "react-icons/ci"
    tag = "CiRedo"


class CiRepeat(rx.Component):
    library = "react-icons/ci"
    tag = "CiRepeat"


class CiRollingSuitcase(rx.Component):
    library = "react-icons/ci"
    tag = "CiRollingSuitcase"


class CiRoute(rx.Component):
    library = "react-icons/ci"
    tag = "CiRoute"


class CiRouter(rx.Component):
    library = "react-icons/ci"
    tag = "CiRouter"


class CiRuler(rx.Component):
    library = "react-icons/ci"
    tag = "CiRuler"


class CiSatellite1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSatellite1"


class CiSaveDown1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSaveDown1"


class CiSaveDown2(rx.Component):
    library = "react-icons/ci"
    tag = "CiSaveDown2"


class CiSaveUp1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSaveUp1"


class CiSaveUp2(rx.Component):
    library = "react-icons/ci"
    tag = "CiSaveUp2"


class CiSearch(rx.Component):
    library = "react-icons/ci"
    tag = "CiSearch"


class CiServer(rx.Component):
    library = "react-icons/ci"
    tag = "CiServer"


class CiSettings(rx.Component):
    library = "react-icons/ci"
    tag = "CiSettings"


class CiShare1(rx.Component):
    library = "react-icons/ci"
    tag = "CiShare1"


class CiShare2(rx.Component):
    library = "react-icons/ci"
    tag = "CiShare2"


class CiShirt(rx.Component):
    library = "react-icons/ci"
    tag = "CiShirt"


class CiShop(rx.Component):
    library = "react-icons/ci"
    tag = "CiShop"


class CiShoppingBasket(rx.Component):
    library = "react-icons/ci"
    tag = "CiShoppingBasket"


class CiShoppingCart(rx.Component):
    library = "react-icons/ci"
    tag = "CiShoppingCart"


class CiShoppingTag(rx.Component):
    library = "react-icons/ci"
    tag = "CiShoppingTag"


class CiShuffle(rx.Component):
    library = "react-icons/ci"
    tag = "CiShuffle"


class CiSignpostDuo1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSignpostDuo1"


class CiSignpostL1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSignpostL1"


class CiSignpostR1(rx.Component):
    library = "react-icons/ci"
    tag = "CiSignpostR1"


class CiSliderHorizontal(rx.Component):
    library = "react-icons/ci"
    tag = "CiSliderHorizontal"


class CiSliderVertical(rx.Component):
    library = "react-icons/ci"
    tag = "CiSliderVertical"


class CiSpeaker(rx.Component):
    library = "react-icons/ci"
    tag = "CiSpeaker"


class CiSquareAlert(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareAlert"


class CiSquareCheck(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareCheck"


class CiSquareChevDown(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareChevDown"


class CiSquareChevLeft(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareChevLeft"


class CiSquareChevRight(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareChevRight"


class CiSquareChevUp(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareChevUp"


class CiSquareInfo(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareInfo"


class CiSquareMinus(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareMinus"


class CiSquareMore(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareMore"


class CiSquarePlus(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquarePlus"


class CiSquareQuestion(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareQuestion"


class CiSquareRemove(rx.Component):
    library = "react-icons/ci"
    tag = "CiSquareRemove"


class CiStar(rx.Component):
    library = "react-icons/ci"
    tag = "CiStar"


class CiStethoscope(rx.Component):
    library = "react-icons/ci"
    tag = "CiStethoscope"


class CiStickyNote(rx.Component):
    library = "react-icons/ci"
    tag = "CiStickyNote"


class CiStop1(rx.Component):
    library = "react-icons/ci"
    tag = "CiStop1"


class CiStopSign1(rx.Component):
    library = "react-icons/ci"
    tag = "CiStopSign1"


class CiStopwatch(rx.Component):
    library = "react-icons/ci"
    tag = "CiStopwatch"


class CiStreamOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiStreamOff"


class CiStreamOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiStreamOn"


class CiSun(rx.Component):
    library = "react-icons/ci"
    tag = "CiSun"


class CiTablets1(rx.Component):
    library = "react-icons/ci"
    tag = "CiTablets1"


class CiTempHigh(rx.Component):
    library = "react-icons/ci"
    tag = "CiTempHigh"


class CiTextAlignCenter(rx.Component):
    library = "react-icons/ci"
    tag = "CiTextAlignCenter"


class CiTextAlignJustify(rx.Component):
    library = "react-icons/ci"
    tag = "CiTextAlignJustify"


class CiTextAlignLeft(rx.Component):
    library = "react-icons/ci"
    tag = "CiTextAlignLeft"


class CiTextAlignRight(rx.Component):
    library = "react-icons/ci"
    tag = "CiTextAlignRight"


class CiText(rx.Component):
    library = "react-icons/ci"
    tag = "CiText"


class CiTimer(rx.Component):
    library = "react-icons/ci"
    tag = "CiTimer"


class CiTrash(rx.Component):
    library = "react-icons/ci"
    tag = "CiTrash"


class CiTrophy(rx.Component):
    library = "react-icons/ci"
    tag = "CiTrophy"


class CiTurnL1(rx.Component):
    library = "react-icons/ci"
    tag = "CiTurnL1"


class CiTurnR1(rx.Component):
    library = "react-icons/ci"
    tag = "CiTurnR1"


class CiTwitter(rx.Component):
    library = "react-icons/ci"
    tag = "CiTwitter"


class CiUmbrella(rx.Component):
    library = "react-icons/ci"
    tag = "CiUmbrella"


class CiUndo(rx.Component):
    library = "react-icons/ci"
    tag = "CiUndo"


class CiUnlock(rx.Component):
    library = "react-icons/ci"
    tag = "CiUnlock"


class CiUnread(rx.Component):
    library = "react-icons/ci"
    tag = "CiUnread"


class CiUsb(rx.Component):
    library = "react-icons/ci"
    tag = "CiUsb"


class CiUser(rx.Component):
    library = "react-icons/ci"
    tag = "CiUser"


class CiVault(rx.Component):
    library = "react-icons/ci"
    tag = "CiVault"


class CiVial(rx.Component):
    library = "react-icons/ci"
    tag = "CiVial"


class CiVideoOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiVideoOff"


class CiVideoOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiVideoOn"


class CiViewBoard(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewBoard"


class CiViewColumn(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewColumn"


class CiViewList(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewList"


class CiViewTable(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewTable"


class CiViewTimeline(rx.Component):
    library = "react-icons/ci"
    tag = "CiViewTimeline"


class CiVirus(rx.Component):
    library = "react-icons/ci"
    tag = "CiVirus"


class CiVoicemail(rx.Component):
    library = "react-icons/ci"
    tag = "CiVoicemail"


class CiVolumeHigh(rx.Component):
    library = "react-icons/ci"
    tag = "CiVolumeHigh"


class CiVolumeMute(rx.Component):
    library = "react-icons/ci"
    tag = "CiVolumeMute"


class CiVolume(rx.Component):
    library = "react-icons/ci"
    tag = "CiVolume"


class CiWallet(rx.Component):
    library = "react-icons/ci"
    tag = "CiWallet"


class CiWarning(rx.Component):
    library = "react-icons/ci"
    tag = "CiWarning"


class CiWavePulse1(rx.Component):
    library = "react-icons/ci"
    tag = "CiWavePulse1"


class CiWheat(rx.Component):
    library = "react-icons/ci"
    tag = "CiWheat"


class CiWifiOff(rx.Component):
    library = "react-icons/ci"
    tag = "CiWifiOff"


class CiWifiOn(rx.Component):
    library = "react-icons/ci"
    tag = "CiWifiOn"


class CiYoutube(rx.Component):
    library = "react-icons/ci"
    tag = "CiYoutube"


class CiZoomIn(rx.Component):
    library = "react-icons/ci"
    tag = "CiZoomIn"


class CiZoomOut(rx.Component):
    library = "react-icons/ci"
    tag = "CiZoomOut"


