import reflex as rx

class Md123(rx.Component):
    library = "react-icons/md"
    tag = "Md123"


class Md3DRotation(rx.Component):
    library = "react-icons/md"
    tag = "Md3DRotation"


class MdAbc(rx.Component):
    library = "react-icons/md"
    tag = "MdAbc"


class MdAccessibilityNew(rx.Component):
    library = "react-icons/md"
    tag = "MdAccessibilityNew"


class MdAccessibility(rx.Component):
    library = "react-icons/md"
    tag = "MdAccessibility"


class MdAccessibleForward(rx.Component):
    library = "react-icons/md"
    tag = "MdAccessibleForward"


class MdAccessible(rx.Component):
    library = "react-icons/md"
    tag = "MdAccessible"


class MdAccountBalanceWallet(rx.Component):
    library = "react-icons/md"
    tag = "MdAccountBalanceWallet"


class MdAccountBalance(rx.Component):
    library = "react-icons/md"
    tag = "MdAccountBalance"


class MdAccountBox(rx.Component):
    library = "react-icons/md"
    tag = "MdAccountBox"


class MdAccountCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdAccountCircle"


class MdAddCard(rx.Component):
    library = "react-icons/md"
    tag = "MdAddCard"


class MdAddHome(rx.Component):
    library = "react-icons/md"
    tag = "MdAddHome"


class MdAddShoppingCart(rx.Component):
    library = "react-icons/md"
    tag = "MdAddShoppingCart"


class MdAddTask(rx.Component):
    library = "react-icons/md"
    tag = "MdAddTask"


class MdAddToDrive(rx.Component):
    library = "react-icons/md"
    tag = "MdAddToDrive"


class MdAddchart(rx.Component):
    library = "react-icons/md"
    tag = "MdAddchart"


class MdAdminPanelSettings(rx.Component):
    library = "react-icons/md"
    tag = "MdAdminPanelSettings"


class MdAdsClick(rx.Component):
    library = "react-icons/md"
    tag = "MdAdsClick"


class MdAlarmAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdAlarmAdd"


class MdAlarmOff(rx.Component):
    library = "react-icons/md"
    tag = "MdAlarmOff"


class MdAlarmOn(rx.Component):
    library = "react-icons/md"
    tag = "MdAlarmOn"


class MdAlarm(rx.Component):
    library = "react-icons/md"
    tag = "MdAlarm"


class MdAllInbox(rx.Component):
    library = "react-icons/md"
    tag = "MdAllInbox"


class MdAllOut(rx.Component):
    library = "react-icons/md"
    tag = "MdAllOut"


class MdAnalytics(rx.Component):
    library = "react-icons/md"
    tag = "MdAnalytics"


class MdAnchor(rx.Component):
    library = "react-icons/md"
    tag = "MdAnchor"


class MdAndroid(rx.Component):
    library = "react-icons/md"
    tag = "MdAndroid"


class MdAnnouncement(rx.Component):
    library = "react-icons/md"
    tag = "MdAnnouncement"


class MdApi(rx.Component):
    library = "react-icons/md"
    tag = "MdApi"


class MdAppBlocking(rx.Component):
    library = "react-icons/md"
    tag = "MdAppBlocking"


class MdAppShortcut(rx.Component):
    library = "react-icons/md"
    tag = "MdAppShortcut"


class MdArrowCircleDown(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowCircleDown"


class MdArrowCircleLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowCircleLeft"


class MdArrowCircleRight(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowCircleRight"


class MdArrowCircleUp(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowCircleUp"


class MdArrowOutward(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowOutward"


class MdArrowRightAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowRightAlt"


class MdArticle(rx.Component):
    library = "react-icons/md"
    tag = "MdArticle"


class MdAspectRatio(rx.Component):
    library = "react-icons/md"
    tag = "MdAspectRatio"


class MdAssessment(rx.Component):
    library = "react-icons/md"
    tag = "MdAssessment"


class MdAssignmentAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdAssignmentAdd"


class MdAssignmentInd(rx.Component):
    library = "react-icons/md"
    tag = "MdAssignmentInd"


class MdAssignmentLate(rx.Component):
    library = "react-icons/md"
    tag = "MdAssignmentLate"


class MdAssignmentReturn(rx.Component):
    library = "react-icons/md"
    tag = "MdAssignmentReturn"


class MdAssignmentReturned(rx.Component):
    library = "react-icons/md"
    tag = "MdAssignmentReturned"


class MdAssignmentTurnedIn(rx.Component):
    library = "react-icons/md"
    tag = "MdAssignmentTurnedIn"


class MdAssignment(rx.Component):
    library = "react-icons/md"
    tag = "MdAssignment"


class MdAssuredWorkload(rx.Component):
    library = "react-icons/md"
    tag = "MdAssuredWorkload"


class MdAutorenew(rx.Component):
    library = "react-icons/md"
    tag = "MdAutorenew"


class MdBackupTable(rx.Component):
    library = "react-icons/md"
    tag = "MdBackupTable"


class MdBackup(rx.Component):
    library = "react-icons/md"
    tag = "MdBackup"


class MdBalance(rx.Component):
    library = "react-icons/md"
    tag = "MdBalance"


class MdBarcodeReader(rx.Component):
    library = "react-icons/md"
    tag = "MdBarcodeReader"


class MdBatchPrediction(rx.Component):
    library = "react-icons/md"
    tag = "MdBatchPrediction"


class MdBookOnline(rx.Component):
    library = "react-icons/md"
    tag = "MdBookOnline"


class MdBook(rx.Component):
    library = "react-icons/md"
    tag = "MdBook"


class MdBookmarkAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdBookmarkAdd"


class MdBookmarkAdded(rx.Component):
    library = "react-icons/md"
    tag = "MdBookmarkAdded"


class MdBookmarkBorder(rx.Component):
    library = "react-icons/md"
    tag = "MdBookmarkBorder"


class MdBookmarkRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdBookmarkRemove"


class MdBookmark(rx.Component):
    library = "react-icons/md"
    tag = "MdBookmark"


class MdBookmarks(rx.Component):
    library = "react-icons/md"
    tag = "MdBookmarks"


class MdBrowseGallery(rx.Component):
    library = "react-icons/md"
    tag = "MdBrowseGallery"


class MdBugReport(rx.Component):
    library = "react-icons/md"
    tag = "MdBugReport"


class MdBuildCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdBuildCircle"


class MdBuild(rx.Component):
    library = "react-icons/md"
    tag = "MdBuild"


class MdCached(rx.Component):
    library = "react-icons/md"
    tag = "MdCached"


class MdCalendarMonth(rx.Component):
    library = "react-icons/md"
    tag = "MdCalendarMonth"


class MdCalendarToday(rx.Component):
    library = "react-icons/md"
    tag = "MdCalendarToday"


class MdCalendarViewDay(rx.Component):
    library = "react-icons/md"
    tag = "MdCalendarViewDay"


class MdCalendarViewMonth(rx.Component):
    library = "react-icons/md"
    tag = "MdCalendarViewMonth"


class MdCalendarViewWeek(rx.Component):
    library = "react-icons/md"
    tag = "MdCalendarViewWeek"


class MdCameraEnhance(rx.Component):
    library = "react-icons/md"
    tag = "MdCameraEnhance"


class MdCancelScheduleSend(rx.Component):
    library = "react-icons/md"
    tag = "MdCancelScheduleSend"


class MdCardGiftcard(rx.Component):
    library = "react-icons/md"
    tag = "MdCardGiftcard"


class MdCardMembership(rx.Component):
    library = "react-icons/md"
    tag = "MdCardMembership"


class MdCardTravel(rx.Component):
    library = "react-icons/md"
    tag = "MdCardTravel"


class MdChangeHistory(rx.Component):
    library = "react-icons/md"
    tag = "MdChangeHistory"


class MdCheckCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdCheckCircleOutline"


class MdCheckCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdCheckCircle"


class MdChromeReaderMode(rx.Component):
    library = "react-icons/md"
    tag = "MdChromeReaderMode"


class MdCircleNotifications(rx.Component):
    library = "react-icons/md"
    tag = "MdCircleNotifications"


class MdClass(rx.Component):
    library = "react-icons/md"
    tag = "MdClass"


class MdCloseFullscreen(rx.Component):
    library = "react-icons/md"
    tag = "MdCloseFullscreen"


class MdCodeOff(rx.Component):
    library = "react-icons/md"
    tag = "MdCodeOff"


class MdCode(rx.Component):
    library = "react-icons/md"
    tag = "MdCode"


class MdCommentBank(rx.Component):
    library = "react-icons/md"
    tag = "MdCommentBank"


class MdCommit(rx.Component):
    library = "react-icons/md"
    tag = "MdCommit"


class MdCommute(rx.Component):
    library = "react-icons/md"
    tag = "MdCommute"


class MdCompareArrows(rx.Component):
    library = "react-icons/md"
    tag = "MdCompareArrows"


class MdCompress(rx.Component):
    library = "react-icons/md"
    tag = "MdCompress"


class MdContactPage(rx.Component):
    library = "react-icons/md"
    tag = "MdContactPage"


class MdContactSupport(rx.Component):
    library = "react-icons/md"
    tag = "MdContactSupport"


class MdContactless(rx.Component):
    library = "react-icons/md"
    tag = "MdContactless"


class MdCopyright(rx.Component):
    library = "react-icons/md"
    tag = "MdCopyright"


class MdCreditCardOff(rx.Component):
    library = "react-icons/md"
    tag = "MdCreditCardOff"


class MdCreditCard(rx.Component):
    library = "react-icons/md"
    tag = "MdCreditCard"


class MdCss(rx.Component):
    library = "react-icons/md"
    tag = "MdCss"


class MdCurrencyExchange(rx.Component):
    library = "react-icons/md"
    tag = "MdCurrencyExchange"


class MdDangerous(rx.Component):
    library = "react-icons/md"
    tag = "MdDangerous"


class MdDashboardCustomize(rx.Component):
    library = "react-icons/md"
    tag = "MdDashboardCustomize"


class MdDashboard(rx.Component):
    library = "react-icons/md"
    tag = "MdDashboard"


class MdDataExploration(rx.Component):
    library = "react-icons/md"
    tag = "MdDataExploration"


class MdDataThresholding(rx.Component):
    library = "react-icons/md"
    tag = "MdDataThresholding"


class MdDateRange(rx.Component):
    library = "react-icons/md"
    tag = "MdDateRange"


class MdDeleteForever(rx.Component):
    library = "react-icons/md"
    tag = "MdDeleteForever"


class MdDeleteOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdDeleteOutline"


class MdDelete(rx.Component):
    library = "react-icons/md"
    tag = "MdDelete"


class MdDensityLarge(rx.Component):
    library = "react-icons/md"
    tag = "MdDensityLarge"


class MdDensityMedium(rx.Component):
    library = "react-icons/md"
    tag = "MdDensityMedium"


class MdDensitySmall(rx.Component):
    library = "react-icons/md"
    tag = "MdDensitySmall"


class MdDescription(rx.Component):
    library = "react-icons/md"
    tag = "MdDescription"


class MdDisabledByDefault(rx.Component):
    library = "react-icons/md"
    tag = "MdDisabledByDefault"


class MdDisabledVisible(rx.Component):
    library = "react-icons/md"
    tag = "MdDisabledVisible"


class MdDisplaySettings(rx.Component):
    library = "react-icons/md"
    tag = "MdDisplaySettings"


class MdDns(rx.Component):
    library = "react-icons/md"
    tag = "MdDns"


class MdDoneAll(rx.Component):
    library = "react-icons/md"
    tag = "MdDoneAll"


class MdDoneOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdDoneOutline"


class MdDone(rx.Component):
    library = "react-icons/md"
    tag = "MdDone"


class MdDonutLarge(rx.Component):
    library = "react-icons/md"
    tag = "MdDonutLarge"


class MdDonutSmall(rx.Component):
    library = "react-icons/md"
    tag = "MdDonutSmall"


class MdDragIndicator(rx.Component):
    library = "react-icons/md"
    tag = "MdDragIndicator"


class MdDynamicForm(rx.Component):
    library = "react-icons/md"
    tag = "MdDynamicForm"


class MdEco(rx.Component):
    library = "react-icons/md"
    tag = "MdEco"


class MdEditCalendar(rx.Component):
    library = "react-icons/md"
    tag = "MdEditCalendar"


class MdEditDocument(rx.Component):
    library = "react-icons/md"
    tag = "MdEditDocument"


class MdEditOff(rx.Component):
    library = "react-icons/md"
    tag = "MdEditOff"


class MdEditSquare(rx.Component):
    library = "react-icons/md"
    tag = "MdEditSquare"


class MdEject(rx.Component):
    library = "react-icons/md"
    tag = "MdEject"


class MdEuroSymbol(rx.Component):
    library = "react-icons/md"
    tag = "MdEuroSymbol"


class MdEventRepeat(rx.Component):
    library = "react-icons/md"
    tag = "MdEventRepeat"


class MdEventSeat(rx.Component):
    library = "react-icons/md"
    tag = "MdEventSeat"


class MdEvent(rx.Component):
    library = "react-icons/md"
    tag = "MdEvent"


class MdExitToApp(rx.Component):
    library = "react-icons/md"
    tag = "MdExitToApp"


class MdExpand(rx.Component):
    library = "react-icons/md"
    tag = "MdExpand"


class MdExploreOff(rx.Component):
    library = "react-icons/md"
    tag = "MdExploreOff"


class MdExplore(rx.Component):
    library = "react-icons/md"
    tag = "MdExplore"


class MdExtensionOff(rx.Component):
    library = "react-icons/md"
    tag = "MdExtensionOff"


class MdExtension(rx.Component):
    library = "react-icons/md"
    tag = "MdExtension"


class MdFace(rx.Component):
    library = "react-icons/md"
    tag = "MdFace"


class MdFactCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdFactCheck"


class MdFavoriteBorder(rx.Component):
    library = "react-icons/md"
    tag = "MdFavoriteBorder"


class MdFavorite(rx.Component):
    library = "react-icons/md"
    tag = "MdFavorite"


class MdFax(rx.Component):
    library = "react-icons/md"
    tag = "MdFax"


class MdFeedback(rx.Component):
    library = "react-icons/md"
    tag = "MdFeedback"


class MdFilePresent(rx.Component):
    library = "react-icons/md"
    tag = "MdFilePresent"


class MdFilterAltOff(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterAltOff"


class MdFilterAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterAlt"


class MdFilterListAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterListAlt"


class MdFindInPage(rx.Component):
    library = "react-icons/md"
    tag = "MdFindInPage"


class MdFindReplace(rx.Component):
    library = "react-icons/md"
    tag = "MdFindReplace"


class MdFingerprint(rx.Component):
    library = "react-icons/md"
    tag = "MdFingerprint"


class MdFitScreen(rx.Component):
    library = "react-icons/md"
    tag = "MdFitScreen"


class MdFlaky(rx.Component):
    library = "react-icons/md"
    tag = "MdFlaky"


class MdFlightLand(rx.Component):
    library = "react-icons/md"
    tag = "MdFlightLand"


class MdFlightTakeoff(rx.Component):
    library = "react-icons/md"
    tag = "MdFlightTakeoff"


class MdFlipToBack(rx.Component):
    library = "react-icons/md"
    tag = "MdFlipToBack"


class MdFlipToFront(rx.Component):
    library = "react-icons/md"
    tag = "MdFlipToFront"


class MdFlutterDash(rx.Component):
    library = "react-icons/md"
    tag = "MdFlutterDash"


class MdFreeCancellation(rx.Component):
    library = "react-icons/md"
    tag = "MdFreeCancellation"


class MdGTranslate(rx.Component):
    library = "react-icons/md"
    tag = "MdGTranslate"


class MdGavel(rx.Component):
    library = "react-icons/md"
    tag = "MdGavel"


class MdGeneratingTokens(rx.Component):
    library = "react-icons/md"
    tag = "MdGeneratingTokens"


class MdGetApp(rx.Component):
    library = "react-icons/md"
    tag = "MdGetApp"


class MdGifBox(rx.Component):
    library = "react-icons/md"
    tag = "MdGifBox"


class MdGif(rx.Component):
    library = "react-icons/md"
    tag = "MdGif"


class MdGrade(rx.Component):
    library = "react-icons/md"
    tag = "MdGrade"


class MdGrading(rx.Component):
    library = "react-icons/md"
    tag = "MdGrading"


class MdGroupWork(rx.Component):
    library = "react-icons/md"
    tag = "MdGroupWork"


class MdHelpCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdHelpCenter"


class MdHelpOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdHelpOutline"


class MdHelp(rx.Component):
    library = "react-icons/md"
    tag = "MdHelp"


class MdHideSource(rx.Component):
    library = "react-icons/md"
    tag = "MdHideSource"


class MdHighlightAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdHighlightAlt"


class MdHighlightOff(rx.Component):
    library = "react-icons/md"
    tag = "MdHighlightOff"


class MdHistoryToggleOff(rx.Component):
    library = "react-icons/md"
    tag = "MdHistoryToggleOff"


class MdHistory(rx.Component):
    library = "react-icons/md"
    tag = "MdHistory"


class MdHlsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdHlsOff"


class MdHls(rx.Component):
    library = "react-icons/md"
    tag = "MdHls"


class MdHomeFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdHomeFilled"


class MdHome(rx.Component):
    library = "react-icons/md"
    tag = "MdHome"


class MdHorizontalSplit(rx.Component):
    library = "react-icons/md"
    tag = "MdHorizontalSplit"


class MdHotelClass(rx.Component):
    library = "react-icons/md"
    tag = "MdHotelClass"


class MdHourglassDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdHourglassDisabled"


class MdHourglassEmpty(rx.Component):
    library = "react-icons/md"
    tag = "MdHourglassEmpty"


class MdHourglassFull(rx.Component):
    library = "react-icons/md"
    tag = "MdHourglassFull"


class MdHtml(rx.Component):
    library = "react-icons/md"
    tag = "MdHtml"


class MdHttp(rx.Component):
    library = "react-icons/md"
    tag = "MdHttp"


class MdHttps(rx.Component):
    library = "react-icons/md"
    tag = "MdHttps"


class MdImportantDevices(rx.Component):
    library = "react-icons/md"
    tag = "MdImportantDevices"


class MdInfoOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdInfoOutline"


class MdInfo(rx.Component):
    library = "react-icons/md"
    tag = "MdInfo"


class MdInput(rx.Component):
    library = "react-icons/md"
    tag = "MdInput"


class MdInstallDesktop(rx.Component):
    library = "react-icons/md"
    tag = "MdInstallDesktop"


class MdInstallMobile(rx.Component):
    library = "react-icons/md"
    tag = "MdInstallMobile"


class MdIntegrationInstructions(rx.Component):
    library = "react-icons/md"
    tag = "MdIntegrationInstructions"


class MdInvertColors(rx.Component):
    library = "react-icons/md"
    tag = "MdInvertColors"


class MdJavascript(rx.Component):
    library = "react-icons/md"
    tag = "MdJavascript"


class MdJoinFull(rx.Component):
    library = "react-icons/md"
    tag = "MdJoinFull"


class MdJoinInner(rx.Component):
    library = "react-icons/md"
    tag = "MdJoinInner"


class MdJoinLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdJoinLeft"


class MdJoinRight(rx.Component):
    library = "react-icons/md"
    tag = "MdJoinRight"


class MdLabelImportantOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdLabelImportantOutline"


class MdLabelImportant(rx.Component):
    library = "react-icons/md"
    tag = "MdLabelImportant"


class MdLabelOff(rx.Component):
    library = "react-icons/md"
    tag = "MdLabelOff"


class MdLabelOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdLabelOutline"


class MdLabel(rx.Component):
    library = "react-icons/md"
    tag = "MdLabel"


class MdLanguage(rx.Component):
    library = "react-icons/md"
    tag = "MdLanguage"


class MdLaunch(rx.Component):
    library = "react-icons/md"
    tag = "MdLaunch"


class MdLeaderboard(rx.Component):
    library = "react-icons/md"
    tag = "MdLeaderboard"


class MdLightbulbCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdLightbulbCircle"


class MdLightbulbOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdLightbulbOutline"


class MdLightbulb(rx.Component):
    library = "react-icons/md"
    tag = "MdLightbulb"


class MdLineStyle(rx.Component):
    library = "react-icons/md"
    tag = "MdLineStyle"


class MdLineWeight(rx.Component):
    library = "react-icons/md"
    tag = "MdLineWeight"


class MdList(rx.Component):
    library = "react-icons/md"
    tag = "MdList"


class MdLockClock(rx.Component):
    library = "react-icons/md"
    tag = "MdLockClock"


class MdLockOpen(rx.Component):
    library = "react-icons/md"
    tag = "MdLockOpen"


class MdLockOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdLockOutline"


class MdLockPerson(rx.Component):
    library = "react-icons/md"
    tag = "MdLockPerson"


class MdLockReset(rx.Component):
    library = "react-icons/md"
    tag = "MdLockReset"


class MdLock(rx.Component):
    library = "react-icons/md"
    tag = "MdLock"


class MdLogin(rx.Component):
    library = "react-icons/md"
    tag = "MdLogin"


class MdLogout(rx.Component):
    library = "react-icons/md"
    tag = "MdLogout"


class MdLoyalty(rx.Component):
    library = "react-icons/md"
    tag = "MdLoyalty"


class MdManageAccounts(rx.Component):
    library = "react-icons/md"
    tag = "MdManageAccounts"


class MdManageHistory(rx.Component):
    library = "react-icons/md"
    tag = "MdManageHistory"


class MdMarkAsUnread(rx.Component):
    library = "react-icons/md"
    tag = "MdMarkAsUnread"


class MdMarkunreadMailbox(rx.Component):
    library = "react-icons/md"
    tag = "MdMarkunreadMailbox"


class MdMaximize(rx.Component):
    library = "react-icons/md"
    tag = "MdMaximize"


class MdMediation(rx.Component):
    library = "react-icons/md"
    tag = "MdMediation"


class MdMinimize(rx.Component):
    library = "react-icons/md"
    tag = "MdMinimize"


class MdModelTraining(rx.Component):
    library = "react-icons/md"
    tag = "MdModelTraining"


class MdNetworkPing(rx.Component):
    library = "react-icons/md"
    tag = "MdNetworkPing"


class MdNewLabel(rx.Component):
    library = "react-icons/md"
    tag = "MdNewLabel"


class MdNextPlan(rx.Component):
    library = "react-icons/md"
    tag = "MdNextPlan"


class MdNightlightRound(rx.Component):
    library = "react-icons/md"
    tag = "MdNightlightRound"


class MdNoAccounts(rx.Component):
    library = "react-icons/md"
    tag = "MdNoAccounts"


class MdNoiseAware(rx.Component):
    library = "react-icons/md"
    tag = "MdNoiseAware"


class MdNoiseControlOff(rx.Component):
    library = "react-icons/md"
    tag = "MdNoiseControlOff"


class MdNotAccessible(rx.Component):
    library = "react-icons/md"
    tag = "MdNotAccessible"


class MdNotStarted(rx.Component):
    library = "react-icons/md"
    tag = "MdNotStarted"


class MdNoteAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdNoteAdd"


class MdOfflineBolt(rx.Component):
    library = "react-icons/md"
    tag = "MdOfflineBolt"


class MdOfflinePin(rx.Component):
    library = "react-icons/md"
    tag = "MdOfflinePin"


class MdOnDeviceTraining(rx.Component):
    library = "react-icons/md"
    tag = "MdOnDeviceTraining"


class MdOnlinePrediction(rx.Component):
    library = "react-icons/md"
    tag = "MdOnlinePrediction"


class MdOpacity(rx.Component):
    library = "react-icons/md"
    tag = "MdOpacity"


class MdOpenInBrowser(rx.Component):
    library = "react-icons/md"
    tag = "MdOpenInBrowser"


class MdOpenInFull(rx.Component):
    library = "react-icons/md"
    tag = "MdOpenInFull"


class MdOpenInNewOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOpenInNewOff"


class MdOpenInNew(rx.Component):
    library = "react-icons/md"
    tag = "MdOpenInNew"


class MdOpenWith(rx.Component):
    library = "react-icons/md"
    tag = "MdOpenWith"


class MdOutbond(rx.Component):
    library = "react-icons/md"
    tag = "MdOutbond"


class MdOutbound(rx.Component):
    library = "react-icons/md"
    tag = "MdOutbound"


class MdOutbox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutbox"


class MdOutgoingMail(rx.Component):
    library = "react-icons/md"
    tag = "MdOutgoingMail"


class MdOutlet(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlet"


class MdOutput(rx.Component):
    library = "react-icons/md"
    tag = "MdOutput"


class MdPageview(rx.Component):
    library = "react-icons/md"
    tag = "MdPageview"


class MdPaid(rx.Component):
    library = "react-icons/md"
    tag = "MdPaid"


class MdPanToolAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdPanToolAlt"


class MdPanTool(rx.Component):
    library = "react-icons/md"
    tag = "MdPanTool"


class MdPayment(rx.Component):
    library = "react-icons/md"
    tag = "MdPayment"


class MdPendingActions(rx.Component):
    library = "react-icons/md"
    tag = "MdPendingActions"


class MdPending(rx.Component):
    library = "react-icons/md"
    tag = "MdPending"


class MdPercent(rx.Component):
    library = "react-icons/md"
    tag = "MdPercent"


class MdPermCameraMic(rx.Component):
    library = "react-icons/md"
    tag = "MdPermCameraMic"


class MdPermContactCalendar(rx.Component):
    library = "react-icons/md"
    tag = "MdPermContactCalendar"


class MdPermDataSetting(rx.Component):
    library = "react-icons/md"
    tag = "MdPermDataSetting"


class MdPermDeviceInformation(rx.Component):
    library = "react-icons/md"
    tag = "MdPermDeviceInformation"


class MdPermIdentity(rx.Component):
    library = "react-icons/md"
    tag = "MdPermIdentity"


class MdPermMedia(rx.Component):
    library = "react-icons/md"
    tag = "MdPermMedia"


class MdPermPhoneMsg(rx.Component):
    library = "react-icons/md"
    tag = "MdPermPhoneMsg"


class MdPermScanWifi(rx.Component):
    library = "react-icons/md"
    tag = "MdPermScanWifi"


class MdPets(rx.Component):
    library = "react-icons/md"
    tag = "MdPets"


class MdPhp(rx.Component):
    library = "react-icons/md"
    tag = "MdPhp"


class MdPictureInPictureAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdPictureInPictureAlt"


class MdPictureInPicture(rx.Component):
    library = "react-icons/md"
    tag = "MdPictureInPicture"


class MdPinEnd(rx.Component):
    library = "react-icons/md"
    tag = "MdPinEnd"


class MdPinInvoke(rx.Component):
    library = "react-icons/md"
    tag = "MdPinInvoke"


class MdPinch(rx.Component):
    library = "react-icons/md"
    tag = "MdPinch"


class MdPlagiarism(rx.Component):
    library = "react-icons/md"
    tag = "MdPlagiarism"


class MdPlayForWork(rx.Component):
    library = "react-icons/md"
    tag = "MdPlayForWork"


class MdPolymer(rx.Component):
    library = "react-icons/md"
    tag = "MdPolymer"


class MdPowerSettingsNew(rx.Component):
    library = "react-icons/md"
    tag = "MdPowerSettingsNew"


class MdPregnantWoman(rx.Component):
    library = "react-icons/md"
    tag = "MdPregnantWoman"


class MdPreview(rx.Component):
    library = "react-icons/md"
    tag = "MdPreview"


class MdPrint(rx.Component):
    library = "react-icons/md"
    tag = "MdPrint"


class MdPrivacyTip(rx.Component):
    library = "react-icons/md"
    tag = "MdPrivacyTip"


class MdPrivateConnectivity(rx.Component):
    library = "react-icons/md"
    tag = "MdPrivateConnectivity"


class MdProductionQuantityLimits(rx.Component):
    library = "react-icons/md"
    tag = "MdProductionQuantityLimits"


class MdPublishedWithChanges(rx.Component):
    library = "react-icons/md"
    tag = "MdPublishedWithChanges"


class MdQueryBuilder(rx.Component):
    library = "react-icons/md"
    tag = "MdQueryBuilder"


class MdQuestionAnswer(rx.Component):
    library = "react-icons/md"
    tag = "MdQuestionAnswer"


class MdQuestionMark(rx.Component):
    library = "react-icons/md"
    tag = "MdQuestionMark"


class MdQuickreply(rx.Component):
    library = "react-icons/md"
    tag = "MdQuickreply"


class MdRebaseEdit(rx.Component):
    library = "react-icons/md"
    tag = "MdRebaseEdit"


class MdReceipt(rx.Component):
    library = "react-icons/md"
    tag = "MdReceipt"


class MdRecordVoiceOver(rx.Component):
    library = "react-icons/md"
    tag = "MdRecordVoiceOver"


class MdRedeem(rx.Component):
    library = "react-icons/md"
    tag = "MdRedeem"


class MdRemoveDone(rx.Component):
    library = "react-icons/md"
    tag = "MdRemoveDone"


class MdRemoveShoppingCart(rx.Component):
    library = "react-icons/md"
    tag = "MdRemoveShoppingCart"


class MdReorder(rx.Component):
    library = "react-icons/md"
    tag = "MdReorder"


class MdRepartition(rx.Component):
    library = "react-icons/md"
    tag = "MdRepartition"


class MdReportProblem(rx.Component):
    library = "react-icons/md"
    tag = "MdReportProblem"


class MdRequestPage(rx.Component):
    library = "react-icons/md"
    tag = "MdRequestPage"


class MdRestoreFromTrash(rx.Component):
    library = "react-icons/md"
    tag = "MdRestoreFromTrash"


class MdRestorePage(rx.Component):
    library = "react-icons/md"
    tag = "MdRestorePage"


class MdRestore(rx.Component):
    library = "react-icons/md"
    tag = "MdRestore"


class MdRocketLaunch(rx.Component):
    library = "react-icons/md"
    tag = "MdRocketLaunch"


class MdRocket(rx.Component):
    library = "react-icons/md"
    tag = "MdRocket"


class MdRoom(rx.Component):
    library = "react-icons/md"
    tag = "MdRoom"


class MdRoundedCorner(rx.Component):
    library = "react-icons/md"
    tag = "MdRoundedCorner"


class MdRowing(rx.Component):
    library = "react-icons/md"
    tag = "MdRowing"


class MdRule(rx.Component):
    library = "react-icons/md"
    tag = "MdRule"


class MdSatelliteAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSatelliteAlt"


class MdSavedSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdSavedSearch"


class MdSavings(rx.Component):
    library = "react-icons/md"
    tag = "MdSavings"


class MdScheduleSend(rx.Component):
    library = "react-icons/md"
    tag = "MdScheduleSend"


class MdSchedule(rx.Component):
    library = "react-icons/md"
    tag = "MdSchedule"


class MdSearchOff(rx.Component):
    library = "react-icons/md"
    tag = "MdSearchOff"


class MdSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdSearch"


class MdSegment(rx.Component):
    library = "react-icons/md"
    tag = "MdSegment"


class MdSendAndArchive(rx.Component):
    library = "react-icons/md"
    tag = "MdSendAndArchive"


class MdSensorsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdSensorsOff"


class MdSensors(rx.Component):
    library = "react-icons/md"
    tag = "MdSensors"


class MdSettingsAccessibility(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsAccessibility"


class MdSettingsApplications(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsApplications"


class MdSettingsBackupRestore(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsBackupRestore"


class MdSettingsBluetooth(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsBluetooth"


class MdSettingsBrightness(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsBrightness"


class MdSettingsCell(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsCell"


class MdSettingsEthernet(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsEthernet"


class MdSettingsInputAntenna(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsInputAntenna"


class MdSettingsInputComponent(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsInputComponent"


class MdSettingsInputComposite(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsInputComposite"


class MdSettingsInputHdmi(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsInputHdmi"


class MdSettingsInputSvideo(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsInputSvideo"


class MdSettingsOverscan(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsOverscan"


class MdSettingsPhone(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsPhone"


class MdSettingsPower(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsPower"


class MdSettingsRemote(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsRemote"


class MdSettingsVoice(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsVoice"


class MdSettings(rx.Component):
    library = "react-icons/md"
    tag = "MdSettings"


class MdShop2(rx.Component):
    library = "react-icons/md"
    tag = "MdShop2"


class MdShopTwo(rx.Component):
    library = "react-icons/md"
    tag = "MdShopTwo"


class MdShop(rx.Component):
    library = "react-icons/md"
    tag = "MdShop"


class MdShoppingBag(rx.Component):
    library = "react-icons/md"
    tag = "MdShoppingBag"


class MdShoppingBasket(rx.Component):
    library = "react-icons/md"
    tag = "MdShoppingBasket"


class MdShoppingCartCheckout(rx.Component):
    library = "react-icons/md"
    tag = "MdShoppingCartCheckout"


class MdShoppingCart(rx.Component):
    library = "react-icons/md"
    tag = "MdShoppingCart"


class MdSmartButton(rx.Component):
    library = "react-icons/md"
    tag = "MdSmartButton"


class MdSource(rx.Component):
    library = "react-icons/md"
    tag = "MdSource"


class MdSpaceDashboard(rx.Component):
    library = "react-icons/md"
    tag = "MdSpaceDashboard"


class MdSpatialAudioOff(rx.Component):
    library = "react-icons/md"
    tag = "MdSpatialAudioOff"


class MdSpatialAudio(rx.Component):
    library = "react-icons/md"
    tag = "MdSpatialAudio"


class MdSpatialTracking(rx.Component):
    library = "react-icons/md"
    tag = "MdSpatialTracking"


class MdSpeakerNotesOff(rx.Component):
    library = "react-icons/md"
    tag = "MdSpeakerNotesOff"


class MdSpeakerNotes(rx.Component):
    library = "react-icons/md"
    tag = "MdSpeakerNotes"


class MdSpellcheck(rx.Component):
    library = "react-icons/md"
    tag = "MdSpellcheck"


class MdStarRate(rx.Component):
    library = "react-icons/md"
    tag = "MdStarRate"


class MdStars(rx.Component):
    library = "react-icons/md"
    tag = "MdStars"


class MdStickyNote2(rx.Component):
    library = "react-icons/md"
    tag = "MdStickyNote2"


class MdStore(rx.Component):
    library = "react-icons/md"
    tag = "MdStore"


class MdSubject(rx.Component):
    library = "react-icons/md"
    tag = "MdSubject"


class MdSubtitlesOff(rx.Component):
    library = "react-icons/md"
    tag = "MdSubtitlesOff"


class MdSupervisedUserCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdSupervisedUserCircle"


class MdSupervisorAccount(rx.Component):
    library = "react-icons/md"
    tag = "MdSupervisorAccount"


class MdSupport(rx.Component):
    library = "react-icons/md"
    tag = "MdSupport"


class MdSwapHoriz(rx.Component):
    library = "react-icons/md"
    tag = "MdSwapHoriz"


class MdSwapHorizontalCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdSwapHorizontalCircle"


class MdSwapVert(rx.Component):
    library = "react-icons/md"
    tag = "MdSwapVert"


class MdSwapVerticalCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdSwapVerticalCircle"


class MdSwipeDownAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipeDownAlt"


class MdSwipeDown(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipeDown"


class MdSwipeLeftAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipeLeftAlt"


class MdSwipeLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipeLeft"


class MdSwipeRightAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipeRightAlt"


class MdSwipeRight(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipeRight"


class MdSwipeUpAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipeUpAlt"


class MdSwipeUp(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipeUp"


class MdSwipeVertical(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipeVertical"


class MdSwipe(rx.Component):
    library = "react-icons/md"
    tag = "MdSwipe"


class MdSwitchAccessShortcutAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdSwitchAccessShortcutAdd"


class MdSwitchAccessShortcut(rx.Component):
    library = "react-icons/md"
    tag = "MdSwitchAccessShortcut"


class MdSyncAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSyncAlt"


class MdSystemUpdateAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSystemUpdateAlt"


class MdTabUnselected(rx.Component):
    library = "react-icons/md"
    tag = "MdTabUnselected"


class MdTab(rx.Component):
    library = "react-icons/md"
    tag = "MdTab"


class MdTableView(rx.Component):
    library = "react-icons/md"
    tag = "MdTableView"


class MdTaskAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdTaskAlt"


class MdTerminal(rx.Component):
    library = "react-icons/md"
    tag = "MdTerminal"


class MdTextRotateUp(rx.Component):
    library = "react-icons/md"
    tag = "MdTextRotateUp"


class MdTextRotateVertical(rx.Component):
    library = "react-icons/md"
    tag = "MdTextRotateVertical"


class MdTextRotationAngledown(rx.Component):
    library = "react-icons/md"
    tag = "MdTextRotationAngledown"


class MdTextRotationAngleup(rx.Component):
    library = "react-icons/md"
    tag = "MdTextRotationAngleup"


class MdTextRotationDown(rx.Component):
    library = "react-icons/md"
    tag = "MdTextRotationDown"


class MdTextRotationNone(rx.Component):
    library = "react-icons/md"
    tag = "MdTextRotationNone"


class MdTheaters(rx.Component):
    library = "react-icons/md"
    tag = "MdTheaters"


class MdThumbDownOffAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdThumbDownOffAlt"


class MdThumbDown(rx.Component):
    library = "react-icons/md"
    tag = "MdThumbDown"


class MdThumbUpOffAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdThumbUpOffAlt"


class MdThumbUp(rx.Component):
    library = "react-icons/md"
    tag = "MdThumbUp"


class MdThumbsUpDown(rx.Component):
    library = "react-icons/md"
    tag = "MdThumbsUpDown"


class MdTimeline(rx.Component):
    library = "react-icons/md"
    tag = "MdTimeline"


class MdTipsAndUpdates(rx.Component):
    library = "react-icons/md"
    tag = "MdTipsAndUpdates"


class MdToc(rx.Component):
    library = "react-icons/md"
    tag = "MdToc"


class MdToday(rx.Component):
    library = "react-icons/md"
    tag = "MdToday"


class MdToken(rx.Component):
    library = "react-icons/md"
    tag = "MdToken"


class MdToll(rx.Component):
    library = "react-icons/md"
    tag = "MdToll"


class MdTouchApp(rx.Component):
    library = "react-icons/md"
    tag = "MdTouchApp"


class MdTour(rx.Component):
    library = "react-icons/md"
    tag = "MdTour"


class MdTrackChanges(rx.Component):
    library = "react-icons/md"
    tag = "MdTrackChanges"


class MdTranscribe(rx.Component):
    library = "react-icons/md"
    tag = "MdTranscribe"


class MdTranslate(rx.Component):
    library = "react-icons/md"
    tag = "MdTranslate"


class MdTrendingDown(rx.Component):
    library = "react-icons/md"
    tag = "MdTrendingDown"


class MdTrendingFlat(rx.Component):
    library = "react-icons/md"
    tag = "MdTrendingFlat"


class MdTrendingUp(rx.Component):
    library = "react-icons/md"
    tag = "MdTrendingUp"


class MdTroubleshoot(rx.Component):
    library = "react-icons/md"
    tag = "MdTroubleshoot"


class MdTry(rx.Component):
    library = "react-icons/md"
    tag = "MdTry"


class MdTurnedInNot(rx.Component):
    library = "react-icons/md"
    tag = "MdTurnedInNot"


class MdTurnedIn(rx.Component):
    library = "react-icons/md"
    tag = "MdTurnedIn"


class MdUnfoldLessDouble(rx.Component):
    library = "react-icons/md"
    tag = "MdUnfoldLessDouble"


class MdUnfoldMoreDouble(rx.Component):
    library = "react-icons/md"
    tag = "MdUnfoldMoreDouble"


class MdUnpublished(rx.Component):
    library = "react-icons/md"
    tag = "MdUnpublished"


class MdUpdateDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdUpdateDisabled"


class MdUpdate(rx.Component):
    library = "react-icons/md"
    tag = "MdUpdate"


class MdUpgrade(rx.Component):
    library = "react-icons/md"
    tag = "MdUpgrade"


class MdVerifiedUser(rx.Component):
    library = "react-icons/md"
    tag = "MdVerifiedUser"


class MdVerified(rx.Component):
    library = "react-icons/md"
    tag = "MdVerified"


class MdVerticalSplit(rx.Component):
    library = "react-icons/md"
    tag = "MdVerticalSplit"


class MdViewAgenda(rx.Component):
    library = "react-icons/md"
    tag = "MdViewAgenda"


class MdViewArray(rx.Component):
    library = "react-icons/md"
    tag = "MdViewArray"


class MdViewCarousel(rx.Component):
    library = "react-icons/md"
    tag = "MdViewCarousel"


class MdViewColumn(rx.Component):
    library = "react-icons/md"
    tag = "MdViewColumn"


class MdViewComfyAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdViewComfyAlt"


class MdViewCompactAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdViewCompactAlt"


class MdViewCozy(rx.Component):
    library = "react-icons/md"
    tag = "MdViewCozy"


class MdViewDay(rx.Component):
    library = "react-icons/md"
    tag = "MdViewDay"


class MdViewHeadline(rx.Component):
    library = "react-icons/md"
    tag = "MdViewHeadline"


class MdViewInAr(rx.Component):
    library = "react-icons/md"
    tag = "MdViewInAr"


class MdViewKanban(rx.Component):
    library = "react-icons/md"
    tag = "MdViewKanban"


class MdViewList(rx.Component):
    library = "react-icons/md"
    tag = "MdViewList"


class MdViewModule(rx.Component):
    library = "react-icons/md"
    tag = "MdViewModule"


class MdViewQuilt(rx.Component):
    library = "react-icons/md"
    tag = "MdViewQuilt"


class MdViewSidebar(rx.Component):
    library = "react-icons/md"
    tag = "MdViewSidebar"


class MdViewStream(rx.Component):
    library = "react-icons/md"
    tag = "MdViewStream"


class MdViewTimeline(rx.Component):
    library = "react-icons/md"
    tag = "MdViewTimeline"


class MdViewWeek(rx.Component):
    library = "react-icons/md"
    tag = "MdViewWeek"


class MdVisibilityOff(rx.Component):
    library = "react-icons/md"
    tag = "MdVisibilityOff"


class MdVisibility(rx.Component):
    library = "react-icons/md"
    tag = "MdVisibility"


class MdVoiceOverOff(rx.Component):
    library = "react-icons/md"
    tag = "MdVoiceOverOff"


class MdWatchLater(rx.Component):
    library = "react-icons/md"
    tag = "MdWatchLater"


class MdWebhook(rx.Component):
    library = "react-icons/md"
    tag = "MdWebhook"


class MdWidthFull(rx.Component):
    library = "react-icons/md"
    tag = "MdWidthFull"


class MdWidthNormal(rx.Component):
    library = "react-icons/md"
    tag = "MdWidthNormal"


class MdWidthWide(rx.Component):
    library = "react-icons/md"
    tag = "MdWidthWide"


class MdWifiProtectedSetup(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiProtectedSetup"


class MdWorkHistory(rx.Component):
    library = "react-icons/md"
    tag = "MdWorkHistory"


class MdWorkOff(rx.Component):
    library = "react-icons/md"
    tag = "MdWorkOff"


class MdWorkOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdWorkOutline"


class MdWork(rx.Component):
    library = "react-icons/md"
    tag = "MdWork"


class MdWysiwyg(rx.Component):
    library = "react-icons/md"
    tag = "MdWysiwyg"


class MdYoutubeSearchedFor(rx.Component):
    library = "react-icons/md"
    tag = "MdYoutubeSearchedFor"


class MdZoomIn(rx.Component):
    library = "react-icons/md"
    tag = "MdZoomIn"


class MdZoomOut(rx.Component):
    library = "react-icons/md"
    tag = "MdZoomOut"


class MdAddAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdAddAlert"


class MdAutoDelete(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoDelete"


class MdErrorOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdErrorOutline"


class MdError(rx.Component):
    library = "react-icons/md"
    tag = "MdError"


class MdNotificationImportant(rx.Component):
    library = "react-icons/md"
    tag = "MdNotificationImportant"


class MdWarningAmber(rx.Component):
    library = "react-icons/md"
    tag = "MdWarningAmber"


class MdWarning(rx.Component):
    library = "react-icons/md"
    tag = "MdWarning"


class Md10K(rx.Component):
    library = "react-icons/md"
    tag = "Md10K"


class Md1KPlus(rx.Component):
    library = "react-icons/md"
    tag = "Md1KPlus"


class Md1K(rx.Component):
    library = "react-icons/md"
    tag = "Md1K"


class Md2KPlus(rx.Component):
    library = "react-icons/md"
    tag = "Md2KPlus"


class Md2K(rx.Component):
    library = "react-icons/md"
    tag = "Md2K"


class Md3KPlus(rx.Component):
    library = "react-icons/md"
    tag = "Md3KPlus"


class Md3K(rx.Component):
    library = "react-icons/md"
    tag = "Md3K"


class Md4KPlus(rx.Component):
    library = "react-icons/md"
    tag = "Md4KPlus"


class Md4K(rx.Component):
    library = "react-icons/md"
    tag = "Md4K"


class Md5G(rx.Component):
    library = "react-icons/md"
    tag = "Md5G"


class Md5KPlus(rx.Component):
    library = "react-icons/md"
    tag = "Md5KPlus"


class Md5K(rx.Component):
    library = "react-icons/md"
    tag = "Md5K"


class Md6KPlus(rx.Component):
    library = "react-icons/md"
    tag = "Md6KPlus"


class Md6K(rx.Component):
    library = "react-icons/md"
    tag = "Md6K"


class Md7KPlus(rx.Component):
    library = "react-icons/md"
    tag = "Md7KPlus"


class Md7K(rx.Component):
    library = "react-icons/md"
    tag = "Md7K"


class Md8KPlus(rx.Component):
    library = "react-icons/md"
    tag = "Md8KPlus"


class Md8K(rx.Component):
    library = "react-icons/md"
    tag = "Md8K"


class Md9KPlus(rx.Component):
    library = "react-icons/md"
    tag = "Md9KPlus"


class Md9K(rx.Component):
    library = "react-icons/md"
    tag = "Md9K"


class MdAddToQueue(rx.Component):
    library = "react-icons/md"
    tag = "MdAddToQueue"


class MdAirplay(rx.Component):
    library = "react-icons/md"
    tag = "MdAirplay"


class MdAlbum(rx.Component):
    library = "react-icons/md"
    tag = "MdAlbum"


class MdArtTrack(rx.Component):
    library = "react-icons/md"
    tag = "MdArtTrack"


class MdAudioFile(rx.Component):
    library = "react-icons/md"
    tag = "MdAudioFile"


class MdAvTimer(rx.Component):
    library = "react-icons/md"
    tag = "MdAvTimer"


class MdBrandingWatermark(rx.Component):
    library = "react-icons/md"
    tag = "MdBrandingWatermark"


class MdCallToAction(rx.Component):
    library = "react-icons/md"
    tag = "MdCallToAction"


class MdClosedCaptionDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdClosedCaptionDisabled"


class MdClosedCaptionOff(rx.Component):
    library = "react-icons/md"
    tag = "MdClosedCaptionOff"


class MdClosedCaption(rx.Component):
    library = "react-icons/md"
    tag = "MdClosedCaption"


class MdControlCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdControlCamera"


class MdEqualizer(rx.Component):
    library = "react-icons/md"
    tag = "MdEqualizer"


class MdExplicit(rx.Component):
    library = "react-icons/md"
    tag = "MdExplicit"


class MdFastForward(rx.Component):
    library = "react-icons/md"
    tag = "MdFastForward"


class MdFastRewind(rx.Component):
    library = "react-icons/md"
    tag = "MdFastRewind"


class MdFeaturedPlayList(rx.Component):
    library = "react-icons/md"
    tag = "MdFeaturedPlayList"


class MdFeaturedVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdFeaturedVideo"


class MdFiberDvr(rx.Component):
    library = "react-icons/md"
    tag = "MdFiberDvr"


class MdFiberManualRecord(rx.Component):
    library = "react-icons/md"
    tag = "MdFiberManualRecord"


class MdFiberNew(rx.Component):
    library = "react-icons/md"
    tag = "MdFiberNew"


class MdFiberPin(rx.Component):
    library = "react-icons/md"
    tag = "MdFiberPin"


class MdFiberSmartRecord(rx.Component):
    library = "react-icons/md"
    tag = "MdFiberSmartRecord"


class MdForward10(rx.Component):
    library = "react-icons/md"
    tag = "MdForward10"


class MdForward30(rx.Component):
    library = "react-icons/md"
    tag = "MdForward30"


class MdForward5(rx.Component):
    library = "react-icons/md"
    tag = "MdForward5"


class MdGames(rx.Component):
    library = "react-icons/md"
    tag = "MdGames"


class MdHd(rx.Component):
    library = "react-icons/md"
    tag = "MdHd"


class MdHearingDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdHearingDisabled"


class MdHearing(rx.Component):
    library = "react-icons/md"
    tag = "MdHearing"


class MdHighQuality(rx.Component):
    library = "react-icons/md"
    tag = "MdHighQuality"


class MdInterpreterMode(rx.Component):
    library = "react-icons/md"
    tag = "MdInterpreterMode"


class MdLibraryAddCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdLibraryAddCheck"


class MdLibraryAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdLibraryAdd"


class MdLibraryBooks(rx.Component):
    library = "react-icons/md"
    tag = "MdLibraryBooks"


class MdLibraryMusic(rx.Component):
    library = "react-icons/md"
    tag = "MdLibraryMusic"


class MdLoop(rx.Component):
    library = "react-icons/md"
    tag = "MdLoop"


class MdLyrics(rx.Component):
    library = "react-icons/md"
    tag = "MdLyrics"


class MdMicNone(rx.Component):
    library = "react-icons/md"
    tag = "MdMicNone"


class MdMicOff(rx.Component):
    library = "react-icons/md"
    tag = "MdMicOff"


class MdMic(rx.Component):
    library = "react-icons/md"
    tag = "MdMic"


class MdMissedVideoCall(rx.Component):
    library = "react-icons/md"
    tag = "MdMissedVideoCall"


class MdMovieEdit(rx.Component):
    library = "react-icons/md"
    tag = "MdMovieEdit"


class MdMovie(rx.Component):
    library = "react-icons/md"
    tag = "MdMovie"


class MdMusicVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdMusicVideo"


class MdNewReleases(rx.Component):
    library = "react-icons/md"
    tag = "MdNewReleases"


class MdNotInterested(rx.Component):
    library = "react-icons/md"
    tag = "MdNotInterested"


class MdNote(rx.Component):
    library = "react-icons/md"
    tag = "MdNote"


class MdPauseCircleFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdPauseCircleFilled"


class MdPauseCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdPauseCircleOutline"


class MdPauseCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdPauseCircle"


class MdPause(rx.Component):
    library = "react-icons/md"
    tag = "MdPause"


class MdPlayArrow(rx.Component):
    library = "react-icons/md"
    tag = "MdPlayArrow"


class MdPlayCircleFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdPlayCircleFilled"


class MdPlayCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdPlayCircleOutline"


class MdPlayCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdPlayCircle"


class MdPlayDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdPlayDisabled"


class MdPlaylistAddCheckCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdPlaylistAddCheckCircle"


class MdPlaylistAddCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdPlaylistAddCheck"


class MdPlaylistAddCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdPlaylistAddCircle"


class MdPlaylistAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdPlaylistAdd"


class MdPlaylistPlay(rx.Component):
    library = "react-icons/md"
    tag = "MdPlaylistPlay"


class MdPlaylistRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdPlaylistRemove"


class MdQueueMusic(rx.Component):
    library = "react-icons/md"
    tag = "MdQueueMusic"


class MdQueuePlayNext(rx.Component):
    library = "react-icons/md"
    tag = "MdQueuePlayNext"


class MdQueue(rx.Component):
    library = "react-icons/md"
    tag = "MdQueue"


class MdRadio(rx.Component):
    library = "react-icons/md"
    tag = "MdRadio"


class MdRecentActors(rx.Component):
    library = "react-icons/md"
    tag = "MdRecentActors"


class MdRemoveFromQueue(rx.Component):
    library = "react-icons/md"
    tag = "MdRemoveFromQueue"


class MdRepeatOn(rx.Component):
    library = "react-icons/md"
    tag = "MdRepeatOn"


class MdRepeatOneOn(rx.Component):
    library = "react-icons/md"
    tag = "MdRepeatOneOn"


class MdRepeatOne(rx.Component):
    library = "react-icons/md"
    tag = "MdRepeatOne"


class MdRepeat(rx.Component):
    library = "react-icons/md"
    tag = "MdRepeat"


class MdReplay10(rx.Component):
    library = "react-icons/md"
    tag = "MdReplay10"


class MdReplay30(rx.Component):
    library = "react-icons/md"
    tag = "MdReplay30"


class MdReplay5(rx.Component):
    library = "react-icons/md"
    tag = "MdReplay5"


class MdReplayCircleFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdReplayCircleFilled"


class MdReplay(rx.Component):
    library = "react-icons/md"
    tag = "MdReplay"


class MdSd(rx.Component):
    library = "react-icons/md"
    tag = "MdSd"


class MdShuffleOn(rx.Component):
    library = "react-icons/md"
    tag = "MdShuffleOn"


class MdShuffle(rx.Component):
    library = "react-icons/md"
    tag = "MdShuffle"


class MdSkipNext(rx.Component):
    library = "react-icons/md"
    tag = "MdSkipNext"


class MdSkipPrevious(rx.Component):
    library = "react-icons/md"
    tag = "MdSkipPrevious"


class MdSlowMotionVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdSlowMotionVideo"


class MdSnooze(rx.Component):
    library = "react-icons/md"
    tag = "MdSnooze"


class MdSortByAlpha(rx.Component):
    library = "react-icons/md"
    tag = "MdSortByAlpha"


class MdSpeed(rx.Component):
    library = "react-icons/md"
    tag = "MdSpeed"


class MdStopCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdStopCircle"


class MdStop(rx.Component):
    library = "react-icons/md"
    tag = "MdStop"


class MdSubscriptions(rx.Component):
    library = "react-icons/md"
    tag = "MdSubscriptions"


class MdSubtitles(rx.Component):
    library = "react-icons/md"
    tag = "MdSubtitles"


class MdSurroundSound(rx.Component):
    library = "react-icons/md"
    tag = "MdSurroundSound"


class MdVideoCall(rx.Component):
    library = "react-icons/md"
    tag = "MdVideoCall"


class MdVideoFile(rx.Component):
    library = "react-icons/md"
    tag = "MdVideoFile"


class MdVideoLabel(rx.Component):
    library = "react-icons/md"
    tag = "MdVideoLabel"


class MdVideoLibrary(rx.Component):
    library = "react-icons/md"
    tag = "MdVideoLibrary"


class MdVideoSettings(rx.Component):
    library = "react-icons/md"
    tag = "MdVideoSettings"


class MdVideocamOff(rx.Component):
    library = "react-icons/md"
    tag = "MdVideocamOff"


class MdVideocam(rx.Component):
    library = "react-icons/md"
    tag = "MdVideocam"


class MdVolumeDownAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdVolumeDownAlt"


class MdVolumeDown(rx.Component):
    library = "react-icons/md"
    tag = "MdVolumeDown"


class MdVolumeMute(rx.Component):
    library = "react-icons/md"
    tag = "MdVolumeMute"


class MdVolumeOff(rx.Component):
    library = "react-icons/md"
    tag = "MdVolumeOff"


class MdVolumeUp(rx.Component):
    library = "react-icons/md"
    tag = "MdVolumeUp"


class MdWebAssetOff(rx.Component):
    library = "react-icons/md"
    tag = "MdWebAssetOff"


class MdWebAsset(rx.Component):
    library = "react-icons/md"
    tag = "MdWebAsset"


class MdWeb(rx.Component):
    library = "react-icons/md"
    tag = "MdWeb"


class Md3P(rx.Component):
    library = "react-icons/md"
    tag = "Md3P"


class MdAddIcCall(rx.Component):
    library = "react-icons/md"
    tag = "MdAddIcCall"


class MdAlternateEmail(rx.Component):
    library = "react-icons/md"
    tag = "MdAlternateEmail"


class MdAppRegistration(rx.Component):
    library = "react-icons/md"
    tag = "MdAppRegistration"


class MdBusiness(rx.Component):
    library = "react-icons/md"
    tag = "MdBusiness"


class MdCallEnd(rx.Component):
    library = "react-icons/md"
    tag = "MdCallEnd"


class MdCallMade(rx.Component):
    library = "react-icons/md"
    tag = "MdCallMade"


class MdCallMerge(rx.Component):
    library = "react-icons/md"
    tag = "MdCallMerge"


class MdCallMissedOutgoing(rx.Component):
    library = "react-icons/md"
    tag = "MdCallMissedOutgoing"


class MdCallMissed(rx.Component):
    library = "react-icons/md"
    tag = "MdCallMissed"


class MdCallReceived(rx.Component):
    library = "react-icons/md"
    tag = "MdCallReceived"


class MdCallSplit(rx.Component):
    library = "react-icons/md"
    tag = "MdCallSplit"


class MdCall(rx.Component):
    library = "react-icons/md"
    tag = "MdCall"


class MdCancelPresentation(rx.Component):
    library = "react-icons/md"
    tag = "MdCancelPresentation"


class MdCellTower(rx.Component):
    library = "react-icons/md"
    tag = "MdCellTower"


class MdCellWifi(rx.Component):
    library = "react-icons/md"
    tag = "MdCellWifi"


class MdChatBubbleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdChatBubbleOutline"


class MdChatBubble(rx.Component):
    library = "react-icons/md"
    tag = "MdChatBubble"


class MdChat(rx.Component):
    library = "react-icons/md"
    tag = "MdChat"


class MdClearAll(rx.Component):
    library = "react-icons/md"
    tag = "MdClearAll"


class MdCoPresent(rx.Component):
    library = "react-icons/md"
    tag = "MdCoPresent"


class MdComment(rx.Component):
    library = "react-icons/md"
    tag = "MdComment"


class MdCommentsDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdCommentsDisabled"


class MdContactEmergency(rx.Component):
    library = "react-icons/md"
    tag = "MdContactEmergency"


class MdContactMail(rx.Component):
    library = "react-icons/md"
    tag = "MdContactMail"


class MdContactPhone(rx.Component):
    library = "react-icons/md"
    tag = "MdContactPhone"


class MdContacts(rx.Component):
    library = "react-icons/md"
    tag = "MdContacts"


class MdDesktopAccessDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdDesktopAccessDisabled"


class MdDialerSip(rx.Component):
    library = "react-icons/md"
    tag = "MdDialerSip"


class MdDialpad(rx.Component):
    library = "react-icons/md"
    tag = "MdDialpad"


class MdDocumentScanner(rx.Component):
    library = "react-icons/md"
    tag = "MdDocumentScanner"


class MdDomainDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdDomainDisabled"


class MdDomainVerification(rx.Component):
    library = "react-icons/md"
    tag = "MdDomainVerification"


class MdDuo(rx.Component):
    library = "react-icons/md"
    tag = "MdDuo"


class MdEmail(rx.Component):
    library = "react-icons/md"
    tag = "MdEmail"


class MdForum(rx.Component):
    library = "react-icons/md"
    tag = "MdForum"


class MdForwardToInbox(rx.Component):
    library = "react-icons/md"
    tag = "MdForwardToInbox"


class MdHourglassBottom(rx.Component):
    library = "react-icons/md"
    tag = "MdHourglassBottom"


class MdHourglassTop(rx.Component):
    library = "react-icons/md"
    tag = "MdHourglassTop"


class MdHub(rx.Component):
    library = "react-icons/md"
    tag = "MdHub"


class MdImportContacts(rx.Component):
    library = "react-icons/md"
    tag = "MdImportContacts"


class MdImportExport(rx.Component):
    library = "react-icons/md"
    tag = "MdImportExport"


class MdInvertColorsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdInvertColorsOff"


class MdKeyOff(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyOff"


class MdKey(rx.Component):
    library = "react-icons/md"
    tag = "MdKey"


class MdListAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdListAlt"


class MdLiveHelp(rx.Component):
    library = "react-icons/md"
    tag = "MdLiveHelp"


class MdLocationOff(rx.Component):
    library = "react-icons/md"
    tag = "MdLocationOff"


class MdLocationOn(rx.Component):
    library = "react-icons/md"
    tag = "MdLocationOn"


class MdMailLock(rx.Component):
    library = "react-icons/md"
    tag = "MdMailLock"


class MdMailOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdMailOutline"


class MdMarkChatRead(rx.Component):
    library = "react-icons/md"
    tag = "MdMarkChatRead"


class MdMarkChatUnread(rx.Component):
    library = "react-icons/md"
    tag = "MdMarkChatUnread"


class MdMarkEmailRead(rx.Component):
    library = "react-icons/md"
    tag = "MdMarkEmailRead"


class MdMarkEmailUnread(rx.Component):
    library = "react-icons/md"
    tag = "MdMarkEmailUnread"


class MdMarkUnreadChatAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdMarkUnreadChatAlt"


class MdMessage(rx.Component):
    library = "react-icons/md"
    tag = "MdMessage"


class MdMobileScreenShare(rx.Component):
    library = "react-icons/md"
    tag = "MdMobileScreenShare"


class MdMoreTime(rx.Component):
    library = "react-icons/md"
    tag = "MdMoreTime"


class MdNat(rx.Component):
    library = "react-icons/md"
    tag = "MdNat"


class MdNoSim(rx.Component):
    library = "react-icons/md"
    tag = "MdNoSim"


class MdPausePresentation(rx.Component):
    library = "react-icons/md"
    tag = "MdPausePresentation"


class MdPersonAddDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonAddDisabled"


class MdPersonSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonSearch"


class MdPhoneDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneDisabled"


class MdPhoneEnabled(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneEnabled"


class MdPhone(rx.Component):
    library = "react-icons/md"
    tag = "MdPhone"


class MdPhonelinkErase(rx.Component):
    library = "react-icons/md"
    tag = "MdPhonelinkErase"


class MdPhonelinkLock(rx.Component):
    library = "react-icons/md"
    tag = "MdPhonelinkLock"


class MdPhonelinkRing(rx.Component):
    library = "react-icons/md"
    tag = "MdPhonelinkRing"


class MdPhonelinkSetup(rx.Component):
    library = "react-icons/md"
    tag = "MdPhonelinkSetup"


class MdPortableWifiOff(rx.Component):
    library = "react-icons/md"
    tag = "MdPortableWifiOff"


class MdPresentToAll(rx.Component):
    library = "react-icons/md"
    tag = "MdPresentToAll"


class MdPrintDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdPrintDisabled"


class MdQrCode2(rx.Component):
    library = "react-icons/md"
    tag = "MdQrCode2"


class MdQrCodeScanner(rx.Component):
    library = "react-icons/md"
    tag = "MdQrCodeScanner"


class MdQrCode(rx.Component):
    library = "react-icons/md"
    tag = "MdQrCode"


class MdReadMore(rx.Component):
    library = "react-icons/md"
    tag = "MdReadMore"


class MdRingVolume(rx.Component):
    library = "react-icons/md"
    tag = "MdRingVolume"


class MdRssFeed(rx.Component):
    library = "react-icons/md"
    tag = "MdRssFeed"


class MdRtt(rx.Component):
    library = "react-icons/md"
    tag = "MdRtt"


class MdScreenShare(rx.Component):
    library = "react-icons/md"
    tag = "MdScreenShare"


class MdSendTimeExtension(rx.Component):
    library = "react-icons/md"
    tag = "MdSendTimeExtension"


class MdSentimentSatisfiedAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSentimentSatisfiedAlt"


class MdSip(rx.Component):
    library = "react-icons/md"
    tag = "MdSip"


class MdSpeakerPhone(rx.Component):
    library = "react-icons/md"
    tag = "MdSpeakerPhone"


class MdSpoke(rx.Component):
    library = "react-icons/md"
    tag = "MdSpoke"


class MdStayCurrentLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdStayCurrentLandscape"


class MdStayCurrentPortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdStayCurrentPortrait"


class MdStayPrimaryLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdStayPrimaryLandscape"


class MdStayPrimaryPortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdStayPrimaryPortrait"


class MdStopScreenShare(rx.Component):
    library = "react-icons/md"
    tag = "MdStopScreenShare"


class MdSwapCalls(rx.Component):
    library = "react-icons/md"
    tag = "MdSwapCalls"


class MdTextsms(rx.Component):
    library = "react-icons/md"
    tag = "MdTextsms"


class MdUnsubscribe(rx.Component):
    library = "react-icons/md"
    tag = "MdUnsubscribe"


class MdVoicemail(rx.Component):
    library = "react-icons/md"
    tag = "MdVoicemail"


class MdVpnKeyOff(rx.Component):
    library = "react-icons/md"
    tag = "MdVpnKeyOff"


class MdVpnKey(rx.Component):
    library = "react-icons/md"
    tag = "MdVpnKey"


class MdWifiCalling(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiCalling"


class MdAddBox(rx.Component):
    library = "react-icons/md"
    tag = "MdAddBox"


class MdAddCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdAddCircleOutline"


class MdAddCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdAddCircle"


class MdAddLink(rx.Component):
    library = "react-icons/md"
    tag = "MdAddLink"


class MdAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdAdd"


class MdAmpStories(rx.Component):
    library = "react-icons/md"
    tag = "MdAmpStories"


class MdArchive(rx.Component):
    library = "react-icons/md"
    tag = "MdArchive"


class MdAttribution(rx.Component):
    library = "react-icons/md"
    tag = "MdAttribution"


class MdBackspace(rx.Component):
    library = "react-icons/md"
    tag = "MdBackspace"


class MdBallot(rx.Component):
    library = "react-icons/md"
    tag = "MdBallot"


class MdBiotech(rx.Component):
    library = "react-icons/md"
    tag = "MdBiotech"


class MdBlockFlipped(rx.Component):
    library = "react-icons/md"
    tag = "MdBlockFlipped"


class MdBlock(rx.Component):
    library = "react-icons/md"
    tag = "MdBlock"


class MdBolt(rx.Component):
    library = "react-icons/md"
    tag = "MdBolt"


class MdCalculate(rx.Component):
    library = "react-icons/md"
    tag = "MdCalculate"


class MdChangeCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdChangeCircle"


class MdClear(rx.Component):
    library = "react-icons/md"
    tag = "MdClear"


class MdContentCopy(rx.Component):
    library = "react-icons/md"
    tag = "MdContentCopy"


class MdContentCut(rx.Component):
    library = "react-icons/md"
    tag = "MdContentCut"


class MdContentPasteGo(rx.Component):
    library = "react-icons/md"
    tag = "MdContentPasteGo"


class MdContentPasteOff(rx.Component):
    library = "react-icons/md"
    tag = "MdContentPasteOff"


class MdContentPasteSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdContentPasteSearch"


class MdContentPaste(rx.Component):
    library = "react-icons/md"
    tag = "MdContentPaste"


class MdCopyAll(rx.Component):
    library = "react-icons/md"
    tag = "MdCopyAll"


class MdCreate(rx.Component):
    library = "react-icons/md"
    tag = "MdCreate"


class MdDeleteSweep(rx.Component):
    library = "react-icons/md"
    tag = "MdDeleteSweep"


class MdDeselect(rx.Component):
    library = "react-icons/md"
    tag = "MdDeselect"


class MdDrafts(rx.Component):
    library = "react-icons/md"
    tag = "MdDrafts"


class MdDynamicFeed(rx.Component):
    library = "react-icons/md"
    tag = "MdDynamicFeed"


class MdFileCopy(rx.Component):
    library = "react-icons/md"
    tag = "MdFileCopy"


class MdFilterListOff(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterListOff"


class MdFilterList(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterList"


class MdFlagCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdFlagCircle"


class MdFlag(rx.Component):
    library = "react-icons/md"
    tag = "MdFlag"


class MdFontDownloadOff(rx.Component):
    library = "react-icons/md"
    tag = "MdFontDownloadOff"


class MdFontDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdFontDownload"


class MdForward(rx.Component):
    library = "react-icons/md"
    tag = "MdForward"


class MdGesture(rx.Component):
    library = "react-icons/md"
    tag = "MdGesture"


class MdHowToReg(rx.Component):
    library = "react-icons/md"
    tag = "MdHowToReg"


class MdHowToVote(rx.Component):
    library = "react-icons/md"
    tag = "MdHowToVote"


class MdInbox(rx.Component):
    library = "react-icons/md"
    tag = "MdInbox"


class MdInsights(rx.Component):
    library = "react-icons/md"
    tag = "MdInsights"


class MdInventory2(rx.Component):
    library = "react-icons/md"
    tag = "MdInventory2"


class MdInventory(rx.Component):
    library = "react-icons/md"
    tag = "MdInventory"


class MdLinkOff(rx.Component):
    library = "react-icons/md"
    tag = "MdLinkOff"


class MdLink(rx.Component):
    library = "react-icons/md"
    tag = "MdLink"


class MdLowPriority(rx.Component):
    library = "react-icons/md"
    tag = "MdLowPriority"


class MdMail(rx.Component):
    library = "react-icons/md"
    tag = "MdMail"


class MdMarkunread(rx.Component):
    library = "react-icons/md"
    tag = "MdMarkunread"


class MdMoveToInbox(rx.Component):
    library = "react-icons/md"
    tag = "MdMoveToInbox"


class MdNextWeek(rx.Component):
    library = "react-icons/md"
    tag = "MdNextWeek"


class MdOutlinedFlag(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinedFlag"


class MdPolicy(rx.Component):
    library = "react-icons/md"
    tag = "MdPolicy"


class MdPushPin(rx.Component):
    library = "react-icons/md"
    tag = "MdPushPin"


class MdRedo(rx.Component):
    library = "react-icons/md"
    tag = "MdRedo"


class MdRemoveCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdRemoveCircleOutline"


class MdRemoveCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdRemoveCircle"


class MdRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdRemove"


class MdReplyAll(rx.Component):
    library = "react-icons/md"
    tag = "MdReplyAll"


class MdReply(rx.Component):
    library = "react-icons/md"
    tag = "MdReply"


class MdReportGmailerrorred(rx.Component):
    library = "react-icons/md"
    tag = "MdReportGmailerrorred"


class MdReportOff(rx.Component):
    library = "react-icons/md"
    tag = "MdReportOff"


class MdReport(rx.Component):
    library = "react-icons/md"
    tag = "MdReport"


class MdSaveAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSaveAlt"


class MdSaveAs(rx.Component):
    library = "react-icons/md"
    tag = "MdSaveAs"


class MdSave(rx.Component):
    library = "react-icons/md"
    tag = "MdSave"


class MdSelectAll(rx.Component):
    library = "react-icons/md"
    tag = "MdSelectAll"


class MdSend(rx.Component):
    library = "react-icons/md"
    tag = "MdSend"


class MdShield(rx.Component):
    library = "react-icons/md"
    tag = "MdShield"


class MdSort(rx.Component):
    library = "react-icons/md"
    tag = "MdSort"


class MdSquareFoot(rx.Component):
    library = "react-icons/md"
    tag = "MdSquareFoot"


class MdStackedBarChart(rx.Component):
    library = "react-icons/md"
    tag = "MdStackedBarChart"


class MdStream(rx.Component):
    library = "react-icons/md"
    tag = "MdStream"


class MdTag(rx.Component):
    library = "react-icons/md"
    tag = "MdTag"


class MdTextFormat(rx.Component):
    library = "react-icons/md"
    tag = "MdTextFormat"


class MdUnarchive(rx.Component):
    library = "react-icons/md"
    tag = "MdUnarchive"


class MdUndo(rx.Component):
    library = "react-icons/md"
    tag = "MdUndo"


class MdUpcoming(rx.Component):
    library = "react-icons/md"
    tag = "MdUpcoming"


class MdWaves(rx.Component):
    library = "react-icons/md"
    tag = "MdWaves"


class MdWebStories(rx.Component):
    library = "react-icons/md"
    tag = "MdWebStories"


class MdWeekend(rx.Component):
    library = "react-icons/md"
    tag = "MdWeekend"


class MdWhereToVote(rx.Component):
    library = "react-icons/md"
    tag = "MdWhereToVote"


class Md1XMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "Md1XMobiledata"


class Md30Fps(rx.Component):
    library = "react-icons/md"
    tag = "Md30Fps"


class Md3GMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "Md3GMobiledata"


class Md4GMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "Md4GMobiledata"


class Md4GPlusMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "Md4GPlusMobiledata"


class Md60Fps(rx.Component):
    library = "react-icons/md"
    tag = "Md60Fps"


class MdAccessAlarm(rx.Component):
    library = "react-icons/md"
    tag = "MdAccessAlarm"


class MdAccessAlarms(rx.Component):
    library = "react-icons/md"
    tag = "MdAccessAlarms"


class MdAccessTimeFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdAccessTimeFilled"


class MdAccessTime(rx.Component):
    library = "react-icons/md"
    tag = "MdAccessTime"


class MdAdUnits(rx.Component):
    library = "react-icons/md"
    tag = "MdAdUnits"


class MdAddAlarm(rx.Component):
    library = "react-icons/md"
    tag = "MdAddAlarm"


class MdAddToHomeScreen(rx.Component):
    library = "react-icons/md"
    tag = "MdAddToHomeScreen"


class MdAir(rx.Component):
    library = "react-icons/md"
    tag = "MdAir"


class MdAirplaneTicket(rx.Component):
    library = "react-icons/md"
    tag = "MdAirplaneTicket"


class MdAirplanemodeActive(rx.Component):
    library = "react-icons/md"
    tag = "MdAirplanemodeActive"


class MdAirplanemodeInactive(rx.Component):
    library = "react-icons/md"
    tag = "MdAirplanemodeInactive"


class MdAod(rx.Component):
    library = "react-icons/md"
    tag = "MdAod"


class MdBattery0Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery0Bar"


class MdBattery1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery1Bar"


class MdBattery2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery2Bar"


class MdBattery3Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery3Bar"


class MdBattery4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery4Bar"


class MdBattery5Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery5Bar"


class MdBattery6Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery6Bar"


class MdBatteryAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryAlert"


class MdBatteryChargingFull(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryChargingFull"


class MdBatteryFull(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryFull"


class MdBatterySaver(rx.Component):
    library = "react-icons/md"
    tag = "MdBatterySaver"


class MdBatteryStd(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryStd"


class MdBatteryUnknown(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryUnknown"


class MdBloodtype(rx.Component):
    library = "react-icons/md"
    tag = "MdBloodtype"


class MdBluetoothConnected(rx.Component):
    library = "react-icons/md"
    tag = "MdBluetoothConnected"


class MdBluetoothDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdBluetoothDisabled"


class MdBluetoothDrive(rx.Component):
    library = "react-icons/md"
    tag = "MdBluetoothDrive"


class MdBluetoothSearching(rx.Component):
    library = "react-icons/md"
    tag = "MdBluetoothSearching"


class MdBluetooth(rx.Component):
    library = "react-icons/md"
    tag = "MdBluetooth"


class MdBrightnessAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightnessAuto"


class MdBrightnessHigh(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightnessHigh"


class MdBrightnessLow(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightnessLow"


class MdBrightnessMedium(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightnessMedium"


class MdCable(rx.Component):
    library = "react-icons/md"
    tag = "MdCable"


class MdCameraswitch(rx.Component):
    library = "react-icons/md"
    tag = "MdCameraswitch"


class MdCreditScore(rx.Component):
    library = "react-icons/md"
    tag = "MdCreditScore"


class MdDarkMode(rx.Component):
    library = "react-icons/md"
    tag = "MdDarkMode"


class MdDataSaverOff(rx.Component):
    library = "react-icons/md"
    tag = "MdDataSaverOff"


class MdDataSaverOn(rx.Component):
    library = "react-icons/md"
    tag = "MdDataSaverOn"


class MdDataUsage(rx.Component):
    library = "react-icons/md"
    tag = "MdDataUsage"


class MdDatasetLinked(rx.Component):
    library = "react-icons/md"
    tag = "MdDatasetLinked"


class MdDataset(rx.Component):
    library = "react-icons/md"
    tag = "MdDataset"


class MdDeveloperMode(rx.Component):
    library = "react-icons/md"
    tag = "MdDeveloperMode"


class MdDeviceThermostat(rx.Component):
    library = "react-icons/md"
    tag = "MdDeviceThermostat"


class MdDevicesFold(rx.Component):
    library = "react-icons/md"
    tag = "MdDevicesFold"


class MdDevices(rx.Component):
    library = "react-icons/md"
    tag = "MdDevices"


class MdDiscount(rx.Component):
    library = "react-icons/md"
    tag = "MdDiscount"


class MdDoNotDisturbOnTotalSilence(rx.Component):
    library = "react-icons/md"
    tag = "MdDoNotDisturbOnTotalSilence"


class MdDvr(rx.Component):
    library = "react-icons/md"
    tag = "MdDvr"


class MdEMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdEMobiledata"


class MdEdgesensorHigh(rx.Component):
    library = "react-icons/md"
    tag = "MdEdgesensorHigh"


class MdEdgesensorLow(rx.Component):
    library = "react-icons/md"
    tag = "MdEdgesensorLow"


class MdFlashlightOff(rx.Component):
    library = "react-icons/md"
    tag = "MdFlashlightOff"


class MdFlashlightOn(rx.Component):
    library = "react-icons/md"
    tag = "MdFlashlightOn"


class MdFlourescent(rx.Component):
    library = "react-icons/md"
    tag = "MdFlourescent"


class MdFluorescent(rx.Component):
    library = "react-icons/md"
    tag = "MdFluorescent"


class MdFmdBad(rx.Component):
    library = "react-icons/md"
    tag = "MdFmdBad"


class MdFmdGood(rx.Component):
    library = "react-icons/md"
    tag = "MdFmdGood"


class MdGMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdGMobiledata"


class MdGppBad(rx.Component):
    library = "react-icons/md"
    tag = "MdGppBad"


class MdGppGood(rx.Component):
    library = "react-icons/md"
    tag = "MdGppGood"


class MdGppMaybe(rx.Component):
    library = "react-icons/md"
    tag = "MdGppMaybe"


class MdGpsFixed(rx.Component):
    library = "react-icons/md"
    tag = "MdGpsFixed"


class MdGpsNotFixed(rx.Component):
    library = "react-icons/md"
    tag = "MdGpsNotFixed"


class MdGpsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdGpsOff"


class MdGraphicEq(rx.Component):
    library = "react-icons/md"
    tag = "MdGraphicEq"


class MdGrid3X3(rx.Component):
    library = "react-icons/md"
    tag = "MdGrid3X3"


class MdGrid4X4(rx.Component):
    library = "react-icons/md"
    tag = "MdGrid4X4"


class MdGridGoldenratio(rx.Component):
    library = "react-icons/md"
    tag = "MdGridGoldenratio"


class MdHMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdHMobiledata"


class MdHPlusMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdHPlusMobiledata"


class MdHdrAutoSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrAutoSelect"


class MdHdrAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrAuto"


class MdHdrOffSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrOffSelect"


class MdHdrOnSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrOnSelect"


class MdLan(rx.Component):
    library = "react-icons/md"
    tag = "MdLan"


class MdLensBlur(rx.Component):
    library = "react-icons/md"
    tag = "MdLensBlur"


class MdLightMode(rx.Component):
    library = "react-icons/md"
    tag = "MdLightMode"


class MdLocationDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdLocationDisabled"


class MdLocationSearching(rx.Component):
    library = "react-icons/md"
    tag = "MdLocationSearching"


class MdLteMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdLteMobiledata"


class MdLtePlusMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdLtePlusMobiledata"


class MdMacroOff(rx.Component):
    library = "react-icons/md"
    tag = "MdMacroOff"


class MdMediaBluetoothOff(rx.Component):
    library = "react-icons/md"
    tag = "MdMediaBluetoothOff"


class MdMediaBluetoothOn(rx.Component):
    library = "react-icons/md"
    tag = "MdMediaBluetoothOn"


class MdMedicationLiquid(rx.Component):
    library = "react-icons/md"
    tag = "MdMedicationLiquid"


class MdMedication(rx.Component):
    library = "react-icons/md"
    tag = "MdMedication"


class MdMobileFriendly(rx.Component):
    library = "react-icons/md"
    tag = "MdMobileFriendly"


class MdMobileOff(rx.Component):
    library = "react-icons/md"
    tag = "MdMobileOff"


class MdMobiledataOff(rx.Component):
    library = "react-icons/md"
    tag = "MdMobiledataOff"


class MdModeNight(rx.Component):
    library = "react-icons/md"
    tag = "MdModeNight"


class MdModeStandby(rx.Component):
    library = "react-icons/md"
    tag = "MdModeStandby"


class MdMonitorHeart(rx.Component):
    library = "react-icons/md"
    tag = "MdMonitorHeart"


class MdMonitorWeight(rx.Component):
    library = "react-icons/md"
    tag = "MdMonitorWeight"


class MdNearbyError(rx.Component):
    library = "react-icons/md"
    tag = "MdNearbyError"


class MdNearbyOff(rx.Component):
    library = "react-icons/md"
    tag = "MdNearbyOff"


class MdNetworkCell(rx.Component):
    library = "react-icons/md"
    tag = "MdNetworkCell"


class MdNetworkWifi1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdNetworkWifi1Bar"


class MdNetworkWifi2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdNetworkWifi2Bar"


class MdNetworkWifi3Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdNetworkWifi3Bar"


class MdNetworkWifi(rx.Component):
    library = "react-icons/md"
    tag = "MdNetworkWifi"


class MdNfc(rx.Component):
    library = "react-icons/md"
    tag = "MdNfc"


class MdNightlight(rx.Component):
    library = "react-icons/md"
    tag = "MdNightlight"


class MdNoteAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdNoteAlt"


class MdPassword(rx.Component):
    library = "react-icons/md"
    tag = "MdPassword"


class MdPattern(rx.Component):
    library = "react-icons/md"
    tag = "MdPattern"


class MdPhishing(rx.Component):
    library = "react-icons/md"
    tag = "MdPhishing"


class MdPin(rx.Component):
    library = "react-icons/md"
    tag = "MdPin"


class MdPlayLesson(rx.Component):
    library = "react-icons/md"
    tag = "MdPlayLesson"


class MdPriceChange(rx.Component):
    library = "react-icons/md"
    tag = "MdPriceChange"


class MdPriceCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdPriceCheck"


class MdPunchClock(rx.Component):
    library = "react-icons/md"
    tag = "MdPunchClock"


class MdQuiz(rx.Component):
    library = "react-icons/md"
    tag = "MdQuiz"


class MdRMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdRMobiledata"


class MdRadar(rx.Component):
    library = "react-icons/md"
    tag = "MdRadar"


class MdRememberMe(rx.Component):
    library = "react-icons/md"
    tag = "MdRememberMe"


class MdResetTv(rx.Component):
    library = "react-icons/md"
    tag = "MdResetTv"


class MdRestartAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdRestartAlt"


class MdReviews(rx.Component):
    library = "react-icons/md"
    tag = "MdReviews"


class MdRsvp(rx.Component):
    library = "react-icons/md"
    tag = "MdRsvp"


class MdScreenLockLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdScreenLockLandscape"


class MdScreenLockPortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdScreenLockPortrait"


class MdScreenLockRotation(rx.Component):
    library = "react-icons/md"
    tag = "MdScreenLockRotation"


class MdScreenRotation(rx.Component):
    library = "react-icons/md"
    tag = "MdScreenRotation"


class MdScreenSearchDesktop(rx.Component):
    library = "react-icons/md"
    tag = "MdScreenSearchDesktop"


class MdScreenshotMonitor(rx.Component):
    library = "react-icons/md"
    tag = "MdScreenshotMonitor"


class MdScreenshot(rx.Component):
    library = "react-icons/md"
    tag = "MdScreenshot"


class MdSdStorage(rx.Component):
    library = "react-icons/md"
    tag = "MdSdStorage"


class MdSecurityUpdateGood(rx.Component):
    library = "react-icons/md"
    tag = "MdSecurityUpdateGood"


class MdSecurityUpdateWarning(rx.Component):
    library = "react-icons/md"
    tag = "MdSecurityUpdateWarning"


class MdSecurityUpdate(rx.Component):
    library = "react-icons/md"
    tag = "MdSecurityUpdate"


class MdSell(rx.Component):
    library = "react-icons/md"
    tag = "MdSell"


class MdSendToMobile(rx.Component):
    library = "react-icons/md"
    tag = "MdSendToMobile"


class MdSettingsSuggest(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsSuggest"


class MdSettingsSystemDaydream(rx.Component):
    library = "react-icons/md"
    tag = "MdSettingsSystemDaydream"


class MdShareLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdShareLocation"


class MdShortcut(rx.Component):
    library = "react-icons/md"
    tag = "MdShortcut"


class MdSignalCellular0Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellular0Bar"


class MdSignalCellular4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellular4Bar"


class MdSignalCellularAlt1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularAlt1Bar"


class MdSignalCellularAlt2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularAlt2Bar"


class MdSignalCellularAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularAlt"


class MdSignalCellularConnectedNoInternet0Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularConnectedNoInternet0Bar"


class MdSignalCellularConnectedNoInternet4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularConnectedNoInternet4Bar"


class MdSignalCellularNoSim(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularNoSim"


class MdSignalCellularNodata(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularNodata"


class MdSignalCellularNull(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularNull"


class MdSignalCellularOff(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularOff"


class MdSignalWifi0Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifi0Bar"


class MdSignalWifi4BarLock(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifi4BarLock"


class MdSignalWifi4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifi4Bar"


class MdSignalWifiBad(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiBad"


class MdSignalWifiConnectedNoInternet4(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiConnectedNoInternet4"


class MdSignalWifiOff(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiOff"


class MdSignalWifiStatusbar4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbar4Bar"


class MdSignalWifiStatusbarConnectedNoInternet4(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbarConnectedNoInternet4"


class MdSignalWifiStatusbarNull(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbarNull"


class MdSimCardDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdSimCardDownload"


class MdSplitscreen(rx.Component):
    library = "react-icons/md"
    tag = "MdSplitscreen"


class MdSportsScore(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsScore"


class MdSsidChart(rx.Component):
    library = "react-icons/md"
    tag = "MdSsidChart"


class MdStorage(rx.Component):
    library = "react-icons/md"
    tag = "MdStorage"


class MdStorm(rx.Component):
    library = "react-icons/md"
    tag = "MdStorm"


class MdSummarize(rx.Component):
    library = "react-icons/md"
    tag = "MdSummarize"


class MdSystemSecurityUpdateGood(rx.Component):
    library = "react-icons/md"
    tag = "MdSystemSecurityUpdateGood"


class MdSystemSecurityUpdateWarning(rx.Component):
    library = "react-icons/md"
    tag = "MdSystemSecurityUpdateWarning"


class MdSystemSecurityUpdate(rx.Component):
    library = "react-icons/md"
    tag = "MdSystemSecurityUpdate"


class MdTask(rx.Component):
    library = "react-icons/md"
    tag = "MdTask"


class MdThermostat(rx.Component):
    library = "react-icons/md"
    tag = "MdThermostat"


class MdTimer10Select(rx.Component):
    library = "react-icons/md"
    tag = "MdTimer10Select"


class MdTimer3Select(rx.Component):
    library = "react-icons/md"
    tag = "MdTimer3Select"


class MdTungsten(rx.Component):
    library = "react-icons/md"
    tag = "MdTungsten"


class MdUsbOff(rx.Component):
    library = "react-icons/md"
    tag = "MdUsbOff"


class MdUsb(rx.Component):
    library = "react-icons/md"
    tag = "MdUsb"


class MdWallpaper(rx.Component):
    library = "react-icons/md"
    tag = "MdWallpaper"


class MdWater(rx.Component):
    library = "react-icons/md"
    tag = "MdWater"


class MdWidgets(rx.Component):
    library = "react-icons/md"
    tag = "MdWidgets"


class MdWifi1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdWifi1Bar"


class MdWifi2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdWifi2Bar"


class MdWifiCalling3(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiCalling3"


class MdWifiChannel(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiChannel"


class MdWifiFind(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiFind"


class MdWifiLock(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiLock"


class MdWifiPassword(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiPassword"


class MdWifiTetheringErrorRounded(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiTetheringErrorRounded"


class MdWifiTetheringError(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiTetheringError"


class MdWifiTetheringOff(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiTetheringOff"


class MdWifiTethering(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiTethering"


class MdAddChart(rx.Component):
    library = "react-icons/md"
    tag = "MdAddChart"


class MdAddComment(rx.Component):
    library = "react-icons/md"
    tag = "MdAddComment"


class MdAlignHorizontalCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdAlignHorizontalCenter"


class MdAlignHorizontalLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdAlignHorizontalLeft"


class MdAlignHorizontalRight(rx.Component):
    library = "react-icons/md"
    tag = "MdAlignHorizontalRight"


class MdAlignVerticalBottom(rx.Component):
    library = "react-icons/md"
    tag = "MdAlignVerticalBottom"


class MdAlignVerticalCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdAlignVerticalCenter"


class MdAlignVerticalTop(rx.Component):
    library = "react-icons/md"
    tag = "MdAlignVerticalTop"


class MdAreaChart(rx.Component):
    library = "react-icons/md"
    tag = "MdAreaChart"


class MdAttachFile(rx.Component):
    library = "react-icons/md"
    tag = "MdAttachFile"


class MdAttachMoney(rx.Component):
    library = "react-icons/md"
    tag = "MdAttachMoney"


class MdAutoGraph(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoGraph"


class MdBarChart(rx.Component):
    library = "react-icons/md"
    tag = "MdBarChart"


class MdBorderAll(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderAll"


class MdBorderBottom(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderBottom"


class MdBorderClear(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderClear"


class MdBorderColor(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderColor"


class MdBorderHorizontal(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderHorizontal"


class MdBorderInner(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderInner"


class MdBorderLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderLeft"


class MdBorderOuter(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderOuter"


class MdBorderRight(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderRight"


class MdBorderStyle(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderStyle"


class MdBorderTop(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderTop"


class MdBorderVertical(rx.Component):
    library = "react-icons/md"
    tag = "MdBorderVertical"


class MdBubbleChart(rx.Component):
    library = "react-icons/md"
    tag = "MdBubbleChart"


class MdCandlestickChart(rx.Component):
    library = "react-icons/md"
    tag = "MdCandlestickChart"


class MdChecklistRtl(rx.Component):
    library = "react-icons/md"
    tag = "MdChecklistRtl"


class MdChecklist(rx.Component):
    library = "react-icons/md"
    tag = "MdChecklist"


class MdDataArray(rx.Component):
    library = "react-icons/md"
    tag = "MdDataArray"


class MdDataObject(rx.Component):
    library = "react-icons/md"
    tag = "MdDataObject"


class MdDragHandle(rx.Component):
    library = "react-icons/md"
    tag = "MdDragHandle"


class MdDraw(rx.Component):
    library = "react-icons/md"
    tag = "MdDraw"


class MdEditNote(rx.Component):
    library = "react-icons/md"
    tag = "MdEditNote"


class MdFormatAlignCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatAlignCenter"


class MdFormatAlignJustify(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatAlignJustify"


class MdFormatAlignLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatAlignLeft"


class MdFormatAlignRight(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatAlignRight"


class MdFormatBold(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatBold"


class MdFormatClear(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatClear"


class MdFormatColorFill(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatColorFill"


class MdFormatColorReset(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatColorReset"


class MdFormatColorText(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatColorText"


class MdFormatIndentDecrease(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatIndentDecrease"


class MdFormatIndentIncrease(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatIndentIncrease"


class MdFormatItalic(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatItalic"


class MdFormatLineSpacing(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatLineSpacing"


class MdFormatListBulletedAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatListBulletedAdd"


class MdFormatListBulleted(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatListBulleted"


class MdFormatListNumberedRtl(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatListNumberedRtl"


class MdFormatListNumbered(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatListNumbered"


class MdFormatPaint(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatPaint"


class MdFormatQuote(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatQuote"


class MdFormatShapes(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatShapes"


class MdFormatSize(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatSize"


class MdFormatStrikethrough(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatStrikethrough"


class MdFormatTextdirectionLToR(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatTextdirectionLToR"


class MdFormatTextdirectionRToL(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatTextdirectionRToL"


class MdFormatUnderlined(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatUnderlined"


class MdFunctions(rx.Component):
    library = "react-icons/md"
    tag = "MdFunctions"


class MdHeight(rx.Component):
    library = "react-icons/md"
    tag = "MdHeight"


class MdHexagon(rx.Component):
    library = "react-icons/md"
    tag = "MdHexagon"


class MdHighlight(rx.Component):
    library = "react-icons/md"
    tag = "MdHighlight"


class MdHorizontalDistribute(rx.Component):
    library = "react-icons/md"
    tag = "MdHorizontalDistribute"


class MdHorizontalRule(rx.Component):
    library = "react-icons/md"
    tag = "MdHorizontalRule"


class MdInsertChartOutlined(rx.Component):
    library = "react-icons/md"
    tag = "MdInsertChartOutlined"


class MdInsertChart(rx.Component):
    library = "react-icons/md"
    tag = "MdInsertChart"


class MdInsertComment(rx.Component):
    library = "react-icons/md"
    tag = "MdInsertComment"


class MdInsertDriveFile(rx.Component):
    library = "react-icons/md"
    tag = "MdInsertDriveFile"


class MdInsertEmoticon(rx.Component):
    library = "react-icons/md"
    tag = "MdInsertEmoticon"


class MdInsertInvitation(rx.Component):
    library = "react-icons/md"
    tag = "MdInsertInvitation"


class MdInsertLink(rx.Component):
    library = "react-icons/md"
    tag = "MdInsertLink"


class MdInsertPageBreak(rx.Component):
    library = "react-icons/md"
    tag = "MdInsertPageBreak"


class MdInsertPhoto(rx.Component):
    library = "react-icons/md"
    tag = "MdInsertPhoto"


class MdLineAxis(rx.Component):
    library = "react-icons/md"
    tag = "MdLineAxis"


class MdLinearScale(rx.Component):
    library = "react-icons/md"
    tag = "MdLinearScale"


class MdMargin(rx.Component):
    library = "react-icons/md"
    tag = "MdMargin"


class MdMergeType(rx.Component):
    library = "react-icons/md"
    tag = "MdMergeType"


class MdModeComment(rx.Component):
    library = "react-icons/md"
    tag = "MdModeComment"


class MdModeEditOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdModeEditOutline"


class MdModeEdit(rx.Component):
    library = "react-icons/md"
    tag = "MdModeEdit"


class MdMode(rx.Component):
    library = "react-icons/md"
    tag = "MdMode"


class MdMonetizationOn(rx.Component):
    library = "react-icons/md"
    tag = "MdMonetizationOn"


class MdMoneyOffCsred(rx.Component):
    library = "react-icons/md"
    tag = "MdMoneyOffCsred"


class MdMoneyOff(rx.Component):
    library = "react-icons/md"
    tag = "MdMoneyOff"


class MdMoveDown(rx.Component):
    library = "react-icons/md"
    tag = "MdMoveDown"


class MdMoveUp(rx.Component):
    library = "react-icons/md"
    tag = "MdMoveUp"


class MdMultilineChart(rx.Component):
    library = "react-icons/md"
    tag = "MdMultilineChart"


class MdNotes(rx.Component):
    library = "react-icons/md"
    tag = "MdNotes"


class MdNumbers(rx.Component):
    library = "react-icons/md"
    tag = "MdNumbers"


class MdPadding(rx.Component):
    library = "react-icons/md"
    tag = "MdPadding"


class MdPentagon(rx.Component):
    library = "react-icons/md"
    tag = "MdPentagon"


class MdPieChartOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdPieChartOutline"


class MdPieChartOutlined(rx.Component):
    library = "react-icons/md"
    tag = "MdPieChartOutlined"


class MdPieChart(rx.Component):
    library = "react-icons/md"
    tag = "MdPieChart"


class MdPolyline(rx.Component):
    library = "react-icons/md"
    tag = "MdPolyline"


class MdPostAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdPostAdd"


class MdPublish(rx.Component):
    library = "react-icons/md"
    tag = "MdPublish"


class MdQueryStats(rx.Component):
    library = "react-icons/md"
    tag = "MdQueryStats"


class MdRectangle(rx.Component):
    library = "react-icons/md"
    tag = "MdRectangle"


class MdScatterPlot(rx.Component):
    library = "react-icons/md"
    tag = "MdScatterPlot"


class MdSchema(rx.Component):
    library = "react-icons/md"
    tag = "MdSchema"


class MdScore(rx.Component):
    library = "react-icons/md"
    tag = "MdScore"


class MdShapeLine(rx.Component):
    library = "react-icons/md"
    tag = "MdShapeLine"


class MdShortText(rx.Component):
    library = "react-icons/md"
    tag = "MdShortText"


class MdShowChart(rx.Component):
    library = "react-icons/md"
    tag = "MdShowChart"


class MdSpaceBar(rx.Component):
    library = "react-icons/md"
    tag = "MdSpaceBar"


class MdSquare(rx.Component):
    library = "react-icons/md"
    tag = "MdSquare"


class MdStackedLineChart(rx.Component):
    library = "react-icons/md"
    tag = "MdStackedLineChart"


class MdStrikethroughS(rx.Component):
    library = "react-icons/md"
    tag = "MdStrikethroughS"


class MdSubscript(rx.Component):
    library = "react-icons/md"
    tag = "MdSubscript"


class MdSuperscript(rx.Component):
    library = "react-icons/md"
    tag = "MdSuperscript"


class MdTableChart(rx.Component):
    library = "react-icons/md"
    tag = "MdTableChart"


class MdTableRows(rx.Component):
    library = "react-icons/md"
    tag = "MdTableRows"


class MdTextDecrease(rx.Component):
    library = "react-icons/md"
    tag = "MdTextDecrease"


class MdTextFields(rx.Component):
    library = "react-icons/md"
    tag = "MdTextFields"


class MdTextIncrease(rx.Component):
    library = "react-icons/md"
    tag = "MdTextIncrease"


class MdTitle(rx.Component):
    library = "react-icons/md"
    tag = "MdTitle"


class MdTypeSpecimen(rx.Component):
    library = "react-icons/md"
    tag = "MdTypeSpecimen"


class MdVerticalAlignBottom(rx.Component):
    library = "react-icons/md"
    tag = "MdVerticalAlignBottom"


class MdVerticalAlignCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdVerticalAlignCenter"


class MdVerticalAlignTop(rx.Component):
    library = "react-icons/md"
    tag = "MdVerticalAlignTop"


class MdVerticalDistribute(rx.Component):
    library = "react-icons/md"
    tag = "MdVerticalDistribute"


class MdWrapText(rx.Component):
    library = "react-icons/md"
    tag = "MdWrapText"


class MdApproval(rx.Component):
    library = "react-icons/md"
    tag = "MdApproval"


class MdAttachEmail(rx.Component):
    library = "react-icons/md"
    tag = "MdAttachEmail"


class MdAttachment(rx.Component):
    library = "react-icons/md"
    tag = "MdAttachment"


class MdCloudCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdCloudCircle"


class MdCloudDone(rx.Component):
    library = "react-icons/md"
    tag = "MdCloudDone"


class MdCloudDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdCloudDownload"


class MdCloudOff(rx.Component):
    library = "react-icons/md"
    tag = "MdCloudOff"


class MdCloudQueue(rx.Component):
    library = "react-icons/md"
    tag = "MdCloudQueue"


class MdCloudSync(rx.Component):
    library = "react-icons/md"
    tag = "MdCloudSync"


class MdCloudUpload(rx.Component):
    library = "react-icons/md"
    tag = "MdCloudUpload"


class MdCloud(rx.Component):
    library = "react-icons/md"
    tag = "MdCloud"


class MdCreateNewFolder(rx.Component):
    library = "react-icons/md"
    tag = "MdCreateNewFolder"


class MdDifference(rx.Component):
    library = "react-icons/md"
    tag = "MdDifference"


class MdDownloadDone(rx.Component):
    library = "react-icons/md"
    tag = "MdDownloadDone"


class MdDownloadForOffline(rx.Component):
    library = "react-icons/md"
    tag = "MdDownloadForOffline"


class MdDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdDownload"


class MdDownloading(rx.Component):
    library = "react-icons/md"
    tag = "MdDownloading"


class MdDriveFileMoveOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdDriveFileMoveOutline"


class MdDriveFileMoveRtl(rx.Component):
    library = "react-icons/md"
    tag = "MdDriveFileMoveRtl"


class MdDriveFileMove(rx.Component):
    library = "react-icons/md"
    tag = "MdDriveFileMove"


class MdDriveFileRenameOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdDriveFileRenameOutline"


class MdDriveFolderUpload(rx.Component):
    library = "react-icons/md"
    tag = "MdDriveFolderUpload"


class MdFileDownloadDone(rx.Component):
    library = "react-icons/md"
    tag = "MdFileDownloadDone"


class MdFileDownloadOff(rx.Component):
    library = "react-icons/md"
    tag = "MdFileDownloadOff"


class MdFileDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdFileDownload"


class MdFileOpen(rx.Component):
    library = "react-icons/md"
    tag = "MdFileOpen"


class MdFileUploadOff(rx.Component):
    library = "react-icons/md"
    tag = "MdFileUploadOff"


class MdFileUpload(rx.Component):
    library = "react-icons/md"
    tag = "MdFileUpload"


class MdFolderCopy(rx.Component):
    library = "react-icons/md"
    tag = "MdFolderCopy"


class MdFolderDelete(rx.Component):
    library = "react-icons/md"
    tag = "MdFolderDelete"


class MdFolderOff(rx.Component):
    library = "react-icons/md"
    tag = "MdFolderOff"


class MdFolderOpen(rx.Component):
    library = "react-icons/md"
    tag = "MdFolderOpen"


class MdFolderShared(rx.Component):
    library = "react-icons/md"
    tag = "MdFolderShared"


class MdFolderZip(rx.Component):
    library = "react-icons/md"
    tag = "MdFolderZip"


class MdFolder(rx.Component):
    library = "react-icons/md"
    tag = "MdFolder"


class MdFormatOverline(rx.Component):
    library = "react-icons/md"
    tag = "MdFormatOverline"


class MdGridView(rx.Component):
    library = "react-icons/md"
    tag = "MdGridView"


class MdNewspaper(rx.Component):
    library = "react-icons/md"
    tag = "MdNewspaper"


class MdRequestQuote(rx.Component):
    library = "react-icons/md"
    tag = "MdRequestQuote"


class MdRuleFolder(rx.Component):
    library = "react-icons/md"
    tag = "MdRuleFolder"


class MdSnippetFolder(rx.Component):
    library = "react-icons/md"
    tag = "MdSnippetFolder"


class MdTextSnippet(rx.Component):
    library = "react-icons/md"
    tag = "MdTextSnippet"


class MdTopic(rx.Component):
    library = "react-icons/md"
    tag = "MdTopic"


class MdUploadFile(rx.Component):
    library = "react-icons/md"
    tag = "MdUploadFile"


class MdUpload(rx.Component):
    library = "react-icons/md"
    tag = "MdUpload"


class MdWorkspacesFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdWorkspacesFilled"


class MdWorkspacesOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdWorkspacesOutline"


class MdWorkspaces(rx.Component):
    library = "react-icons/md"
    tag = "MdWorkspaces"


class MdAdfScanner(rx.Component):
    library = "react-icons/md"
    tag = "MdAdfScanner"


class MdBrowserNotSupported(rx.Component):
    library = "react-icons/md"
    tag = "MdBrowserNotSupported"


class MdBrowserUpdated(rx.Component):
    library = "react-icons/md"
    tag = "MdBrowserUpdated"


class MdCastConnected(rx.Component):
    library = "react-icons/md"
    tag = "MdCastConnected"


class MdCastForEducation(rx.Component):
    library = "react-icons/md"
    tag = "MdCastForEducation"


class MdCast(rx.Component):
    library = "react-icons/md"
    tag = "MdCast"


class MdComputer(rx.Component):
    library = "react-icons/md"
    tag = "MdComputer"


class MdConnectedTv(rx.Component):
    library = "react-icons/md"
    tag = "MdConnectedTv"


class MdConveyorBelt(rx.Component):
    library = "react-icons/md"
    tag = "MdConveyorBelt"


class MdDesktopMac(rx.Component):
    library = "react-icons/md"
    tag = "MdDesktopMac"


class MdDesktopWindows(rx.Component):
    library = "react-icons/md"
    tag = "MdDesktopWindows"


class MdDeveloperBoardOff(rx.Component):
    library = "react-icons/md"
    tag = "MdDeveloperBoardOff"


class MdDeveloperBoard(rx.Component):
    library = "react-icons/md"
    tag = "MdDeveloperBoard"


class MdDeviceHub(rx.Component):
    library = "react-icons/md"
    tag = "MdDeviceHub"


class MdDeviceUnknown(rx.Component):
    library = "react-icons/md"
    tag = "MdDeviceUnknown"


class MdDevicesOther(rx.Component):
    library = "react-icons/md"
    tag = "MdDevicesOther"


class MdDock(rx.Component):
    library = "react-icons/md"
    tag = "MdDock"


class MdEarbudsBattery(rx.Component):
    library = "react-icons/md"
    tag = "MdEarbudsBattery"


class MdEarbuds(rx.Component):
    library = "react-icons/md"
    tag = "MdEarbuds"


class MdForklift(rx.Component):
    library = "react-icons/md"
    tag = "MdForklift"


class MdFrontLoader(rx.Component):
    library = "react-icons/md"
    tag = "MdFrontLoader"


class MdGamepad(rx.Component):
    library = "react-icons/md"
    tag = "MdGamepad"


class MdHeadphonesBattery(rx.Component):
    library = "react-icons/md"
    tag = "MdHeadphonesBattery"


class MdHeadphones(rx.Component):
    library = "react-icons/md"
    tag = "MdHeadphones"


class MdHeadsetMic(rx.Component):
    library = "react-icons/md"
    tag = "MdHeadsetMic"


class MdHeadsetOff(rx.Component):
    library = "react-icons/md"
    tag = "MdHeadsetOff"


class MdHeadset(rx.Component):
    library = "react-icons/md"
    tag = "MdHeadset"


class MdHomeMax(rx.Component):
    library = "react-icons/md"
    tag = "MdHomeMax"


class MdHomeMini(rx.Component):
    library = "react-icons/md"
    tag = "MdHomeMini"


class MdKeyboardAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardAlt"


class MdKeyboardArrowDown(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardArrowDown"


class MdKeyboardArrowLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardArrowLeft"


class MdKeyboardArrowRight(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardArrowRight"


class MdKeyboardArrowUp(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardArrowUp"


class MdKeyboardBackspace(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardBackspace"


class MdKeyboardCapslock(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardCapslock"


class MdKeyboardCommandKey(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardCommandKey"


class MdKeyboardControlKey(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardControlKey"


class MdKeyboardDoubleArrowDown(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardDoubleArrowDown"


class MdKeyboardDoubleArrowLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardDoubleArrowLeft"


class MdKeyboardDoubleArrowRight(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardDoubleArrowRight"


class MdKeyboardDoubleArrowUp(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardDoubleArrowUp"


class MdKeyboardHide(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardHide"


class MdKeyboardOptionKey(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardOptionKey"


class MdKeyboardReturn(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardReturn"


class MdKeyboardTab(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardTab"


class MdKeyboardVoice(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboardVoice"


class MdKeyboard(rx.Component):
    library = "react-icons/md"
    tag = "MdKeyboard"


class MdLaptopChromebook(rx.Component):
    library = "react-icons/md"
    tag = "MdLaptopChromebook"


class MdLaptopMac(rx.Component):
    library = "react-icons/md"
    tag = "MdLaptopMac"


class MdLaptopWindows(rx.Component):
    library = "react-icons/md"
    tag = "MdLaptopWindows"


class MdLaptop(rx.Component):
    library = "react-icons/md"
    tag = "MdLaptop"


class MdMemory(rx.Component):
    library = "react-icons/md"
    tag = "MdMemory"


class MdMonitor(rx.Component):
    library = "react-icons/md"
    tag = "MdMonitor"


class MdMouse(rx.Component):
    library = "react-icons/md"
    tag = "MdMouse"


class MdPallet(rx.Component):
    library = "react-icons/md"
    tag = "MdPallet"


class MdPhoneAndroid(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneAndroid"


class MdPhoneIphone(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneIphone"


class MdPhonelinkOff(rx.Component):
    library = "react-icons/md"
    tag = "MdPhonelinkOff"


class MdPhonelink(rx.Component):
    library = "react-icons/md"
    tag = "MdPhonelink"


class MdPointOfSale(rx.Component):
    library = "react-icons/md"
    tag = "MdPointOfSale"


class MdPowerInput(rx.Component):
    library = "react-icons/md"
    tag = "MdPowerInput"


class MdRouter(rx.Component):
    library = "react-icons/md"
    tag = "MdRouter"


class MdScanner(rx.Component):
    library = "react-icons/md"
    tag = "MdScanner"


class MdSecurity(rx.Component):
    library = "react-icons/md"
    tag = "MdSecurity"


class MdSimCard(rx.Component):
    library = "react-icons/md"
    tag = "MdSimCard"


class MdSmartDisplay(rx.Component):
    library = "react-icons/md"
    tag = "MdSmartDisplay"


class MdSmartScreen(rx.Component):
    library = "react-icons/md"
    tag = "MdSmartScreen"


class MdSmartToy(rx.Component):
    library = "react-icons/md"
    tag = "MdSmartToy"


class MdSmartphone(rx.Component):
    library = "react-icons/md"
    tag = "MdSmartphone"


class MdSpeakerGroup(rx.Component):
    library = "react-icons/md"
    tag = "MdSpeakerGroup"


class MdSpeaker(rx.Component):
    library = "react-icons/md"
    tag = "MdSpeaker"


class MdStart(rx.Component):
    library = "react-icons/md"
    tag = "MdStart"


class MdTabletAndroid(rx.Component):
    library = "react-icons/md"
    tag = "MdTabletAndroid"


class MdTabletMac(rx.Component):
    library = "react-icons/md"
    tag = "MdTabletMac"


class MdTablet(rx.Component):
    library = "react-icons/md"
    tag = "MdTablet"


class MdToys(rx.Component):
    library = "react-icons/md"
    tag = "MdToys"


class MdTrolley(rx.Component):
    library = "react-icons/md"
    tag = "MdTrolley"


class MdTv(rx.Component):
    library = "react-icons/md"
    tag = "MdTv"


class MdVideogameAssetOff(rx.Component):
    library = "react-icons/md"
    tag = "MdVideogameAssetOff"


class MdVideogameAsset(rx.Component):
    library = "react-icons/md"
    tag = "MdVideogameAsset"


class MdWatchOff(rx.Component):
    library = "react-icons/md"
    tag = "MdWatchOff"


class MdWatch(rx.Component):
    library = "react-icons/md"
    tag = "MdWatch"


class MdAutoMode(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoMode"


class MdBlindsClosed(rx.Component):
    library = "react-icons/md"
    tag = "MdBlindsClosed"


class MdBlinds(rx.Component):
    library = "react-icons/md"
    tag = "MdBlinds"


class MdBroadcastOnHome(rx.Component):
    library = "react-icons/md"
    tag = "MdBroadcastOnHome"


class MdBroadcastOnPersonal(rx.Component):
    library = "react-icons/md"
    tag = "MdBroadcastOnPersonal"


class MdCloudySnowing(rx.Component):
    library = "react-icons/md"
    tag = "MdCloudySnowing"


class MdCurtainsClosed(rx.Component):
    library = "react-icons/md"
    tag = "MdCurtainsClosed"


class MdCurtains(rx.Component):
    library = "react-icons/md"
    tag = "MdCurtains"


class MdElectricBolt(rx.Component):
    library = "react-icons/md"
    tag = "MdElectricBolt"


class MdElectricMeter(rx.Component):
    library = "react-icons/md"
    tag = "MdElectricMeter"


class MdEnergySavingsLeaf(rx.Component):
    library = "react-icons/md"
    tag = "MdEnergySavingsLeaf"


class MdFoggy(rx.Component):
    library = "react-icons/md"
    tag = "MdFoggy"


class MdGasMeter(rx.Component):
    library = "react-icons/md"
    tag = "MdGasMeter"


class MdHeatPump(rx.Component):
    library = "react-icons/md"
    tag = "MdHeatPump"


class MdModeFanOff(rx.Component):
    library = "react-icons/md"
    tag = "MdModeFanOff"


class MdNestCamWiredStand(rx.Component):
    library = "react-icons/md"
    tag = "MdNestCamWiredStand"


class MdOilBarrel(rx.Component):
    library = "react-icons/md"
    tag = "MdOilBarrel"


class MdPropaneTank(rx.Component):
    library = "react-icons/md"
    tag = "MdPropaneTank"


class MdPropane(rx.Component):
    library = "react-icons/md"
    tag = "MdPropane"


class MdRollerShadesClosed(rx.Component):
    library = "react-icons/md"
    tag = "MdRollerShadesClosed"


class MdRollerShades(rx.Component):
    library = "react-icons/md"
    tag = "MdRollerShades"


class MdSensorDoor(rx.Component):
    library = "react-icons/md"
    tag = "MdSensorDoor"


class MdSensorOccupied(rx.Component):
    library = "react-icons/md"
    tag = "MdSensorOccupied"


class MdSensorWindow(rx.Component):
    library = "react-icons/md"
    tag = "MdSensorWindow"


class MdShelves(rx.Component):
    library = "react-icons/md"
    tag = "MdShelves"


class MdShieldMoon(rx.Component):
    library = "react-icons/md"
    tag = "MdShieldMoon"


class MdSnowing(rx.Component):
    library = "react-icons/md"
    tag = "MdSnowing"


class MdSolarPower(rx.Component):
    library = "react-icons/md"
    tag = "MdSolarPower"


class MdSunnySnowing(rx.Component):
    library = "react-icons/md"
    tag = "MdSunnySnowing"


class MdSunny(rx.Component):
    library = "react-icons/md"
    tag = "MdSunny"


class MdVerticalShadesClosed(rx.Component):
    library = "react-icons/md"
    tag = "MdVerticalShadesClosed"


class MdVerticalShades(rx.Component):
    library = "react-icons/md"
    tag = "MdVerticalShades"


class MdWindPower(rx.Component):
    library = "react-icons/md"
    tag = "MdWindPower"


class Md10Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md10Mp"


class Md11Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md11Mp"


class Md12Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md12Mp"


class Md13Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md13Mp"


class Md14Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md14Mp"


class Md15Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md15Mp"


class Md16Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md16Mp"


class Md17Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md17Mp"


class Md18Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md18Mp"


class Md19Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md19Mp"


class Md20Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md20Mp"


class Md21Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md21Mp"


class Md22Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md22Mp"


class Md23Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md23Mp"


class Md24Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md24Mp"


class Md2Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md2Mp"


class Md30FpsSelect(rx.Component):
    library = "react-icons/md"
    tag = "Md30FpsSelect"


class Md3Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md3Mp"


class Md4Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md4Mp"


class Md5Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md5Mp"


class Md60FpsSelect(rx.Component):
    library = "react-icons/md"
    tag = "Md60FpsSelect"


class Md6Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md6Mp"


class Md7Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md7Mp"


class Md8Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md8Mp"


class Md9Mp(rx.Component):
    library = "react-icons/md"
    tag = "Md9Mp"


class MdAddAPhoto(rx.Component):
    library = "react-icons/md"
    tag = "MdAddAPhoto"


class MdAddPhotoAlternate(rx.Component):
    library = "react-icons/md"
    tag = "MdAddPhotoAlternate"


class MdAddToPhotos(rx.Component):
    library = "react-icons/md"
    tag = "MdAddToPhotos"


class MdAdjust(rx.Component):
    library = "react-icons/md"
    tag = "MdAdjust"


class MdAnimation(rx.Component):
    library = "react-icons/md"
    tag = "MdAnimation"


class MdAssistantPhoto(rx.Component):
    library = "react-icons/md"
    tag = "MdAssistantPhoto"


class MdAssistant(rx.Component):
    library = "react-icons/md"
    tag = "MdAssistant"


class MdAudiotrack(rx.Component):
    library = "react-icons/md"
    tag = "MdAudiotrack"


class MdAutoAwesomeMosaic(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoAwesomeMosaic"


class MdAutoAwesomeMotion(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoAwesomeMotion"


class MdAutoAwesome(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoAwesome"


class MdAutoFixHigh(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoFixHigh"


class MdAutoFixNormal(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoFixNormal"


class MdAutoFixOff(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoFixOff"


class MdAutoStories(rx.Component):
    library = "react-icons/md"
    tag = "MdAutoStories"


class MdAutofpsSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdAutofpsSelect"


class MdBedtimeOff(rx.Component):
    library = "react-icons/md"
    tag = "MdBedtimeOff"


class MdBedtime(rx.Component):
    library = "react-icons/md"
    tag = "MdBedtime"


class MdBlurCircular(rx.Component):
    library = "react-icons/md"
    tag = "MdBlurCircular"


class MdBlurLinear(rx.Component):
    library = "react-icons/md"
    tag = "MdBlurLinear"


class MdBlurOff(rx.Component):
    library = "react-icons/md"
    tag = "MdBlurOff"


class MdBlurOn(rx.Component):
    library = "react-icons/md"
    tag = "MdBlurOn"


class MdBrightness1(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightness1"


class MdBrightness2(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightness2"


class MdBrightness3(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightness3"


class MdBrightness4(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightness4"


class MdBrightness5(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightness5"


class MdBrightness6(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightness6"


class MdBrightness7(rx.Component):
    library = "react-icons/md"
    tag = "MdBrightness7"


class MdBrokenImage(rx.Component):
    library = "react-icons/md"
    tag = "MdBrokenImage"


class MdBrush(rx.Component):
    library = "react-icons/md"
    tag = "MdBrush"


class MdBurstMode(rx.Component):
    library = "react-icons/md"
    tag = "MdBurstMode"


class MdCameraAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdCameraAlt"


class MdCameraFront(rx.Component):
    library = "react-icons/md"
    tag = "MdCameraFront"


class MdCameraRear(rx.Component):
    library = "react-icons/md"
    tag = "MdCameraRear"


class MdCameraRoll(rx.Component):
    library = "react-icons/md"
    tag = "MdCameraRoll"


class MdCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdCamera"


class MdCases(rx.Component):
    library = "react-icons/md"
    tag = "MdCases"


class MdCenterFocusStrong(rx.Component):
    library = "react-icons/md"
    tag = "MdCenterFocusStrong"


class MdCenterFocusWeak(rx.Component):
    library = "react-icons/md"
    tag = "MdCenterFocusWeak"


class MdCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdCircle"


class MdCollectionsBookmark(rx.Component):
    library = "react-icons/md"
    tag = "MdCollectionsBookmark"


class MdCollections(rx.Component):
    library = "react-icons/md"
    tag = "MdCollections"


class MdColorLens(rx.Component):
    library = "react-icons/md"
    tag = "MdColorLens"


class MdColorize(rx.Component):
    library = "react-icons/md"
    tag = "MdColorize"


class MdCompare(rx.Component):
    library = "react-icons/md"
    tag = "MdCompare"


class MdContrast(rx.Component):
    library = "react-icons/md"
    tag = "MdContrast"


class MdControlPointDuplicate(rx.Component):
    library = "react-icons/md"
    tag = "MdControlPointDuplicate"


class MdControlPoint(rx.Component):
    library = "react-icons/md"
    tag = "MdControlPoint"


class MdCrop169(rx.Component):
    library = "react-icons/md"
    tag = "MdCrop169"


class MdCrop32(rx.Component):
    library = "react-icons/md"
    tag = "MdCrop32"


class MdCrop54(rx.Component):
    library = "react-icons/md"
    tag = "MdCrop54"


class MdCrop75(rx.Component):
    library = "react-icons/md"
    tag = "MdCrop75"


class MdCropDin(rx.Component):
    library = "react-icons/md"
    tag = "MdCropDin"


class MdCropFree(rx.Component):
    library = "react-icons/md"
    tag = "MdCropFree"


class MdCropLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdCropLandscape"


class MdCropOriginal(rx.Component):
    library = "react-icons/md"
    tag = "MdCropOriginal"


class MdCropPortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdCropPortrait"


class MdCropRotate(rx.Component):
    library = "react-icons/md"
    tag = "MdCropRotate"


class MdCropSquare(rx.Component):
    library = "react-icons/md"
    tag = "MdCropSquare"


class MdCrop(rx.Component):
    library = "react-icons/md"
    tag = "MdCrop"


class MdCurrencyBitcoin(rx.Component):
    library = "react-icons/md"
    tag = "MdCurrencyBitcoin"


class MdCurrencyFranc(rx.Component):
    library = "react-icons/md"
    tag = "MdCurrencyFranc"


class MdCurrencyLira(rx.Component):
    library = "react-icons/md"
    tag = "MdCurrencyLira"


class MdCurrencyPound(rx.Component):
    library = "react-icons/md"
    tag = "MdCurrencyPound"


class MdCurrencyRuble(rx.Component):
    library = "react-icons/md"
    tag = "MdCurrencyRuble"


class MdCurrencyRupee(rx.Component):
    library = "react-icons/md"
    tag = "MdCurrencyRupee"


class MdCurrencyYen(rx.Component):
    library = "react-icons/md"
    tag = "MdCurrencyYen"


class MdCurrencyYuan(rx.Component):
    library = "react-icons/md"
    tag = "MdCurrencyYuan"


class MdDeblur(rx.Component):
    library = "react-icons/md"
    tag = "MdDeblur"


class MdDehaze(rx.Component):
    library = "react-icons/md"
    tag = "MdDehaze"


class MdDetails(rx.Component):
    library = "react-icons/md"
    tag = "MdDetails"


class MdDirtyLens(rx.Component):
    library = "react-icons/md"
    tag = "MdDirtyLens"


class MdEdit(rx.Component):
    library = "react-icons/md"
    tag = "MdEdit"


class MdEuro(rx.Component):
    library = "react-icons/md"
    tag = "MdEuro"


class MdExposureNeg1(rx.Component):
    library = "react-icons/md"
    tag = "MdExposureNeg1"


class MdExposureNeg2(rx.Component):
    library = "react-icons/md"
    tag = "MdExposureNeg2"


class MdExposurePlus1(rx.Component):
    library = "react-icons/md"
    tag = "MdExposurePlus1"


class MdExposurePlus2(rx.Component):
    library = "react-icons/md"
    tag = "MdExposurePlus2"


class MdExposureZero(rx.Component):
    library = "react-icons/md"
    tag = "MdExposureZero"


class MdExposure(rx.Component):
    library = "react-icons/md"
    tag = "MdExposure"


class MdFaceRetouchingNatural(rx.Component):
    library = "react-icons/md"
    tag = "MdFaceRetouchingNatural"


class MdFaceRetouchingOff(rx.Component):
    library = "react-icons/md"
    tag = "MdFaceRetouchingOff"


class MdFilter1(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter1"


class MdFilter2(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter2"


class MdFilter3(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter3"


class MdFilter4(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter4"


class MdFilter5(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter5"


class MdFilter6(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter6"


class MdFilter7(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter7"


class MdFilter8(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter8"


class MdFilter9Plus(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter9Plus"


class MdFilter9(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter9"


class MdFilterBAndW(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterBAndW"


class MdFilterCenterFocus(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterCenterFocus"


class MdFilterDrama(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterDrama"


class MdFilterFrames(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterFrames"


class MdFilterHdr(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterHdr"


class MdFilterNone(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterNone"


class MdFilterTiltShift(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterTiltShift"


class MdFilterVintage(rx.Component):
    library = "react-icons/md"
    tag = "MdFilterVintage"


class MdFilter(rx.Component):
    library = "react-icons/md"
    tag = "MdFilter"


class MdFlare(rx.Component):
    library = "react-icons/md"
    tag = "MdFlare"


class MdFlashAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdFlashAuto"


class MdFlashOff(rx.Component):
    library = "react-icons/md"
    tag = "MdFlashOff"


class MdFlashOn(rx.Component):
    library = "react-icons/md"
    tag = "MdFlashOn"


class MdFlipCameraAndroid(rx.Component):
    library = "react-icons/md"
    tag = "MdFlipCameraAndroid"


class MdFlipCameraIos(rx.Component):
    library = "react-icons/md"
    tag = "MdFlipCameraIos"


class MdFlip(rx.Component):
    library = "react-icons/md"
    tag = "MdFlip"


class MdGradient(rx.Component):
    library = "react-icons/md"
    tag = "MdGradient"


class MdGrain(rx.Component):
    library = "react-icons/md"
    tag = "MdGrain"


class MdGridOff(rx.Component):
    library = "react-icons/md"
    tag = "MdGridOff"


class MdGridOn(rx.Component):
    library = "react-icons/md"
    tag = "MdGridOn"


class MdHdrEnhancedSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrEnhancedSelect"


class MdHdrOff(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrOff"


class MdHdrOn(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrOn"


class MdHdrPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrPlus"


class MdHdrStrong(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrStrong"


class MdHdrWeak(rx.Component):
    library = "react-icons/md"
    tag = "MdHdrWeak"


class MdHealing(rx.Component):
    library = "react-icons/md"
    tag = "MdHealing"


class MdHevc(rx.Component):
    library = "react-icons/md"
    tag = "MdHevc"


class MdHideImage(rx.Component):
    library = "react-icons/md"
    tag = "MdHideImage"


class MdImageAspectRatio(rx.Component):
    library = "react-icons/md"
    tag = "MdImageAspectRatio"


class MdImageNotSupported(rx.Component):
    library = "react-icons/md"
    tag = "MdImageNotSupported"


class MdImageSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdImageSearch"


class MdImage(rx.Component):
    library = "react-icons/md"
    tag = "MdImage"


class MdIncompleteCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdIncompleteCircle"


class MdIso(rx.Component):
    library = "react-icons/md"
    tag = "MdIso"


class MdLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdLandscape"


class MdLeakAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdLeakAdd"


class MdLeakRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdLeakRemove"


class MdLens(rx.Component):
    library = "react-icons/md"
    tag = "MdLens"


class MdLinkedCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdLinkedCamera"


class MdLogoDev(rx.Component):
    library = "react-icons/md"
    tag = "MdLogoDev"


class MdLooks3(rx.Component):
    library = "react-icons/md"
    tag = "MdLooks3"


class MdLooks4(rx.Component):
    library = "react-icons/md"
    tag = "MdLooks4"


class MdLooks5(rx.Component):
    library = "react-icons/md"
    tag = "MdLooks5"


class MdLooks6(rx.Component):
    library = "react-icons/md"
    tag = "MdLooks6"


class MdLooksOne(rx.Component):
    library = "react-icons/md"
    tag = "MdLooksOne"


class MdLooksTwo(rx.Component):
    library = "react-icons/md"
    tag = "MdLooksTwo"


class MdLooks(rx.Component):
    library = "react-icons/md"
    tag = "MdLooks"


class MdLoupe(rx.Component):
    library = "react-icons/md"
    tag = "MdLoupe"


class MdMicExternalOff(rx.Component):
    library = "react-icons/md"
    tag = "MdMicExternalOff"


class MdMicExternalOn(rx.Component):
    library = "react-icons/md"
    tag = "MdMicExternalOn"


class MdMonochromePhotos(rx.Component):
    library = "react-icons/md"
    tag = "MdMonochromePhotos"


class MdMotionPhotosAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdMotionPhotosAuto"


class MdMotionPhotosOff(rx.Component):
    library = "react-icons/md"
    tag = "MdMotionPhotosOff"


class MdMotionPhotosOn(rx.Component):
    library = "react-icons/md"
    tag = "MdMotionPhotosOn"


class MdMotionPhotosPause(rx.Component):
    library = "react-icons/md"
    tag = "MdMotionPhotosPause"


class MdMotionPhotosPaused(rx.Component):
    library = "react-icons/md"
    tag = "MdMotionPhotosPaused"


class MdMovieCreation(rx.Component):
    library = "react-icons/md"
    tag = "MdMovieCreation"


class MdMovieFilter(rx.Component):
    library = "react-icons/md"
    tag = "MdMovieFilter"


class MdMp(rx.Component):
    library = "react-icons/md"
    tag = "MdMp"


class MdMusicNote(rx.Component):
    library = "react-icons/md"
    tag = "MdMusicNote"


class MdMusicOff(rx.Component):
    library = "react-icons/md"
    tag = "MdMusicOff"


class MdNaturePeople(rx.Component):
    library = "react-icons/md"
    tag = "MdNaturePeople"


class MdNature(rx.Component):
    library = "react-icons/md"
    tag = "MdNature"


class MdNavigateBefore(rx.Component):
    library = "react-icons/md"
    tag = "MdNavigateBefore"


class MdNavigateNext(rx.Component):
    library = "react-icons/md"
    tag = "MdNavigateNext"


class MdPalette(rx.Component):
    library = "react-icons/md"
    tag = "MdPalette"


class MdPanoramaFishEye(rx.Component):
    library = "react-icons/md"
    tag = "MdPanoramaFishEye"


class MdPanoramaHorizontalSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdPanoramaHorizontalSelect"


class MdPanoramaHorizontal(rx.Component):
    library = "react-icons/md"
    tag = "MdPanoramaHorizontal"


class MdPanoramaPhotosphereSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdPanoramaPhotosphereSelect"


class MdPanoramaPhotosphere(rx.Component):
    library = "react-icons/md"
    tag = "MdPanoramaPhotosphere"


class MdPanoramaVerticalSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdPanoramaVerticalSelect"


class MdPanoramaVertical(rx.Component):
    library = "react-icons/md"
    tag = "MdPanoramaVertical"


class MdPanoramaWideAngleSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdPanoramaWideAngleSelect"


class MdPanoramaWideAngle(rx.Component):
    library = "react-icons/md"
    tag = "MdPanoramaWideAngle"


class MdPanorama(rx.Component):
    library = "react-icons/md"
    tag = "MdPanorama"


class MdPhotoAlbum(rx.Component):
    library = "react-icons/md"
    tag = "MdPhotoAlbum"


class MdPhotoCameraBack(rx.Component):
    library = "react-icons/md"
    tag = "MdPhotoCameraBack"


class MdPhotoCameraFront(rx.Component):
    library = "react-icons/md"
    tag = "MdPhotoCameraFront"


class MdPhotoCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdPhotoCamera"


class MdPhotoFilter(rx.Component):
    library = "react-icons/md"
    tag = "MdPhotoFilter"


class MdPhotoLibrary(rx.Component):
    library = "react-icons/md"
    tag = "MdPhotoLibrary"


class MdPhotoSizeSelectActual(rx.Component):
    library = "react-icons/md"
    tag = "MdPhotoSizeSelectActual"


class MdPhotoSizeSelectLarge(rx.Component):
    library = "react-icons/md"
    tag = "MdPhotoSizeSelectLarge"


class MdPhotoSizeSelectSmall(rx.Component):
    library = "react-icons/md"
    tag = "MdPhotoSizeSelectSmall"


class MdPhoto(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoto"


class MdPictureAsPdf(rx.Component):
    library = "react-icons/md"
    tag = "MdPictureAsPdf"


class MdPortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdPortrait"


class MdRawOff(rx.Component):
    library = "react-icons/md"
    tag = "MdRawOff"


class MdRawOn(rx.Component):
    library = "react-icons/md"
    tag = "MdRawOn"


class MdReceiptLong(rx.Component):
    library = "react-icons/md"
    tag = "MdReceiptLong"


class MdRemoveRedEye(rx.Component):
    library = "react-icons/md"
    tag = "MdRemoveRedEye"


class MdRotate90DegreesCcw(rx.Component):
    library = "react-icons/md"
    tag = "MdRotate90DegreesCcw"


class MdRotate90DegreesCw(rx.Component):
    library = "react-icons/md"
    tag = "MdRotate90DegreesCw"


class MdRotateLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdRotateLeft"


class MdRotateRight(rx.Component):
    library = "react-icons/md"
    tag = "MdRotateRight"


class MdShutterSpeed(rx.Component):
    library = "react-icons/md"
    tag = "MdShutterSpeed"


class MdSlideshow(rx.Component):
    library = "react-icons/md"
    tag = "MdSlideshow"


class MdStraighten(rx.Component):
    library = "react-icons/md"
    tag = "MdStraighten"


class MdStyle(rx.Component):
    library = "react-icons/md"
    tag = "MdStyle"


class MdSwitchCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdSwitchCamera"


class MdSwitchVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdSwitchVideo"


class MdTagFaces(rx.Component):
    library = "react-icons/md"
    tag = "MdTagFaces"


class MdTexture(rx.Component):
    library = "react-icons/md"
    tag = "MdTexture"


class MdThermostatAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdThermostatAuto"


class MdTimelapse(rx.Component):
    library = "react-icons/md"
    tag = "MdTimelapse"


class MdTimer10(rx.Component):
    library = "react-icons/md"
    tag = "MdTimer10"


class MdTimer3(rx.Component):
    library = "react-icons/md"
    tag = "MdTimer3"


class MdTimerOff(rx.Component):
    library = "react-icons/md"
    tag = "MdTimerOff"


class MdTimer(rx.Component):
    library = "react-icons/md"
    tag = "MdTimer"


class MdTonality(rx.Component):
    library = "react-icons/md"
    tag = "MdTonality"


class MdTransform(rx.Component):
    library = "react-icons/md"
    tag = "MdTransform"


class MdTune(rx.Component):
    library = "react-icons/md"
    tag = "MdTune"


class MdVideoCameraBack(rx.Component):
    library = "react-icons/md"
    tag = "MdVideoCameraBack"


class MdVideoCameraFront(rx.Component):
    library = "react-icons/md"
    tag = "MdVideoCameraFront"


class MdVideoStable(rx.Component):
    library = "react-icons/md"
    tag = "MdVideoStable"


class MdViewComfy(rx.Component):
    library = "react-icons/md"
    tag = "MdViewComfy"


class MdViewCompact(rx.Component):
    library = "react-icons/md"
    tag = "MdViewCompact"


class MdVignette(rx.Component):
    library = "react-icons/md"
    tag = "MdVignette"


class MdVrpano(rx.Component):
    library = "react-icons/md"
    tag = "MdVrpano"


class MdWbAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdWbAuto"


class MdWbCloudy(rx.Component):
    library = "react-icons/md"
    tag = "MdWbCloudy"


class MdWbIncandescent(rx.Component):
    library = "react-icons/md"
    tag = "MdWbIncandescent"


class MdWbIridescent(rx.Component):
    library = "react-icons/md"
    tag = "MdWbIridescent"


class MdWbShade(rx.Component):
    library = "react-icons/md"
    tag = "MdWbShade"


class MdWbSunny(rx.Component):
    library = "react-icons/md"
    tag = "MdWbSunny"


class MdWbTwighlight(rx.Component):
    library = "react-icons/md"
    tag = "MdWbTwighlight"


class MdWbTwilight(rx.Component):
    library = "react-icons/md"
    tag = "MdWbTwilight"


class Md360(rx.Component):
    library = "react-icons/md"
    tag = "Md360"


class MdAddBusiness(rx.Component):
    library = "react-icons/md"
    tag = "MdAddBusiness"


class MdAddLocationAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdAddLocationAlt"


class MdAddLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdAddLocation"


class MdAddRoad(rx.Component):
    library = "react-icons/md"
    tag = "MdAddRoad"


class MdAgriculture(rx.Component):
    library = "react-icons/md"
    tag = "MdAgriculture"


class MdAirlineStops(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlineStops"


class MdAirlines(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlines"


class MdAltRoute(rx.Component):
    library = "react-icons/md"
    tag = "MdAltRoute"


class MdAtm(rx.Component):
    library = "react-icons/md"
    tag = "MdAtm"


class MdAttractions(rx.Component):
    library = "react-icons/md"
    tag = "MdAttractions"


class MdBadge(rx.Component):
    library = "react-icons/md"
    tag = "MdBadge"


class MdBakeryDining(rx.Component):
    library = "react-icons/md"
    tag = "MdBakeryDining"


class MdBeenhere(rx.Component):
    library = "react-icons/md"
    tag = "MdBeenhere"


class MdBikeScooter(rx.Component):
    library = "react-icons/md"
    tag = "MdBikeScooter"


class MdBreakfastDining(rx.Component):
    library = "react-icons/md"
    tag = "MdBreakfastDining"


class MdBrunchDining(rx.Component):
    library = "react-icons/md"
    tag = "MdBrunchDining"


class MdBusAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdBusAlert"


class MdCarCrash(rx.Component):
    library = "react-icons/md"
    tag = "MdCarCrash"


class MdCarRental(rx.Component):
    library = "react-icons/md"
    tag = "MdCarRental"


class MdCarRepair(rx.Component):
    library = "react-icons/md"
    tag = "MdCarRepair"


class MdCastle(rx.Component):
    library = "react-icons/md"
    tag = "MdCastle"


class MdCategory(rx.Component):
    library = "react-icons/md"
    tag = "MdCategory"


class MdCelebration(rx.Component):
    library = "react-icons/md"
    tag = "MdCelebration"


class MdChurch(rx.Component):
    library = "react-icons/md"
    tag = "MdChurch"


class MdCleaningServices(rx.Component):
    library = "react-icons/md"
    tag = "MdCleaningServices"


class MdCompassCalibration(rx.Component):
    library = "react-icons/md"
    tag = "MdCompassCalibration"


class MdConnectingAirports(rx.Component):
    library = "react-icons/md"
    tag = "MdConnectingAirports"


class MdCrisisAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdCrisisAlert"


class MdDeliveryDining(rx.Component):
    library = "react-icons/md"
    tag = "MdDeliveryDining"


class MdDepartureBoard(rx.Component):
    library = "react-icons/md"
    tag = "MdDepartureBoard"


class MdDesignServices(rx.Component):
    library = "react-icons/md"
    tag = "MdDesignServices"


class MdDiamond(rx.Component):
    library = "react-icons/md"
    tag = "MdDiamond"


class MdDinnerDining(rx.Component):
    library = "react-icons/md"
    tag = "MdDinnerDining"


class MdDirectionsBike(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsBike"


class MdDirectionsBoatFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsBoatFilled"


class MdDirectionsBoat(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsBoat"


class MdDirectionsBusFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsBusFilled"


class MdDirectionsBus(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsBus"


class MdDirectionsCarFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsCarFilled"


class MdDirectionsCar(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsCar"


class MdDirectionsRailwayFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsRailwayFilled"


class MdDirectionsRailway(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsRailway"


class MdDirectionsRun(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsRun"


class MdDirectionsSubwayFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsSubwayFilled"


class MdDirectionsSubway(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsSubway"


class MdDirectionsTransitFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsTransitFilled"


class MdDirectionsTransit(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsTransit"


class MdDirectionsWalk(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsWalk"


class MdDirections(rx.Component):
    library = "react-icons/md"
    tag = "MdDirections"


class MdDryCleaning(rx.Component):
    library = "react-icons/md"
    tag = "MdDryCleaning"


class MdEditAttributes(rx.Component):
    library = "react-icons/md"
    tag = "MdEditAttributes"


class MdEditLocationAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdEditLocationAlt"


class MdEditLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdEditLocation"


class MdEditRoad(rx.Component):
    library = "react-icons/md"
    tag = "MdEditRoad"


class MdEggAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdEggAlt"


class MdEgg(rx.Component):
    library = "react-icons/md"
    tag = "MdEgg"


class MdElectricBike(rx.Component):
    library = "react-icons/md"
    tag = "MdElectricBike"


class MdElectricCar(rx.Component):
    library = "react-icons/md"
    tag = "MdElectricCar"


class MdElectricMoped(rx.Component):
    library = "react-icons/md"
    tag = "MdElectricMoped"


class MdElectricRickshaw(rx.Component):
    library = "react-icons/md"
    tag = "MdElectricRickshaw"


class MdElectricScooter(rx.Component):
    library = "react-icons/md"
    tag = "MdElectricScooter"


class MdElectricalServices(rx.Component):
    library = "react-icons/md"
    tag = "MdElectricalServices"


class MdEmergencyRecording(rx.Component):
    library = "react-icons/md"
    tag = "MdEmergencyRecording"


class MdEmergencyShare(rx.Component):
    library = "react-icons/md"
    tag = "MdEmergencyShare"


class MdEmergency(rx.Component):
    library = "react-icons/md"
    tag = "MdEmergency"


class MdEvStation(rx.Component):
    library = "react-icons/md"
    tag = "MdEvStation"


class MdFactory(rx.Component):
    library = "react-icons/md"
    tag = "MdFactory"


class MdFastfood(rx.Component):
    library = "react-icons/md"
    tag = "MdFastfood"


class MdFestival(rx.Component):
    library = "react-icons/md"
    tag = "MdFestival"


class MdFireHydrantAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdFireHydrantAlt"


class MdFireTruck(rx.Component):
    library = "react-icons/md"
    tag = "MdFireTruck"


class MdFlightClass(rx.Component):
    library = "react-icons/md"
    tag = "MdFlightClass"


class MdFlight(rx.Component):
    library = "react-icons/md"
    tag = "MdFlight"


class MdForest(rx.Component):
    library = "react-icons/md"
    tag = "MdForest"


class MdForkLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdForkLeft"


class MdForkRight(rx.Component):
    library = "react-icons/md"
    tag = "MdForkRight"


class MdFort(rx.Component):
    library = "react-icons/md"
    tag = "MdFort"


class MdHail(rx.Component):
    library = "react-icons/md"
    tag = "MdHail"


class MdHandyman(rx.Component):
    library = "react-icons/md"
    tag = "MdHandyman"


class MdHardware(rx.Component):
    library = "react-icons/md"
    tag = "MdHardware"


class MdHomeRepairService(rx.Component):
    library = "react-icons/md"
    tag = "MdHomeRepairService"


class MdHotel(rx.Component):
    library = "react-icons/md"
    tag = "MdHotel"


class MdHvac(rx.Component):
    library = "react-icons/md"
    tag = "MdHvac"


class MdIcecream(rx.Component):
    library = "react-icons/md"
    tag = "MdIcecream"


class MdKebabDining(rx.Component):
    library = "react-icons/md"
    tag = "MdKebabDining"


class MdLayersClear(rx.Component):
    library = "react-icons/md"
    tag = "MdLayersClear"


class MdLayers(rx.Component):
    library = "react-icons/md"
    tag = "MdLayers"


class MdLiquor(rx.Component):
    library = "react-icons/md"
    tag = "MdLiquor"


class MdLocalActivity(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalActivity"


class MdLocalAirport(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalAirport"


class MdLocalAtm(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalAtm"


class MdLocalBar(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalBar"


class MdLocalCafe(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalCafe"


class MdLocalCarWash(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalCarWash"


class MdLocalConvenienceStore(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalConvenienceStore"


class MdLocalDining(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalDining"


class MdLocalDrink(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalDrink"


class MdLocalFireDepartment(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalFireDepartment"


class MdLocalFlorist(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalFlorist"


class MdLocalGasStation(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalGasStation"


class MdLocalGroceryStore(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalGroceryStore"


class MdLocalHospital(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalHospital"


class MdLocalHotel(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalHotel"


class MdLocalLaundryService(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalLaundryService"


class MdLocalLibrary(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalLibrary"


class MdLocalMall(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalMall"


class MdLocalMovies(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalMovies"


class MdLocalOffer(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalOffer"


class MdLocalParking(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalParking"


class MdLocalPharmacy(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalPharmacy"


class MdLocalPhone(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalPhone"


class MdLocalPizza(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalPizza"


class MdLocalPlay(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalPlay"


class MdLocalPolice(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalPolice"


class MdLocalPostOffice(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalPostOffice"


class MdLocalPrintshop(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalPrintshop"


class MdLocalSee(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalSee"


class MdLocalShipping(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalShipping"


class MdLocalTaxi(rx.Component):
    library = "react-icons/md"
    tag = "MdLocalTaxi"


class MdLocationPin(rx.Component):
    library = "react-icons/md"
    tag = "MdLocationPin"


class MdLunchDining(rx.Component):
    library = "react-icons/md"
    tag = "MdLunchDining"


class MdMap(rx.Component):
    library = "react-icons/md"
    tag = "MdMap"


class MdMapsUgc(rx.Component):
    library = "react-icons/md"
    tag = "MdMapsUgc"


class MdMedicalInformation(rx.Component):
    library = "react-icons/md"
    tag = "MdMedicalInformation"


class MdMedicalServices(rx.Component):
    library = "react-icons/md"
    tag = "MdMedicalServices"


class MdMenuBook(rx.Component):
    library = "react-icons/md"
    tag = "MdMenuBook"


class MdMerge(rx.Component):
    library = "react-icons/md"
    tag = "MdMerge"


class MdMinorCrash(rx.Component):
    library = "react-icons/md"
    tag = "MdMinorCrash"


class MdMiscellaneousServices(rx.Component):
    library = "react-icons/md"
    tag = "MdMiscellaneousServices"


class MdModeOfTravel(rx.Component):
    library = "react-icons/md"
    tag = "MdModeOfTravel"


class MdMoney(rx.Component):
    library = "react-icons/md"
    tag = "MdMoney"


class MdMoped(rx.Component):
    library = "react-icons/md"
    tag = "MdMoped"


class MdMosque(rx.Component):
    library = "react-icons/md"
    tag = "MdMosque"


class MdMoving(rx.Component):
    library = "react-icons/md"
    tag = "MdMoving"


class MdMultipleStop(rx.Component):
    library = "react-icons/md"
    tag = "MdMultipleStop"


class MdMuseum(rx.Component):
    library = "react-icons/md"
    tag = "MdMuseum"


class MdMyLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdMyLocation"


class MdNavigation(rx.Component):
    library = "react-icons/md"
    tag = "MdNavigation"


class MdNearMeDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdNearMeDisabled"


class MdNearMe(rx.Component):
    library = "react-icons/md"
    tag = "MdNearMe"


class MdNightlife(rx.Component):
    library = "react-icons/md"
    tag = "MdNightlife"


class MdNoCrash(rx.Component):
    library = "react-icons/md"
    tag = "MdNoCrash"


class MdNoMealsOuline(rx.Component):
    library = "react-icons/md"
    tag = "MdNoMealsOuline"


class MdNoMeals(rx.Component):
    library = "react-icons/md"
    tag = "MdNoMeals"


class MdNoTransfer(rx.Component):
    library = "react-icons/md"
    tag = "MdNoTransfer"


class MdNotListedLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdNotListedLocation"


class MdPark(rx.Component):
    library = "react-icons/md"
    tag = "MdPark"


class MdPedalBike(rx.Component):
    library = "react-icons/md"
    tag = "MdPedalBike"


class MdPersonPinCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonPinCircle"


class MdPersonPin(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonPin"


class MdPestControlRodent(rx.Component):
    library = "react-icons/md"
    tag = "MdPestControlRodent"


class MdPestControl(rx.Component):
    library = "react-icons/md"
    tag = "MdPestControl"


class MdPinDrop(rx.Component):
    library = "react-icons/md"
    tag = "MdPinDrop"


class MdPlace(rx.Component):
    library = "react-icons/md"
    tag = "MdPlace"


class MdPlumbing(rx.Component):
    library = "react-icons/md"
    tag = "MdPlumbing"


class MdRailwayAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdRailwayAlert"


class MdRamenDining(rx.Component):
    library = "react-icons/md"
    tag = "MdRamenDining"


class MdRampLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdRampLeft"


class MdRampRight(rx.Component):
    library = "react-icons/md"
    tag = "MdRampRight"


class MdRateReview(rx.Component):
    library = "react-icons/md"
    tag = "MdRateReview"


class MdRemoveRoad(rx.Component):
    library = "react-icons/md"
    tag = "MdRemoveRoad"


class MdRestaurantMenu(rx.Component):
    library = "react-icons/md"
    tag = "MdRestaurantMenu"


class MdRestaurant(rx.Component):
    library = "react-icons/md"
    tag = "MdRestaurant"


class MdRoundaboutLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdRoundaboutLeft"


class MdRoundaboutRight(rx.Component):
    library = "react-icons/md"
    tag = "MdRoundaboutRight"


class MdRoute(rx.Component):
    library = "react-icons/md"
    tag = "MdRoute"


class MdRunCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdRunCircle"


class MdSafetyCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdSafetyCheck"


class MdSailing(rx.Component):
    library = "react-icons/md"
    tag = "MdSailing"


class MdSatellite(rx.Component):
    library = "react-icons/md"
    tag = "MdSatellite"


class MdScreenRotationAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdScreenRotationAlt"


class MdSetMeal(rx.Component):
    library = "react-icons/md"
    tag = "MdSetMeal"


class MdSignpost(rx.Component):
    library = "react-icons/md"
    tag = "MdSignpost"


class MdSnowmobile(rx.Component):
    library = "react-icons/md"
    tag = "MdSnowmobile"


class MdSos(rx.Component):
    library = "react-icons/md"
    tag = "MdSos"


class MdSoupKitchen(rx.Component):
    library = "react-icons/md"
    tag = "MdSoupKitchen"


class MdStadium(rx.Component):
    library = "react-icons/md"
    tag = "MdStadium"


class MdStoreMallDirectory(rx.Component):
    library = "react-icons/md"
    tag = "MdStoreMallDirectory"


class MdStraight(rx.Component):
    library = "react-icons/md"
    tag = "MdStraight"


class MdStreetview(rx.Component):
    library = "react-icons/md"
    tag = "MdStreetview"


class MdSubway(rx.Component):
    library = "react-icons/md"
    tag = "MdSubway"


class MdSynagogue(rx.Component):
    library = "react-icons/md"
    tag = "MdSynagogue"


class MdTakeoutDining(rx.Component):
    library = "react-icons/md"
    tag = "MdTakeoutDining"


class MdTaxiAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdTaxiAlert"


class MdTempleBuddhist(rx.Component):
    library = "react-icons/md"
    tag = "MdTempleBuddhist"


class MdTempleHindu(rx.Component):
    library = "react-icons/md"
    tag = "MdTempleHindu"


class MdTerrain(rx.Component):
    library = "react-icons/md"
    tag = "MdTerrain"


class MdTheaterComedy(rx.Component):
    library = "react-icons/md"
    tag = "MdTheaterComedy"


class MdTireRepair(rx.Component):
    library = "react-icons/md"
    tag = "MdTireRepair"


class MdTraffic(rx.Component):
    library = "react-icons/md"
    tag = "MdTraffic"


class MdTrain(rx.Component):
    library = "react-icons/md"
    tag = "MdTrain"


class MdTram(rx.Component):
    library = "react-icons/md"
    tag = "MdTram"


class MdTransferWithinAStation(rx.Component):
    library = "react-icons/md"
    tag = "MdTransferWithinAStation"


class MdTransitEnterexit(rx.Component):
    library = "react-icons/md"
    tag = "MdTransitEnterexit"


class MdTripOrigin(rx.Component):
    library = "react-icons/md"
    tag = "MdTripOrigin"


class MdTurnLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdTurnLeft"


class MdTurnRight(rx.Component):
    library = "react-icons/md"
    tag = "MdTurnRight"


class MdTurnSharpLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdTurnSharpLeft"


class MdTurnSharpRight(rx.Component):
    library = "react-icons/md"
    tag = "MdTurnSharpRight"


class MdTurnSlightLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdTurnSlightLeft"


class MdTurnSlightRight(rx.Component):
    library = "react-icons/md"
    tag = "MdTurnSlightRight"


class MdTwoWheeler(rx.Component):
    library = "react-icons/md"
    tag = "MdTwoWheeler"


class MdUTurnLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdUTurnLeft"


class MdUTurnRight(rx.Component):
    library = "react-icons/md"
    tag = "MdUTurnRight"


class MdVolunteerActivism(rx.Component):
    library = "react-icons/md"
    tag = "MdVolunteerActivism"


class MdWarehouse(rx.Component):
    library = "react-icons/md"
    tag = "MdWarehouse"


class MdWineBar(rx.Component):
    library = "react-icons/md"
    tag = "MdWineBar"


class MdWrongLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdWrongLocation"


class MdZoomInMap(rx.Component):
    library = "react-icons/md"
    tag = "MdZoomInMap"


class MdZoomOutMap(rx.Component):
    library = "react-icons/md"
    tag = "MdZoomOutMap"


class MdAddHomeWork(rx.Component):
    library = "react-icons/md"
    tag = "MdAddHomeWork"


class MdAppSettingsAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdAppSettingsAlt"


class MdAppsOutage(rx.Component):
    library = "react-icons/md"
    tag = "MdAppsOutage"


class MdApps(rx.Component):
    library = "react-icons/md"
    tag = "MdApps"


class MdArrowBackIosNew(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowBackIosNew"


class MdArrowBackIos(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowBackIos"


class MdArrowBack(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowBack"


class MdArrowDownward(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowDownward"


class MdArrowDropDownCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowDropDownCircle"


class MdArrowDropDown(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowDropDown"


class MdArrowDropUp(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowDropUp"


class MdArrowForwardIos(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowForwardIos"


class MdArrowForward(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowForward"


class MdArrowLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowLeft"


class MdArrowRight(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowRight"


class MdArrowUpward(rx.Component):
    library = "react-icons/md"
    tag = "MdArrowUpward"


class MdAssistantDirection(rx.Component):
    library = "react-icons/md"
    tag = "MdAssistantDirection"


class MdAssistantNavigation(rx.Component):
    library = "react-icons/md"
    tag = "MdAssistantNavigation"


class MdCampaign(rx.Component):
    library = "react-icons/md"
    tag = "MdCampaign"


class MdCancel(rx.Component):
    library = "react-icons/md"
    tag = "MdCancel"


class MdCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdCheck"


class MdChevronLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdChevronLeft"


class MdChevronRight(rx.Component):
    library = "react-icons/md"
    tag = "MdChevronRight"


class MdClose(rx.Component):
    library = "react-icons/md"
    tag = "MdClose"


class MdDoubleArrow(rx.Component):
    library = "react-icons/md"
    tag = "MdDoubleArrow"


class MdEast(rx.Component):
    library = "react-icons/md"
    tag = "MdEast"


class MdExpandCircleDown(rx.Component):
    library = "react-icons/md"
    tag = "MdExpandCircleDown"


class MdExpandLess(rx.Component):
    library = "react-icons/md"
    tag = "MdExpandLess"


class MdExpandMore(rx.Component):
    library = "react-icons/md"
    tag = "MdExpandMore"


class MdFirstPage(rx.Component):
    library = "react-icons/md"
    tag = "MdFirstPage"


class MdFullscreenExit(rx.Component):
    library = "react-icons/md"
    tag = "MdFullscreenExit"


class MdFullscreen(rx.Component):
    library = "react-icons/md"
    tag = "MdFullscreen"


class MdHomeWork(rx.Component):
    library = "react-icons/md"
    tag = "MdHomeWork"


class MdLastPage(rx.Component):
    library = "react-icons/md"
    tag = "MdLastPage"


class MdLegendToggle(rx.Component):
    library = "react-icons/md"
    tag = "MdLegendToggle"


class MdMapsHomeWork(rx.Component):
    library = "react-icons/md"
    tag = "MdMapsHomeWork"


class MdMenuOpen(rx.Component):
    library = "react-icons/md"
    tag = "MdMenuOpen"


class MdMenu(rx.Component):
    library = "react-icons/md"
    tag = "MdMenu"


class MdMoreHoriz(rx.Component):
    library = "react-icons/md"
    tag = "MdMoreHoriz"


class MdMoreVert(rx.Component):
    library = "react-icons/md"
    tag = "MdMoreVert"


class MdNorthEast(rx.Component):
    library = "react-icons/md"
    tag = "MdNorthEast"


class MdNorthWest(rx.Component):
    library = "react-icons/md"
    tag = "MdNorthWest"


class MdNorth(rx.Component):
    library = "react-icons/md"
    tag = "MdNorth"


class MdOfflineShare(rx.Component):
    library = "react-icons/md"
    tag = "MdOfflineShare"


class MdPayments(rx.Component):
    library = "react-icons/md"
    tag = "MdPayments"


class MdPivotTableChart(rx.Component):
    library = "react-icons/md"
    tag = "MdPivotTableChart"


class MdRefresh(rx.Component):
    library = "react-icons/md"
    tag = "MdRefresh"


class MdSouthEast(rx.Component):
    library = "react-icons/md"
    tag = "MdSouthEast"


class MdSouthWest(rx.Component):
    library = "react-icons/md"
    tag = "MdSouthWest"


class MdSouth(rx.Component):
    library = "react-icons/md"
    tag = "MdSouth"


class MdSubdirectoryArrowLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdSubdirectoryArrowLeft"


class MdSubdirectoryArrowRight(rx.Component):
    library = "react-icons/md"
    tag = "MdSubdirectoryArrowRight"


class MdSwitchLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdSwitchLeft"


class MdSwitchRight(rx.Component):
    library = "react-icons/md"
    tag = "MdSwitchRight"


class MdUnfoldLess(rx.Component):
    library = "react-icons/md"
    tag = "MdUnfoldLess"


class MdUnfoldMore(rx.Component):
    library = "react-icons/md"
    tag = "MdUnfoldMore"


class MdWaterfallChart(rx.Component):
    library = "react-icons/md"
    tag = "MdWaterfallChart"


class MdWest(rx.Component):
    library = "react-icons/md"
    tag = "MdWest"


class MdAccountTree(rx.Component):
    library = "react-icons/md"
    tag = "MdAccountTree"


class MdAdb(rx.Component):
    library = "react-icons/md"
    tag = "MdAdb"


class MdAddCall(rx.Component):
    library = "react-icons/md"
    tag = "MdAddCall"


class MdAirlineSeatFlatAngled(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlineSeatFlatAngled"


class MdAirlineSeatFlat(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlineSeatFlat"


class MdAirlineSeatIndividualSuite(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlineSeatIndividualSuite"


class MdAirlineSeatLegroomExtra(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlineSeatLegroomExtra"


class MdAirlineSeatLegroomNormal(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlineSeatLegroomNormal"


class MdAirlineSeatLegroomReduced(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlineSeatLegroomReduced"


class MdAirlineSeatReclineExtra(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlineSeatReclineExtra"


class MdAirlineSeatReclineNormal(rx.Component):
    library = "react-icons/md"
    tag = "MdAirlineSeatReclineNormal"


class MdBluetoothAudio(rx.Component):
    library = "react-icons/md"
    tag = "MdBluetoothAudio"


class MdConfirmationNumber(rx.Component):
    library = "react-icons/md"
    tag = "MdConfirmationNumber"


class MdDirectionsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdDirectionsOff"


class MdDiscFull(rx.Component):
    library = "react-icons/md"
    tag = "MdDiscFull"


class MdDoDisturbAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdDoDisturbAlt"


class MdDoDisturbOff(rx.Component):
    library = "react-icons/md"
    tag = "MdDoDisturbOff"


class MdDoDisturbOn(rx.Component):
    library = "react-icons/md"
    tag = "MdDoDisturbOn"


class MdDoDisturb(rx.Component):
    library = "react-icons/md"
    tag = "MdDoDisturb"


class MdDoNotDisturbAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdDoNotDisturbAlt"


class MdDoNotDisturbOff(rx.Component):
    library = "react-icons/md"
    tag = "MdDoNotDisturbOff"


class MdDoNotDisturbOn(rx.Component):
    library = "react-icons/md"
    tag = "MdDoNotDisturbOn"


class MdDoNotDisturb(rx.Component):
    library = "react-icons/md"
    tag = "MdDoNotDisturb"


class MdDriveEta(rx.Component):
    library = "react-icons/md"
    tag = "MdDriveEta"


class MdEnhancedEncryption(rx.Component):
    library = "react-icons/md"
    tag = "MdEnhancedEncryption"


class MdEventAvailable(rx.Component):
    library = "react-icons/md"
    tag = "MdEventAvailable"


class MdEventBusy(rx.Component):
    library = "react-icons/md"
    tag = "MdEventBusy"


class MdEventNote(rx.Component):
    library = "react-icons/md"
    tag = "MdEventNote"


class MdFolderSpecial(rx.Component):
    library = "react-icons/md"
    tag = "MdFolderSpecial"


class MdImagesearchRoller(rx.Component):
    library = "react-icons/md"
    tag = "MdImagesearchRoller"


class MdLiveTv(rx.Component):
    library = "react-icons/md"
    tag = "MdLiveTv"


class MdMms(rx.Component):
    library = "react-icons/md"
    tag = "MdMms"


class MdMore(rx.Component):
    library = "react-icons/md"
    tag = "MdMore"


class MdNetworkCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdNetworkCheck"


class MdNetworkLocked(rx.Component):
    library = "react-icons/md"
    tag = "MdNetworkLocked"


class MdNoEncryptionGmailerrorred(rx.Component):
    library = "react-icons/md"
    tag = "MdNoEncryptionGmailerrorred"


class MdNoEncryption(rx.Component):
    library = "react-icons/md"
    tag = "MdNoEncryption"


class MdOndemandVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdOndemandVideo"


class MdPersonalVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonalVideo"


class MdPhoneBluetoothSpeaker(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneBluetoothSpeaker"


class MdPhoneCallback(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneCallback"


class MdPhoneForwarded(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneForwarded"


class MdPhoneInTalk(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneInTalk"


class MdPhoneLocked(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneLocked"


class MdPhoneMissed(rx.Component):
    library = "react-icons/md"
    tag = "MdPhoneMissed"


class MdPhonePaused(rx.Component):
    library = "react-icons/md"
    tag = "MdPhonePaused"


class MdPowerOff(rx.Component):
    library = "react-icons/md"
    tag = "MdPowerOff"


class MdPower(rx.Component):
    library = "react-icons/md"
    tag = "MdPower"


class MdPriorityHigh(rx.Component):
    library = "react-icons/md"
    tag = "MdPriorityHigh"


class MdRunningWithErrors(rx.Component):
    library = "react-icons/md"
    tag = "MdRunningWithErrors"


class MdSdCardAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdSdCardAlert"


class MdSdCard(rx.Component):
    library = "react-icons/md"
    tag = "MdSdCard"


class MdSimCardAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdSimCardAlert"


class MdSmsFailed(rx.Component):
    library = "react-icons/md"
    tag = "MdSmsFailed"


class MdSms(rx.Component):
    library = "react-icons/md"
    tag = "MdSms"


class MdSupportAgent(rx.Component):
    library = "react-icons/md"
    tag = "MdSupportAgent"


class MdSyncDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdSyncDisabled"


class MdSyncLock(rx.Component):
    library = "react-icons/md"
    tag = "MdSyncLock"


class MdSyncProblem(rx.Component):
    library = "react-icons/md"
    tag = "MdSyncProblem"


class MdSync(rx.Component):
    library = "react-icons/md"
    tag = "MdSync"


class MdSystemUpdate(rx.Component):
    library = "react-icons/md"
    tag = "MdSystemUpdate"


class MdTapAndPlay(rx.Component):
    library = "react-icons/md"
    tag = "MdTapAndPlay"


class MdTimeToLeave(rx.Component):
    library = "react-icons/md"
    tag = "MdTimeToLeave"


class MdTvOff(rx.Component):
    library = "react-icons/md"
    tag = "MdTvOff"


class MdVibration(rx.Component):
    library = "react-icons/md"
    tag = "MdVibration"


class MdVideoChat(rx.Component):
    library = "react-icons/md"
    tag = "MdVideoChat"


class MdVoiceChat(rx.Component):
    library = "react-icons/md"
    tag = "MdVoiceChat"


class MdVpnLock(rx.Component):
    library = "react-icons/md"
    tag = "MdVpnLock"


class MdWc(rx.Component):
    library = "react-icons/md"
    tag = "MdWc"


class MdWifiOff(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiOff"


class MdWifi(rx.Component):
    library = "react-icons/md"
    tag = "MdWifi"


class MdAcUnit(rx.Component):
    library = "react-icons/md"
    tag = "MdAcUnit"


class MdAirportShuttle(rx.Component):
    library = "react-icons/md"
    tag = "MdAirportShuttle"


class MdAllInclusive(rx.Component):
    library = "react-icons/md"
    tag = "MdAllInclusive"


class MdApartment(rx.Component):
    library = "react-icons/md"
    tag = "MdApartment"


class MdBabyChangingStation(rx.Component):
    library = "react-icons/md"
    tag = "MdBabyChangingStation"


class MdBackpack(rx.Component):
    library = "react-icons/md"
    tag = "MdBackpack"


class MdBalcony(rx.Component):
    library = "react-icons/md"
    tag = "MdBalcony"


class MdBathtub(rx.Component):
    library = "react-icons/md"
    tag = "MdBathtub"


class MdBeachAccess(rx.Component):
    library = "react-icons/md"
    tag = "MdBeachAccess"


class MdBento(rx.Component):
    library = "react-icons/md"
    tag = "MdBento"


class MdBungalow(rx.Component):
    library = "react-icons/md"
    tag = "MdBungalow"


class MdBusinessCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdBusinessCenter"


class MdCabin(rx.Component):
    library = "react-icons/md"
    tag = "MdCabin"


class MdCarpenter(rx.Component):
    library = "react-icons/md"
    tag = "MdCarpenter"


class MdCasino(rx.Component):
    library = "react-icons/md"
    tag = "MdCasino"


class MdChalet(rx.Component):
    library = "react-icons/md"
    tag = "MdChalet"


class MdChargingStation(rx.Component):
    library = "react-icons/md"
    tag = "MdChargingStation"


class MdCheckroom(rx.Component):
    library = "react-icons/md"
    tag = "MdCheckroom"


class MdChildCare(rx.Component):
    library = "react-icons/md"
    tag = "MdChildCare"


class MdChildFriendly(rx.Component):
    library = "react-icons/md"
    tag = "MdChildFriendly"


class MdCorporateFare(rx.Component):
    library = "react-icons/md"
    tag = "MdCorporateFare"


class MdCottage(rx.Component):
    library = "react-icons/md"
    tag = "MdCottage"


class MdCountertops(rx.Component):
    library = "react-icons/md"
    tag = "MdCountertops"


class MdCrib(rx.Component):
    library = "react-icons/md"
    tag = "MdCrib"


class MdDesk(rx.Component):
    library = "react-icons/md"
    tag = "MdDesk"


class MdDoNotStep(rx.Component):
    library = "react-icons/md"
    tag = "MdDoNotStep"


class MdDoNotTouch(rx.Component):
    library = "react-icons/md"
    tag = "MdDoNotTouch"


class MdDry(rx.Component):
    library = "react-icons/md"
    tag = "MdDry"


class MdElevator(rx.Component):
    library = "react-icons/md"
    tag = "MdElevator"


class MdEscalatorWarning(rx.Component):
    library = "react-icons/md"
    tag = "MdEscalatorWarning"


class MdEscalator(rx.Component):
    library = "react-icons/md"
    tag = "MdEscalator"


class MdFamilyRestroom(rx.Component):
    library = "react-icons/md"
    tag = "MdFamilyRestroom"


class MdFence(rx.Component):
    library = "react-icons/md"
    tag = "MdFence"


class MdFireExtinguisher(rx.Component):
    library = "react-icons/md"
    tag = "MdFireExtinguisher"


class MdFitnessCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdFitnessCenter"


class MdFoodBank(rx.Component):
    library = "react-icons/md"
    tag = "MdFoodBank"


class MdFoundation(rx.Component):
    library = "react-icons/md"
    tag = "MdFoundation"


class MdFreeBreakfast(rx.Component):
    library = "react-icons/md"
    tag = "MdFreeBreakfast"


class MdGite(rx.Component):
    library = "react-icons/md"
    tag = "MdGite"


class MdGolfCourse(rx.Component):
    library = "react-icons/md"
    tag = "MdGolfCourse"


class MdGrass(rx.Component):
    library = "react-icons/md"
    tag = "MdGrass"


class MdHolidayVillage(rx.Component):
    library = "react-icons/md"
    tag = "MdHolidayVillage"


class MdHotTub(rx.Component):
    library = "react-icons/md"
    tag = "MdHotTub"


class MdHouseSiding(rx.Component):
    library = "react-icons/md"
    tag = "MdHouseSiding"


class MdHouse(rx.Component):
    library = "react-icons/md"
    tag = "MdHouse"


class MdHouseboat(rx.Component):
    library = "react-icons/md"
    tag = "MdHouseboat"


class MdIron(rx.Component):
    library = "react-icons/md"
    tag = "MdIron"


class MdKitchen(rx.Component):
    library = "react-icons/md"
    tag = "MdKitchen"


class MdMeetingRoom(rx.Component):
    library = "react-icons/md"
    tag = "MdMeetingRoom"


class MdMicrowave(rx.Component):
    library = "react-icons/md"
    tag = "MdMicrowave"


class MdNightShelter(rx.Component):
    library = "react-icons/md"
    tag = "MdNightShelter"


class MdNoBackpack(rx.Component):
    library = "react-icons/md"
    tag = "MdNoBackpack"


class MdNoCell(rx.Component):
    library = "react-icons/md"
    tag = "MdNoCell"


class MdNoDrinks(rx.Component):
    library = "react-icons/md"
    tag = "MdNoDrinks"


class MdNoFlash(rx.Component):
    library = "react-icons/md"
    tag = "MdNoFlash"


class MdNoFood(rx.Component):
    library = "react-icons/md"
    tag = "MdNoFood"


class MdNoMeetingRoom(rx.Component):
    library = "react-icons/md"
    tag = "MdNoMeetingRoom"


class MdNoPhotography(rx.Component):
    library = "react-icons/md"
    tag = "MdNoPhotography"


class MdNoStroller(rx.Component):
    library = "react-icons/md"
    tag = "MdNoStroller"


class MdOtherHouses(rx.Component):
    library = "react-icons/md"
    tag = "MdOtherHouses"


class MdPool(rx.Component):
    library = "react-icons/md"
    tag = "MdPool"


class MdRiceBowl(rx.Component):
    library = "react-icons/md"
    tag = "MdRiceBowl"


class MdRoofing(rx.Component):
    library = "react-icons/md"
    tag = "MdRoofing"


class MdRoomPreferences(rx.Component):
    library = "react-icons/md"
    tag = "MdRoomPreferences"


class MdRoomService(rx.Component):
    library = "react-icons/md"
    tag = "MdRoomService"


class MdRvHookup(rx.Component):
    library = "react-icons/md"
    tag = "MdRvHookup"


class MdSmokeFree(rx.Component):
    library = "react-icons/md"
    tag = "MdSmokeFree"


class MdSmokingRooms(rx.Component):
    library = "react-icons/md"
    tag = "MdSmokingRooms"


class MdSoap(rx.Component):
    library = "react-icons/md"
    tag = "MdSoap"


class MdSpa(rx.Component):
    library = "react-icons/md"
    tag = "MdSpa"


class MdSportsBar(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsBar"


class MdStairs(rx.Component):
    library = "react-icons/md"
    tag = "MdStairs"


class MdStorefront(rx.Component):
    library = "react-icons/md"
    tag = "MdStorefront"


class MdStroller(rx.Component):
    library = "react-icons/md"
    tag = "MdStroller"


class MdTapas(rx.Component):
    library = "react-icons/md"
    tag = "MdTapas"


class MdTty(rx.Component):
    library = "react-icons/md"
    tag = "MdTty"


class MdUmbrella(rx.Component):
    library = "react-icons/md"
    tag = "MdUmbrella"


class MdVapeFree(rx.Component):
    library = "react-icons/md"
    tag = "MdVapeFree"


class MdVapingRooms(rx.Component):
    library = "react-icons/md"
    tag = "MdVapingRooms"


class MdVilla(rx.Component):
    library = "react-icons/md"
    tag = "MdVilla"


class MdWash(rx.Component):
    library = "react-icons/md"
    tag = "MdWash"


class MdWaterDamage(rx.Component):
    library = "react-icons/md"
    tag = "MdWaterDamage"


class MdWheelchairPickup(rx.Component):
    library = "react-icons/md"
    tag = "MdWheelchairPickup"


class MdBathroom(rx.Component):
    library = "react-icons/md"
    tag = "MdBathroom"


class MdBed(rx.Component):
    library = "react-icons/md"
    tag = "MdBed"


class MdBedroomBaby(rx.Component):
    library = "react-icons/md"
    tag = "MdBedroomBaby"


class MdBedroomChild(rx.Component):
    library = "react-icons/md"
    tag = "MdBedroomChild"


class MdBedroomParent(rx.Component):
    library = "react-icons/md"
    tag = "MdBedroomParent"


class MdBlender(rx.Component):
    library = "react-icons/md"
    tag = "MdBlender"


class MdCameraIndoor(rx.Component):
    library = "react-icons/md"
    tag = "MdCameraIndoor"


class MdCameraOutdoor(rx.Component):
    library = "react-icons/md"
    tag = "MdCameraOutdoor"


class MdChairAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdChairAlt"


class MdChair(rx.Component):
    library = "react-icons/md"
    tag = "MdChair"


class MdCoffeeMaker(rx.Component):
    library = "react-icons/md"
    tag = "MdCoffeeMaker"


class MdCoffee(rx.Component):
    library = "react-icons/md"
    tag = "MdCoffee"


class MdDining(rx.Component):
    library = "react-icons/md"
    tag = "MdDining"


class MdDoorBack(rx.Component):
    library = "react-icons/md"
    tag = "MdDoorBack"


class MdDoorFront(rx.Component):
    library = "react-icons/md"
    tag = "MdDoorFront"


class MdDoorSliding(rx.Component):
    library = "react-icons/md"
    tag = "MdDoorSliding"


class MdDoorbell(rx.Component):
    library = "react-icons/md"
    tag = "MdDoorbell"


class MdFeed(rx.Component):
    library = "react-icons/md"
    tag = "MdFeed"


class MdFlatware(rx.Component):
    library = "react-icons/md"
    tag = "MdFlatware"


class MdGarage(rx.Component):
    library = "react-icons/md"
    tag = "MdGarage"


class MdLight(rx.Component):
    library = "react-icons/md"
    tag = "MdLight"


class MdLiving(rx.Component):
    library = "react-icons/md"
    tag = "MdLiving"


class MdManageSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdManageSearch"


class MdPodcasts(rx.Component):
    library = "react-icons/md"
    tag = "MdPodcasts"


class MdShower(rx.Component):
    library = "react-icons/md"
    tag = "MdShower"


class MdTableBar(rx.Component):
    library = "react-icons/md"
    tag = "MdTableBar"


class MdTableRestaurant(rx.Component):
    library = "react-icons/md"
    tag = "MdTableRestaurant"


class MdWindow(rx.Component):
    library = "react-icons/md"
    tag = "MdWindow"


class MdYard(rx.Component):
    library = "react-icons/md"
    tag = "MdYard"


class Md18UpRating(rx.Component):
    library = "react-icons/md"
    tag = "Md18UpRating"


class Md6FtApart(rx.Component):
    library = "react-icons/md"
    tag = "Md6FtApart"


class MdAddModerator(rx.Component):
    library = "react-icons/md"
    tag = "MdAddModerator"


class MdAddReaction(rx.Component):
    library = "react-icons/md"
    tag = "MdAddReaction"


class MdArchitecture(rx.Component):
    library = "react-icons/md"
    tag = "MdArchitecture"


class MdAssistWalker(rx.Component):
    library = "react-icons/md"
    tag = "MdAssistWalker"


class MdBackHand(rx.Component):
    library = "react-icons/md"
    tag = "MdBackHand"


class MdBlind(rx.Component):
    library = "react-icons/md"
    tag = "MdBlind"


class MdBoy(rx.Component):
    library = "react-icons/md"
    tag = "MdBoy"


class MdCake(rx.Component):
    library = "react-icons/md"
    tag = "MdCake"


class MdCatchingPokemon(rx.Component):
    library = "react-icons/md"
    tag = "MdCatchingPokemon"


class MdCleanHands(rx.Component):
    library = "react-icons/md"
    tag = "MdCleanHands"


class MdCo2(rx.Component):
    library = "react-icons/md"
    tag = "MdCo2"


class MdCompost(rx.Component):
    library = "react-icons/md"
    tag = "MdCompost"


class MdConnectWithoutContact(rx.Component):
    library = "react-icons/md"
    tag = "MdConnectWithoutContact"


class MdConstruction(rx.Component):
    library = "react-icons/md"
    tag = "MdConstruction"


class MdCookie(rx.Component):
    library = "react-icons/md"
    tag = "MdCookie"


class MdCoronavirus(rx.Component):
    library = "react-icons/md"
    tag = "MdCoronavirus"


class MdCrueltyFree(rx.Component):
    library = "react-icons/md"
    tag = "MdCrueltyFree"


class MdCyclone(rx.Component):
    library = "react-icons/md"
    tag = "MdCyclone"


class MdDeck(rx.Component):
    library = "react-icons/md"
    tag = "MdDeck"


class MdDewPoint(rx.Component):
    library = "react-icons/md"
    tag = "MdDewPoint"


class MdDiversity1(rx.Component):
    library = "react-icons/md"
    tag = "MdDiversity1"


class MdDiversity2(rx.Component):
    library = "react-icons/md"
    tag = "MdDiversity2"


class MdDiversity3(rx.Component):
    library = "react-icons/md"
    tag = "MdDiversity3"


class MdDomainAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdDomainAdd"


class MdDomain(rx.Component):
    library = "react-icons/md"
    tag = "MdDomain"


class MdDownhillSkiing(rx.Component):
    library = "react-icons/md"
    tag = "MdDownhillSkiing"


class MdEditNotifications(rx.Component):
    library = "react-icons/md"
    tag = "MdEditNotifications"


class MdElderlyWoman(rx.Component):
    library = "react-icons/md"
    tag = "MdElderlyWoman"


class MdElderly(rx.Component):
    library = "react-icons/md"
    tag = "MdElderly"


class MdEmojiEmotions(rx.Component):
    library = "react-icons/md"
    tag = "MdEmojiEmotions"


class MdEmojiEvents(rx.Component):
    library = "react-icons/md"
    tag = "MdEmojiEvents"


class MdEmojiFlags(rx.Component):
    library = "react-icons/md"
    tag = "MdEmojiFlags"


class MdEmojiFoodBeverage(rx.Component):
    library = "react-icons/md"
    tag = "MdEmojiFoodBeverage"


class MdEmojiNature(rx.Component):
    library = "react-icons/md"
    tag = "MdEmojiNature"


class MdEmojiObjects(rx.Component):
    library = "react-icons/md"
    tag = "MdEmojiObjects"


class MdEmojiPeople(rx.Component):
    library = "react-icons/md"
    tag = "MdEmojiPeople"


class MdEmojiSymbols(rx.Component):
    library = "react-icons/md"
    tag = "MdEmojiSymbols"


class MdEmojiTransportation(rx.Component):
    library = "react-icons/md"
    tag = "MdEmojiTransportation"


class MdEngineering(rx.Component):
    library = "react-icons/md"
    tag = "MdEngineering"


class MdFace2(rx.Component):
    library = "react-icons/md"
    tag = "MdFace2"


class MdFace3(rx.Component):
    library = "react-icons/md"
    tag = "MdFace3"


class MdFace4(rx.Component):
    library = "react-icons/md"
    tag = "MdFace4"


class MdFace5(rx.Component):
    library = "react-icons/md"
    tag = "MdFace5"


class MdFace6(rx.Component):
    library = "react-icons/md"
    tag = "MdFace6"


class MdFacebook(rx.Component):
    library = "react-icons/md"
    tag = "MdFacebook"


class MdFemale(rx.Component):
    library = "react-icons/md"
    tag = "MdFemale"


class MdFireplace(rx.Component):
    library = "react-icons/md"
    tag = "MdFireplace"


class MdFitbit(rx.Component):
    library = "react-icons/md"
    tag = "MdFitbit"


class MdFlood(rx.Component):
    library = "react-icons/md"
    tag = "MdFlood"


class MdFollowTheSigns(rx.Component):
    library = "react-icons/md"
    tag = "MdFollowTheSigns"


class MdFrontHand(rx.Component):
    library = "react-icons/md"
    tag = "MdFrontHand"


class MdGirl(rx.Component):
    library = "react-icons/md"
    tag = "MdGirl"


class MdGroupAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdGroupAdd"


class MdGroupOff(rx.Component):
    library = "react-icons/md"
    tag = "MdGroupOff"


class MdGroupRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdGroupRemove"


class MdGroup(rx.Component):
    library = "react-icons/md"
    tag = "MdGroup"


class MdGroups2(rx.Component):
    library = "react-icons/md"
    tag = "MdGroups2"


class MdGroups3(rx.Component):
    library = "react-icons/md"
    tag = "MdGroups3"


class MdGroups(rx.Component):
    library = "react-icons/md"
    tag = "MdGroups"


class MdHandshake(rx.Component):
    library = "react-icons/md"
    tag = "MdHandshake"


class MdHealthAndSafety(rx.Component):
    library = "react-icons/md"
    tag = "MdHealthAndSafety"


class MdHeartBroken(rx.Component):
    library = "react-icons/md"
    tag = "MdHeartBroken"


class MdHiking(rx.Component):
    library = "react-icons/md"
    tag = "MdHiking"


class MdHistoryEdu(rx.Component):
    library = "react-icons/md"
    tag = "MdHistoryEdu"


class MdHive(rx.Component):
    library = "react-icons/md"
    tag = "MdHive"


class MdIceSkating(rx.Component):
    library = "react-icons/md"
    tag = "MdIceSkating"


class MdInterests(rx.Component):
    library = "react-icons/md"
    tag = "MdInterests"


class MdIosShare(rx.Component):
    library = "react-icons/md"
    tag = "MdIosShare"


class MdKayaking(rx.Component):
    library = "react-icons/md"
    tag = "MdKayaking"


class MdKingBed(rx.Component):
    library = "react-icons/md"
    tag = "MdKingBed"


class MdKitesurfing(rx.Component):
    library = "react-icons/md"
    tag = "MdKitesurfing"


class MdLandslide(rx.Component):
    library = "react-icons/md"
    tag = "MdLandslide"


class MdLocationCity(rx.Component):
    library = "react-icons/md"
    tag = "MdLocationCity"


class MdLuggage(rx.Component):
    library = "react-icons/md"
    tag = "MdLuggage"


class MdMale(rx.Component):
    library = "react-icons/md"
    tag = "MdMale"


class MdMan2(rx.Component):
    library = "react-icons/md"
    tag = "MdMan2"


class MdMan3(rx.Component):
    library = "react-icons/md"
    tag = "MdMan3"


class MdMan4(rx.Component):
    library = "react-icons/md"
    tag = "MdMan4"


class MdMan(rx.Component):
    library = "react-icons/md"
    tag = "MdMan"


class MdMasks(rx.Component):
    library = "react-icons/md"
    tag = "MdMasks"


class MdMilitaryTech(rx.Component):
    library = "react-icons/md"
    tag = "MdMilitaryTech"


class MdMoodBad(rx.Component):
    library = "react-icons/md"
    tag = "MdMoodBad"


class MdMood(rx.Component):
    library = "react-icons/md"
    tag = "MdMood"


class MdNightsStay(rx.Component):
    library = "react-icons/md"
    tag = "MdNightsStay"


class MdNoAdultContent(rx.Component):
    library = "react-icons/md"
    tag = "MdNoAdultContent"


class MdNoLuggage(rx.Component):
    library = "react-icons/md"
    tag = "MdNoLuggage"


class MdNordicWalking(rx.Component):
    library = "react-icons/md"
    tag = "MdNordicWalking"


class MdNotificationAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdNotificationAdd"


class MdNotificationsActive(rx.Component):
    library = "react-icons/md"
    tag = "MdNotificationsActive"


class MdNotificationsNone(rx.Component):
    library = "react-icons/md"
    tag = "MdNotificationsNone"


class MdNotificationsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdNotificationsOff"


class MdNotificationsPaused(rx.Component):
    library = "react-icons/md"
    tag = "MdNotificationsPaused"


class MdNotifications(rx.Component):
    library = "react-icons/md"
    tag = "MdNotifications"


class MdOutdoorGrill(rx.Component):
    library = "react-icons/md"
    tag = "MdOutdoorGrill"


class MdPages(rx.Component):
    library = "react-icons/md"
    tag = "MdPages"


class MdParagliding(rx.Component):
    library = "react-icons/md"
    tag = "MdParagliding"


class MdPartyMode(rx.Component):
    library = "react-icons/md"
    tag = "MdPartyMode"


class MdPeopleAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdPeopleAlt"


class MdPeopleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdPeopleOutline"


class MdPeople(rx.Component):
    library = "react-icons/md"
    tag = "MdPeople"


class MdPerson2(rx.Component):
    library = "react-icons/md"
    tag = "MdPerson2"


class MdPerson3(rx.Component):
    library = "react-icons/md"
    tag = "MdPerson3"


class MdPerson4(rx.Component):
    library = "react-icons/md"
    tag = "MdPerson4"


class MdPersonAddAlt1(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonAddAlt1"


class MdPersonAddAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonAddAlt"


class MdPersonAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonAdd"


class MdPersonOff(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonOff"


class MdPersonOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonOutline"


class MdPersonRemoveAlt1(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonRemoveAlt1"


class MdPersonRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonRemove"


class MdPerson(rx.Component):
    library = "react-icons/md"
    tag = "MdPerson"


class MdPersonalInjury(rx.Component):
    library = "react-icons/md"
    tag = "MdPersonalInjury"


class MdPianoOff(rx.Component):
    library = "react-icons/md"
    tag = "MdPianoOff"


class MdPiano(rx.Component):
    library = "react-icons/md"
    tag = "MdPiano"


class MdPix(rx.Component):
    library = "react-icons/md"
    tag = "MdPix"


class MdPlusOne(rx.Component):
    library = "react-icons/md"
    tag = "MdPlusOne"


class MdPoll(rx.Component):
    library = "react-icons/md"
    tag = "MdPoll"


class MdPrecisionManufacturing(rx.Component):
    library = "react-icons/md"
    tag = "MdPrecisionManufacturing"


class MdPsychologyAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdPsychologyAlt"


class MdPsychology(rx.Component):
    library = "react-icons/md"
    tag = "MdPsychology"


class MdPublicOff(rx.Component):
    library = "react-icons/md"
    tag = "MdPublicOff"


class MdPublic(rx.Component):
    library = "react-icons/md"
    tag = "MdPublic"


class MdRealEstateAgent(rx.Component):
    library = "react-icons/md"
    tag = "MdRealEstateAgent"


class MdRecommend(rx.Component):
    library = "react-icons/md"
    tag = "MdRecommend"


class MdRecycling(rx.Component):
    library = "react-icons/md"
    tag = "MdRecycling"


class MdReduceCapacity(rx.Component):
    library = "react-icons/md"
    tag = "MdReduceCapacity"


class MdRemoveModerator(rx.Component):
    library = "react-icons/md"
    tag = "MdRemoveModerator"


class MdRollerSkating(rx.Component):
    library = "react-icons/md"
    tag = "MdRollerSkating"


class MdSafetyDivider(rx.Component):
    library = "react-icons/md"
    tag = "MdSafetyDivider"


class MdSanitizer(rx.Component):
    library = "react-icons/md"
    tag = "MdSanitizer"


class MdScale(rx.Component):
    library = "react-icons/md"
    tag = "MdScale"


class MdSchool(rx.Component):
    library = "react-icons/md"
    tag = "MdSchool"


class MdScience(rx.Component):
    library = "react-icons/md"
    tag = "MdScience"


class MdScoreboard(rx.Component):
    library = "react-icons/md"
    tag = "MdScoreboard"


class MdScubaDiving(rx.Component):
    library = "react-icons/md"
    tag = "MdScubaDiving"


class MdSelfImprovement(rx.Component):
    library = "react-icons/md"
    tag = "MdSelfImprovement"


class MdSentimentDissatisfied(rx.Component):
    library = "react-icons/md"
    tag = "MdSentimentDissatisfied"


class MdSentimentNeutral(rx.Component):
    library = "react-icons/md"
    tag = "MdSentimentNeutral"


class MdSentimentSatisfied(rx.Component):
    library = "react-icons/md"
    tag = "MdSentimentSatisfied"


class MdSentimentVeryDissatisfied(rx.Component):
    library = "react-icons/md"
    tag = "MdSentimentVeryDissatisfied"


class MdSentimentVerySatisfied(rx.Component):
    library = "react-icons/md"
    tag = "MdSentimentVerySatisfied"


class MdSevereCold(rx.Component):
    library = "react-icons/md"
    tag = "MdSevereCold"


class MdShare(rx.Component):
    library = "react-icons/md"
    tag = "MdShare"


class MdSick(rx.Component):
    library = "react-icons/md"
    tag = "MdSick"


class MdSignLanguage(rx.Component):
    library = "react-icons/md"
    tag = "MdSignLanguage"


class MdSingleBed(rx.Component):
    library = "react-icons/md"
    tag = "MdSingleBed"


class MdSkateboarding(rx.Component):
    library = "react-icons/md"
    tag = "MdSkateboarding"


class MdSledding(rx.Component):
    library = "react-icons/md"
    tag = "MdSledding"


class MdSnowboarding(rx.Component):
    library = "react-icons/md"
    tag = "MdSnowboarding"


class MdSnowshoeing(rx.Component):
    library = "react-icons/md"
    tag = "MdSnowshoeing"


class MdSocialDistance(rx.Component):
    library = "react-icons/md"
    tag = "MdSocialDistance"


class MdSouthAmerica(rx.Component):
    library = "react-icons/md"
    tag = "MdSouthAmerica"


class MdSportsBaseball(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsBaseball"


class MdSportsBasketball(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsBasketball"


class MdSportsCricket(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsCricket"


class MdSportsEsports(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsEsports"


class MdSportsFootball(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsFootball"


class MdSportsGolf(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsGolf"


class MdSportsGymnastics(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsGymnastics"


class MdSportsHandball(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsHandball"


class MdSportsHockey(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsHockey"


class MdSportsKabaddi(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsKabaddi"


class MdSportsMartialArts(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsMartialArts"


class MdSportsMma(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsMma"


class MdSportsMotorsports(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsMotorsports"


class MdSportsRugby(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsRugby"


class MdSportsSoccer(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsSoccer"


class MdSportsTennis(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsTennis"


class MdSportsVolleyball(rx.Component):
    library = "react-icons/md"
    tag = "MdSportsVolleyball"


class MdSports(rx.Component):
    library = "react-icons/md"
    tag = "MdSports"


class MdSurfing(rx.Component):
    library = "react-icons/md"
    tag = "MdSurfing"


class MdSwitchAccount(rx.Component):
    library = "react-icons/md"
    tag = "MdSwitchAccount"


class MdThumbDownAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdThumbDownAlt"


class MdThumbUpAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdThumbUpAlt"


class MdThunderstorm(rx.Component):
    library = "react-icons/md"
    tag = "MdThunderstorm"


class MdTornado(rx.Component):
    library = "react-icons/md"
    tag = "MdTornado"


class MdTransgender(rx.Component):
    library = "react-icons/md"
    tag = "MdTransgender"


class MdTravelExplore(rx.Component):
    library = "react-icons/md"
    tag = "MdTravelExplore"


class MdTsunami(rx.Component):
    library = "react-icons/md"
    tag = "MdTsunami"


class MdVaccines(rx.Component):
    library = "react-icons/md"
    tag = "MdVaccines"


class MdVolcano(rx.Component):
    library = "react-icons/md"
    tag = "MdVolcano"


class MdWallet(rx.Component):
    library = "react-icons/md"
    tag = "MdWallet"


class MdWaterDrop(rx.Component):
    library = "react-icons/md"
    tag = "MdWaterDrop"


class MdWavingHand(rx.Component):
    library = "react-icons/md"
    tag = "MdWavingHand"


class MdWhatsapp(rx.Component):
    library = "react-icons/md"
    tag = "MdWhatsapp"


class MdWhatshot(rx.Component):
    library = "react-icons/md"
    tag = "MdWhatshot"


class MdWoman2(rx.Component):
    library = "react-icons/md"
    tag = "MdWoman2"


class MdWoman(rx.Component):
    library = "react-icons/md"
    tag = "MdWoman"


class MdWorkspacePremium(rx.Component):
    library = "react-icons/md"
    tag = "MdWorkspacePremium"


class MdCheckBoxOutlineBlank(rx.Component):
    library = "react-icons/md"
    tag = "MdCheckBoxOutlineBlank"


class MdCheckBox(rx.Component):
    library = "react-icons/md"
    tag = "MdCheckBox"


class MdIndeterminateCheckBox(rx.Component):
    library = "react-icons/md"
    tag = "MdIndeterminateCheckBox"


class MdRadioButtonChecked(rx.Component):
    library = "react-icons/md"
    tag = "MdRadioButtonChecked"


class MdRadioButtonUnchecked(rx.Component):
    library = "react-icons/md"
    tag = "MdRadioButtonUnchecked"


class MdStarBorderPurple500(rx.Component):
    library = "react-icons/md"
    tag = "MdStarBorderPurple500"


class MdStarBorder(rx.Component):
    library = "react-icons/md"
    tag = "MdStarBorder"


class MdStarHalf(rx.Component):
    library = "react-icons/md"
    tag = "MdStarHalf"


class MdStarOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdStarOutline"


class MdStarPurple500(rx.Component):
    library = "react-icons/md"
    tag = "MdStarPurple500"


class MdStar(rx.Component):
    library = "react-icons/md"
    tag = "MdStar"


class MdToggleOff(rx.Component):
    library = "react-icons/md"
    tag = "MdToggleOff"


class MdToggleOn(rx.Component):
    library = "react-icons/md"
    tag = "MdToggleOn"


class MdFaceUnlock(rx.Component):
    library = "react-icons/md"
    tag = "MdFaceUnlock"


class MdBattery20(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery20"


class MdBattery30(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery30"


class MdBattery50(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery50"


class MdBattery60(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery60"


class MdBattery80(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery80"


class MdBattery90(rx.Component):
    library = "react-icons/md"
    tag = "MdBattery90"


class MdBatteryCharging20(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryCharging20"


class MdBatteryCharging30(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryCharging30"


class MdBatteryCharging50(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryCharging50"


class MdBatteryCharging60(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryCharging60"


class MdBatteryCharging80(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryCharging80"


class MdBatteryCharging90(rx.Component):
    library = "react-icons/md"
    tag = "MdBatteryCharging90"


class MdSignalCellular1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellular1Bar"


class MdSignalCellular2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellular2Bar"


class MdSignalCellular3Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellular3Bar"


class MdSignalCellularConnectedNoInternet1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularConnectedNoInternet1Bar"


class MdSignalCellularConnectedNoInternet2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularConnectedNoInternet2Bar"


class MdSignalCellularConnectedNoInternet3Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalCellularConnectedNoInternet3Bar"


class MdSignalWifi1BarLock(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifi1BarLock"


class MdSignalWifi1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifi1Bar"


class MdSignalWifi2BarLock(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifi2BarLock"


class MdSignalWifi2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifi2Bar"


class MdSignalWifi3BarLock(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifi3BarLock"


class MdSignalWifi3Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifi3Bar"


class MdSignalWifiConnectedNoInternet0(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiConnectedNoInternet0"


class MdSignalWifiConnectedNoInternet1(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiConnectedNoInternet1"


class MdSignalWifiConnectedNoInternet2(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiConnectedNoInternet2"


class MdSignalWifiConnectedNoInternet3(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiConnectedNoInternet3"


class MdSignalWifiStatusbar1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbar1Bar"


class MdSignalWifiStatusbar2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbar2Bar"


class MdSignalWifiStatusbar3Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbar3Bar"


class MdSignalWifiStatusbarConnectedNoInternet1(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbarConnectedNoInternet1"


class MdSignalWifiStatusbarConnectedNoInternet2(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbarConnectedNoInternet2"


class MdSignalWifiStatusbarConnectedNoInternet3(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbarConnectedNoInternet3"


class MdSignalWifiStatusbarConnectedNoInternet(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbarConnectedNoInternet"


class MdSignalWifiStatusbarNotConnected(rx.Component):
    library = "react-icons/md"
    tag = "MdSignalWifiStatusbarNotConnected"


class MdWifiCalling1(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiCalling1"


class MdWifiCalling2(rx.Component):
    library = "react-icons/md"
    tag = "MdWifiCalling2"


class MdOutline123(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline123"


class MdOutline3DRotation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline3DRotation"


class MdOutlineAbc(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAbc"


class MdOutlineAccessibilityNew(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccessibilityNew"


class MdOutlineAccessibility(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccessibility"


class MdOutlineAccessibleForward(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccessibleForward"


class MdOutlineAccessible(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccessible"


class MdOutlineAccountBalanceWallet(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccountBalanceWallet"


class MdOutlineAccountBalance(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccountBalance"


class MdOutlineAccountBox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccountBox"


class MdOutlineAccountCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccountCircle"


class MdOutlineAddCard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddCard"


class MdOutlineAddHome(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddHome"


class MdOutlineAddShoppingCart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddShoppingCart"


class MdOutlineAddTask(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddTask"


class MdOutlineAddToDrive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddToDrive"


class MdOutlineAddchart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddchart"


class MdOutlineAdminPanelSettings(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAdminPanelSettings"


class MdOutlineAdsClick(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAdsClick"


class MdOutlineAlarmAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlarmAdd"


class MdOutlineAlarmOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlarmOff"


class MdOutlineAlarmOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlarmOn"


class MdOutlineAlarm(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlarm"


class MdOutlineAllInbox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAllInbox"


class MdOutlineAllOut(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAllOut"


class MdOutlineAnalytics(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAnalytics"


class MdOutlineAnchor(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAnchor"


class MdOutlineAndroid(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAndroid"


class MdOutlineAnnouncement(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAnnouncement"


class MdOutlineApi(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineApi"


class MdOutlineAppBlocking(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAppBlocking"


class MdOutlineAppShortcut(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAppShortcut"


class MdOutlineArrowCircleDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowCircleDown"


class MdOutlineArrowCircleLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowCircleLeft"


class MdOutlineArrowCircleRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowCircleRight"


class MdOutlineArrowCircleUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowCircleUp"


class MdOutlineArrowOutward(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowOutward"


class MdOutlineArrowRightAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowRightAlt"


class MdOutlineArticle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArticle"


class MdOutlineAspectRatio(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAspectRatio"


class MdOutlineAssessment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssessment"


class MdOutlineAssignmentInd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssignmentInd"


class MdOutlineAssignmentLate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssignmentLate"


class MdOutlineAssignmentReturn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssignmentReturn"


class MdOutlineAssignmentReturned(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssignmentReturned"


class MdOutlineAssignmentTurnedIn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssignmentTurnedIn"


class MdOutlineAssignment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssignment"


class MdOutlineAssuredWorkload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssuredWorkload"


class MdOutlineAutorenew(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutorenew"


class MdOutlineBackupTable(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBackupTable"


class MdOutlineBackup(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBackup"


class MdOutlineBalance(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBalance"


class MdOutlineBatchPrediction(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBatchPrediction"


class MdOutlineBookOnline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBookOnline"


class MdOutlineBook(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBook"


class MdOutlineBookmarkAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBookmarkAdd"


class MdOutlineBookmarkAdded(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBookmarkAdded"


class MdOutlineBookmarkBorder(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBookmarkBorder"


class MdOutlineBookmarkRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBookmarkRemove"


class MdOutlineBookmark(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBookmark"


class MdOutlineBookmarks(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBookmarks"


class MdOutlineBrowseGallery(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrowseGallery"


class MdOutlineBugReport(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBugReport"


class MdOutlineBuildCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBuildCircle"


class MdOutlineBuild(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBuild"


class MdOutlineCached(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCached"


class MdOutlineCalendarMonth(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCalendarMonth"


class MdOutlineCalendarToday(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCalendarToday"


class MdOutlineCalendarViewDay(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCalendarViewDay"


class MdOutlineCalendarViewMonth(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCalendarViewMonth"


class MdOutlineCalendarViewWeek(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCalendarViewWeek"


class MdOutlineCameraEnhance(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCameraEnhance"


class MdOutlineCancelScheduleSend(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCancelScheduleSend"


class MdOutlineCardGiftcard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCardGiftcard"


class MdOutlineCardMembership(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCardMembership"


class MdOutlineCardTravel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCardTravel"


class MdOutlineChangeHistory(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChangeHistory"


class MdOutlineCheckCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCheckCircleOutline"


class MdOutlineCheckCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCheckCircle"


class MdOutlineChromeReaderMode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChromeReaderMode"


class MdOutlineCircleNotifications(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCircleNotifications"


class MdOutlineClass(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineClass"


class MdOutlineCloseFullscreen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCloseFullscreen"


class MdOutlineCodeOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCodeOff"


class MdOutlineCode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCode"


class MdOutlineCommentBank(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCommentBank"


class MdOutlineCommit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCommit"


class MdOutlineCommute(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCommute"


class MdOutlineCompareArrows(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCompareArrows"


class MdOutlineCompress(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCompress"


class MdOutlineContactPage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContactPage"


class MdOutlineContactSupport(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContactSupport"


class MdOutlineContactless(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContactless"


class MdOutlineCopyright(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCopyright"


class MdOutlineCreditCardOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCreditCardOff"


class MdOutlineCreditCard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCreditCard"


class MdOutlineCss(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCss"


class MdOutlineCurrencyExchange(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurrencyExchange"


class MdOutlineDangerous(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDangerous"


class MdOutlineDashboardCustomize(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDashboardCustomize"


class MdOutlineDashboard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDashboard"


class MdOutlineDataExploration(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDataExploration"


class MdOutlineDataThresholding(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDataThresholding"


class MdOutlineDateRange(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDateRange"


class MdOutlineDeleteForever(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeleteForever"


class MdOutlineDeleteOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeleteOutline"


class MdOutlineDelete(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDelete"


class MdOutlineDensityLarge(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDensityLarge"


class MdOutlineDensityMedium(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDensityMedium"


class MdOutlineDensitySmall(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDensitySmall"


class MdOutlineDescription(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDescription"


class MdOutlineDisabledByDefault(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDisabledByDefault"


class MdOutlineDisabledVisible(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDisabledVisible"


class MdOutlineDisplaySettings(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDisplaySettings"


class MdOutlineDns(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDns"


class MdOutlineDoneAll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoneAll"


class MdOutlineDoneOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoneOutline"


class MdOutlineDone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDone"


class MdOutlineDonutLarge(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDonutLarge"


class MdOutlineDonutSmall(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDonutSmall"


class MdOutlineDragIndicator(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDragIndicator"


class MdOutlineDynamicForm(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDynamicForm"


class MdOutlineEco(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEco"


class MdOutlineEditCalendar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEditCalendar"


class MdOutlineEditOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEditOff"


class MdOutlineEject(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEject"


class MdOutlineEuroSymbol(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEuroSymbol"


class MdOutlineEventRepeat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEventRepeat"


class MdOutlineEventSeat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEventSeat"


class MdOutlineEvent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEvent"


class MdOutlineExitToApp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExitToApp"


class MdOutlineExpand(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExpand"


class MdOutlineExploreOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExploreOff"


class MdOutlineExplore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExplore"


class MdOutlineExtensionOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExtensionOff"


class MdOutlineExtension(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExtension"


class MdOutlineFaceUnlock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFaceUnlock"


class MdOutlineFace(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFace"


class MdOutlineFactCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFactCheck"


class MdOutlineFavoriteBorder(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFavoriteBorder"


class MdOutlineFavorite(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFavorite"


class MdOutlineFax(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFax"


class MdOutlineFeedback(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFeedback"


class MdOutlineFilePresent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilePresent"


class MdOutlineFilterAltOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterAltOff"


class MdOutlineFilterAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterAlt"


class MdOutlineFindInPage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFindInPage"


class MdOutlineFindReplace(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFindReplace"


class MdOutlineFingerprint(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFingerprint"


class MdOutlineFitScreen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFitScreen"


class MdOutlineFlaky(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlaky"


class MdOutlineFlightLand(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlightLand"


class MdOutlineFlightTakeoff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlightTakeoff"


class MdOutlineFlipToBack(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlipToBack"


class MdOutlineFlipToFront(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlipToFront"


class MdOutlineFlutterDash(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlutterDash"


class MdOutlineFreeCancellation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFreeCancellation"


class MdOutlineGTranslate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGTranslate"


class MdOutlineGavel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGavel"


class MdOutlineGeneratingTokens(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGeneratingTokens"


class MdOutlineGetApp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGetApp"


class MdOutlineGifBox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGifBox"


class MdOutlineGif(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGif"


class MdOutlineGrade(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGrade"


class MdOutlineGrading(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGrading"


class MdOutlineGroupWork(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGroupWork"


class MdOutlineHelpCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHelpCenter"


class MdOutlineHelpOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHelpOutline"


class MdOutlineHelp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHelp"


class MdOutlineHideSource(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHideSource"


class MdOutlineHighlightAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHighlightAlt"


class MdOutlineHighlightOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHighlightOff"


class MdOutlineHistoryToggleOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHistoryToggleOff"


class MdOutlineHistory(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHistory"


class MdOutlineHlsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHlsOff"


class MdOutlineHls(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHls"


class MdOutlineHome(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHome"


class MdOutlineHorizontalSplit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHorizontalSplit"


class MdOutlineHotelClass(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHotelClass"


class MdOutlineHourglassDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHourglassDisabled"


class MdOutlineHourglassEmpty(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHourglassEmpty"


class MdOutlineHourglassFull(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHourglassFull"


class MdOutlineHtml(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHtml"


class MdOutlineHttp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHttp"


class MdOutlineHttps(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHttps"


class MdOutlineImportantDevices(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineImportantDevices"


class MdOutlineInfo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInfo"


class MdOutlineInput(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInput"


class MdOutlineInstallDesktop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInstallDesktop"


class MdOutlineInstallMobile(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInstallMobile"


class MdOutlineIntegrationInstructions(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineIntegrationInstructions"


class MdOutlineInvertColors(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInvertColors"


class MdOutlineJavascript(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineJavascript"


class MdOutlineJoinFull(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineJoinFull"


class MdOutlineJoinInner(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineJoinInner"


class MdOutlineJoinLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineJoinLeft"


class MdOutlineJoinRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineJoinRight"


class MdOutlineLabelImportant(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLabelImportant"


class MdOutlineLabelOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLabelOff"


class MdOutlineLabel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLabel"


class MdOutlineLanguage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLanguage"


class MdOutlineLaunch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLaunch"


class MdOutlineLeaderboard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLeaderboard"


class MdOutlineLightbulbCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLightbulbCircle"


class MdOutlineLightbulb(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLightbulb"


class MdOutlineLineStyle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLineStyle"


class MdOutlineLineWeight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLineWeight"


class MdOutlineList(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineList"


class MdOutlineLockClock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLockClock"


class MdOutlineLockOpen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLockOpen"


class MdOutlineLockPerson(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLockPerson"


class MdOutlineLockReset(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLockReset"


class MdOutlineLock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLock"


class MdOutlineLogin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLogin"


class MdOutlineLogout(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLogout"


class MdOutlineLoyalty(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLoyalty"


class MdOutlineManageAccounts(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineManageAccounts"


class MdOutlineManageHistory(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineManageHistory"


class MdOutlineMarkAsUnread(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMarkAsUnread"


class MdOutlineMarkunreadMailbox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMarkunreadMailbox"


class MdOutlineMaximize(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMaximize"


class MdOutlineMediation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMediation"


class MdOutlineMinimize(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMinimize"


class MdOutlineModelTraining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineModelTraining"


class MdOutlineNetworkPing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNetworkPing"


class MdOutlineNewLabel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNewLabel"


class MdOutlineNextPlan(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNextPlan"


class MdOutlineNightlightRound(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNightlightRound"


class MdOutlineNoAccounts(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoAccounts"


class MdOutlineNoiseAware(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoiseAware"


class MdOutlineNoiseControlOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoiseControlOff"


class MdOutlineNotAccessible(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotAccessible"


class MdOutlineNotStarted(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotStarted"


class MdOutlineNoteAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoteAdd"


class MdOutlineOfflineBolt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOfflineBolt"


class MdOutlineOfflinePin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOfflinePin"


class MdOutlineOnDeviceTraining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOnDeviceTraining"


class MdOutlineOnlinePrediction(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOnlinePrediction"


class MdOutlineOpacity(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOpacity"


class MdOutlineOpenInBrowser(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOpenInBrowser"


class MdOutlineOpenInFull(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOpenInFull"


class MdOutlineOpenInNewOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOpenInNewOff"


class MdOutlineOpenInNew(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOpenInNew"


class MdOutlineOpenWith(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOpenWith"


class MdOutlineOutbond(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOutbond"


class MdOutlineOutbound(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOutbound"


class MdOutlineOutbox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOutbox"


class MdOutlineOutlet(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOutlet"


class MdOutlineOutput(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOutput"


class MdOutlinePageview(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePageview"


class MdOutlinePaid(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePaid"


class MdOutlinePanToolAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanToolAlt"


class MdOutlinePanTool(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanTool"


class MdOutlinePayment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePayment"


class MdOutlinePendingActions(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePendingActions"


class MdOutlinePending(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePending"


class MdOutlinePercent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePercent"


class MdOutlinePermCameraMic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePermCameraMic"


class MdOutlinePermContactCalendar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePermContactCalendar"


class MdOutlinePermDataSetting(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePermDataSetting"


class MdOutlinePermDeviceInformation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePermDeviceInformation"


class MdOutlinePermIdentity(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePermIdentity"


class MdOutlinePermMedia(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePermMedia"


class MdOutlinePermPhoneMsg(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePermPhoneMsg"


class MdOutlinePermScanWifi(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePermScanWifi"


class MdOutlinePets(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePets"


class MdOutlinePhp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhp"


class MdOutlinePictureInPictureAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePictureInPictureAlt"


class MdOutlinePictureInPicture(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePictureInPicture"


class MdOutlinePinEnd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePinEnd"


class MdOutlinePinInvoke(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePinInvoke"


class MdOutlinePinch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePinch"


class MdOutlinePlagiarism(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlagiarism"


class MdOutlinePlayForWork(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlayForWork"


class MdOutlinePolymer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePolymer"


class MdOutlinePowerSettingsNew(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePowerSettingsNew"


class MdOutlinePregnantWoman(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePregnantWoman"


class MdOutlinePreview(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePreview"


class MdOutlinePrint(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePrint"


class MdOutlinePrivacyTip(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePrivacyTip"


class MdOutlinePrivateConnectivity(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePrivateConnectivity"


class MdOutlineProductionQuantityLimits(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineProductionQuantityLimits"


class MdOutlinePublishedWithChanges(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePublishedWithChanges"


class MdOutlineQueryBuilder(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQueryBuilder"


class MdOutlineQuestionAnswer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQuestionAnswer"


class MdOutlineQuestionMark(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQuestionMark"


class MdOutlineQuickreply(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQuickreply"


class MdOutlineReceipt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReceipt"


class MdOutlineRecordVoiceOver(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRecordVoiceOver"


class MdOutlineRedeem(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRedeem"


class MdOutlineRemoveDone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRemoveDone"


class MdOutlineRemoveShoppingCart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRemoveShoppingCart"


class MdOutlineReorder(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReorder"


class MdOutlineRepartition(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRepartition"


class MdOutlineReportProblem(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReportProblem"


class MdOutlineRequestPage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRequestPage"


class MdOutlineRestoreFromTrash(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRestoreFromTrash"


class MdOutlineRestorePage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRestorePage"


class MdOutlineRestore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRestore"


class MdOutlineRocketLaunch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRocketLaunch"


class MdOutlineRocket(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRocket"


class MdOutlineRoom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRoom"


class MdOutlineRoundedCorner(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRoundedCorner"


class MdOutlineRowing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRowing"


class MdOutlineRule(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRule"


class MdOutlineSatelliteAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSatelliteAlt"


class MdOutlineSavedSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSavedSearch"


class MdOutlineSavings(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSavings"


class MdOutlineScheduleSend(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScheduleSend"


class MdOutlineSchedule(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSchedule"


class MdOutlineSearchOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSearchOff"


class MdOutlineSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSearch"


class MdOutlineSegment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSegment"


class MdOutlineSendAndArchive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSendAndArchive"


class MdOutlineSensorsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSensorsOff"


class MdOutlineSensors(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSensors"


class MdOutlineSettingsAccessibility(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsAccessibility"


class MdOutlineSettingsApplications(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsApplications"


class MdOutlineSettingsBackupRestore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsBackupRestore"


class MdOutlineSettingsBluetooth(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsBluetooth"


class MdOutlineSettingsBrightness(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsBrightness"


class MdOutlineSettingsCell(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsCell"


class MdOutlineSettingsEthernet(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsEthernet"


class MdOutlineSettingsInputAntenna(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsInputAntenna"


class MdOutlineSettingsInputComponent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsInputComponent"


class MdOutlineSettingsInputComposite(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsInputComposite"


class MdOutlineSettingsInputHdmi(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsInputHdmi"


class MdOutlineSettingsInputSvideo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsInputSvideo"


class MdOutlineSettingsOverscan(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsOverscan"


class MdOutlineSettingsPhone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsPhone"


class MdOutlineSettingsPower(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsPower"


class MdOutlineSettingsRemote(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsRemote"


class MdOutlineSettingsVoice(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsVoice"


class MdOutlineSettings(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettings"


class MdOutlineShop2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShop2"


class MdOutlineShopTwo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShopTwo"


class MdOutlineShop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShop"


class MdOutlineShoppingBag(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShoppingBag"


class MdOutlineShoppingBasket(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShoppingBasket"


class MdOutlineShoppingCartCheckout(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShoppingCartCheckout"


class MdOutlineShoppingCart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShoppingCart"


class MdOutlineSmartButton(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSmartButton"


class MdOutlineSource(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSource"


class MdOutlineSpaceDashboard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpaceDashboard"


class MdOutlineSpatialAudioOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpatialAudioOff"


class MdOutlineSpatialAudio(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpatialAudio"


class MdOutlineSpatialTracking(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpatialTracking"


class MdOutlineSpeakerNotesOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpeakerNotesOff"


class MdOutlineSpeakerNotes(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpeakerNotes"


class MdOutlineSpellcheck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpellcheck"


class MdOutlineStarRate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStarRate"


class MdOutlineStars(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStars"


class MdOutlineStickyNote2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStickyNote2"


class MdOutlineStore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStore"


class MdOutlineSubject(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSubject"


class MdOutlineSubtitlesOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSubtitlesOff"


class MdOutlineSupervisedUserCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSupervisedUserCircle"


class MdOutlineSupervisorAccount(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSupervisorAccount"


class MdOutlineSupport(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSupport"


class MdOutlineSwapHoriz(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwapHoriz"


class MdOutlineSwapHorizontalCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwapHorizontalCircle"


class MdOutlineSwapVert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwapVert"


class MdOutlineSwapVerticalCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwapVerticalCircle"


class MdOutlineSwipeDownAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipeDownAlt"


class MdOutlineSwipeDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipeDown"


class MdOutlineSwipeLeftAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipeLeftAlt"


class MdOutlineSwipeLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipeLeft"


class MdOutlineSwipeRightAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipeRightAlt"


class MdOutlineSwipeRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipeRight"


class MdOutlineSwipeUpAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipeUpAlt"


class MdOutlineSwipeUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipeUp"


class MdOutlineSwipeVertical(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipeVertical"


class MdOutlineSwipe(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwipe"


class MdOutlineSwitchAccessShortcutAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwitchAccessShortcutAdd"


class MdOutlineSwitchAccessShortcut(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwitchAccessShortcut"


class MdOutlineSyncAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSyncAlt"


class MdOutlineSystemUpdateAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSystemUpdateAlt"


class MdOutlineTabUnselected(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTabUnselected"


class MdOutlineTab(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTab"


class MdOutlineTableView(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTableView"


class MdOutlineTaskAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTaskAlt"


class MdOutlineTerminal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTerminal"


class MdOutlineTextRotateUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextRotateUp"


class MdOutlineTextRotateVertical(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextRotateVertical"


class MdOutlineTextRotationAngledown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextRotationAngledown"


class MdOutlineTextRotationAngleup(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextRotationAngleup"


class MdOutlineTextRotationDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextRotationDown"


class MdOutlineTextRotationNone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextRotationNone"


class MdOutlineTheaters(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTheaters"


class MdOutlineThumbDownOffAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThumbDownOffAlt"


class MdOutlineThumbDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThumbDown"


class MdOutlineThumbUpOffAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThumbUpOffAlt"


class MdOutlineThumbUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThumbUp"


class MdOutlineThumbsUpDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThumbsUpDown"


class MdOutlineTimeline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTimeline"


class MdOutlineTipsAndUpdates(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTipsAndUpdates"


class MdOutlineToc(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineToc"


class MdOutlineToday(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineToday"


class MdOutlineToken(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineToken"


class MdOutlineToll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineToll"


class MdOutlineTouchApp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTouchApp"


class MdOutlineTour(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTour"


class MdOutlineTrackChanges(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTrackChanges"


class MdOutlineTranscribe(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTranscribe"


class MdOutlineTranslate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTranslate"


class MdOutlineTrendingDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTrendingDown"


class MdOutlineTrendingFlat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTrendingFlat"


class MdOutlineTrendingUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTrendingUp"


class MdOutlineTroubleshoot(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTroubleshoot"


class MdOutlineTry(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTry"


class MdOutlineTurnedInNot(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTurnedInNot"


class MdOutlineTurnedIn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTurnedIn"


class MdOutlineUnfoldLessDouble(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUnfoldLessDouble"


class MdOutlineUnfoldMoreDouble(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUnfoldMoreDouble"


class MdOutlineUnpublished(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUnpublished"


class MdOutlineUpdateDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUpdateDisabled"


class MdOutlineUpdate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUpdate"


class MdOutlineUpgrade(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUpgrade"


class MdOutlineVerifiedUser(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVerifiedUser"


class MdOutlineVerified(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVerified"


class MdOutlineVerticalSplit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVerticalSplit"


class MdOutlineViewAgenda(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewAgenda"


class MdOutlineViewArray(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewArray"


class MdOutlineViewCarousel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewCarousel"


class MdOutlineViewColumn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewColumn"


class MdOutlineViewComfyAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewComfyAlt"


class MdOutlineViewCompactAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewCompactAlt"


class MdOutlineViewCozy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewCozy"


class MdOutlineViewDay(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewDay"


class MdOutlineViewHeadline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewHeadline"


class MdOutlineViewInAr(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewInAr"


class MdOutlineViewKanban(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewKanban"


class MdOutlineViewList(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewList"


class MdOutlineViewModule(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewModule"


class MdOutlineViewQuilt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewQuilt"


class MdOutlineViewSidebar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewSidebar"


class MdOutlineViewStream(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewStream"


class MdOutlineViewTimeline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewTimeline"


class MdOutlineViewWeek(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewWeek"


class MdOutlineVisibilityOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVisibilityOff"


class MdOutlineVisibility(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVisibility"


class MdOutlineVoiceOverOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVoiceOverOff"


class MdOutlineWatchLater(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWatchLater"


class MdOutlineWebhook(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWebhook"


class MdOutlineWidthFull(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWidthFull"


class MdOutlineWidthNormal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWidthNormal"


class MdOutlineWidthWide(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWidthWide"


class MdOutlineWifiProtectedSetup(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiProtectedSetup"


class MdOutlineWorkHistory(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWorkHistory"


class MdOutlineWorkOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWorkOff"


class MdOutlineWorkOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWorkOutline"


class MdOutlineWork(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWork"


class MdOutlineWysiwyg(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWysiwyg"


class MdOutlineYoutubeSearchedFor(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineYoutubeSearchedFor"


class MdOutlineZoomIn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineZoomIn"


class MdOutlineZoomOut(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineZoomOut"


class MdOutlineAddAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddAlert"


class MdOutlineAutoDelete(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoDelete"


class MdOutlineErrorOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineErrorOutline"


class MdOutlineError(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineError"


class MdOutlineNotificationImportant(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotificationImportant"


class MdOutlineWarningAmber(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWarningAmber"


class MdOutlineWarning(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWarning"


class MdOutline10K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline10K"


class MdOutline1KPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline1KPlus"


class MdOutline1K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline1K"


class MdOutline2KPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline2KPlus"


class MdOutline2K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline2K"


class MdOutline3KPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline3KPlus"


class MdOutline3K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline3K"


class MdOutline4KPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline4KPlus"


class MdOutline4K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline4K"


class MdOutline5G(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline5G"


class MdOutline5KPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline5KPlus"


class MdOutline5K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline5K"


class MdOutline6KPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline6KPlus"


class MdOutline6K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline6K"


class MdOutline7KPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline7KPlus"


class MdOutline7K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline7K"


class MdOutline8KPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline8KPlus"


class MdOutline8K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline8K"


class MdOutline9KPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline9KPlus"


class MdOutline9K(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline9K"


class MdOutlineAddToQueue(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddToQueue"


class MdOutlineAirplay(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirplay"


class MdOutlineAlbum(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlbum"


class MdOutlineArtTrack(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArtTrack"


class MdOutlineAudioFile(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAudioFile"


class MdOutlineAvTimer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAvTimer"


class MdOutlineBrandingWatermark(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrandingWatermark"


class MdOutlineCallToAction(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCallToAction"


class MdOutlineClosedCaptionDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineClosedCaptionDisabled"


class MdOutlineClosedCaptionOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineClosedCaptionOff"


class MdOutlineClosedCaption(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineClosedCaption"


class MdOutlineControlCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineControlCamera"


class MdOutlineEqualizer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEqualizer"


class MdOutlineExplicit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExplicit"


class MdOutlineFastForward(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFastForward"


class MdOutlineFastRewind(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFastRewind"


class MdOutlineFeaturedPlayList(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFeaturedPlayList"


class MdOutlineFeaturedVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFeaturedVideo"


class MdOutlineFiberDvr(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFiberDvr"


class MdOutlineFiberManualRecord(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFiberManualRecord"


class MdOutlineFiberNew(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFiberNew"


class MdOutlineFiberPin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFiberPin"


class MdOutlineFiberSmartRecord(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFiberSmartRecord"


class MdOutlineForward10(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineForward10"


class MdOutlineForward30(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineForward30"


class MdOutlineForward5(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineForward5"


class MdOutlineGames(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGames"


class MdOutlineHd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHd"


class MdOutlineHearingDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHearingDisabled"


class MdOutlineHearing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHearing"


class MdOutlineHighQuality(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHighQuality"


class MdOutlineInterpreterMode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInterpreterMode"


class MdOutlineLibraryAddCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLibraryAddCheck"


class MdOutlineLibraryAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLibraryAdd"


class MdOutlineLibraryBooks(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLibraryBooks"


class MdOutlineLibraryMusic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLibraryMusic"


class MdOutlineLoop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLoop"


class MdOutlineLyrics(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLyrics"


class MdOutlineMicNone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMicNone"


class MdOutlineMicOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMicOff"


class MdOutlineMic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMic"


class MdOutlineMissedVideoCall(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMissedVideoCall"


class MdOutlineMovie(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMovie"


class MdOutlineMusicVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMusicVideo"


class MdOutlineNewReleases(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNewReleases"


class MdOutlineNotInterested(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotInterested"


class MdOutlineNote(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNote"


class MdOutlinePauseCircleFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePauseCircleFilled"


class MdOutlinePauseCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePauseCircleOutline"


class MdOutlinePauseCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePauseCircle"


class MdOutlinePause(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePause"


class MdOutlinePlayArrow(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlayArrow"


class MdOutlinePlayCircleFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlayCircleFilled"


class MdOutlinePlayCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlayCircleOutline"


class MdOutlinePlayCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlayCircle"


class MdOutlinePlayDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlayDisabled"


class MdOutlinePlaylistAddCheckCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlaylistAddCheckCircle"


class MdOutlinePlaylistAddCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlaylistAddCheck"


class MdOutlinePlaylistAddCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlaylistAddCircle"


class MdOutlinePlaylistAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlaylistAdd"


class MdOutlinePlaylistPlay(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlaylistPlay"


class MdOutlinePlaylistRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlaylistRemove"


class MdOutlineQueueMusic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQueueMusic"


class MdOutlineQueuePlayNext(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQueuePlayNext"


class MdOutlineQueue(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQueue"


class MdOutlineRadio(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRadio"


class MdOutlineRecentActors(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRecentActors"


class MdOutlineRemoveFromQueue(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRemoveFromQueue"


class MdOutlineRepeatOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRepeatOn"


class MdOutlineRepeatOneOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRepeatOneOn"


class MdOutlineRepeatOne(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRepeatOne"


class MdOutlineRepeat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRepeat"


class MdOutlineReplay10(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReplay10"


class MdOutlineReplay30(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReplay30"


class MdOutlineReplay5(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReplay5"


class MdOutlineReplayCircleFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReplayCircleFilled"


class MdOutlineReplay(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReplay"


class MdOutlineSd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSd"


class MdOutlineShuffleOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShuffleOn"


class MdOutlineShuffle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShuffle"


class MdOutlineSkipNext(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSkipNext"


class MdOutlineSkipPrevious(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSkipPrevious"


class MdOutlineSlowMotionVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSlowMotionVideo"


class MdOutlineSnooze(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSnooze"


class MdOutlineSortByAlpha(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSortByAlpha"


class MdOutlineSpeed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpeed"


class MdOutlineStopCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStopCircle"


class MdOutlineStop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStop"


class MdOutlineSubscriptions(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSubscriptions"


class MdOutlineSubtitles(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSubtitles"


class MdOutlineSurroundSound(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSurroundSound"


class MdOutlineVideoCall(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideoCall"


class MdOutlineVideoFile(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideoFile"


class MdOutlineVideoLabel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideoLabel"


class MdOutlineVideoLibrary(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideoLibrary"


class MdOutlineVideoSettings(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideoSettings"


class MdOutlineVideocamOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideocamOff"


class MdOutlineVideocam(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideocam"


class MdOutlineVolumeDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVolumeDown"


class MdOutlineVolumeMute(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVolumeMute"


class MdOutlineVolumeOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVolumeOff"


class MdOutlineVolumeUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVolumeUp"


class MdOutlineWebAssetOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWebAssetOff"


class MdOutlineWebAsset(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWebAsset"


class MdOutlineWeb(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWeb"


class MdOutline3P(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline3P"


class MdOutlineAddIcCall(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddIcCall"


class MdOutlineAlternateEmail(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlternateEmail"


class MdOutlineAppRegistration(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAppRegistration"


class MdOutlineBusiness(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBusiness"


class MdOutlineCallEnd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCallEnd"


class MdOutlineCallMade(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCallMade"


class MdOutlineCallMerge(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCallMerge"


class MdOutlineCallMissedOutgoing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCallMissedOutgoing"


class MdOutlineCallMissed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCallMissed"


class MdOutlineCallReceived(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCallReceived"


class MdOutlineCallSplit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCallSplit"


class MdOutlineCall(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCall"


class MdOutlineCancelPresentation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCancelPresentation"


class MdOutlineCellTower(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCellTower"


class MdOutlineCellWifi(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCellWifi"


class MdOutlineChatBubbleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChatBubbleOutline"


class MdOutlineChatBubble(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChatBubble"


class MdOutlineChat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChat"


class MdOutlineClearAll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineClearAll"


class MdOutlineCoPresent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCoPresent"


class MdOutlineComment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineComment"


class MdOutlineCommentsDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCommentsDisabled"


class MdOutlineContactEmergency(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContactEmergency"


class MdOutlineContactMail(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContactMail"


class MdOutlineContactPhone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContactPhone"


class MdOutlineContacts(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContacts"


class MdOutlineDesktopAccessDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDesktopAccessDisabled"


class MdOutlineDialerSip(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDialerSip"


class MdOutlineDialpad(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDialpad"


class MdOutlineDocumentScanner(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDocumentScanner"


class MdOutlineDomainDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDomainDisabled"


class MdOutlineDomainVerification(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDomainVerification"


class MdOutlineDuo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDuo"


class MdOutlineEmail(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmail"


class MdOutlineForum(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineForum"


class MdOutlineForwardToInbox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineForwardToInbox"


class MdOutlineHourglassBottom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHourglassBottom"


class MdOutlineHourglassTop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHourglassTop"


class MdOutlineHub(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHub"


class MdOutlineImportContacts(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineImportContacts"


class MdOutlineImportExport(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineImportExport"


class MdOutlineInvertColorsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInvertColorsOff"


class MdOutlineKeyOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyOff"


class MdOutlineKey(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKey"


class MdOutlineListAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineListAlt"


class MdOutlineLiveHelp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLiveHelp"


class MdOutlineLocationOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocationOff"


class MdOutlineLocationOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocationOn"


class MdOutlineMailLock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMailLock"


class MdOutlineMailOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMailOutline"


class MdOutlineMarkChatRead(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMarkChatRead"


class MdOutlineMarkChatUnread(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMarkChatUnread"


class MdOutlineMarkEmailRead(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMarkEmailRead"


class MdOutlineMarkEmailUnread(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMarkEmailUnread"


class MdOutlineMarkUnreadChatAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMarkUnreadChatAlt"


class MdOutlineMessage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMessage"


class MdOutlineMobileScreenShare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMobileScreenShare"


class MdOutlineMoreTime(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoreTime"


class MdOutlineNat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNat"


class MdOutlineNoSim(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoSim"


class MdOutlinePausePresentation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePausePresentation"


class MdOutlinePersonAddDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonAddDisabled"


class MdOutlinePersonSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonSearch"


class MdOutlinePhoneDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneDisabled"


class MdOutlinePhoneEnabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneEnabled"


class MdOutlinePhone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhone"


class MdOutlinePhonelinkErase(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhonelinkErase"


class MdOutlinePhonelinkLock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhonelinkLock"


class MdOutlinePhonelinkRing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhonelinkRing"


class MdOutlinePhonelinkSetup(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhonelinkSetup"


class MdOutlinePortableWifiOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePortableWifiOff"


class MdOutlinePresentToAll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePresentToAll"


class MdOutlinePrintDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePrintDisabled"


class MdOutlineQrCode2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQrCode2"


class MdOutlineQrCodeScanner(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQrCodeScanner"


class MdOutlineQrCode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQrCode"


class MdOutlineReadMore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReadMore"


class MdOutlineRingVolume(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRingVolume"


class MdOutlineRssFeed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRssFeed"


class MdOutlineRtt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRtt"


class MdOutlineScreenShare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScreenShare"


class MdOutlineSendTimeExtension(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSendTimeExtension"


class MdOutlineSentimentSatisfiedAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSentimentSatisfiedAlt"


class MdOutlineSip(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSip"


class MdOutlineSpeakerPhone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpeakerPhone"


class MdOutlineSpoke(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpoke"


class MdOutlineStayCurrentLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStayCurrentLandscape"


class MdOutlineStayCurrentPortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStayCurrentPortrait"


class MdOutlineStayPrimaryLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStayPrimaryLandscape"


class MdOutlineStayPrimaryPortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStayPrimaryPortrait"


class MdOutlineStopScreenShare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStopScreenShare"


class MdOutlineSwapCalls(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwapCalls"


class MdOutlineTextsms(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextsms"


class MdOutlineUnsubscribe(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUnsubscribe"


class MdOutlineVoicemail(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVoicemail"


class MdOutlineVpnKeyOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVpnKeyOff"


class MdOutlineVpnKey(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVpnKey"


class MdOutlineWifiCalling(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiCalling"


class MdOutlineAddBox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddBox"


class MdOutlineAddCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddCircleOutline"


class MdOutlineAddCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddCircle"


class MdOutlineAddLink(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddLink"


class MdOutlineAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAdd"


class MdOutlineAmpStories(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAmpStories"


class MdOutlineArchive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArchive"


class MdOutlineAttribution(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAttribution"


class MdOutlineBackspace(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBackspace"


class MdOutlineBallot(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBallot"


class MdOutlineBiotech(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBiotech"


class MdOutlineBlock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBlock"


class MdOutlineBolt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBolt"


class MdOutlineCalculate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCalculate"


class MdOutlineChangeCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChangeCircle"


class MdOutlineClear(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineClear"


class MdOutlineContentCopy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContentCopy"


class MdOutlineContentCut(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContentCut"


class MdOutlineContentPasteGo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContentPasteGo"


class MdOutlineContentPasteOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContentPasteOff"


class MdOutlineContentPasteSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContentPasteSearch"


class MdOutlineContentPaste(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContentPaste"


class MdOutlineCopyAll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCopyAll"


class MdOutlineCreate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCreate"


class MdOutlineDeleteSweep(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeleteSweep"


class MdOutlineDeselect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeselect"


class MdOutlineDrafts(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDrafts"


class MdOutlineDynamicFeed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDynamicFeed"


class MdOutlineFileCopy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFileCopy"


class MdOutlineFilterListOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterListOff"


class MdOutlineFilterList(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterList"


class MdOutlineFlagCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlagCircle"


class MdOutlineFlag(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlag"


class MdOutlineFontDownloadOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFontDownloadOff"


class MdOutlineFontDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFontDownload"


class MdOutlineForward(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineForward"


class MdOutlineGesture(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGesture"


class MdOutlineHowToReg(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHowToReg"


class MdOutlineHowToVote(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHowToVote"


class MdOutlineInbox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInbox"


class MdOutlineInsights(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsights"


class MdOutlineInventory2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInventory2"


class MdOutlineInventory(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInventory"


class MdOutlineLinkOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLinkOff"


class MdOutlineLink(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLink"


class MdOutlineLowPriority(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLowPriority"


class MdOutlineMail(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMail"


class MdOutlineMarkunread(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMarkunread"


class MdOutlineMoveToInbox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoveToInbox"


class MdOutlineNextWeek(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNextWeek"


class MdOutlineOutlinedFlag(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOutlinedFlag"


class MdOutlinePolicy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePolicy"


class MdOutlinePushPin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePushPin"


class MdOutlineRedo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRedo"


class MdOutlineRemoveCircleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRemoveCircleOutline"


class MdOutlineRemoveCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRemoveCircle"


class MdOutlineRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRemove"


class MdOutlineReplyAll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReplyAll"


class MdOutlineReply(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReply"


class MdOutlineReportGmailerrorred(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReportGmailerrorred"


class MdOutlineReportOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReportOff"


class MdOutlineReport(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReport"


class MdOutlineSaveAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSaveAlt"


class MdOutlineSaveAs(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSaveAs"


class MdOutlineSave(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSave"


class MdOutlineSelectAll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSelectAll"


class MdOutlineSend(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSend"


class MdOutlineShield(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShield"


class MdOutlineSort(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSort"


class MdOutlineSquareFoot(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSquareFoot"


class MdOutlineStackedBarChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStackedBarChart"


class MdOutlineStream(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStream"


class MdOutlineTag(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTag"


class MdOutlineTextFormat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextFormat"


class MdOutlineUnarchive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUnarchive"


class MdOutlineUndo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUndo"


class MdOutlineUpcoming(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUpcoming"


class MdOutlineWaves(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWaves"


class MdOutlineWebStories(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWebStories"


class MdOutlineWeekend(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWeekend"


class MdOutlineWhereToVote(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWhereToVote"


class MdOutline1XMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline1XMobiledata"


class MdOutline30Fps(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline30Fps"


class MdOutline3GMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline3GMobiledata"


class MdOutline4GMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline4GMobiledata"


class MdOutline4GPlusMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline4GPlusMobiledata"


class MdOutline60Fps(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline60Fps"


class MdOutlineAccessAlarm(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccessAlarm"


class MdOutlineAccessAlarms(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccessAlarms"


class MdOutlineAccessTimeFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccessTimeFilled"


class MdOutlineAccessTime(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccessTime"


class MdOutlineAdUnits(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAdUnits"


class MdOutlineAddAlarm(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddAlarm"


class MdOutlineAddToHomeScreen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddToHomeScreen"


class MdOutlineAir(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAir"


class MdOutlineAirplaneTicket(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirplaneTicket"


class MdOutlineAirplanemodeActive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirplanemodeActive"


class MdOutlineAirplanemodeInactive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirplanemodeInactive"


class MdOutlineAod(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAod"


class MdOutlineBattery0Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBattery0Bar"


class MdOutlineBattery1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBattery1Bar"


class MdOutlineBattery2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBattery2Bar"


class MdOutlineBattery3Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBattery3Bar"


class MdOutlineBattery4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBattery4Bar"


class MdOutlineBattery5Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBattery5Bar"


class MdOutlineBattery6Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBattery6Bar"


class MdOutlineBatteryAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBatteryAlert"


class MdOutlineBatteryChargingFull(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBatteryChargingFull"


class MdOutlineBatteryFull(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBatteryFull"


class MdOutlineBatterySaver(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBatterySaver"


class MdOutlineBatteryStd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBatteryStd"


class MdOutlineBatteryUnknown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBatteryUnknown"


class MdOutlineBloodtype(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBloodtype"


class MdOutlineBluetoothConnected(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBluetoothConnected"


class MdOutlineBluetoothDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBluetoothDisabled"


class MdOutlineBluetoothDrive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBluetoothDrive"


class MdOutlineBluetoothSearching(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBluetoothSearching"


class MdOutlineBluetooth(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBluetooth"


class MdOutlineBrightnessAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightnessAuto"


class MdOutlineBrightnessHigh(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightnessHigh"


class MdOutlineBrightnessLow(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightnessLow"


class MdOutlineBrightnessMedium(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightnessMedium"


class MdOutlineCable(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCable"


class MdOutlineCameraswitch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCameraswitch"


class MdOutlineCreditScore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCreditScore"


class MdOutlineDarkMode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDarkMode"


class MdOutlineDataSaverOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDataSaverOff"


class MdOutlineDataSaverOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDataSaverOn"


class MdOutlineDataUsage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDataUsage"


class MdOutlineDatasetLinked(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDatasetLinked"


class MdOutlineDataset(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDataset"


class MdOutlineDeveloperMode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeveloperMode"


class MdOutlineDeviceThermostat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeviceThermostat"


class MdOutlineDevicesFold(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDevicesFold"


class MdOutlineDevices(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDevices"


class MdOutlineDiscount(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDiscount"


class MdOutlineDoNotDisturbOnTotalSilence(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoNotDisturbOnTotalSilence"


class MdOutlineDvr(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDvr"


class MdOutlineEMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEMobiledata"


class MdOutlineEdgesensorHigh(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEdgesensorHigh"


class MdOutlineEdgesensorLow(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEdgesensorLow"


class MdOutlineFlashlightOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlashlightOff"


class MdOutlineFlashlightOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlashlightOn"


class MdOutlineFlourescent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlourescent"


class MdOutlineFluorescent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFluorescent"


class MdOutlineFmdBad(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFmdBad"


class MdOutlineFmdGood(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFmdGood"


class MdOutlineGMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGMobiledata"


class MdOutlineGppBad(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGppBad"


class MdOutlineGppGood(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGppGood"


class MdOutlineGppMaybe(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGppMaybe"


class MdOutlineGpsFixed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGpsFixed"


class MdOutlineGpsNotFixed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGpsNotFixed"


class MdOutlineGpsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGpsOff"


class MdOutlineGraphicEq(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGraphicEq"


class MdOutlineGrid3X3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGrid3X3"


class MdOutlineGrid4X4(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGrid4X4"


class MdOutlineGridGoldenratio(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGridGoldenratio"


class MdOutlineHMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHMobiledata"


class MdOutlineHPlusMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHPlusMobiledata"


class MdOutlineHdrAutoSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrAutoSelect"


class MdOutlineHdrAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrAuto"


class MdOutlineHdrOffSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrOffSelect"


class MdOutlineHdrOnSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrOnSelect"


class MdOutlineLan(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLan"


class MdOutlineLensBlur(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLensBlur"


class MdOutlineLightMode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLightMode"


class MdOutlineLocationDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocationDisabled"


class MdOutlineLocationSearching(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocationSearching"


class MdOutlineLteMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLteMobiledata"


class MdOutlineLtePlusMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLtePlusMobiledata"


class MdOutlineMacroOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMacroOff"


class MdOutlineMediaBluetoothOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMediaBluetoothOff"


class MdOutlineMediaBluetoothOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMediaBluetoothOn"


class MdOutlineMedicationLiquid(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMedicationLiquid"


class MdOutlineMedication(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMedication"


class MdOutlineMobileFriendly(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMobileFriendly"


class MdOutlineMobileOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMobileOff"


class MdOutlineMobiledataOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMobiledataOff"


class MdOutlineModeNight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineModeNight"


class MdOutlineModeStandby(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineModeStandby"


class MdOutlineMonitorHeart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMonitorHeart"


class MdOutlineMonitorWeight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMonitorWeight"


class MdOutlineNearbyError(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNearbyError"


class MdOutlineNearbyOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNearbyOff"


class MdOutlineNetworkCell(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNetworkCell"


class MdOutlineNetworkWifi1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNetworkWifi1Bar"


class MdOutlineNetworkWifi2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNetworkWifi2Bar"


class MdOutlineNetworkWifi3Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNetworkWifi3Bar"


class MdOutlineNetworkWifi(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNetworkWifi"


class MdOutlineNfc(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNfc"


class MdOutlineNightlight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNightlight"


class MdOutlineNoteAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoteAlt"


class MdOutlinePassword(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePassword"


class MdOutlinePattern(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePattern"


class MdOutlinePhishing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhishing"


class MdOutlinePin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePin"


class MdOutlinePlayLesson(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlayLesson"


class MdOutlinePriceChange(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePriceChange"


class MdOutlinePriceCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePriceCheck"


class MdOutlinePunchClock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePunchClock"


class MdOutlineQuiz(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQuiz"


class MdOutlineRMobiledata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRMobiledata"


class MdOutlineRadar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRadar"


class MdOutlineRememberMe(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRememberMe"


class MdOutlineResetTv(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineResetTv"


class MdOutlineRestartAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRestartAlt"


class MdOutlineReviews(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReviews"


class MdOutlineRsvp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRsvp"


class MdOutlineScreenLockLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScreenLockLandscape"


class MdOutlineScreenLockPortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScreenLockPortrait"


class MdOutlineScreenLockRotation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScreenLockRotation"


class MdOutlineScreenRotation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScreenRotation"


class MdOutlineScreenSearchDesktop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScreenSearchDesktop"


class MdOutlineScreenshotMonitor(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScreenshotMonitor"


class MdOutlineScreenshot(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScreenshot"


class MdOutlineSdStorage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSdStorage"


class MdOutlineSecurityUpdateGood(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSecurityUpdateGood"


class MdOutlineSecurityUpdateWarning(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSecurityUpdateWarning"


class MdOutlineSecurityUpdate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSecurityUpdate"


class MdOutlineSell(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSell"


class MdOutlineSendToMobile(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSendToMobile"


class MdOutlineSettingsSuggest(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsSuggest"


class MdOutlineSettingsSystemDaydream(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSettingsSystemDaydream"


class MdOutlineShareLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShareLocation"


class MdOutlineShortcut(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShortcut"


class MdOutlineSignalCellular0Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellular0Bar"


class MdOutlineSignalCellular4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellular4Bar"


class MdOutlineSignalCellularAlt1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellularAlt1Bar"


class MdOutlineSignalCellularAlt2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellularAlt2Bar"


class MdOutlineSignalCellularAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellularAlt"


class MdOutlineSignalCellularConnectedNoInternet0Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellularConnectedNoInternet0Bar"


class MdOutlineSignalCellularConnectedNoInternet4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellularConnectedNoInternet4Bar"


class MdOutlineSignalCellularNoSim(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellularNoSim"


class MdOutlineSignalCellularNodata(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellularNodata"


class MdOutlineSignalCellularNull(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellularNull"


class MdOutlineSignalCellularOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalCellularOff"


class MdOutlineSignalWifi0Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalWifi0Bar"


class MdOutlineSignalWifi4BarLock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalWifi4BarLock"


class MdOutlineSignalWifi4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalWifi4Bar"


class MdOutlineSignalWifiBad(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalWifiBad"


class MdOutlineSignalWifiConnectedNoInternet4(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalWifiConnectedNoInternet4"


class MdOutlineSignalWifiOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalWifiOff"


class MdOutlineSignalWifiStatusbar4Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalWifiStatusbar4Bar"


class MdOutlineSignalWifiStatusbarConnectedNoInternet4(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalWifiStatusbarConnectedNoInternet4"


class MdOutlineSignalWifiStatusbarNull(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignalWifiStatusbarNull"


class MdOutlineSimCardDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSimCardDownload"


class MdOutlineSplitscreen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSplitscreen"


class MdOutlineSportsScore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsScore"


class MdOutlineSsidChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSsidChart"


class MdOutlineStorage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStorage"


class MdOutlineStorm(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStorm"


class MdOutlineSummarize(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSummarize"


class MdOutlineSystemSecurityUpdateGood(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSystemSecurityUpdateGood"


class MdOutlineSystemSecurityUpdateWarning(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSystemSecurityUpdateWarning"


class MdOutlineSystemSecurityUpdate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSystemSecurityUpdate"


class MdOutlineTask(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTask"


class MdOutlineThermostat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThermostat"


class MdOutlineTimer10Select(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTimer10Select"


class MdOutlineTimer3Select(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTimer3Select"


class MdOutlineTungsten(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTungsten"


class MdOutlineUsbOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUsbOff"


class MdOutlineUsb(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUsb"


class MdOutlineWallpaper(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWallpaper"


class MdOutlineWater(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWater"


class MdOutlineWidgets(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWidgets"


class MdOutlineWifi1Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifi1Bar"


class MdOutlineWifi2Bar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifi2Bar"


class MdOutlineWifiCalling3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiCalling3"


class MdOutlineWifiChannel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiChannel"


class MdOutlineWifiFind(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiFind"


class MdOutlineWifiLock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiLock"


class MdOutlineWifiPassword(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiPassword"


class MdOutlineWifiTetheringErrorRounded(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiTetheringErrorRounded"


class MdOutlineWifiTetheringError(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiTetheringError"


class MdOutlineWifiTetheringOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiTetheringOff"


class MdOutlineWifiTethering(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiTethering"


class MdOutlineAddChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddChart"


class MdOutlineAddComment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddComment"


class MdOutlineAlignHorizontalCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlignHorizontalCenter"


class MdOutlineAlignHorizontalLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlignHorizontalLeft"


class MdOutlineAlignHorizontalRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlignHorizontalRight"


class MdOutlineAlignVerticalBottom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlignVerticalBottom"


class MdOutlineAlignVerticalCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlignVerticalCenter"


class MdOutlineAlignVerticalTop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAlignVerticalTop"


class MdOutlineAreaChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAreaChart"


class MdOutlineAttachFile(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAttachFile"


class MdOutlineAttachMoney(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAttachMoney"


class MdOutlineAutoGraph(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoGraph"


class MdOutlineBarChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBarChart"


class MdOutlineBorderAll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderAll"


class MdOutlineBorderBottom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderBottom"


class MdOutlineBorderClear(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderClear"


class MdOutlineBorderColor(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderColor"


class MdOutlineBorderHorizontal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderHorizontal"


class MdOutlineBorderInner(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderInner"


class MdOutlineBorderLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderLeft"


class MdOutlineBorderOuter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderOuter"


class MdOutlineBorderRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderRight"


class MdOutlineBorderStyle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderStyle"


class MdOutlineBorderTop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderTop"


class MdOutlineBorderVertical(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBorderVertical"


class MdOutlineBubbleChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBubbleChart"


class MdOutlineCandlestickChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCandlestickChart"


class MdOutlineChecklistRtl(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChecklistRtl"


class MdOutlineChecklist(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChecklist"


class MdOutlineDataArray(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDataArray"


class MdOutlineDataObject(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDataObject"


class MdOutlineDragHandle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDragHandle"


class MdOutlineDraw(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDraw"


class MdOutlineEditNote(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEditNote"


class MdOutlineFormatAlignCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatAlignCenter"


class MdOutlineFormatAlignJustify(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatAlignJustify"


class MdOutlineFormatAlignLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatAlignLeft"


class MdOutlineFormatAlignRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatAlignRight"


class MdOutlineFormatBold(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatBold"


class MdOutlineFormatClear(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatClear"


class MdOutlineFormatColorFill(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatColorFill"


class MdOutlineFormatColorReset(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatColorReset"


class MdOutlineFormatColorText(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatColorText"


class MdOutlineFormatIndentDecrease(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatIndentDecrease"


class MdOutlineFormatIndentIncrease(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatIndentIncrease"


class MdOutlineFormatItalic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatItalic"


class MdOutlineFormatLineSpacing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatLineSpacing"


class MdOutlineFormatListBulleted(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatListBulleted"


class MdOutlineFormatListNumberedRtl(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatListNumberedRtl"


class MdOutlineFormatListNumbered(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatListNumbered"


class MdOutlineFormatPaint(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatPaint"


class MdOutlineFormatQuote(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatQuote"


class MdOutlineFormatShapes(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatShapes"


class MdOutlineFormatSize(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatSize"


class MdOutlineFormatStrikethrough(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatStrikethrough"


class MdOutlineFormatTextdirectionLToR(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatTextdirectionLToR"


class MdOutlineFormatTextdirectionRToL(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatTextdirectionRToL"


class MdOutlineFormatUnderlined(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatUnderlined"


class MdOutlineFunctions(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFunctions"


class MdOutlineHeight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHeight"


class MdOutlineHexagon(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHexagon"


class MdOutlineHighlight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHighlight"


class MdOutlineHorizontalDistribute(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHorizontalDistribute"


class MdOutlineHorizontalRule(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHorizontalRule"


class MdOutlineInsertChartOutlined(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsertChartOutlined"


class MdOutlineInsertChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsertChart"


class MdOutlineInsertComment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsertComment"


class MdOutlineInsertDriveFile(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsertDriveFile"


class MdOutlineInsertEmoticon(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsertEmoticon"


class MdOutlineInsertInvitation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsertInvitation"


class MdOutlineInsertLink(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsertLink"


class MdOutlineInsertPageBreak(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsertPageBreak"


class MdOutlineInsertPhoto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInsertPhoto"


class MdOutlineLineAxis(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLineAxis"


class MdOutlineLinearScale(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLinearScale"


class MdOutlineMargin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMargin"


class MdOutlineMergeType(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMergeType"


class MdOutlineModeComment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineModeComment"


class MdOutlineModeEditOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineModeEditOutline"


class MdOutlineModeEdit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineModeEdit"


class MdOutlineMode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMode"


class MdOutlineMonetizationOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMonetizationOn"


class MdOutlineMoneyOffCsred(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoneyOffCsred"


class MdOutlineMoneyOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoneyOff"


class MdOutlineMoveDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoveDown"


class MdOutlineMoveUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoveUp"


class MdOutlineMultilineChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMultilineChart"


class MdOutlineNotes(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotes"


class MdOutlineNumbers(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNumbers"


class MdOutlinePadding(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePadding"


class MdOutlinePentagon(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePentagon"


class MdOutlinePieChartOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePieChartOutline"


class MdOutlinePieChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePieChart"


class MdOutlinePolyline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePolyline"


class MdOutlinePostAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePostAdd"


class MdOutlinePublish(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePublish"


class MdOutlineQueryStats(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineQueryStats"


class MdOutlineRectangle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRectangle"


class MdOutlineScatterPlot(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScatterPlot"


class MdOutlineSchema(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSchema"


class MdOutlineScore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScore"


class MdOutlineShapeLine(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShapeLine"


class MdOutlineShortText(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShortText"


class MdOutlineShowChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShowChart"


class MdOutlineSpaceBar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpaceBar"


class MdOutlineSquare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSquare"


class MdOutlineStackedLineChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStackedLineChart"


class MdOutlineStrikethroughS(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStrikethroughS"


class MdOutlineSubscript(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSubscript"


class MdOutlineSuperscript(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSuperscript"


class MdOutlineTableChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTableChart"


class MdOutlineTableRows(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTableRows"


class MdOutlineTextDecrease(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextDecrease"


class MdOutlineTextFields(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextFields"


class MdOutlineTextIncrease(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextIncrease"


class MdOutlineTitle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTitle"


class MdOutlineTypeSpecimen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTypeSpecimen"


class MdOutlineVerticalAlignBottom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVerticalAlignBottom"


class MdOutlineVerticalAlignCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVerticalAlignCenter"


class MdOutlineVerticalAlignTop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVerticalAlignTop"


class MdOutlineVerticalDistribute(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVerticalDistribute"


class MdOutlineWrapText(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWrapText"


class MdOutlineApproval(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineApproval"


class MdOutlineAttachEmail(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAttachEmail"


class MdOutlineAttachment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAttachment"


class MdOutlineCloudCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCloudCircle"


class MdOutlineCloudDone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCloudDone"


class MdOutlineCloudDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCloudDownload"


class MdOutlineCloudOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCloudOff"


class MdOutlineCloudQueue(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCloudQueue"


class MdOutlineCloudSync(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCloudSync"


class MdOutlineCloudUpload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCloudUpload"


class MdOutlineCloud(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCloud"


class MdOutlineCreateNewFolder(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCreateNewFolder"


class MdOutlineDifference(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDifference"


class MdOutlineDownloadDone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDownloadDone"


class MdOutlineDownloadForOffline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDownloadForOffline"


class MdOutlineDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDownload"


class MdOutlineDownloading(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDownloading"


class MdOutlineDriveFileMoveRtl(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDriveFileMoveRtl"


class MdOutlineDriveFileMove(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDriveFileMove"


class MdOutlineDriveFileRenameOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDriveFileRenameOutline"


class MdOutlineDriveFolderUpload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDriveFolderUpload"


class MdOutlineFileDownloadDone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFileDownloadDone"


class MdOutlineFileDownloadOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFileDownloadOff"


class MdOutlineFileDownload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFileDownload"


class MdOutlineFileOpen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFileOpen"


class MdOutlineFileUpload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFileUpload"


class MdOutlineFolderCopy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFolderCopy"


class MdOutlineFolderDelete(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFolderDelete"


class MdOutlineFolderOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFolderOff"


class MdOutlineFolderOpen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFolderOpen"


class MdOutlineFolderShared(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFolderShared"


class MdOutlineFolderZip(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFolderZip"


class MdOutlineFolder(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFolder"


class MdOutlineFormatOverline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFormatOverline"


class MdOutlineGridView(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGridView"


class MdOutlineNewspaper(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNewspaper"


class MdOutlineRequestQuote(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRequestQuote"


class MdOutlineRuleFolder(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRuleFolder"


class MdOutlineSnippetFolder(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSnippetFolder"


class MdOutlineTextSnippet(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTextSnippet"


class MdOutlineTopic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTopic"


class MdOutlineUploadFile(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUploadFile"


class MdOutlineUpload(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUpload"


class MdOutlineWorkspaces(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWorkspaces"


class MdOutlineAdfScanner(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAdfScanner"


class MdOutlineBrowserNotSupported(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrowserNotSupported"


class MdOutlineBrowserUpdated(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrowserUpdated"


class MdOutlineCastConnected(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCastConnected"


class MdOutlineCastForEducation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCastForEducation"


class MdOutlineCast(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCast"


class MdOutlineComputer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineComputer"


class MdOutlineConnectedTv(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineConnectedTv"


class MdOutlineDesktopMac(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDesktopMac"


class MdOutlineDesktopWindows(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDesktopWindows"


class MdOutlineDeveloperBoardOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeveloperBoardOff"


class MdOutlineDeveloperBoard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeveloperBoard"


class MdOutlineDeviceHub(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeviceHub"


class MdOutlineDeviceUnknown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeviceUnknown"


class MdOutlineDevicesOther(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDevicesOther"


class MdOutlineDock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDock"


class MdOutlineEarbudsBattery(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEarbudsBattery"


class MdOutlineEarbuds(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEarbuds"


class MdOutlineGamepad(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGamepad"


class MdOutlineHeadphonesBattery(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHeadphonesBattery"


class MdOutlineHeadphones(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHeadphones"


class MdOutlineHeadsetMic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHeadsetMic"


class MdOutlineHeadsetOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHeadsetOff"


class MdOutlineHeadset(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHeadset"


class MdOutlineHomeMax(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHomeMax"


class MdOutlineHomeMini(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHomeMini"


class MdOutlineKeyboardAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardAlt"


class MdOutlineKeyboardArrowDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardArrowDown"


class MdOutlineKeyboardArrowLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardArrowLeft"


class MdOutlineKeyboardArrowRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardArrowRight"


class MdOutlineKeyboardArrowUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardArrowUp"


class MdOutlineKeyboardBackspace(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardBackspace"


class MdOutlineKeyboardCapslock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardCapslock"


class MdOutlineKeyboardCommandKey(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardCommandKey"


class MdOutlineKeyboardControlKey(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardControlKey"


class MdOutlineKeyboardDoubleArrowDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardDoubleArrowDown"


class MdOutlineKeyboardDoubleArrowLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardDoubleArrowLeft"


class MdOutlineKeyboardDoubleArrowRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardDoubleArrowRight"


class MdOutlineKeyboardDoubleArrowUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardDoubleArrowUp"


class MdOutlineKeyboardHide(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardHide"


class MdOutlineKeyboardOptionKey(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardOptionKey"


class MdOutlineKeyboardReturn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardReturn"


class MdOutlineKeyboardTab(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardTab"


class MdOutlineKeyboardVoice(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboardVoice"


class MdOutlineKeyboard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKeyboard"


class MdOutlineLaptopChromebook(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLaptopChromebook"


class MdOutlineLaptopMac(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLaptopMac"


class MdOutlineLaptopWindows(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLaptopWindows"


class MdOutlineLaptop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLaptop"


class MdOutlineMemory(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMemory"


class MdOutlineMonitor(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMonitor"


class MdOutlineMouse(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMouse"


class MdOutlinePhoneAndroid(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneAndroid"


class MdOutlinePhoneIphone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneIphone"


class MdOutlinePhonelinkOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhonelinkOff"


class MdOutlinePhonelink(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhonelink"


class MdOutlinePointOfSale(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePointOfSale"


class MdOutlinePowerInput(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePowerInput"


class MdOutlineRouter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRouter"


class MdOutlineScanner(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScanner"


class MdOutlineSecurity(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSecurity"


class MdOutlineSimCard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSimCard"


class MdOutlineSmartDisplay(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSmartDisplay"


class MdOutlineSmartScreen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSmartScreen"


class MdOutlineSmartToy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSmartToy"


class MdOutlineSmartphone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSmartphone"


class MdOutlineSpeakerGroup(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpeakerGroup"


class MdOutlineSpeaker(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpeaker"


class MdOutlineStart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStart"


class MdOutlineTabletAndroid(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTabletAndroid"


class MdOutlineTabletMac(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTabletMac"


class MdOutlineTablet(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTablet"


class MdOutlineToys(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineToys"


class MdOutlineTv(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTv"


class MdOutlineVideogameAssetOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideogameAssetOff"


class MdOutlineVideogameAsset(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideogameAsset"


class MdOutlineWatchOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWatchOff"


class MdOutlineWatch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWatch"


class MdOutlineAutoMode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoMode"


class MdOutlineBlindsClosed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBlindsClosed"


class MdOutlineBlinds(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBlinds"


class MdOutlineBroadcastOnHome(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBroadcastOnHome"


class MdOutlineBroadcastOnPersonal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBroadcastOnPersonal"


class MdOutlineCurtainsClosed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurtainsClosed"


class MdOutlineCurtains(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurtains"


class MdOutlineElectricBolt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElectricBolt"


class MdOutlineElectricMeter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElectricMeter"


class MdOutlineEnergySavingsLeaf(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEnergySavingsLeaf"


class MdOutlineGasMeter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGasMeter"


class MdOutlineHeatPump(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHeatPump"


class MdOutlineModeFanOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineModeFanOff"


class MdOutlineNestCamWiredStand(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNestCamWiredStand"


class MdOutlineOilBarrel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOilBarrel"


class MdOutlinePropaneTank(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePropaneTank"


class MdOutlinePropane(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePropane"


class MdOutlineRollerShadesClosed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRollerShadesClosed"


class MdOutlineRollerShades(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRollerShades"


class MdOutlineSensorDoor(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSensorDoor"


class MdOutlineSensorOccupied(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSensorOccupied"


class MdOutlineSensorWindow(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSensorWindow"


class MdOutlineShieldMoon(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShieldMoon"


class MdOutlineSolarPower(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSolarPower"


class MdOutlineVerticalShadesClosed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVerticalShadesClosed"


class MdOutlineVerticalShades(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVerticalShades"


class MdOutlineWindPower(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWindPower"


class MdOutline10Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline10Mp"


class MdOutline11Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline11Mp"


class MdOutline12Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline12Mp"


class MdOutline13Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline13Mp"


class MdOutline14Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline14Mp"


class MdOutline15Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline15Mp"


class MdOutline16Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline16Mp"


class MdOutline17Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline17Mp"


class MdOutline18Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline18Mp"


class MdOutline19Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline19Mp"


class MdOutline20Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline20Mp"


class MdOutline21Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline21Mp"


class MdOutline22Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline22Mp"


class MdOutline23Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline23Mp"


class MdOutline24Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline24Mp"


class MdOutline2Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline2Mp"


class MdOutline30FpsSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline30FpsSelect"


class MdOutline3Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline3Mp"


class MdOutline4Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline4Mp"


class MdOutline5Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline5Mp"


class MdOutline60FpsSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline60FpsSelect"


class MdOutline6Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline6Mp"


class MdOutline7Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline7Mp"


class MdOutline8Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline8Mp"


class MdOutline9Mp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline9Mp"


class MdOutlineAddAPhoto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddAPhoto"


class MdOutlineAddPhotoAlternate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddPhotoAlternate"


class MdOutlineAddToPhotos(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddToPhotos"


class MdOutlineAdjust(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAdjust"


class MdOutlineAnimation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAnimation"


class MdOutlineAssistantPhoto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssistantPhoto"


class MdOutlineAssistant(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssistant"


class MdOutlineAudiotrack(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAudiotrack"


class MdOutlineAutoAwesomeMosaic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoAwesomeMosaic"


class MdOutlineAutoAwesomeMotion(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoAwesomeMotion"


class MdOutlineAutoAwesome(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoAwesome"


class MdOutlineAutoFixHigh(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoFixHigh"


class MdOutlineAutoFixNormal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoFixNormal"


class MdOutlineAutoFixOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoFixOff"


class MdOutlineAutoStories(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutoStories"


class MdOutlineAutofpsSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAutofpsSelect"


class MdOutlineBedtimeOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBedtimeOff"


class MdOutlineBedtime(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBedtime"


class MdOutlineBlurCircular(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBlurCircular"


class MdOutlineBlurLinear(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBlurLinear"


class MdOutlineBlurOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBlurOff"


class MdOutlineBlurOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBlurOn"


class MdOutlineBrightness1(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightness1"


class MdOutlineBrightness2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightness2"


class MdOutlineBrightness3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightness3"


class MdOutlineBrightness4(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightness4"


class MdOutlineBrightness5(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightness5"


class MdOutlineBrightness6(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightness6"


class MdOutlineBrightness7(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrightness7"


class MdOutlineBrokenImage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrokenImage"


class MdOutlineBrush(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrush"


class MdOutlineBurstMode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBurstMode"


class MdOutlineCameraAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCameraAlt"


class MdOutlineCameraFront(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCameraFront"


class MdOutlineCameraRear(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCameraRear"


class MdOutlineCameraRoll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCameraRoll"


class MdOutlineCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCamera"


class MdOutlineCases(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCases"


class MdOutlineCenterFocusStrong(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCenterFocusStrong"


class MdOutlineCenterFocusWeak(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCenterFocusWeak"


class MdOutlineCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCircle"


class MdOutlineCollectionsBookmark(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCollectionsBookmark"


class MdOutlineCollections(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCollections"


class MdOutlineColorLens(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineColorLens"


class MdOutlineColorize(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineColorize"


class MdOutlineCompare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCompare"


class MdOutlineContrast(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineContrast"


class MdOutlineControlPointDuplicate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineControlPointDuplicate"


class MdOutlineControlPoint(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineControlPoint"


class MdOutlineCrop169(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCrop169"


class MdOutlineCrop32(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCrop32"


class MdOutlineCrop54(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCrop54"


class MdOutlineCrop75(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCrop75"


class MdOutlineCropDin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCropDin"


class MdOutlineCropFree(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCropFree"


class MdOutlineCropLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCropLandscape"


class MdOutlineCropOriginal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCropOriginal"


class MdOutlineCropPortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCropPortrait"


class MdOutlineCropRotate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCropRotate"


class MdOutlineCropSquare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCropSquare"


class MdOutlineCrop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCrop"


class MdOutlineCurrencyBitcoin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurrencyBitcoin"


class MdOutlineCurrencyFranc(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurrencyFranc"


class MdOutlineCurrencyLira(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurrencyLira"


class MdOutlineCurrencyPound(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurrencyPound"


class MdOutlineCurrencyRuble(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurrencyRuble"


class MdOutlineCurrencyRupee(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurrencyRupee"


class MdOutlineCurrencyYen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurrencyYen"


class MdOutlineCurrencyYuan(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCurrencyYuan"


class MdOutlineDeblur(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeblur"


class MdOutlineDehaze(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDehaze"


class MdOutlineDetails(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDetails"


class MdOutlineDirtyLens(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirtyLens"


class MdOutlineEdit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEdit"


class MdOutlineEuro(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEuro"


class MdOutlineExposureNeg1(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExposureNeg1"


class MdOutlineExposureNeg2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExposureNeg2"


class MdOutlineExposurePlus1(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExposurePlus1"


class MdOutlineExposurePlus2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExposurePlus2"


class MdOutlineExposureZero(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExposureZero"


class MdOutlineExposure(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExposure"


class MdOutlineFaceRetouchingNatural(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFaceRetouchingNatural"


class MdOutlineFaceRetouchingOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFaceRetouchingOff"


class MdOutlineFilter1(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter1"


class MdOutlineFilter2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter2"


class MdOutlineFilter3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter3"


class MdOutlineFilter4(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter4"


class MdOutlineFilter5(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter5"


class MdOutlineFilter6(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter6"


class MdOutlineFilter7(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter7"


class MdOutlineFilter8(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter8"


class MdOutlineFilter9Plus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter9Plus"


class MdOutlineFilter9(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter9"


class MdOutlineFilterBAndW(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterBAndW"


class MdOutlineFilterCenterFocus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterCenterFocus"


class MdOutlineFilterDrama(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterDrama"


class MdOutlineFilterFrames(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterFrames"


class MdOutlineFilterHdr(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterHdr"


class MdOutlineFilterNone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterNone"


class MdOutlineFilterTiltShift(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterTiltShift"


class MdOutlineFilterVintage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilterVintage"


class MdOutlineFilter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFilter"


class MdOutlineFlare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlare"


class MdOutlineFlashAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlashAuto"


class MdOutlineFlashOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlashOff"


class MdOutlineFlashOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlashOn"


class MdOutlineFlipCameraAndroid(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlipCameraAndroid"


class MdOutlineFlipCameraIos(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlipCameraIos"


class MdOutlineFlip(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlip"


class MdOutlineGradient(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGradient"


class MdOutlineGrain(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGrain"


class MdOutlineGridOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGridOff"


class MdOutlineGridOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGridOn"


class MdOutlineHdrEnhancedSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrEnhancedSelect"


class MdOutlineHdrOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrOff"


class MdOutlineHdrOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrOn"


class MdOutlineHdrPlus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrPlus"


class MdOutlineHdrStrong(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrStrong"


class MdOutlineHdrWeak(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHdrWeak"


class MdOutlineHealing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHealing"


class MdOutlineHevc(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHevc"


class MdOutlineHideImage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHideImage"


class MdOutlineImageAspectRatio(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineImageAspectRatio"


class MdOutlineImageNotSupported(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineImageNotSupported"


class MdOutlineImageSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineImageSearch"


class MdOutlineImage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineImage"


class MdOutlineIncompleteCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineIncompleteCircle"


class MdOutlineIso(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineIso"


class MdOutlineLandscape(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLandscape"


class MdOutlineLeakAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLeakAdd"


class MdOutlineLeakRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLeakRemove"


class MdOutlineLens(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLens"


class MdOutlineLinkedCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLinkedCamera"


class MdOutlineLogoDev(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLogoDev"


class MdOutlineLooks3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLooks3"


class MdOutlineLooks4(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLooks4"


class MdOutlineLooks5(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLooks5"


class MdOutlineLooks6(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLooks6"


class MdOutlineLooksOne(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLooksOne"


class MdOutlineLooksTwo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLooksTwo"


class MdOutlineLooks(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLooks"


class MdOutlineLoupe(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLoupe"


class MdOutlineMicExternalOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMicExternalOff"


class MdOutlineMicExternalOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMicExternalOn"


class MdOutlineMonochromePhotos(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMonochromePhotos"


class MdOutlineMotionPhotosAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMotionPhotosAuto"


class MdOutlineMotionPhotosOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMotionPhotosOff"


class MdOutlineMotionPhotosOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMotionPhotosOn"


class MdOutlineMotionPhotosPause(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMotionPhotosPause"


class MdOutlineMotionPhotosPaused(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMotionPhotosPaused"


class MdOutlineMovieCreation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMovieCreation"


class MdOutlineMovieFilter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMovieFilter"


class MdOutlineMp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMp"


class MdOutlineMusicNote(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMusicNote"


class MdOutlineMusicOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMusicOff"


class MdOutlineNaturePeople(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNaturePeople"


class MdOutlineNature(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNature"


class MdOutlineNavigateBefore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNavigateBefore"


class MdOutlineNavigateNext(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNavigateNext"


class MdOutlinePalette(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePalette"


class MdOutlinePanoramaFishEye(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanoramaFishEye"


class MdOutlinePanoramaHorizontalSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanoramaHorizontalSelect"


class MdOutlinePanoramaHorizontal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanoramaHorizontal"


class MdOutlinePanoramaPhotosphereSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanoramaPhotosphereSelect"


class MdOutlinePanoramaPhotosphere(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanoramaPhotosphere"


class MdOutlinePanoramaVerticalSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanoramaVerticalSelect"


class MdOutlinePanoramaVertical(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanoramaVertical"


class MdOutlinePanoramaWideAngleSelect(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanoramaWideAngleSelect"


class MdOutlinePanoramaWideAngle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanoramaWideAngle"


class MdOutlinePanorama(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePanorama"


class MdOutlinePhotoAlbum(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhotoAlbum"


class MdOutlinePhotoCameraBack(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhotoCameraBack"


class MdOutlinePhotoCameraFront(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhotoCameraFront"


class MdOutlinePhotoCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhotoCamera"


class MdOutlinePhotoFilter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhotoFilter"


class MdOutlinePhotoLibrary(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhotoLibrary"


class MdOutlinePhotoSizeSelectActual(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhotoSizeSelectActual"


class MdOutlinePhotoSizeSelectLarge(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhotoSizeSelectLarge"


class MdOutlinePhotoSizeSelectSmall(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhotoSizeSelectSmall"


class MdOutlinePhoto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoto"


class MdOutlinePictureAsPdf(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePictureAsPdf"


class MdOutlinePortrait(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePortrait"


class MdOutlineRawOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRawOff"


class MdOutlineRawOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRawOn"


class MdOutlineReceiptLong(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReceiptLong"


class MdOutlineRemoveRedEye(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRemoveRedEye"


class MdOutlineRotate90DegreesCcw(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRotate90DegreesCcw"


class MdOutlineRotate90DegreesCw(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRotate90DegreesCw"


class MdOutlineRotateLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRotateLeft"


class MdOutlineRotateRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRotateRight"


class MdOutlineShutterSpeed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShutterSpeed"


class MdOutlineSlideshow(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSlideshow"


class MdOutlineStraighten(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStraighten"


class MdOutlineStyle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStyle"


class MdOutlineSwitchCamera(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwitchCamera"


class MdOutlineSwitchVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwitchVideo"


class MdOutlineTagFaces(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTagFaces"


class MdOutlineTexture(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTexture"


class MdOutlineThermostatAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThermostatAuto"


class MdOutlineTimelapse(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTimelapse"


class MdOutlineTimer10(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTimer10"


class MdOutlineTimer3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTimer3"


class MdOutlineTimerOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTimerOff"


class MdOutlineTimer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTimer"


class MdOutlineTonality(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTonality"


class MdOutlineTransform(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTransform"


class MdOutlineTune(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTune"


class MdOutlineVideoCameraBack(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideoCameraBack"


class MdOutlineVideoCameraFront(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideoCameraFront"


class MdOutlineVideoStable(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideoStable"


class MdOutlineViewComfy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewComfy"


class MdOutlineViewCompact(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineViewCompact"


class MdOutlineVignette(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVignette"


class MdOutlineVrpano(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVrpano"


class MdOutlineWbAuto(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWbAuto"


class MdOutlineWbCloudy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWbCloudy"


class MdOutlineWbIncandescent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWbIncandescent"


class MdOutlineWbIridescent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWbIridescent"


class MdOutlineWbShade(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWbShade"


class MdOutlineWbSunny(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWbSunny"


class MdOutlineWbTwilight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWbTwilight"


class MdOutline360(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline360"


class MdOutlineAddBusiness(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddBusiness"


class MdOutlineAddLocationAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddLocationAlt"


class MdOutlineAddLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddLocation"


class MdOutlineAddRoad(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddRoad"


class MdOutlineAgriculture(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAgriculture"


class MdOutlineAirlineStops(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlineStops"


class MdOutlineAirlines(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlines"


class MdOutlineAltRoute(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAltRoute"


class MdOutlineAtm(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAtm"


class MdOutlineAttractions(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAttractions"


class MdOutlineBadge(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBadge"


class MdOutlineBakeryDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBakeryDining"


class MdOutlineBeenhere(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBeenhere"


class MdOutlineBikeScooter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBikeScooter"


class MdOutlineBreakfastDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBreakfastDining"


class MdOutlineBrunchDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBrunchDining"


class MdOutlineBusAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBusAlert"


class MdOutlineCarCrash(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCarCrash"


class MdOutlineCarRental(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCarRental"


class MdOutlineCarRepair(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCarRepair"


class MdOutlineCastle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCastle"


class MdOutlineCategory(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCategory"


class MdOutlineCelebration(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCelebration"


class MdOutlineChurch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChurch"


class MdOutlineCleaningServices(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCleaningServices"


class MdOutlineCompassCalibration(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCompassCalibration"


class MdOutlineConnectingAirports(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineConnectingAirports"


class MdOutlineCrisisAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCrisisAlert"


class MdOutlineDeliveryDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeliveryDining"


class MdOutlineDepartureBoard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDepartureBoard"


class MdOutlineDesignServices(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDesignServices"


class MdOutlineDiamond(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDiamond"


class MdOutlineDinnerDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDinnerDining"


class MdOutlineDirectionsBike(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsBike"


class MdOutlineDirectionsBoatFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsBoatFilled"


class MdOutlineDirectionsBoat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsBoat"


class MdOutlineDirectionsBusFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsBusFilled"


class MdOutlineDirectionsBus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsBus"


class MdOutlineDirectionsCarFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsCarFilled"


class MdOutlineDirectionsCar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsCar"


class MdOutlineDirectionsRailwayFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsRailwayFilled"


class MdOutlineDirectionsRailway(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsRailway"


class MdOutlineDirectionsRun(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsRun"


class MdOutlineDirectionsSubwayFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsSubwayFilled"


class MdOutlineDirectionsSubway(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsSubway"


class MdOutlineDirectionsTransitFilled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsTransitFilled"


class MdOutlineDirectionsTransit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsTransit"


class MdOutlineDirectionsWalk(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsWalk"


class MdOutlineDirections(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirections"


class MdOutlineDryCleaning(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDryCleaning"


class MdOutlineEditAttributes(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEditAttributes"


class MdOutlineEditLocationAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEditLocationAlt"


class MdOutlineEditLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEditLocation"


class MdOutlineEditRoad(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEditRoad"


class MdOutlineEggAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEggAlt"


class MdOutlineEgg(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEgg"


class MdOutlineElectricBike(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElectricBike"


class MdOutlineElectricCar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElectricCar"


class MdOutlineElectricMoped(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElectricMoped"


class MdOutlineElectricRickshaw(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElectricRickshaw"


class MdOutlineElectricScooter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElectricScooter"


class MdOutlineElectricalServices(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElectricalServices"


class MdOutlineEmergencyRecording(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmergencyRecording"


class MdOutlineEmergencyShare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmergencyShare"


class MdOutlineEmergency(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmergency"


class MdOutlineEvStation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEvStation"


class MdOutlineFactory(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFactory"


class MdOutlineFastfood(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFastfood"


class MdOutlineFestival(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFestival"


class MdOutlineFireHydrantAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFireHydrantAlt"


class MdOutlineFireTruck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFireTruck"


class MdOutlineFlightClass(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlightClass"


class MdOutlineFlight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlight"


class MdOutlineForest(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineForest"


class MdOutlineForkLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineForkLeft"


class MdOutlineForkRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineForkRight"


class MdOutlineFort(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFort"


class MdOutlineHail(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHail"


class MdOutlineHandyman(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHandyman"


class MdOutlineHardware(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHardware"


class MdOutlineHomeRepairService(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHomeRepairService"


class MdOutlineHotel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHotel"


class MdOutlineHvac(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHvac"


class MdOutlineIcecream(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineIcecream"


class MdOutlineKebabDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKebabDining"


class MdOutlineLayersClear(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLayersClear"


class MdOutlineLayers(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLayers"


class MdOutlineLiquor(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLiquor"


class MdOutlineLocalActivity(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalActivity"


class MdOutlineLocalAirport(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalAirport"


class MdOutlineLocalAtm(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalAtm"


class MdOutlineLocalBar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalBar"


class MdOutlineLocalCafe(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalCafe"


class MdOutlineLocalCarWash(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalCarWash"


class MdOutlineLocalConvenienceStore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalConvenienceStore"


class MdOutlineLocalDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalDining"


class MdOutlineLocalDrink(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalDrink"


class MdOutlineLocalFireDepartment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalFireDepartment"


class MdOutlineLocalFlorist(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalFlorist"


class MdOutlineLocalGasStation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalGasStation"


class MdOutlineLocalGroceryStore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalGroceryStore"


class MdOutlineLocalHospital(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalHospital"


class MdOutlineLocalHotel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalHotel"


class MdOutlineLocalLaundryService(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalLaundryService"


class MdOutlineLocalLibrary(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalLibrary"


class MdOutlineLocalMall(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalMall"


class MdOutlineLocalMovies(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalMovies"


class MdOutlineLocalOffer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalOffer"


class MdOutlineLocalParking(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalParking"


class MdOutlineLocalPharmacy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalPharmacy"


class MdOutlineLocalPhone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalPhone"


class MdOutlineLocalPizza(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalPizza"


class MdOutlineLocalPlay(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalPlay"


class MdOutlineLocalPolice(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalPolice"


class MdOutlineLocalPostOffice(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalPostOffice"


class MdOutlineLocalPrintshop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalPrintshop"


class MdOutlineLocalSee(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalSee"


class MdOutlineLocalShipping(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalShipping"


class MdOutlineLocalTaxi(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocalTaxi"


class MdOutlineLunchDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLunchDining"


class MdOutlineMap(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMap"


class MdOutlineMapsUgc(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMapsUgc"


class MdOutlineMedicalInformation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMedicalInformation"


class MdOutlineMedicalServices(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMedicalServices"


class MdOutlineMenuBook(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMenuBook"


class MdOutlineMerge(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMerge"


class MdOutlineMinorCrash(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMinorCrash"


class MdOutlineMiscellaneousServices(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMiscellaneousServices"


class MdOutlineModeOfTravel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineModeOfTravel"


class MdOutlineMoney(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoney"


class MdOutlineMoped(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoped"


class MdOutlineMosque(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMosque"


class MdOutlineMoving(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoving"


class MdOutlineMultipleStop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMultipleStop"


class MdOutlineMuseum(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMuseum"


class MdOutlineMyLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMyLocation"


class MdOutlineNavigation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNavigation"


class MdOutlineNearMeDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNearMeDisabled"


class MdOutlineNearMe(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNearMe"


class MdOutlineNightlife(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNightlife"


class MdOutlineNoCrash(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoCrash"


class MdOutlineNoMeals(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoMeals"


class MdOutlineNoTransfer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoTransfer"


class MdOutlineNotListedLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotListedLocation"


class MdOutlinePark(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePark"


class MdOutlinePedalBike(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePedalBike"


class MdOutlinePersonPinCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonPinCircle"


class MdOutlinePersonPin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonPin"


class MdOutlinePestControlRodent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePestControlRodent"


class MdOutlinePestControl(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePestControl"


class MdOutlinePinDrop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePinDrop"


class MdOutlinePlace(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlace"


class MdOutlinePlumbing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlumbing"


class MdOutlineRailwayAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRailwayAlert"


class MdOutlineRamenDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRamenDining"


class MdOutlineRampLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRampLeft"


class MdOutlineRampRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRampRight"


class MdOutlineRateReview(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRateReview"


class MdOutlineRemoveRoad(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRemoveRoad"


class MdOutlineRestaurantMenu(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRestaurantMenu"


class MdOutlineRestaurant(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRestaurant"


class MdOutlineRoundaboutLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRoundaboutLeft"


class MdOutlineRoundaboutRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRoundaboutRight"


class MdOutlineRoute(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRoute"


class MdOutlineRunCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRunCircle"


class MdOutlineSafetyCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSafetyCheck"


class MdOutlineSailing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSailing"


class MdOutlineSatellite(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSatellite"


class MdOutlineScreenRotationAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScreenRotationAlt"


class MdOutlineSetMeal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSetMeal"


class MdOutlineSignpost(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignpost"


class MdOutlineSnowmobile(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSnowmobile"


class MdOutlineSos(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSos"


class MdOutlineSoupKitchen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSoupKitchen"


class MdOutlineStadium(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStadium"


class MdOutlineStoreMallDirectory(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStoreMallDirectory"


class MdOutlineStraight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStraight"


class MdOutlineStreetview(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStreetview"


class MdOutlineSubway(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSubway"


class MdOutlineSynagogue(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSynagogue"


class MdOutlineTakeoutDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTakeoutDining"


class MdOutlineTaxiAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTaxiAlert"


class MdOutlineTempleBuddhist(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTempleBuddhist"


class MdOutlineTempleHindu(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTempleHindu"


class MdOutlineTerrain(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTerrain"


class MdOutlineTheaterComedy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTheaterComedy"


class MdOutlineTireRepair(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTireRepair"


class MdOutlineTraffic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTraffic"


class MdOutlineTrain(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTrain"


class MdOutlineTram(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTram"


class MdOutlineTransferWithinAStation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTransferWithinAStation"


class MdOutlineTransitEnterexit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTransitEnterexit"


class MdOutlineTripOrigin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTripOrigin"


class MdOutlineTurnLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTurnLeft"


class MdOutlineTurnRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTurnRight"


class MdOutlineTurnSharpLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTurnSharpLeft"


class MdOutlineTurnSharpRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTurnSharpRight"


class MdOutlineTurnSlightLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTurnSlightLeft"


class MdOutlineTurnSlightRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTurnSlightRight"


class MdOutlineTwoWheeler(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTwoWheeler"


class MdOutlineUTurnLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUTurnLeft"


class MdOutlineUTurnRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUTurnRight"


class MdOutlineVolunteerActivism(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVolunteerActivism"


class MdOutlineWarehouse(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWarehouse"


class MdOutlineWineBar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWineBar"


class MdOutlineWrongLocation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWrongLocation"


class MdOutlineZoomInMap(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineZoomInMap"


class MdOutlineZoomOutMap(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineZoomOutMap"


class MdOutlineAddHomeWork(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddHomeWork"


class MdOutlineAppSettingsAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAppSettingsAlt"


class MdOutlineAppsOutage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAppsOutage"


class MdOutlineApps(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineApps"


class MdOutlineArrowBackIosNew(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowBackIosNew"


class MdOutlineArrowBackIos(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowBackIos"


class MdOutlineArrowBack(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowBack"


class MdOutlineArrowDownward(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowDownward"


class MdOutlineArrowDropDownCircle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowDropDownCircle"


class MdOutlineArrowDropDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowDropDown"


class MdOutlineArrowDropUp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowDropUp"


class MdOutlineArrowForwardIos(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowForwardIos"


class MdOutlineArrowForward(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowForward"


class MdOutlineArrowLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowLeft"


class MdOutlineArrowRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowRight"


class MdOutlineArrowUpward(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArrowUpward"


class MdOutlineAssistantDirection(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssistantDirection"


class MdOutlineCampaign(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCampaign"


class MdOutlineCancel(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCancel"


class MdOutlineCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCheck"


class MdOutlineChevronLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChevronLeft"


class MdOutlineChevronRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChevronRight"


class MdOutlineClose(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineClose"


class MdOutlineDoubleArrow(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoubleArrow"


class MdOutlineEast(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEast"


class MdOutlineExpandCircleDown(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExpandCircleDown"


class MdOutlineExpandLess(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExpandLess"


class MdOutlineExpandMore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineExpandMore"


class MdOutlineFirstPage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFirstPage"


class MdOutlineFullscreenExit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFullscreenExit"


class MdOutlineFullscreen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFullscreen"


class MdOutlineHomeWork(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHomeWork"


class MdOutlineLastPage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLastPage"


class MdOutlineLegendToggle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLegendToggle"


class MdOutlineMapsHomeWork(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMapsHomeWork"


class MdOutlineMenuOpen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMenuOpen"


class MdOutlineMenu(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMenu"


class MdOutlineMoreHoriz(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoreHoriz"


class MdOutlineMoreVert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoreVert"


class MdOutlineNorthEast(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNorthEast"


class MdOutlineNorthWest(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNorthWest"


class MdOutlineNorth(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNorth"


class MdOutlineOfflineShare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOfflineShare"


class MdOutlinePayments(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePayments"


class MdOutlinePivotTableChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePivotTableChart"


class MdOutlineRefresh(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRefresh"


class MdOutlineSouthEast(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSouthEast"


class MdOutlineSouthWest(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSouthWest"


class MdOutlineSouth(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSouth"


class MdOutlineSubdirectoryArrowLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSubdirectoryArrowLeft"


class MdOutlineSubdirectoryArrowRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSubdirectoryArrowRight"


class MdOutlineSwitchLeft(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwitchLeft"


class MdOutlineSwitchRight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwitchRight"


class MdOutlineUnfoldLess(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUnfoldLess"


class MdOutlineUnfoldMore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUnfoldMore"


class MdOutlineWaterfallChart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWaterfallChart"


class MdOutlineWest(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWest"


class MdOutlineAccountTree(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAccountTree"


class MdOutlineAdb(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAdb"


class MdOutlineAirlineSeatFlatAngled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlineSeatFlatAngled"


class MdOutlineAirlineSeatFlat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlineSeatFlat"


class MdOutlineAirlineSeatIndividualSuite(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlineSeatIndividualSuite"


class MdOutlineAirlineSeatLegroomExtra(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlineSeatLegroomExtra"


class MdOutlineAirlineSeatLegroomNormal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlineSeatLegroomNormal"


class MdOutlineAirlineSeatLegroomReduced(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlineSeatLegroomReduced"


class MdOutlineAirlineSeatReclineExtra(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlineSeatReclineExtra"


class MdOutlineAirlineSeatReclineNormal(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirlineSeatReclineNormal"


class MdOutlineBluetoothAudio(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBluetoothAudio"


class MdOutlineConfirmationNumber(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineConfirmationNumber"


class MdOutlineDirectionsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDirectionsOff"


class MdOutlineDiscFull(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDiscFull"


class MdOutlineDoDisturbAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoDisturbAlt"


class MdOutlineDoDisturbOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoDisturbOff"


class MdOutlineDoDisturbOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoDisturbOn"


class MdOutlineDoDisturb(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoDisturb"


class MdOutlineDoNotDisturbAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoNotDisturbAlt"


class MdOutlineDoNotDisturbOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoNotDisturbOff"


class MdOutlineDoNotDisturbOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoNotDisturbOn"


class MdOutlineDoNotDisturb(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoNotDisturb"


class MdOutlineDriveEta(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDriveEta"


class MdOutlineEnhancedEncryption(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEnhancedEncryption"


class MdOutlineEventAvailable(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEventAvailable"


class MdOutlineEventBusy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEventBusy"


class MdOutlineEventNote(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEventNote"


class MdOutlineFolderSpecial(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFolderSpecial"


class MdOutlineImagesearchRoller(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineImagesearchRoller"


class MdOutlineLiveTv(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLiveTv"


class MdOutlineMms(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMms"


class MdOutlineMore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMore"


class MdOutlineNetworkCheck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNetworkCheck"


class MdOutlineNetworkLocked(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNetworkLocked"


class MdOutlineNoEncryptionGmailerrorred(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoEncryptionGmailerrorred"


class MdOutlineNoEncryption(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoEncryption"


class MdOutlineOndemandVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOndemandVideo"


class MdOutlinePersonalVideo(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonalVideo"


class MdOutlinePhoneBluetoothSpeaker(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneBluetoothSpeaker"


class MdOutlinePhoneCallback(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneCallback"


class MdOutlinePhoneForwarded(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneForwarded"


class MdOutlinePhoneInTalk(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneInTalk"


class MdOutlinePhoneLocked(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneLocked"


class MdOutlinePhoneMissed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhoneMissed"


class MdOutlinePhonePaused(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePhonePaused"


class MdOutlinePowerOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePowerOff"


class MdOutlinePower(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePower"


class MdOutlinePriorityHigh(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePriorityHigh"


class MdOutlineRunningWithErrors(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRunningWithErrors"


class MdOutlineSdCardAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSdCardAlert"


class MdOutlineSdCard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSdCard"


class MdOutlineSimCardAlert(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSimCardAlert"


class MdOutlineSmsFailed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSmsFailed"


class MdOutlineSms(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSms"


class MdOutlineSupportAgent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSupportAgent"


class MdOutlineSyncDisabled(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSyncDisabled"


class MdOutlineSyncLock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSyncLock"


class MdOutlineSyncProblem(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSyncProblem"


class MdOutlineSync(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSync"


class MdOutlineSystemUpdate(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSystemUpdate"


class MdOutlineTapAndPlay(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTapAndPlay"


class MdOutlineTimeToLeave(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTimeToLeave"


class MdOutlineTvOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTvOff"


class MdOutlineVibration(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVibration"


class MdOutlineVideoChat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVideoChat"


class MdOutlineVoiceChat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVoiceChat"


class MdOutlineVpnLock(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVpnLock"


class MdOutlineWc(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWc"


class MdOutlineWifiOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifiOff"


class MdOutlineWifi(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWifi"


class MdOutlineAcUnit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAcUnit"


class MdOutlineAirportShuttle(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAirportShuttle"


class MdOutlineAllInclusive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAllInclusive"


class MdOutlineApartment(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineApartment"


class MdOutlineBabyChangingStation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBabyChangingStation"


class MdOutlineBackpack(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBackpack"


class MdOutlineBalcony(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBalcony"


class MdOutlineBathtub(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBathtub"


class MdOutlineBeachAccess(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBeachAccess"


class MdOutlineBento(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBento"


class MdOutlineBungalow(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBungalow"


class MdOutlineBusinessCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBusinessCenter"


class MdOutlineCabin(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCabin"


class MdOutlineCarpenter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCarpenter"


class MdOutlineCasino(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCasino"


class MdOutlineChalet(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChalet"


class MdOutlineChargingStation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChargingStation"


class MdOutlineCheckroom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCheckroom"


class MdOutlineChildCare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChildCare"


class MdOutlineChildFriendly(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChildFriendly"


class MdOutlineCorporateFare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCorporateFare"


class MdOutlineCottage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCottage"


class MdOutlineCountertops(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCountertops"


class MdOutlineCrib(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCrib"


class MdOutlineDesk(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDesk"


class MdOutlineDoNotStep(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoNotStep"


class MdOutlineDoNotTouch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoNotTouch"


class MdOutlineDry(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDry"


class MdOutlineElevator(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElevator"


class MdOutlineEscalatorWarning(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEscalatorWarning"


class MdOutlineEscalator(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEscalator"


class MdOutlineFamilyRestroom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFamilyRestroom"


class MdOutlineFence(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFence"


class MdOutlineFireExtinguisher(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFireExtinguisher"


class MdOutlineFitnessCenter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFitnessCenter"


class MdOutlineFoodBank(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFoodBank"


class MdOutlineFoundation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFoundation"


class MdOutlineFreeBreakfast(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFreeBreakfast"


class MdOutlineGite(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGite"


class MdOutlineGolfCourse(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGolfCourse"


class MdOutlineGrass(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGrass"


class MdOutlineHolidayVillage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHolidayVillage"


class MdOutlineHotTub(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHotTub"


class MdOutlineHouseSiding(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHouseSiding"


class MdOutlineHouse(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHouse"


class MdOutlineHouseboat(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHouseboat"


class MdOutlineIron(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineIron"


class MdOutlineKitchen(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKitchen"


class MdOutlineMeetingRoom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMeetingRoom"


class MdOutlineMicrowave(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMicrowave"


class MdOutlineNightShelter(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNightShelter"


class MdOutlineNoBackpack(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoBackpack"


class MdOutlineNoCell(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoCell"


class MdOutlineNoDrinks(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoDrinks"


class MdOutlineNoFlash(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoFlash"


class MdOutlineNoFood(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoFood"


class MdOutlineNoMeetingRoom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoMeetingRoom"


class MdOutlineNoPhotography(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoPhotography"


class MdOutlineNoStroller(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoStroller"


class MdOutlineOtherHouses(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOtherHouses"


class MdOutlinePool(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePool"


class MdOutlineRiceBowl(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRiceBowl"


class MdOutlineRoofing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRoofing"


class MdOutlineRoomPreferences(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRoomPreferences"


class MdOutlineRoomService(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRoomService"


class MdOutlineRvHookup(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRvHookup"


class MdOutlineSmokeFree(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSmokeFree"


class MdOutlineSmokingRooms(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSmokingRooms"


class MdOutlineSoap(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSoap"


class MdOutlineSpa(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSpa"


class MdOutlineSportsBar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsBar"


class MdOutlineStairs(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStairs"


class MdOutlineStorefront(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStorefront"


class MdOutlineStroller(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStroller"


class MdOutlineTapas(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTapas"


class MdOutlineTty(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTty"


class MdOutlineUmbrella(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineUmbrella"


class MdOutlineVapeFree(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVapeFree"


class MdOutlineVapingRooms(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVapingRooms"


class MdOutlineVilla(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVilla"


class MdOutlineWash(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWash"


class MdOutlineWaterDamage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWaterDamage"


class MdOutlineWheelchairPickup(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWheelchairPickup"


class MdOutlineBathroom(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBathroom"


class MdOutlineBed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBed"


class MdOutlineBedroomBaby(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBedroomBaby"


class MdOutlineBedroomChild(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBedroomChild"


class MdOutlineBedroomParent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBedroomParent"


class MdOutlineBlender(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBlender"


class MdOutlineCameraIndoor(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCameraIndoor"


class MdOutlineCameraOutdoor(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCameraOutdoor"


class MdOutlineChairAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChairAlt"


class MdOutlineChair(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineChair"


class MdOutlineCoffeeMaker(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCoffeeMaker"


class MdOutlineCoffee(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCoffee"


class MdOutlineDining(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDining"


class MdOutlineDoorBack(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoorBack"


class MdOutlineDoorFront(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoorFront"


class MdOutlineDoorSliding(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoorSliding"


class MdOutlineDoorbell(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDoorbell"


class MdOutlineFeed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFeed"


class MdOutlineFlatware(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlatware"


class MdOutlineGarage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGarage"


class MdOutlineLight(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLight"


class MdOutlineLiving(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLiving"


class MdOutlineManageSearch(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineManageSearch"


class MdOutlinePodcasts(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePodcasts"


class MdOutlineShower(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShower"


class MdOutlineTableBar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTableBar"


class MdOutlineTableRestaurant(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTableRestaurant"


class MdOutlineWindow(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWindow"


class MdOutlineYard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineYard"


class MdOutline18UpRating(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline18UpRating"


class MdOutline6FtApart(rx.Component):
    library = "react-icons/md"
    tag = "MdOutline6FtApart"


class MdOutlineAddModerator(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddModerator"


class MdOutlineAddReaction(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAddReaction"


class MdOutlineArchitecture(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineArchitecture"


class MdOutlineAssistWalker(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineAssistWalker"


class MdOutlineBackHand(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBackHand"


class MdOutlineBlind(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBlind"


class MdOutlineBoy(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineBoy"


class MdOutlineCake(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCake"


class MdOutlineCatchingPokemon(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCatchingPokemon"


class MdOutlineCleanHands(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCleanHands"


class MdOutlineCo2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCo2"


class MdOutlineCompost(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCompost"


class MdOutlineConnectWithoutContact(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineConnectWithoutContact"


class MdOutlineConstruction(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineConstruction"


class MdOutlineCookie(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCookie"


class MdOutlineCoronavirus(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCoronavirus"


class MdOutlineCrueltyFree(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCrueltyFree"


class MdOutlineCyclone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCyclone"


class MdOutlineDeck(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDeck"


class MdOutlineDiversity1(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDiversity1"


class MdOutlineDiversity2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDiversity2"


class MdOutlineDiversity3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDiversity3"


class MdOutlineDomainAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDomainAdd"


class MdOutlineDomain(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDomain"


class MdOutlineDownhillSkiing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineDownhillSkiing"


class MdOutlineEditNotifications(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEditNotifications"


class MdOutlineElderlyWoman(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElderlyWoman"


class MdOutlineElderly(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineElderly"


class MdOutlineEmojiEmotions(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmojiEmotions"


class MdOutlineEmojiEvents(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmojiEvents"


class MdOutlineEmojiFlags(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmojiFlags"


class MdOutlineEmojiFoodBeverage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmojiFoodBeverage"


class MdOutlineEmojiNature(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmojiNature"


class MdOutlineEmojiObjects(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmojiObjects"


class MdOutlineEmojiPeople(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmojiPeople"


class MdOutlineEmojiSymbols(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmojiSymbols"


class MdOutlineEmojiTransportation(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEmojiTransportation"


class MdOutlineEngineering(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineEngineering"


class MdOutlineFace2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFace2"


class MdOutlineFace3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFace3"


class MdOutlineFace4(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFace4"


class MdOutlineFace5(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFace5"


class MdOutlineFace6(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFace6"


class MdOutlineFacebook(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFacebook"


class MdOutlineFemale(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFemale"


class MdOutlineFireplace(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFireplace"


class MdOutlineFitbit(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFitbit"


class MdOutlineFlood(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFlood"


class MdOutlineFollowTheSigns(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFollowTheSigns"


class MdOutlineFrontHand(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineFrontHand"


class MdOutlineGirl(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGirl"


class MdOutlineGroupAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGroupAdd"


class MdOutlineGroupOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGroupOff"


class MdOutlineGroupRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGroupRemove"


class MdOutlineGroup(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGroup"


class MdOutlineGroups2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGroups2"


class MdOutlineGroups3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGroups3"


class MdOutlineGroups(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineGroups"


class MdOutlineHandshake(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHandshake"


class MdOutlineHealthAndSafety(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHealthAndSafety"


class MdOutlineHeartBroken(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHeartBroken"


class MdOutlineHiking(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHiking"


class MdOutlineHistoryEdu(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHistoryEdu"


class MdOutlineHive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineHive"


class MdOutlineIceSkating(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineIceSkating"


class MdOutlineInterests(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineInterests"


class MdOutlineIosShare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineIosShare"


class MdOutlineKayaking(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKayaking"


class MdOutlineKingBed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKingBed"


class MdOutlineKitesurfing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineKitesurfing"


class MdOutlineLandslide(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLandslide"


class MdOutlineLocationCity(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLocationCity"


class MdOutlineLuggage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineLuggage"


class MdOutlineMale(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMale"


class MdOutlineMan2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMan2"


class MdOutlineMan3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMan3"


class MdOutlineMan4(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMan4"


class MdOutlineMan(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMan"


class MdOutlineMasks(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMasks"


class MdOutlineMilitaryTech(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMilitaryTech"


class MdOutlineMoodBad(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMoodBad"


class MdOutlineMood(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineMood"


class MdOutlineNightsStay(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNightsStay"


class MdOutlineNoAdultContent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoAdultContent"


class MdOutlineNoLuggage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNoLuggage"


class MdOutlineNordicWalking(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNordicWalking"


class MdOutlineNotificationAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotificationAdd"


class MdOutlineNotificationsActive(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotificationsActive"


class MdOutlineNotificationsNone(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotificationsNone"


class MdOutlineNotificationsOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotificationsOff"


class MdOutlineNotificationsPaused(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotificationsPaused"


class MdOutlineNotifications(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineNotifications"


class MdOutlineOutdoorGrill(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineOutdoorGrill"


class MdOutlinePages(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePages"


class MdOutlineParagliding(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineParagliding"


class MdOutlinePartyMode(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePartyMode"


class MdOutlinePeopleAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePeopleAlt"


class MdOutlinePeopleOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePeopleOutline"


class MdOutlinePeople(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePeople"


class MdOutlinePerson2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePerson2"


class MdOutlinePerson3(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePerson3"


class MdOutlinePerson4(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePerson4"


class MdOutlinePersonAddAlt1(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonAddAlt1"


class MdOutlinePersonAddAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonAddAlt"


class MdOutlinePersonAdd(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonAdd"


class MdOutlinePersonOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonOff"


class MdOutlinePersonOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonOutline"


class MdOutlinePersonRemoveAlt1(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonRemoveAlt1"


class MdOutlinePersonRemove(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonRemove"


class MdOutlinePerson(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePerson"


class MdOutlinePersonalInjury(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePersonalInjury"


class MdOutlinePianoOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePianoOff"


class MdOutlinePiano(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePiano"


class MdOutlinePix(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePix"


class MdOutlinePlusOne(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePlusOne"


class MdOutlinePoll(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePoll"


class MdOutlinePrecisionManufacturing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePrecisionManufacturing"


class MdOutlinePsychologyAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePsychologyAlt"


class MdOutlinePsychology(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePsychology"


class MdOutlinePublicOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePublicOff"


class MdOutlinePublic(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlinePublic"


class MdOutlineRealEstateAgent(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRealEstateAgent"


class MdOutlineRecommend(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRecommend"


class MdOutlineRecycling(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRecycling"


class MdOutlineReduceCapacity(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineReduceCapacity"


class MdOutlineRemoveModerator(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRemoveModerator"


class MdOutlineRollerSkating(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRollerSkating"


class MdOutlineSafetyDivider(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSafetyDivider"


class MdOutlineSanitizer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSanitizer"


class MdOutlineScale(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScale"


class MdOutlineSchool(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSchool"


class MdOutlineScience(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScience"


class MdOutlineScoreboard(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScoreboard"


class MdOutlineScubaDiving(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineScubaDiving"


class MdOutlineSelfImprovement(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSelfImprovement"


class MdOutlineSentimentDissatisfied(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSentimentDissatisfied"


class MdOutlineSentimentNeutral(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSentimentNeutral"


class MdOutlineSentimentSatisfied(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSentimentSatisfied"


class MdOutlineSentimentVeryDissatisfied(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSentimentVeryDissatisfied"


class MdOutlineSentimentVerySatisfied(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSentimentVerySatisfied"


class MdOutlineSevereCold(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSevereCold"


class MdOutlineShare(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineShare"


class MdOutlineSick(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSick"


class MdOutlineSignLanguage(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSignLanguage"


class MdOutlineSingleBed(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSingleBed"


class MdOutlineSkateboarding(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSkateboarding"


class MdOutlineSledding(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSledding"


class MdOutlineSnowboarding(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSnowboarding"


class MdOutlineSnowshoeing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSnowshoeing"


class MdOutlineSocialDistance(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSocialDistance"


class MdOutlineSouthAmerica(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSouthAmerica"


class MdOutlineSportsBaseball(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsBaseball"


class MdOutlineSportsBasketball(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsBasketball"


class MdOutlineSportsCricket(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsCricket"


class MdOutlineSportsEsports(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsEsports"


class MdOutlineSportsFootball(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsFootball"


class MdOutlineSportsGolf(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsGolf"


class MdOutlineSportsGymnastics(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsGymnastics"


class MdOutlineSportsHandball(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsHandball"


class MdOutlineSportsHockey(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsHockey"


class MdOutlineSportsKabaddi(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsKabaddi"


class MdOutlineSportsMartialArts(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsMartialArts"


class MdOutlineSportsMma(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsMma"


class MdOutlineSportsMotorsports(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsMotorsports"


class MdOutlineSportsRugby(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsRugby"


class MdOutlineSportsSoccer(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsSoccer"


class MdOutlineSportsTennis(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsTennis"


class MdOutlineSportsVolleyball(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSportsVolleyball"


class MdOutlineSports(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSports"


class MdOutlineSurfing(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSurfing"


class MdOutlineSwitchAccount(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineSwitchAccount"


class MdOutlineThumbDownAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThumbDownAlt"


class MdOutlineThumbUpAlt(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThumbUpAlt"


class MdOutlineThunderstorm(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineThunderstorm"


class MdOutlineTornado(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTornado"


class MdOutlineTransgender(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTransgender"


class MdOutlineTravelExplore(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTravelExplore"


class MdOutlineTsunami(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineTsunami"


class MdOutlineVaccines(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVaccines"


class MdOutlineVolcano(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineVolcano"


class MdOutlineWallet(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWallet"


class MdOutlineWaterDrop(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWaterDrop"


class MdOutlineWavingHand(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWavingHand"


class MdOutlineWhatsapp(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWhatsapp"


class MdOutlineWhatshot(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWhatshot"


class MdOutlineWoman2(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWoman2"


class MdOutlineWoman(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWoman"


class MdOutlineWorkspacePremium(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineWorkspacePremium"


class MdOutlineCheckBoxOutlineBlank(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCheckBoxOutlineBlank"


class MdOutlineCheckBox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineCheckBox"


class MdOutlineIndeterminateCheckBox(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineIndeterminateCheckBox"


class MdOutlineRadioButtonChecked(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRadioButtonChecked"


class MdOutlineRadioButtonUnchecked(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineRadioButtonUnchecked"


class MdOutlineStarBorderPurple500(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStarBorderPurple500"


class MdOutlineStarBorder(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStarBorder"


class MdOutlineStarHalf(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStarHalf"


class MdOutlineStarOutline(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStarOutline"


class MdOutlineStarPurple500(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStarPurple500"


class MdOutlineStar(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineStar"


class MdOutlineToggleOff(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineToggleOff"


class MdOutlineToggleOn(rx.Component):
    library = "react-icons/md"
    tag = "MdOutlineToggleOn"


