import reflex as rx

class PiAddressBookBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAddressBookBold"


class PiAirTrafficControlBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirTrafficControlBold"


class PiAirplaneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneBold"


class PiAirplaneInFlightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneInFlightBold"


class PiAirplaneLandingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneLandingBold"


class PiAirplaneTakeoffBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTakeoffBold"


class PiAirplaneTiltBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTiltBold"


class PiAirplayBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplayBold"


class PiAlarmBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlarmBold"


class PiAlienBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlienBold"


class PiAlignBottomBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomBold"


class PiAlignBottomSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomSimpleBold"


class PiAlignCenterHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalBold"


class PiAlignCenterHorizontalSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalSimpleBold"


class PiAlignCenterVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalBold"


class PiAlignCenterVerticalSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalSimpleBold"


class PiAlignLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftBold"


class PiAlignLeftSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftSimpleBold"


class PiAlignRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightBold"


class PiAlignRightSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightSimpleBold"


class PiAlignTopBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopBold"


class PiAlignTopSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopSimpleBold"


class PiAmazonLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAmazonLogoBold"


class PiAnchorBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorBold"


class PiAnchorSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorSimpleBold"


class PiAndroidLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAndroidLogoBold"


class PiAngularLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAngularLogoBold"


class PiApertureBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiApertureBold"


class PiAppStoreLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppStoreLogoBold"


class PiAppWindowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppWindowBold"


class PiAppleLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppleLogoBold"


class PiApplePodcastsLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiApplePodcastsLogoBold"


class PiArchiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveBold"


class PiArchiveBoxBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveBoxBold"


class PiArchiveTrayBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveTrayBold"


class PiArmchairBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArmchairBold"


class PiArrowArcLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcLeftBold"


class PiArrowArcRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcRightBold"


class PiArrowBendDoubleUpLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpLeftBold"


class PiArrowBendDoubleUpRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpRightBold"


class PiArrowBendDownLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownLeftBold"


class PiArrowBendDownRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownRightBold"


class PiArrowBendLeftDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftDownBold"


class PiArrowBendLeftUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftUpBold"


class PiArrowBendRightDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightDownBold"


class PiArrowBendRightUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightUpBold"


class PiArrowBendUpLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpLeftBold"


class PiArrowBendUpRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpRightBold"


class PiArrowCircleDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownBold"


class PiArrowCircleDownLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownLeftBold"


class PiArrowCircleDownRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownRightBold"


class PiArrowCircleLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleLeftBold"


class PiArrowCircleRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleRightBold"


class PiArrowCircleUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpBold"


class PiArrowCircleUpLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpLeftBold"


class PiArrowCircleUpRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpRightBold"


class PiArrowClockwiseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowClockwiseBold"


class PiArrowCounterClockwiseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCounterClockwiseBold"


class PiArrowDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownBold"


class PiArrowDownLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownLeftBold"


class PiArrowDownRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownRightBold"


class PiArrowElbowDownLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownLeftBold"


class PiArrowElbowDownRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownRightBold"


class PiArrowElbowLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftBold"


class PiArrowElbowLeftDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftDownBold"


class PiArrowElbowLeftUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftUpBold"


class PiArrowElbowRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightBold"


class PiArrowElbowRightDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightDownBold"


class PiArrowElbowRightUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightUpBold"


class PiArrowElbowUpLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpLeftBold"


class PiArrowElbowUpRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpRightBold"


class PiArrowFatDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatDownBold"


class PiArrowFatLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLeftBold"


class PiArrowFatLineDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineDownBold"


class PiArrowFatLineLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineLeftBold"


class PiArrowFatLineRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineRightBold"


class PiArrowFatLineUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineUpBold"


class PiArrowFatLinesDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesDownBold"


class PiArrowFatLinesLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesLeftBold"


class PiArrowFatLinesRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesRightBold"


class PiArrowFatLinesUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesUpBold"


class PiArrowFatRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatRightBold"


class PiArrowFatUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatUpBold"


class PiArrowLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLeftBold"


class PiArrowLineDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownBold"


class PiArrowLineDownLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownLeftBold"


class PiArrowLineDownRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownRightBold"


class PiArrowLineLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineLeftBold"


class PiArrowLineRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineRightBold"


class PiArrowLineUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpBold"


class PiArrowLineUpLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpLeftBold"


class PiArrowLineUpRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpRightBold"


class PiArrowRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowRightBold"


class PiArrowSquareDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownBold"


class PiArrowSquareDownLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownLeftBold"


class PiArrowSquareDownRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownRightBold"


class PiArrowSquareInBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareInBold"


class PiArrowSquareLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareLeftBold"


class PiArrowSquareOutBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareOutBold"


class PiArrowSquareRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareRightBold"


class PiArrowSquareUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpBold"


class PiArrowSquareUpLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpLeftBold"


class PiArrowSquareUpRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpRightBold"


class PiArrowUDownLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownLeftBold"


class PiArrowUDownRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownRightBold"


class PiArrowULeftDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftDownBold"


class PiArrowULeftUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftUpBold"


class PiArrowURightDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightDownBold"


class PiArrowURightUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightUpBold"


class PiArrowUUpLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpLeftBold"


class PiArrowUUpRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpRightBold"


class PiArrowUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpBold"


class PiArrowUpLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpLeftBold"


class PiArrowUpRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpRightBold"


class PiArrowsClockwiseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsClockwiseBold"


class PiArrowsCounterClockwiseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsCounterClockwiseBold"


class PiArrowsDownUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsDownUpBold"


class PiArrowsHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsHorizontalBold"


class PiArrowsInBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInBold"


class PiArrowsInCardinalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInCardinalBold"


class PiArrowsInLineHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineHorizontalBold"


class PiArrowsInLineVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineVerticalBold"


class PiArrowsInSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInSimpleBold"


class PiArrowsLeftRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsLeftRightBold"


class PiArrowsMergeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsMergeBold"


class PiArrowsOutBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutBold"


class PiArrowsOutCardinalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutCardinalBold"


class PiArrowsOutLineHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineHorizontalBold"


class PiArrowsOutLineVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineVerticalBold"


class PiArrowsOutSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutSimpleBold"


class PiArrowsSplitBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsSplitBold"


class PiArrowsVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsVerticalBold"


class PiArticleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleBold"


class PiArticleMediumBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleMediumBold"


class PiArticleNyTimesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleNyTimesBold"


class PiAsteriskBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskBold"


class PiAsteriskSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskSimpleBold"


class PiAtBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtBold"


class PiAtomBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtomBold"


class PiBabyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBabyBold"


class PiBackpackBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackpackBold"


class PiBackspaceBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackspaceBold"


class PiBagBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagBold"


class PiBagSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagSimpleBold"


class PiBalloonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBalloonBold"


class PiBandaidsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBandaidsBold"


class PiBankBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBankBold"


class PiBarbellBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarbellBold"


class PiBarcodeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarcodeBold"


class PiBarricadeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarricadeBold"


class PiBaseballBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballBold"


class PiBaseballCapBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballCapBold"


class PiBasketBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketBold"


class PiBasketballBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketballBold"


class PiBathtubBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBathtubBold"


class PiBatteryChargingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingBold"


class PiBatteryChargingVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingVerticalBold"


class PiBatteryEmptyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryEmptyBold"


class PiBatteryFullBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryFullBold"


class PiBatteryHighBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryHighBold"


class PiBatteryLowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryLowBold"


class PiBatteryMediumBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryMediumBold"


class PiBatteryPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusBold"


class PiBatteryPlusVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusVerticalBold"


class PiBatteryVerticalEmptyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalEmptyBold"


class PiBatteryVerticalFullBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalFullBold"


class PiBatteryVerticalHighBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalHighBold"


class PiBatteryVerticalLowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalLowBold"


class PiBatteryVerticalMediumBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalMediumBold"


class PiBatteryWarningBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningBold"


class PiBatteryWarningVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningVerticalBold"


class PiBedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBedBold"


class PiBeerBottleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerBottleBold"


class PiBeerSteinBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerSteinBold"


class PiBehanceLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBehanceLogoBold"


class PiBellBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellBold"


class PiBellRingingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellRingingBold"


class PiBellSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleBold"


class PiBellSimpleRingingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleRingingBold"


class PiBellSimpleSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleSlashBold"


class PiBellSimpleZBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleZBold"


class PiBellSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSlashBold"


class PiBellZBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellZBold"


class PiBezierCurveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBezierCurveBold"


class PiBicycleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBicycleBold"


class PiBinocularsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBinocularsBold"


class PiBirdBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBirdBold"


class PiBluetoothBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothBold"


class PiBluetoothConnectedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothConnectedBold"


class PiBluetoothSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothSlashBold"


class PiBluetoothXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothXBold"


class PiBoatBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoatBold"


class PiBoneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoneBold"


class PiBookBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookBold"


class PiBookBookmarkBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookBookmarkBold"


class PiBookOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenBold"


class PiBookOpenTextBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenTextBold"


class PiBookmarkBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkBold"


class PiBookmarkSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkSimpleBold"


class PiBookmarksBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksBold"


class PiBookmarksSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksSimpleBold"


class PiBooksBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBooksBold"


class PiBootBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBootBold"


class PiBoundingBoxBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoundingBoxBold"


class PiBowlFoodBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBowlFoodBold"


class PiBracketsAngleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsAngleBold"


class PiBracketsCurlyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsCurlyBold"


class PiBracketsRoundBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsRoundBold"


class PiBracketsSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsSquareBold"


class PiBrainBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrainBold"


class PiBrandyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrandyBold"


class PiBridgeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBridgeBold"


class PiBriefcaseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseBold"


class PiBriefcaseMetalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseMetalBold"


class PiBroadcastBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroadcastBold"


class PiBroomBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroomBold"


class PiBrowserBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowserBold"


class PiBrowsersBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowsersBold"


class PiBugBeetleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugBeetleBold"


class PiBugBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugBold"


class PiBugDroidBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugDroidBold"


class PiBuildingsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBuildingsBold"


class PiBusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiBusBold"


class PiButterflyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiButterflyBold"


class PiCactusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCactusBold"


class PiCakeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCakeBold"


class PiCalculatorBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalculatorBold"


class PiCalendarBlankBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarBlankBold"


class PiCalendarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarBold"


class PiCalendarCheckBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarCheckBold"


class PiCalendarPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarPlusBold"


class PiCalendarXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarXBold"


class PiCallBellBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCallBellBold"


class PiCameraBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraBold"


class PiCameraPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraPlusBold"


class PiCameraRotateBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraRotateBold"


class PiCameraSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraSlashBold"


class PiCampfireBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCampfireBold"


class PiCarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarBold"


class PiCarProfileBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarProfileBold"


class PiCarSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarSimpleBold"


class PiCardholderBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardholderBold"


class PiCardsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardsBold"


class PiCaretCircleDoubleDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleDownBold"


class PiCaretCircleDoubleLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleLeftBold"


class PiCaretCircleDoubleRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleRightBold"


class PiCaretCircleDoubleUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleUpBold"


class PiCaretCircleDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDownBold"


class PiCaretCircleLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleLeftBold"


class PiCaretCircleRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleRightBold"


class PiCaretCircleUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpBold"


class PiCaretCircleUpDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpDownBold"


class PiCaretDoubleDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleDownBold"


class PiCaretDoubleLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleLeftBold"


class PiCaretDoubleRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleRightBold"


class PiCaretDoubleUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleUpBold"


class PiCaretDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDownBold"


class PiCaretLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretLeftBold"


class PiCaretRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretRightBold"


class PiCaretUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpBold"


class PiCaretUpDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpDownBold"


class PiCarrotBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarrotBold"


class PiCassetteTapeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCassetteTapeBold"


class PiCastleTurretBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCastleTurretBold"


class PiCatBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCatBold"


class PiCellSignalFullBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalFullBold"


class PiCellSignalHighBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalHighBold"


class PiCellSignalLowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalLowBold"


class PiCellSignalMediumBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalMediumBold"


class PiCellSignalNoneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalNoneBold"


class PiCellSignalSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalSlashBold"


class PiCellSignalXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalXBold"


class PiCertificateBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCertificateBold"


class PiChairBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChairBold"


class PiChalkboardBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardBold"


class PiChalkboardSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardSimpleBold"


class PiChalkboardTeacherBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardTeacherBold"


class PiChampagneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChampagneBold"


class PiChargingStationBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChargingStationBold"


class PiChartBarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarBold"


class PiChartBarHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarHorizontalBold"


class PiChartDonutBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartDonutBold"


class PiChartLineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineBold"


class PiChartLineDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineDownBold"


class PiChartLineUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineUpBold"


class PiChartPieBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieBold"


class PiChartPieSliceBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieSliceBold"


class PiChartPolarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPolarBold"


class PiChartScatterBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartScatterBold"


class PiChatBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatBold"


class PiChatCenteredBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredBold"


class PiChatCenteredDotsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredDotsBold"


class PiChatCenteredTextBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredTextBold"


class PiChatCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleBold"


class PiChatCircleDotsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleDotsBold"


class PiChatCircleTextBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleTextBold"


class PiChatDotsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatDotsBold"


class PiChatTeardropBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropBold"


class PiChatTeardropDotsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropDotsBold"


class PiChatTeardropTextBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropTextBold"


class PiChatTextBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTextBold"


class PiChatsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsBold"


class PiChatsCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsCircleBold"


class PiChatsTeardropBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsTeardropBold"


class PiCheckBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckBold"


class PiCheckCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckCircleBold"


class PiCheckFatBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckFatBold"


class PiCheckSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareBold"


class PiCheckSquareOffsetBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareOffsetBold"


class PiChecksBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChecksBold"


class PiChurchBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiChurchBold"


class PiCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleBold"


class PiCircleDashedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleDashedBold"


class PiCircleHalfBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfBold"


class PiCircleHalfTiltBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfTiltBold"


class PiCircleNotchBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleNotchBold"


class PiCirclesFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesFourBold"


class PiCirclesThreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreeBold"


class PiCirclesThreePlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreePlusBold"


class PiCircuitryBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircuitryBold"


class PiClipboardBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardBold"


class PiClipboardTextBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardTextBold"


class PiClockAfternoonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockAfternoonBold"


class PiClockBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockBold"


class PiClockClockwiseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockClockwiseBold"


class PiClockCountdownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCountdownBold"


class PiClockCounterClockwiseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCounterClockwiseBold"


class PiClosedCaptioningBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiClosedCaptioningBold"


class PiCloudArrowDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowDownBold"


class PiCloudArrowUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowUpBold"


class PiCloudBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudBold"


class PiCloudCheckBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudCheckBold"


class PiCloudFogBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudFogBold"


class PiCloudLightningBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudLightningBold"


class PiCloudMoonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudMoonBold"


class PiCloudRainBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudRainBold"


class PiCloudSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSlashBold"


class PiCloudSnowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSnowBold"


class PiCloudSunBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSunBold"


class PiCloudWarningBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudWarningBold"


class PiCloudXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudXBold"


class PiClubBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiClubBold"


class PiCoatHangerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoatHangerBold"


class PiCodaLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodaLogoBold"


class PiCodeBlockBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeBlockBold"


class PiCodeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeBold"


class PiCodeSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeSimpleBold"


class PiCodepenLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodepenLogoBold"


class PiCodesandboxLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodesandboxLogoBold"


class PiCoffeeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoffeeBold"


class PiCoinBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinBold"


class PiCoinVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinVerticalBold"


class PiCoinsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinsBold"


class PiColumnsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiColumnsBold"


class PiCommandBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCommandBold"


class PiCompassBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassBold"


class PiCompassToolBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassToolBold"


class PiComputerTowerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiComputerTowerBold"


class PiConfettiBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiConfettiBold"


class PiContactlessPaymentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiContactlessPaymentBold"


class PiControlBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiControlBold"


class PiCookieBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookieBold"


class PiCookingPotBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookingPotBold"


class PiCopyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyBold"


class PiCopySimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopySimpleBold"


class PiCopyleftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyleftBold"


class PiCopyrightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyrightBold"


class PiCornersInBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersInBold"


class PiCornersOutBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersOutBold"


class PiCouchBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCouchBold"


class PiCpuBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCpuBold"


class PiCreditCardBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCreditCardBold"


class PiCropBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCropBold"


class PiCrossBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrossBold"


class PiCrosshairBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairBold"


class PiCrosshairSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairSimpleBold"


class PiCrownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownBold"


class PiCrownSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownSimpleBold"


class PiCubeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeBold"


class PiCubeFocusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeFocusBold"


class PiCubeTransparentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeTransparentBold"


class PiCurrencyBtcBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyBtcBold"


class PiCurrencyCircleDollarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCircleDollarBold"


class PiCurrencyCnyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCnyBold"


class PiCurrencyDollarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarBold"


class PiCurrencyDollarSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarSimpleBold"


class PiCurrencyEthBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEthBold"


class PiCurrencyEurBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEurBold"


class PiCurrencyGbpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyGbpBold"


class PiCurrencyInrBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyInrBold"


class PiCurrencyJpyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyJpyBold"


class PiCurrencyKrwBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKrwBold"


class PiCurrencyKztBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKztBold"


class PiCurrencyNgnBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyNgnBold"


class PiCurrencyRubBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyRubBold"


class PiCursorBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorBold"


class PiCursorClickBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorClickBold"


class PiCursorTextBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorTextBold"


class PiCylinderBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiCylinderBold"


class PiDatabaseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDatabaseBold"


class PiDesktopBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopBold"


class PiDesktopTowerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopTowerBold"


class PiDetectiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDetectiveBold"


class PiDevToLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevToLogoBold"


class PiDeviceMobileBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileBold"


class PiDeviceMobileCameraBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileCameraBold"


class PiDeviceMobileSpeakerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileSpeakerBold"


class PiDeviceTabletBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletBold"


class PiDeviceTabletCameraBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletCameraBold"


class PiDeviceTabletSpeakerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletSpeakerBold"


class PiDevicesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevicesBold"


class PiDiamondBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondBold"


class PiDiamondsFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondsFourBold"


class PiDiceFiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFiveBold"


class PiDiceFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFourBold"


class PiDiceOneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceOneBold"


class PiDiceSixBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceSixBold"


class PiDiceThreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceThreeBold"


class PiDiceTwoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceTwoBold"


class PiDiscBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscBold"


class PiDiscordLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscordLogoBold"


class PiDivideBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDivideBold"


class PiDnaBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDnaBold"


class PiDogBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDogBold"


class PiDoorBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorBold"


class PiDoorOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorOpenBold"


class PiDotBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotBold"


class PiDotOutlineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotOutlineBold"


class PiDotsNineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsNineBold"


class PiDotsSixBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixBold"


class PiDotsSixVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixVerticalBold"


class PiDotsThreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeBold"


class PiDotsThreeCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleBold"


class PiDotsThreeCircleVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleVerticalBold"


class PiDotsThreeOutlineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineBold"


class PiDotsThreeOutlineVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineVerticalBold"


class PiDotsThreeVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeVerticalBold"


class PiDownloadBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadBold"


class PiDownloadSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadSimpleBold"


class PiDressBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDressBold"


class PiDribbbleLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDribbbleLogoBold"


class PiDropBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropBold"


class PiDropHalfBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfBold"


class PiDropHalfBottomBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfBottomBold"


class PiDropboxLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropboxLogoBold"


class PiEarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarBold"


class PiEarSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarSlashBold"


class PiEggBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggBold"


class PiEggCrackBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggCrackBold"


class PiEjectBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectBold"


class PiEjectSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectSimpleBold"


class PiElevatorBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiElevatorBold"


class PiEngineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEngineBold"


class PiEnvelopeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeBold"


class PiEnvelopeOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeOpenBold"


class PiEnvelopeSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleBold"


class PiEnvelopeSimpleOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleOpenBold"


class PiEqualizerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualizerBold"


class PiEqualsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualsBold"


class PiEraserBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEraserBold"


class PiEscalatorDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorDownBold"


class PiEscalatorUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorUpBold"


class PiExamBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiExamBold"


class PiExcludeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeBold"


class PiExcludeSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeSquareBold"


class PiExportBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiExportBold"


class PiEyeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeBold"


class PiEyeClosedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeClosedBold"


class PiEyeSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeSlashBold"


class PiEyedropperBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperBold"


class PiEyedropperSampleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperSampleBold"


class PiEyeglassesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeglassesBold"


class PiFaceMaskBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFaceMaskBold"


class PiFacebookLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFacebookLogoBold"


class PiFactoryBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFactoryBold"


class PiFadersBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersBold"


class PiFadersHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersHorizontalBold"


class PiFanBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFanBold"


class PiFastForwardBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardBold"


class PiFastForwardCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardCircleBold"


class PiFeatherBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFeatherBold"


class PiFigmaLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFigmaLogoBold"


class PiFileArchiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArchiveBold"


class PiFileArrowDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowDownBold"


class PiFileArrowUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowUpBold"


class PiFileAudioBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileAudioBold"


class PiFileBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileBold"


class PiFileCloudBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCloudBold"


class PiFileCodeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCodeBold"


class PiFileCssBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCssBold"


class PiFileCsvBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCsvBold"


class PiFileDashedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDashedBold"


class PiFileDocBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDocBold"


class PiFileHtmlBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileHtmlBold"


class PiFileImageBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileImageBold"


class PiFileJpgBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJpgBold"


class PiFileJsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsBold"


class PiFileJsxBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsxBold"


class PiFileLockBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileLockBold"


class PiFileMagnifyingGlassBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMagnifyingGlassBold"


class PiFileMinusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMinusBold"


class PiFilePdfBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePdfBold"


class PiFilePlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePlusBold"


class PiFilePngBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePngBold"


class PiFilePptBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePptBold"


class PiFileRsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileRsBold"


class PiFileSqlBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSqlBold"


class PiFileSvgBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSvgBold"


class PiFileTextBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTextBold"


class PiFileTsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsBold"


class PiFileTsxBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsxBold"


class PiFileVideoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVideoBold"


class PiFileVueBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVueBold"


class PiFileXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXBold"


class PiFileXlsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXlsBold"


class PiFileZipBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileZipBold"


class PiFilesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilesBold"


class PiFilmReelBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmReelBold"


class PiFilmScriptBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmScriptBold"


class PiFilmSlateBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmSlateBold"


class PiFilmStripBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmStripBold"


class PiFingerprintBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintBold"


class PiFingerprintSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintSimpleBold"


class PiFinnTheHumanBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFinnTheHumanBold"


class PiFireBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireBold"


class PiFireExtinguisherBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireExtinguisherBold"


class PiFireSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireSimpleBold"


class PiFirstAidBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidBold"


class PiFirstAidKitBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidKitBold"


class PiFishBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishBold"


class PiFishSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishSimpleBold"


class PiFlagBannerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagBannerBold"


class PiFlagBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagBold"


class PiFlagCheckeredBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagCheckeredBold"


class PiFlagPennantBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagPennantBold"


class PiFlameBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlameBold"


class PiFlashlightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlashlightBold"


class PiFlaskBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlaskBold"


class PiFloppyDiskBackBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskBackBold"


class PiFloppyDiskBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskBold"


class PiFlowArrowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowArrowBold"


class PiFlowerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerBold"


class PiFlowerLotusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerLotusBold"


class PiFlowerTulipBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerTulipBold"


class PiFlyingSaucerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlyingSaucerBold"


class PiFolderBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderBold"


class PiFolderDashedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderDashedBold"


class PiFolderLockBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderLockBold"


class PiFolderMinusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderMinusBold"


class PiFolderNotchBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchBold"


class PiFolderNotchMinusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchMinusBold"


class PiFolderNotchOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchOpenBold"


class PiFolderNotchPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchPlusBold"


class PiFolderOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderOpenBold"


class PiFolderPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderPlusBold"


class PiFolderSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleBold"


class PiFolderSimpleDashedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleDashedBold"


class PiFolderSimpleLockBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleLockBold"


class PiFolderSimpleMinusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleMinusBold"


class PiFolderSimplePlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimplePlusBold"


class PiFolderSimpleStarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleStarBold"


class PiFolderSimpleUserBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleUserBold"


class PiFolderStarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderStarBold"


class PiFolderUserBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderUserBold"


class PiFoldersBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFoldersBold"


class PiFootballBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootballBold"


class PiFootprintsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootprintsBold"


class PiForkKnifeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiForkKnifeBold"


class PiFrameCornersBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFrameCornersBold"


class PiFramerLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFramerLogoBold"


class PiFunctionBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunctionBold"


class PiFunnelBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelBold"


class PiFunnelSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelSimpleBold"


class PiGameControllerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGameControllerBold"


class PiGarageBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGarageBold"


class PiGasCanBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasCanBold"


class PiGasPumpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasPumpBold"


class PiGaugeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGaugeBold"


class PiGavelBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGavelBold"


class PiGearBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearBold"


class PiGearFineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearFineBold"


class PiGearSixBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearSixBold"


class PiGenderFemaleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderFemaleBold"


class PiGenderIntersexBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderIntersexBold"


class PiGenderMaleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderMaleBold"


class PiGenderNeuterBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNeuterBold"


class PiGenderNonbinaryBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNonbinaryBold"


class PiGenderTransgenderBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderTransgenderBold"


class PiGhostBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGhostBold"


class PiGifBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGifBold"


class PiGiftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGiftBold"


class PiGitBranchBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitBranchBold"


class PiGitCommitBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitCommitBold"


class PiGitDiffBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitDiffBold"


class PiGitForkBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitForkBold"


class PiGitMergeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitMergeBold"


class PiGitPullRequestBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitPullRequestBold"


class PiGithubLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGithubLogoBold"


class PiGitlabLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoBold"


class PiGitlabLogoSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoSimpleBold"


class PiGlobeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeBold"


class PiGlobeHemisphereEastBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereEastBold"


class PiGlobeHemisphereWestBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereWestBold"


class PiGlobeSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeSimpleBold"


class PiGlobeStandBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeStandBold"


class PiGogglesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGogglesBold"


class PiGoodreadsLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoodreadsLogoBold"


class PiGoogleCardboardLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleCardboardLogoBold"


class PiGoogleChromeLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleChromeLogoBold"


class PiGoogleDriveLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleDriveLogoBold"


class PiGoogleLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleLogoBold"


class PiGooglePhotosLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePhotosLogoBold"


class PiGooglePlayLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePlayLogoBold"


class PiGooglePodcastsLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePodcastsLogoBold"


class PiGradientBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGradientBold"


class PiGraduationCapBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraduationCapBold"


class PiGrainsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsBold"


class PiGrainsSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsSlashBold"


class PiGraphBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraphBold"


class PiGridFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridFourBold"


class PiGridNineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridNineBold"


class PiGuitarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiGuitarBold"


class PiHamburgerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHamburgerBold"


class PiHammerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHammerBold"


class PiHandBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandBold"


class PiHandCoinsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandCoinsBold"


class PiHandEyeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandEyeBold"


class PiHandFistBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandFistBold"


class PiHandGrabbingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandGrabbingBold"


class PiHandHeartBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandHeartBold"


class PiHandPalmBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPalmBold"


class PiHandPointingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPointingBold"


class PiHandSoapBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSoapBold"


class PiHandSwipeLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeLeftBold"


class PiHandSwipeRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeRightBold"


class PiHandTapBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandTapBold"


class PiHandWavingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandWavingBold"


class PiHandbagBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagBold"


class PiHandbagSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagSimpleBold"


class PiHandsClappingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsClappingBold"


class PiHandsPrayingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsPrayingBold"


class PiHandshakeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandshakeBold"


class PiHardDriveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDriveBold"


class PiHardDrivesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDrivesBold"


class PiHashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashBold"


class PiHashStraightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashStraightBold"


class PiHeadlightsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadlightsBold"


class PiHeadphonesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadphonesBold"


class PiHeadsetBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadsetBold"


class PiHeartBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartBold"


class PiHeartBreakBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartBreakBold"


class PiHeartHalfBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartHalfBold"


class PiHeartStraightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightBold"


class PiHeartStraightBreakBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightBreakBold"


class PiHeartbeatBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartbeatBold"


class PiHexagonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHexagonBold"


class PiHighHeelBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighHeelBold"


class PiHighlighterCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighlighterCircleBold"


class PiHoodieBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHoodieBold"


class PiHorseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHorseBold"


class PiHourglassBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassBold"


class PiHourglassHighBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassHighBold"


class PiHourglassLowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassLowBold"


class PiHourglassMediumBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassMediumBold"


class PiHourglassSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleBold"


class PiHourglassSimpleHighBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleHighBold"


class PiHourglassSimpleLowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleLowBold"


class PiHourglassSimpleMediumBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleMediumBold"


class PiHouseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseBold"


class PiHouseLineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseLineBold"


class PiHouseSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseSimpleBold"


class PiIceCreamBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiIceCreamBold"


class PiIdentificationBadgeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationBadgeBold"


class PiIdentificationCardBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationCardBold"


class PiImageBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageBold"


class PiImageSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageSquareBold"


class PiImagesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesBold"


class PiImagesSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesSquareBold"


class PiInfinityBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfinityBold"


class PiInfoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfoBold"


class PiInstagramLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiInstagramLogoBold"


class PiIntersectBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectBold"


class PiIntersectSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectSquareBold"


class PiIntersectThreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectThreeBold"


class PiJeepBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiJeepBold"


class PiKanbanBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiKanbanBold"


class PiKeyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyBold"


class PiKeyReturnBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyReturnBold"


class PiKeyboardBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyboardBold"


class PiKeyholeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyholeBold"


class PiKnifeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiKnifeBold"


class PiLadderBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderBold"


class PiLadderSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderSimpleBold"


class PiLampBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLampBold"


class PiLaptopBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLaptopBold"


class PiLayoutBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLayoutBold"


class PiLeafBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLeafBold"


class PiLifebuoyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLifebuoyBold"


class PiLightbulbBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbBold"


class PiLightbulbFilamentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbFilamentBold"


class PiLighthouseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLighthouseBold"


class PiLightningABold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningABold"


class PiLightningBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningBold"


class PiLightningSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningSlashBold"


class PiLineSegmentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentBold"


class PiLineSegmentsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentsBold"


class PiLinkBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkBold"


class PiLinkBreakBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkBreakBold"


class PiLinkSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleBold"


class PiLinkSimpleBreakBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleBreakBold"


class PiLinkSimpleHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalBold"


class PiLinkSimpleHorizontalBreakBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalBreakBold"


class PiLinkedinLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkedinLogoBold"


class PiLinuxLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinuxLogoBold"


class PiListBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiListBold"


class PiListBulletsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiListBulletsBold"


class PiListChecksBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiListChecksBold"


class PiListDashesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiListDashesBold"


class PiListMagnifyingGlassBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiListMagnifyingGlassBold"


class PiListNumbersBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiListNumbersBold"


class PiListPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiListPlusBold"


class PiLockBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockBold"


class PiLockKeyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyBold"


class PiLockKeyOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyOpenBold"


class PiLockLaminatedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedBold"


class PiLockLaminatedOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedOpenBold"


class PiLockOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockOpenBold"


class PiLockSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleBold"


class PiLockSimpleOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleOpenBold"


class PiLockersBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockersBold"


class PiMagicWandBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagicWandBold"


class PiMagnetBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetBold"


class PiMagnetStraightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetStraightBold"


class PiMagnifyingGlassBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassBold"


class PiMagnifyingGlassMinusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassMinusBold"


class PiMagnifyingGlassPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassPlusBold"


class PiMapPinBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinBold"


class PiMapPinLineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinLineBold"


class PiMapTrifoldBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapTrifoldBold"


class PiMarkerCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMarkerCircleBold"


class PiMartiniBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMartiniBold"


class PiMaskHappyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskHappyBold"


class PiMaskSadBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskSadBold"


class PiMathOperationsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMathOperationsBold"


class PiMedalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalBold"


class PiMedalMilitaryBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalMilitaryBold"


class PiMediumLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMediumLogoBold"


class PiMegaphoneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneBold"


class PiMegaphoneSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneSimpleBold"


class PiMessengerLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMessengerLogoBold"


class PiMetaLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetaLogoBold"


class PiMetronomeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetronomeBold"


class PiMicrophoneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneBold"


class PiMicrophoneSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneSlashBold"


class PiMicrophoneStageBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneStageBold"


class PiMicrosoftExcelLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftExcelLogoBold"


class PiMicrosoftOutlookLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftOutlookLogoBold"


class PiMicrosoftPowerpointLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftPowerpointLogoBold"


class PiMicrosoftTeamsLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftTeamsLogoBold"


class PiMicrosoftWordLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftWordLogoBold"


class PiMinusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusBold"


class PiMinusCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusCircleBold"


class PiMinusSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusSquareBold"


class PiMoneyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoneyBold"


class PiMonitorBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorBold"


class PiMonitorPlayBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorPlayBold"


class PiMoonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonBold"


class PiMoonStarsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonStarsBold"


class PiMopedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedBold"


class PiMopedFrontBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedFrontBold"


class PiMosqueBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMosqueBold"


class PiMotorcycleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMotorcycleBold"


class PiMountainsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMountainsBold"


class PiMouseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseBold"


class PiMouseSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseSimpleBold"


class PiMusicNoteBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteBold"


class PiMusicNoteSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteSimpleBold"


class PiMusicNotesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesBold"


class PiMusicNotesPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesPlusBold"


class PiMusicNotesSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesSimpleBold"


class PiNavigationArrowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNavigationArrowBold"


class PiNeedleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNeedleBold"


class PiNewspaperBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperBold"


class PiNewspaperClippingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperClippingBold"


class PiNotchesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotchesBold"


class PiNoteBlankBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteBlankBold"


class PiNoteBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteBold"


class PiNotePencilBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotePencilBold"


class PiNotebookBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotebookBold"


class PiNotepadBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotepadBold"


class PiNotificationBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotificationBold"


class PiNotionLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotionLogoBold"


class PiNumberCircleEightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleEightBold"


class PiNumberCircleFiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFiveBold"


class PiNumberCircleFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFourBold"


class PiNumberCircleNineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleNineBold"


class PiNumberCircleOneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleOneBold"


class PiNumberCircleSevenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSevenBold"


class PiNumberCircleSixBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSixBold"


class PiNumberCircleThreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleThreeBold"


class PiNumberCircleTwoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleTwoBold"


class PiNumberCircleZeroBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleZeroBold"


class PiNumberEightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberEightBold"


class PiNumberFiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFiveBold"


class PiNumberFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFourBold"


class PiNumberNineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberNineBold"


class PiNumberOneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberOneBold"


class PiNumberSevenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSevenBold"


class PiNumberSixBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSixBold"


class PiNumberSquareEightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareEightBold"


class PiNumberSquareFiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFiveBold"


class PiNumberSquareFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFourBold"


class PiNumberSquareNineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareNineBold"


class PiNumberSquareOneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareOneBold"


class PiNumberSquareSevenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSevenBold"


class PiNumberSquareSixBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSixBold"


class PiNumberSquareThreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareThreeBold"


class PiNumberSquareTwoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareTwoBold"


class PiNumberSquareZeroBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareZeroBold"


class PiNumberThreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberThreeBold"


class PiNumberTwoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberTwoBold"


class PiNumberZeroBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberZeroBold"


class PiNutBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNutBold"


class PiNyTimesLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiNyTimesLogoBold"


class PiOctagonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiOctagonBold"


class PiOfficeChairBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiOfficeChairBold"


class PiOptionBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiOptionBold"


class PiOrangeSliceBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiOrangeSliceBold"


class PiPackageBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPackageBold"


class PiPaintBrushBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushBold"


class PiPaintBrushBroadBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushBroadBold"


class PiPaintBrushHouseholdBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushHouseholdBold"


class PiPaintBucketBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBucketBold"


class PiPaintRollerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintRollerBold"


class PiPaletteBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaletteBold"


class PiPantsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPantsBold"


class PiPaperPlaneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneBold"


class PiPaperPlaneRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneRightBold"


class PiPaperPlaneTiltBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneTiltBold"


class PiPaperclipBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipBold"


class PiPaperclipHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipHorizontalBold"


class PiParachuteBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiParachuteBold"


class PiParagraphBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiParagraphBold"


class PiParallelogramBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiParallelogramBold"


class PiParkBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiParkBold"


class PiPasswordBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPasswordBold"


class PiPathBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPathBold"


class PiPatreonLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPatreonLogoBold"


class PiPauseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseBold"


class PiPauseCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseCircleBold"


class PiPawPrintBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPawPrintBold"


class PiPaypalLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaypalLogoBold"


class PiPeaceBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPeaceBold"


class PiPenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenBold"


class PiPenNibBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibBold"


class PiPenNibStraightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibStraightBold"


class PiPencilBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilBold"


class PiPencilCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilCircleBold"


class PiPencilLineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilLineBold"


class PiPencilSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleBold"


class PiPencilSimpleLineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleLineBold"


class PiPencilSimpleSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleSlashBold"


class PiPencilSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSlashBold"


class PiPentagramBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPentagramBold"


class PiPepperBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPepperBold"


class PiPercentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPercentBold"


class PiPersonArmsSpreadBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonArmsSpreadBold"


class PiPersonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonBold"


class PiPersonSimpleBikeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleBikeBold"


class PiPersonSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleBold"


class PiPersonSimpleRunBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleRunBold"


class PiPersonSimpleThrowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleThrowBold"


class PiPersonSimpleWalkBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleWalkBold"


class PiPerspectiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPerspectiveBold"


class PiPhoneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneBold"


class PiPhoneCallBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneCallBold"


class PiPhoneDisconnectBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneDisconnectBold"


class PiPhoneIncomingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneIncomingBold"


class PiPhoneOutgoingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneOutgoingBold"


class PiPhonePlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhonePlusBold"


class PiPhoneSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneSlashBold"


class PiPhoneXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneXBold"


class PiPhosphorLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhosphorLogoBold"


class PiPiBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiBold"


class PiPianoKeysBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPianoKeysBold"


class PiPictureInPictureBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPictureInPictureBold"


class PiPiggyBankBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiggyBankBold"


class PiPillBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPillBold"


class PiPinterestLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinterestLogoBold"


class PiPinwheelBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinwheelBold"


class PiPizzaBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPizzaBold"


class PiPlaceholderBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaceholderBold"


class PiPlanetBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlanetBold"


class PiPlantBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlantBold"


class PiPlayBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayBold"


class PiPlayCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayCircleBold"


class PiPlayPauseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayPauseBold"


class PiPlaylistBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaylistBold"


class PiPlugBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugBold"


class PiPlugChargingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugChargingBold"


class PiPlugsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsBold"


class PiPlugsConnectedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsConnectedBold"


class PiPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusBold"


class PiPlusCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusCircleBold"


class PiPlusMinusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusMinusBold"


class PiPlusSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusSquareBold"


class PiPokerChipBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPokerChipBold"


class PiPoliceCarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPoliceCarBold"


class PiPolygonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPolygonBold"


class PiPopcornBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPopcornBold"


class PiPottedPlantBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPottedPlantBold"


class PiPowerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPowerBold"


class PiPrescriptionBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrescriptionBold"


class PiPresentationBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationBold"


class PiPresentationChartBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationChartBold"


class PiPrinterBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrinterBold"


class PiProhibitBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitBold"


class PiProhibitInsetBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitInsetBold"


class PiProjectorScreenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenBold"


class PiProjectorScreenChartBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenChartBold"


class PiPulseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPulseBold"


class PiPushPinBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinBold"


class PiPushPinSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleBold"


class PiPushPinSimpleSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleSlashBold"


class PiPushPinSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSlashBold"


class PiPuzzlePieceBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPuzzlePieceBold"


class PiQrCodeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiQrCodeBold"


class PiQuestionBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuestionBold"


class PiQueueBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiQueueBold"


class PiQuotesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuotesBold"


class PiRadicalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadicalBold"


class PiRadioBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioBold"


class PiRadioButtonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioButtonBold"


class PiRadioactiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioactiveBold"


class PiRainbowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowBold"


class PiRainbowCloudBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowCloudBold"


class PiReadCvLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiReadCvLogoBold"


class PiReceiptBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptBold"


class PiReceiptXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptXBold"


class PiRecordBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecordBold"


class PiRectangleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRectangleBold"


class PiRecycleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecycleBold"


class PiRedditLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRedditLogoBold"


class PiRepeatBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatBold"


class PiRepeatOnceBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatOnceBold"


class PiRewindBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindBold"


class PiRewindCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindCircleBold"


class PiRoadHorizonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRoadHorizonBold"


class PiRobotBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRobotBold"


class PiRocketBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketBold"


class PiRocketLaunchBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketLaunchBold"


class PiRowsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRowsBold"


class PiRssBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssBold"


class PiRssSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssSimpleBold"


class PiRugBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRugBold"


class PiRulerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiRulerBold"


class PiScalesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiScalesBold"


class PiScanBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiScanBold"


class PiScissorsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiScissorsBold"


class PiScooterBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiScooterBold"


class PiScreencastBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiScreencastBold"


class PiScribbleLoopBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiScribbleLoopBold"


class PiScrollBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiScrollBold"


class PiSealBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealBold"


class PiSealCheckBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealCheckBold"


class PiSealQuestionBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealQuestionBold"


class PiSealWarningBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealWarningBold"


class PiSelectionAllBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionAllBold"


class PiSelectionBackgroundBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionBackgroundBold"


class PiSelectionBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionBold"


class PiSelectionForegroundBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionForegroundBold"


class PiSelectionInverseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionInverseBold"


class PiSelectionPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionPlusBold"


class PiSelectionSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionSlashBold"


class PiShapesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShapesBold"


class PiShareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareBold"


class PiShareFatBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareFatBold"


class PiShareNetworkBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareNetworkBold"


class PiShieldBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldBold"


class PiShieldCheckBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckBold"


class PiShieldCheckeredBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckeredBold"


class PiShieldChevronBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldChevronBold"


class PiShieldPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldPlusBold"


class PiShieldSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldSlashBold"


class PiShieldStarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldStarBold"


class PiShieldWarningBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldWarningBold"


class PiShirtFoldedBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShirtFoldedBold"


class PiShootingStarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShootingStarBold"


class PiShoppingBagBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagBold"


class PiShoppingBagOpenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagOpenBold"


class PiShoppingCartBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartBold"


class PiShoppingCartSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartSimpleBold"


class PiShowerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShowerBold"


class PiShrimpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShrimpBold"


class PiShuffleAngularBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleAngularBold"


class PiShuffleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleBold"


class PiShuffleSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleSimpleBold"


class PiSidebarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarBold"


class PiSidebarSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarSimpleBold"


class PiSigmaBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSigmaBold"


class PiSignInBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignInBold"


class PiSignOutBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignOutBold"


class PiSignatureBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignatureBold"


class PiSignpostBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignpostBold"


class PiSimCardBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSimCardBold"


class PiSirenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSirenBold"


class PiSketchLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSketchLogoBold"


class PiSkipBackBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackBold"


class PiSkipBackCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackCircleBold"


class PiSkipForwardBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardBold"


class PiSkipForwardCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardCircleBold"


class PiSkullBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkullBold"


class PiSlackLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlackLogoBold"


class PiSlidersBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersBold"


class PiSlidersHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersHorizontalBold"


class PiSlideshowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlideshowBold"


class PiSmileyAngryBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyAngryBold"


class PiSmileyBlankBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyBlankBold"


class PiSmileyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyBold"


class PiSmileyMehBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyMehBold"


class PiSmileyNervousBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyNervousBold"


class PiSmileySadBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileySadBold"


class PiSmileyStickerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyStickerBold"


class PiSmileyWinkBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyWinkBold"


class PiSmileyXEyesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyXEyesBold"


class PiSnapchatLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnapchatLogoBold"


class PiSneakerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerBold"


class PiSneakerMoveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerMoveBold"


class PiSnowflakeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnowflakeBold"


class PiSoccerBallBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoccerBallBold"


class PiSortAscendingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortAscendingBold"


class PiSortDescendingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortDescendingBold"


class PiSoundcloudLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoundcloudLogoBold"


class PiSpadeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpadeBold"


class PiSparkleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSparkleBold"


class PiSpeakerHifiBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHifiBold"


class PiSpeakerHighBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHighBold"


class PiSpeakerLowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerLowBold"


class PiSpeakerNoneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerNoneBold"


class PiSpeakerSimpleHighBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleHighBold"


class PiSpeakerSimpleLowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleLowBold"


class PiSpeakerSimpleNoneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleNoneBold"


class PiSpeakerSimpleSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleSlashBold"


class PiSpeakerSimpleXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleXBold"


class PiSpeakerSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSlashBold"


class PiSpeakerXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerXBold"


class PiSpinnerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerBold"


class PiSpinnerGapBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerGapBold"


class PiSpiralBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpiralBold"


class PiSplitHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitHorizontalBold"


class PiSplitVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitVerticalBold"


class PiSpotifyLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpotifyLogoBold"


class PiSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareBold"


class PiSquareHalfBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfBold"


class PiSquareHalfBottomBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfBottomBold"


class PiSquareLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareLogoBold"


class PiSquareSplitHorizontalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitHorizontalBold"


class PiSquareSplitVerticalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitVerticalBold"


class PiSquaresFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquaresFourBold"


class PiStackBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackBold"


class PiStackOverflowLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackOverflowLogoBold"


class PiStackSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackSimpleBold"


class PiStairsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStairsBold"


class PiStampBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStampBold"


class PiStarAndCrescentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarAndCrescentBold"


class PiStarBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarBold"


class PiStarFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarFourBold"


class PiStarHalfBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarHalfBold"


class PiStarOfDavidBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarOfDavidBold"


class PiSteeringWheelBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSteeringWheelBold"


class PiStepsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStepsBold"


class PiStethoscopeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStethoscopeBold"


class PiStickerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStickerBold"


class PiStoolBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStoolBold"


class PiStopBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopBold"


class PiStopCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopCircleBold"


class PiStorefrontBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStorefrontBold"


class PiStrategyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStrategyBold"


class PiStripeLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStripeLogoBold"


class PiStudentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiStudentBold"


class PiSubtitlesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtitlesBold"


class PiSubtractBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractBold"


class PiSubtractSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractSquareBold"


class PiSuitcaseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseBold"


class PiSuitcaseRollingBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseRollingBold"


class PiSuitcaseSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseSimpleBold"


class PiSunBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunBold"


class PiSunDimBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunDimBold"


class PiSunHorizonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunHorizonBold"


class PiSunglassesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunglassesBold"


class PiSwapBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwapBold"


class PiSwatchesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwatchesBold"


class PiSwimmingPoolBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwimmingPoolBold"


class PiSwordBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwordBold"


class PiSynagogueBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSynagogueBold"


class PiSyringeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiSyringeBold"


class PiTShirtBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTShirtBold"


class PiTableBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTableBold"


class PiTabsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTabsBold"


class PiTagBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagBold"


class PiTagChevronBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagChevronBold"


class PiTagSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagSimpleBold"


class PiTargetBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTargetBold"


class PiTaxiBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTaxiBold"


class PiTelegramLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelegramLogoBold"


class PiTelevisionBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionBold"


class PiTelevisionSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionSimpleBold"


class PiTennisBallBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTennisBallBold"


class PiTentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTentBold"


class PiTerminalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalBold"


class PiTerminalWindowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalWindowBold"


class PiTestTubeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTestTubeBold"


class PiTextAUnderlineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAUnderlineBold"


class PiTextAaBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAaBold"


class PiTextAlignCenterBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignCenterBold"


class PiTextAlignJustifyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignJustifyBold"


class PiTextAlignLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignLeftBold"


class PiTextAlignRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignRightBold"


class PiTextBBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextBBold"


class PiTextColumnsBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextColumnsBold"


class PiTextHBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHBold"


class PiTextHFiveBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFiveBold"


class PiTextHFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFourBold"


class PiTextHOneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHOneBold"


class PiTextHSixBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHSixBold"


class PiTextHThreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHThreeBold"


class PiTextHTwoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHTwoBold"


class PiTextIndentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextIndentBold"


class PiTextItalicBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextItalicBold"


class PiTextOutdentBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextOutdentBold"


class PiTextStrikethroughBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextStrikethroughBold"


class PiTextTBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextTBold"


class PiTextUnderlineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextUnderlineBold"


class PiTextboxBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextboxBold"


class PiThermometerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerBold"


class PiThermometerColdBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerColdBold"


class PiThermometerHotBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerHotBold"


class PiThermometerSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerSimpleBold"


class PiThumbsDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsDownBold"


class PiThumbsUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsUpBold"


class PiTicketBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTicketBold"


class PiTidalLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTidalLogoBold"


class PiTiktokLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTiktokLogoBold"


class PiTimerBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTimerBold"


class PiTipiBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTipiBold"


class PiToggleLeftBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleLeftBold"


class PiToggleRightBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleRightBold"


class PiToiletBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletBold"


class PiToiletPaperBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletPaperBold"


class PiToolboxBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiToolboxBold"


class PiToothBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiToothBold"


class PiToteBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteBold"


class PiToteSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteSimpleBold"


class PiTrademarkBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkBold"


class PiTrademarkRegisteredBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkRegisteredBold"


class PiTrafficConeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficConeBold"


class PiTrafficSignBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignBold"


class PiTrafficSignalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignalBold"


class PiTrainBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainBold"


class PiTrainRegionalBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainRegionalBold"


class PiTrainSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainSimpleBold"


class PiTramBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTramBold"


class PiTranslateBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTranslateBold"


class PiTrashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashBold"


class PiTrashSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashSimpleBold"


class PiTrayBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrayBold"


class PiTreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeBold"


class PiTreeEvergreenBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeEvergreenBold"


class PiTreePalmBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreePalmBold"


class PiTreeStructureBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeStructureBold"


class PiTrendDownBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendDownBold"


class PiTrendUpBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendUpBold"


class PiTriangleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTriangleBold"


class PiTrophyBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrophyBold"


class PiTruckBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTruckBold"


class PiTwitchLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitchLogoBold"


class PiTwitterLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitterLogoBold"


class PiUmbrellaBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaBold"


class PiUmbrellaSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaSimpleBold"


class PiUniteBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteBold"


class PiUniteSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteSquareBold"


class PiUploadBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadBold"


class PiUploadSimpleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadSimpleBold"


class PiUsbBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsbBold"


class PiUserBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserBold"


class PiUserCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleBold"


class PiUserCircleGearBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleGearBold"


class PiUserCircleMinusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleMinusBold"


class PiUserCirclePlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCirclePlusBold"


class PiUserFocusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserFocusBold"


class PiUserGearBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserGearBold"


class PiUserListBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserListBold"


class PiUserMinusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserMinusBold"


class PiUserPlusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserPlusBold"


class PiUserRectangleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserRectangleBold"


class PiUserSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSquareBold"


class PiUserSwitchBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSwitchBold"


class PiUsersBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersBold"


class PiUsersFourBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersFourBold"


class PiUsersThreeBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersThreeBold"


class PiVanBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVanBold"


class PiVaultBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVaultBold"


class PiVibrateBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVibrateBold"


class PiVideoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoBold"


class PiVideoCameraBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraBold"


class PiVideoCameraSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraSlashBold"


class PiVignetteBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVignetteBold"


class PiVinylRecordBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVinylRecordBold"


class PiVirtualRealityBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirtualRealityBold"


class PiVirusBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirusBold"


class PiVoicemailBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVoicemailBold"


class PiVolleyballBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiVolleyballBold"


class PiWallBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWallBold"


class PiWalletBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWalletBold"


class PiWarehouseBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarehouseBold"


class PiWarningBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningBold"


class PiWarningCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningCircleBold"


class PiWarningDiamondBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningDiamondBold"


class PiWarningOctagonBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningOctagonBold"


class PiWatchBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWatchBold"


class PiWaveSawtoothBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSawtoothBold"


class PiWaveSineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSineBold"


class PiWaveSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSquareBold"


class PiWaveTriangleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveTriangleBold"


class PiWaveformBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveformBold"


class PiWavesBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWavesBold"


class PiWebcamBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamBold"


class PiWebcamSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamSlashBold"


class PiWebhooksLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebhooksLogoBold"


class PiWechatLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWechatLogoBold"


class PiWhatsappLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWhatsappLogoBold"


class PiWheelchairBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairBold"


class PiWheelchairMotionBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairMotionBold"


class PiWifiHighBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiHighBold"


class PiWifiLowBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiLowBold"


class PiWifiMediumBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiMediumBold"


class PiWifiNoneBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiNoneBold"


class PiWifiSlashBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiSlashBold"


class PiWifiXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiXBold"


class PiWindBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindBold"


class PiWindowsLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindowsLogoBold"


class PiWineBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWineBold"


class PiWrenchBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiWrenchBold"


class PiXBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiXBold"


class PiXCircleBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiXCircleBold"


class PiXSquareBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiXSquareBold"


class PiYinYangBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiYinYangBold"


class PiYoutubeLogoBold(rx.Component):
    library = "react-icons/pi"
    tag = "PiYoutubeLogoBold"


class PiAddressBookDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAddressBookDuotone"


class PiAirTrafficControlDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirTrafficControlDuotone"


class PiAirplaneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneDuotone"


class PiAirplaneInFlightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneInFlightDuotone"


class PiAirplaneLandingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneLandingDuotone"


class PiAirplaneTakeoffDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTakeoffDuotone"


class PiAirplaneTiltDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTiltDuotone"


class PiAirplayDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplayDuotone"


class PiAlarmDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlarmDuotone"


class PiAlienDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlienDuotone"


class PiAlignBottomDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomDuotone"


class PiAlignBottomSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomSimpleDuotone"


class PiAlignCenterHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalDuotone"


class PiAlignCenterHorizontalSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalSimpleDuotone"


class PiAlignCenterVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalDuotone"


class PiAlignCenterVerticalSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalSimpleDuotone"


class PiAlignLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftDuotone"


class PiAlignLeftSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftSimpleDuotone"


class PiAlignRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightDuotone"


class PiAlignRightSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightSimpleDuotone"


class PiAlignTopDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopDuotone"


class PiAlignTopSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopSimpleDuotone"


class PiAmazonLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAmazonLogoDuotone"


class PiAnchorDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorDuotone"


class PiAnchorSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorSimpleDuotone"


class PiAndroidLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAndroidLogoDuotone"


class PiAngularLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAngularLogoDuotone"


class PiApertureDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiApertureDuotone"


class PiAppStoreLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppStoreLogoDuotone"


class PiAppWindowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppWindowDuotone"


class PiAppleLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppleLogoDuotone"


class PiApplePodcastsLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiApplePodcastsLogoDuotone"


class PiArchiveBoxDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveBoxDuotone"


class PiArchiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveDuotone"


class PiArchiveTrayDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveTrayDuotone"


class PiArmchairDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArmchairDuotone"


class PiArrowArcLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcLeftDuotone"


class PiArrowArcRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcRightDuotone"


class PiArrowBendDoubleUpLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpLeftDuotone"


class PiArrowBendDoubleUpRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpRightDuotone"


class PiArrowBendDownLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownLeftDuotone"


class PiArrowBendDownRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownRightDuotone"


class PiArrowBendLeftDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftDownDuotone"


class PiArrowBendLeftUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftUpDuotone"


class PiArrowBendRightDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightDownDuotone"


class PiArrowBendRightUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightUpDuotone"


class PiArrowBendUpLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpLeftDuotone"


class PiArrowBendUpRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpRightDuotone"


class PiArrowCircleDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownDuotone"


class PiArrowCircleDownLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownLeftDuotone"


class PiArrowCircleDownRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownRightDuotone"


class PiArrowCircleLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleLeftDuotone"


class PiArrowCircleRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleRightDuotone"


class PiArrowCircleUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpDuotone"


class PiArrowCircleUpLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpLeftDuotone"


class PiArrowCircleUpRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpRightDuotone"


class PiArrowClockwiseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowClockwiseDuotone"


class PiArrowCounterClockwiseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCounterClockwiseDuotone"


class PiArrowDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownDuotone"


class PiArrowDownLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownLeftDuotone"


class PiArrowDownRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownRightDuotone"


class PiArrowElbowDownLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownLeftDuotone"


class PiArrowElbowDownRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownRightDuotone"


class PiArrowElbowLeftDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftDownDuotone"


class PiArrowElbowLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftDuotone"


class PiArrowElbowLeftUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftUpDuotone"


class PiArrowElbowRightDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightDownDuotone"


class PiArrowElbowRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightDuotone"


class PiArrowElbowRightUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightUpDuotone"


class PiArrowElbowUpLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpLeftDuotone"


class PiArrowElbowUpRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpRightDuotone"


class PiArrowFatDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatDownDuotone"


class PiArrowFatLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLeftDuotone"


class PiArrowFatLineDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineDownDuotone"


class PiArrowFatLineLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineLeftDuotone"


class PiArrowFatLineRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineRightDuotone"


class PiArrowFatLineUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineUpDuotone"


class PiArrowFatLinesDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesDownDuotone"


class PiArrowFatLinesLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesLeftDuotone"


class PiArrowFatLinesRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesRightDuotone"


class PiArrowFatLinesUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesUpDuotone"


class PiArrowFatRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatRightDuotone"


class PiArrowFatUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatUpDuotone"


class PiArrowLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLeftDuotone"


class PiArrowLineDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownDuotone"


class PiArrowLineDownLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownLeftDuotone"


class PiArrowLineDownRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownRightDuotone"


class PiArrowLineLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineLeftDuotone"


class PiArrowLineRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineRightDuotone"


class PiArrowLineUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpDuotone"


class PiArrowLineUpLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpLeftDuotone"


class PiArrowLineUpRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpRightDuotone"


class PiArrowRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowRightDuotone"


class PiArrowSquareDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownDuotone"


class PiArrowSquareDownLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownLeftDuotone"


class PiArrowSquareDownRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownRightDuotone"


class PiArrowSquareInDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareInDuotone"


class PiArrowSquareLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareLeftDuotone"


class PiArrowSquareOutDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareOutDuotone"


class PiArrowSquareRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareRightDuotone"


class PiArrowSquareUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpDuotone"


class PiArrowSquareUpLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpLeftDuotone"


class PiArrowSquareUpRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpRightDuotone"


class PiArrowUDownLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownLeftDuotone"


class PiArrowUDownRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownRightDuotone"


class PiArrowULeftDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftDownDuotone"


class PiArrowULeftUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftUpDuotone"


class PiArrowURightDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightDownDuotone"


class PiArrowURightUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightUpDuotone"


class PiArrowUUpLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpLeftDuotone"


class PiArrowUUpRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpRightDuotone"


class PiArrowUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpDuotone"


class PiArrowUpLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpLeftDuotone"


class PiArrowUpRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpRightDuotone"


class PiArrowsClockwiseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsClockwiseDuotone"


class PiArrowsCounterClockwiseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsCounterClockwiseDuotone"


class PiArrowsDownUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsDownUpDuotone"


class PiArrowsHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsHorizontalDuotone"


class PiArrowsInCardinalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInCardinalDuotone"


class PiArrowsInDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInDuotone"


class PiArrowsInLineHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineHorizontalDuotone"


class PiArrowsInLineVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineVerticalDuotone"


class PiArrowsInSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInSimpleDuotone"


class PiArrowsLeftRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsLeftRightDuotone"


class PiArrowsMergeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsMergeDuotone"


class PiArrowsOutCardinalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutCardinalDuotone"


class PiArrowsOutDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutDuotone"


class PiArrowsOutLineHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineHorizontalDuotone"


class PiArrowsOutLineVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineVerticalDuotone"


class PiArrowsOutSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutSimpleDuotone"


class PiArrowsSplitDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsSplitDuotone"


class PiArrowsVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsVerticalDuotone"


class PiArticleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleDuotone"


class PiArticleMediumDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleMediumDuotone"


class PiArticleNyTimesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleNyTimesDuotone"


class PiAsteriskDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskDuotone"


class PiAsteriskSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskSimpleDuotone"


class PiAtDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtDuotone"


class PiAtomDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtomDuotone"


class PiBabyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBabyDuotone"


class PiBackpackDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackpackDuotone"


class PiBackspaceDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackspaceDuotone"


class PiBagDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagDuotone"


class PiBagSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagSimpleDuotone"


class PiBalloonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBalloonDuotone"


class PiBandaidsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBandaidsDuotone"


class PiBankDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBankDuotone"


class PiBarbellDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarbellDuotone"


class PiBarcodeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarcodeDuotone"


class PiBarricadeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarricadeDuotone"


class PiBaseballCapDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballCapDuotone"


class PiBaseballDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballDuotone"


class PiBasketDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketDuotone"


class PiBasketballDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketballDuotone"


class PiBathtubDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBathtubDuotone"


class PiBatteryChargingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingDuotone"


class PiBatteryChargingVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingVerticalDuotone"


class PiBatteryEmptyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryEmptyDuotone"


class PiBatteryFullDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryFullDuotone"


class PiBatteryHighDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryHighDuotone"


class PiBatteryLowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryLowDuotone"


class PiBatteryMediumDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryMediumDuotone"


class PiBatteryPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusDuotone"


class PiBatteryPlusVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusVerticalDuotone"


class PiBatteryVerticalEmptyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalEmptyDuotone"


class PiBatteryVerticalFullDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalFullDuotone"


class PiBatteryVerticalHighDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalHighDuotone"


class PiBatteryVerticalLowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalLowDuotone"


class PiBatteryVerticalMediumDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalMediumDuotone"


class PiBatteryWarningDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningDuotone"


class PiBatteryWarningVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningVerticalDuotone"


class PiBedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBedDuotone"


class PiBeerBottleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerBottleDuotone"


class PiBeerSteinDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerSteinDuotone"


class PiBehanceLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBehanceLogoDuotone"


class PiBellDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellDuotone"


class PiBellRingingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellRingingDuotone"


class PiBellSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleDuotone"


class PiBellSimpleRingingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleRingingDuotone"


class PiBellSimpleSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleSlashDuotone"


class PiBellSimpleZDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleZDuotone"


class PiBellSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSlashDuotone"


class PiBellZDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellZDuotone"


class PiBezierCurveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBezierCurveDuotone"


class PiBicycleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBicycleDuotone"


class PiBinocularsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBinocularsDuotone"


class PiBirdDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBirdDuotone"


class PiBluetoothConnectedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothConnectedDuotone"


class PiBluetoothDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothDuotone"


class PiBluetoothSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothSlashDuotone"


class PiBluetoothXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothXDuotone"


class PiBoatDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoatDuotone"


class PiBoneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoneDuotone"


class PiBookBookmarkDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookBookmarkDuotone"


class PiBookDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookDuotone"


class PiBookOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenDuotone"


class PiBookOpenTextDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenTextDuotone"


class PiBookmarkDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkDuotone"


class PiBookmarkSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkSimpleDuotone"


class PiBookmarksDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksDuotone"


class PiBookmarksSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksSimpleDuotone"


class PiBooksDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBooksDuotone"


class PiBootDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBootDuotone"


class PiBoundingBoxDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoundingBoxDuotone"


class PiBowlFoodDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBowlFoodDuotone"


class PiBracketsAngleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsAngleDuotone"


class PiBracketsCurlyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsCurlyDuotone"


class PiBracketsRoundDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsRoundDuotone"


class PiBracketsSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsSquareDuotone"


class PiBrainDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrainDuotone"


class PiBrandyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrandyDuotone"


class PiBridgeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBridgeDuotone"


class PiBriefcaseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseDuotone"


class PiBriefcaseMetalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseMetalDuotone"


class PiBroadcastDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroadcastDuotone"


class PiBroomDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroomDuotone"


class PiBrowserDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowserDuotone"


class PiBrowsersDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowsersDuotone"


class PiBugBeetleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugBeetleDuotone"


class PiBugDroidDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugDroidDuotone"


class PiBugDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugDuotone"


class PiBuildingsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBuildingsDuotone"


class PiBusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBusDuotone"


class PiButterflyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiButterflyDuotone"


class PiCactusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCactusDuotone"


class PiCakeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCakeDuotone"


class PiCalculatorDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalculatorDuotone"


class PiCalendarBlankDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarBlankDuotone"


class PiCalendarCheckDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarCheckDuotone"


class PiCalendarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarDuotone"


class PiCalendarPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarPlusDuotone"


class PiCalendarXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarXDuotone"


class PiCallBellDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCallBellDuotone"


class PiCameraDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraDuotone"


class PiCameraPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraPlusDuotone"


class PiCameraRotateDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraRotateDuotone"


class PiCameraSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraSlashDuotone"


class PiCampfireDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCampfireDuotone"


class PiCarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarDuotone"


class PiCarProfileDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarProfileDuotone"


class PiCarSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarSimpleDuotone"


class PiCardholderDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardholderDuotone"


class PiCardsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardsDuotone"


class PiCaretCircleDoubleDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleDownDuotone"


class PiCaretCircleDoubleLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleLeftDuotone"


class PiCaretCircleDoubleRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleRightDuotone"


class PiCaretCircleDoubleUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleUpDuotone"


class PiCaretCircleDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDownDuotone"


class PiCaretCircleLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleLeftDuotone"


class PiCaretCircleRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleRightDuotone"


class PiCaretCircleUpDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpDownDuotone"


class PiCaretCircleUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpDuotone"


class PiCaretDoubleDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleDownDuotone"


class PiCaretDoubleLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleLeftDuotone"


class PiCaretDoubleRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleRightDuotone"


class PiCaretDoubleUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleUpDuotone"


class PiCaretDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDownDuotone"


class PiCaretLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretLeftDuotone"


class PiCaretRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretRightDuotone"


class PiCaretUpDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpDownDuotone"


class PiCaretUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpDuotone"


class PiCarrotDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarrotDuotone"


class PiCassetteTapeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCassetteTapeDuotone"


class PiCastleTurretDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCastleTurretDuotone"


class PiCatDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCatDuotone"


class PiCellSignalFullDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalFullDuotone"


class PiCellSignalHighDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalHighDuotone"


class PiCellSignalLowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalLowDuotone"


class PiCellSignalMediumDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalMediumDuotone"


class PiCellSignalNoneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalNoneDuotone"


class PiCellSignalSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalSlashDuotone"


class PiCellSignalXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalXDuotone"


class PiCertificateDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCertificateDuotone"


class PiChairDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChairDuotone"


class PiChalkboardDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardDuotone"


class PiChalkboardSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardSimpleDuotone"


class PiChalkboardTeacherDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardTeacherDuotone"


class PiChampagneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChampagneDuotone"


class PiChargingStationDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChargingStationDuotone"


class PiChartBarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarDuotone"


class PiChartBarHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarHorizontalDuotone"


class PiChartDonutDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartDonutDuotone"


class PiChartLineDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineDownDuotone"


class PiChartLineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineDuotone"


class PiChartLineUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineUpDuotone"


class PiChartPieDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieDuotone"


class PiChartPieSliceDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieSliceDuotone"


class PiChartPolarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPolarDuotone"


class PiChartScatterDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartScatterDuotone"


class PiChatCenteredDotsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredDotsDuotone"


class PiChatCenteredDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredDuotone"


class PiChatCenteredTextDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredTextDuotone"


class PiChatCircleDotsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleDotsDuotone"


class PiChatCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleDuotone"


class PiChatCircleTextDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleTextDuotone"


class PiChatDotsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatDotsDuotone"


class PiChatDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatDuotone"


class PiChatTeardropDotsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropDotsDuotone"


class PiChatTeardropDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropDuotone"


class PiChatTeardropTextDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropTextDuotone"


class PiChatTextDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTextDuotone"


class PiChatsCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsCircleDuotone"


class PiChatsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsDuotone"


class PiChatsTeardropDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsTeardropDuotone"


class PiCheckCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckCircleDuotone"


class PiCheckDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckDuotone"


class PiCheckFatDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckFatDuotone"


class PiCheckSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareDuotone"


class PiCheckSquareOffsetDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareOffsetDuotone"


class PiChecksDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChecksDuotone"


class PiChurchDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiChurchDuotone"


class PiCircleDashedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleDashedDuotone"


class PiCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleDuotone"


class PiCircleHalfDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfDuotone"


class PiCircleHalfTiltDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfTiltDuotone"


class PiCircleNotchDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleNotchDuotone"


class PiCirclesFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesFourDuotone"


class PiCirclesThreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreeDuotone"


class PiCirclesThreePlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreePlusDuotone"


class PiCircuitryDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircuitryDuotone"


class PiClipboardDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardDuotone"


class PiClipboardTextDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardTextDuotone"


class PiClockAfternoonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockAfternoonDuotone"


class PiClockClockwiseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockClockwiseDuotone"


class PiClockCountdownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCountdownDuotone"


class PiClockCounterClockwiseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCounterClockwiseDuotone"


class PiClockDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockDuotone"


class PiClosedCaptioningDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiClosedCaptioningDuotone"


class PiCloudArrowDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowDownDuotone"


class PiCloudArrowUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowUpDuotone"


class PiCloudCheckDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudCheckDuotone"


class PiCloudDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudDuotone"


class PiCloudFogDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudFogDuotone"


class PiCloudLightningDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudLightningDuotone"


class PiCloudMoonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudMoonDuotone"


class PiCloudRainDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudRainDuotone"


class PiCloudSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSlashDuotone"


class PiCloudSnowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSnowDuotone"


class PiCloudSunDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSunDuotone"


class PiCloudWarningDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudWarningDuotone"


class PiCloudXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudXDuotone"


class PiClubDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiClubDuotone"


class PiCoatHangerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoatHangerDuotone"


class PiCodaLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodaLogoDuotone"


class PiCodeBlockDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeBlockDuotone"


class PiCodeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeDuotone"


class PiCodeSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeSimpleDuotone"


class PiCodepenLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodepenLogoDuotone"


class PiCodesandboxLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodesandboxLogoDuotone"


class PiCoffeeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoffeeDuotone"


class PiCoinDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinDuotone"


class PiCoinVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinVerticalDuotone"


class PiCoinsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinsDuotone"


class PiColumnsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiColumnsDuotone"


class PiCommandDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCommandDuotone"


class PiCompassDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassDuotone"


class PiCompassToolDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassToolDuotone"


class PiComputerTowerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiComputerTowerDuotone"


class PiConfettiDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiConfettiDuotone"


class PiContactlessPaymentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiContactlessPaymentDuotone"


class PiControlDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiControlDuotone"


class PiCookieDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookieDuotone"


class PiCookingPotDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookingPotDuotone"


class PiCopyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyDuotone"


class PiCopySimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopySimpleDuotone"


class PiCopyleftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyleftDuotone"


class PiCopyrightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyrightDuotone"


class PiCornersInDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersInDuotone"


class PiCornersOutDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersOutDuotone"


class PiCouchDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCouchDuotone"


class PiCpuDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCpuDuotone"


class PiCreditCardDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCreditCardDuotone"


class PiCropDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCropDuotone"


class PiCrossDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrossDuotone"


class PiCrosshairDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairDuotone"


class PiCrosshairSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairSimpleDuotone"


class PiCrownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownDuotone"


class PiCrownSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownSimpleDuotone"


class PiCubeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeDuotone"


class PiCubeFocusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeFocusDuotone"


class PiCubeTransparentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeTransparentDuotone"


class PiCurrencyBtcDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyBtcDuotone"


class PiCurrencyCircleDollarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCircleDollarDuotone"


class PiCurrencyCnyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCnyDuotone"


class PiCurrencyDollarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarDuotone"


class PiCurrencyDollarSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarSimpleDuotone"


class PiCurrencyEthDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEthDuotone"


class PiCurrencyEurDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEurDuotone"


class PiCurrencyGbpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyGbpDuotone"


class PiCurrencyInrDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyInrDuotone"


class PiCurrencyJpyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyJpyDuotone"


class PiCurrencyKrwDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKrwDuotone"


class PiCurrencyKztDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKztDuotone"


class PiCurrencyNgnDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyNgnDuotone"


class PiCurrencyRubDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyRubDuotone"


class PiCursorClickDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorClickDuotone"


class PiCursorDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorDuotone"


class PiCursorTextDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorTextDuotone"


class PiCylinderDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCylinderDuotone"


class PiDatabaseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDatabaseDuotone"


class PiDesktopDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopDuotone"


class PiDesktopTowerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopTowerDuotone"


class PiDetectiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDetectiveDuotone"


class PiDevToLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevToLogoDuotone"


class PiDeviceMobileCameraDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileCameraDuotone"


class PiDeviceMobileDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileDuotone"


class PiDeviceMobileSpeakerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileSpeakerDuotone"


class PiDeviceTabletCameraDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletCameraDuotone"


class PiDeviceTabletDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletDuotone"


class PiDeviceTabletSpeakerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletSpeakerDuotone"


class PiDevicesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevicesDuotone"


class PiDiamondDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondDuotone"


class PiDiamondsFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondsFourDuotone"


class PiDiceFiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFiveDuotone"


class PiDiceFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFourDuotone"


class PiDiceOneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceOneDuotone"


class PiDiceSixDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceSixDuotone"


class PiDiceThreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceThreeDuotone"


class PiDiceTwoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceTwoDuotone"


class PiDiscDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscDuotone"


class PiDiscordLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscordLogoDuotone"


class PiDivideDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDivideDuotone"


class PiDnaDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDnaDuotone"


class PiDogDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDogDuotone"


class PiDoorDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorDuotone"


class PiDoorOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorOpenDuotone"


class PiDotDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotDuotone"


class PiDotOutlineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotOutlineDuotone"


class PiDotsNineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsNineDuotone"


class PiDotsSixDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixDuotone"


class PiDotsSixVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixVerticalDuotone"


class PiDotsThreeCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleDuotone"


class PiDotsThreeCircleVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleVerticalDuotone"


class PiDotsThreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeDuotone"


class PiDotsThreeOutlineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineDuotone"


class PiDotsThreeOutlineVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineVerticalDuotone"


class PiDotsThreeVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeVerticalDuotone"


class PiDownloadDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadDuotone"


class PiDownloadSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadSimpleDuotone"


class PiDressDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDressDuotone"


class PiDribbbleLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDribbbleLogoDuotone"


class PiDropDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropDuotone"


class PiDropHalfBottomDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfBottomDuotone"


class PiDropHalfDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfDuotone"


class PiDropboxLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropboxLogoDuotone"


class PiEarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarDuotone"


class PiEarSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarSlashDuotone"


class PiEggCrackDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggCrackDuotone"


class PiEggDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggDuotone"


class PiEjectDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectDuotone"


class PiEjectSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectSimpleDuotone"


class PiElevatorDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiElevatorDuotone"


class PiEngineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEngineDuotone"


class PiEnvelopeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeDuotone"


class PiEnvelopeOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeOpenDuotone"


class PiEnvelopeSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleDuotone"


class PiEnvelopeSimpleOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleOpenDuotone"


class PiEqualizerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualizerDuotone"


class PiEqualsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualsDuotone"


class PiEraserDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEraserDuotone"


class PiEscalatorDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorDownDuotone"


class PiEscalatorUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorUpDuotone"


class PiExamDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiExamDuotone"


class PiExcludeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeDuotone"


class PiExcludeSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeSquareDuotone"


class PiExportDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiExportDuotone"


class PiEyeClosedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeClosedDuotone"


class PiEyeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeDuotone"


class PiEyeSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeSlashDuotone"


class PiEyedropperDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperDuotone"


class PiEyedropperSampleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperSampleDuotone"


class PiEyeglassesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeglassesDuotone"


class PiFaceMaskDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFaceMaskDuotone"


class PiFacebookLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFacebookLogoDuotone"


class PiFactoryDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFactoryDuotone"


class PiFadersDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersDuotone"


class PiFadersHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersHorizontalDuotone"


class PiFanDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFanDuotone"


class PiFastForwardCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardCircleDuotone"


class PiFastForwardDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardDuotone"


class PiFeatherDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFeatherDuotone"


class PiFigmaLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFigmaLogoDuotone"


class PiFileArchiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArchiveDuotone"


class PiFileArrowDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowDownDuotone"


class PiFileArrowUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowUpDuotone"


class PiFileAudioDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileAudioDuotone"


class PiFileCloudDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCloudDuotone"


class PiFileCodeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCodeDuotone"


class PiFileCssDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCssDuotone"


class PiFileCsvDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCsvDuotone"


class PiFileDashedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDashedDuotone"


class PiFileDocDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDocDuotone"


class PiFileDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDuotone"


class PiFileHtmlDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileHtmlDuotone"


class PiFileImageDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileImageDuotone"


class PiFileJpgDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJpgDuotone"


class PiFileJsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsDuotone"


class PiFileJsxDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsxDuotone"


class PiFileLockDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileLockDuotone"


class PiFileMagnifyingGlassDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMagnifyingGlassDuotone"


class PiFileMinusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMinusDuotone"


class PiFilePdfDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePdfDuotone"


class PiFilePlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePlusDuotone"


class PiFilePngDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePngDuotone"


class PiFilePptDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePptDuotone"


class PiFileRsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileRsDuotone"


class PiFileSqlDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSqlDuotone"


class PiFileSvgDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSvgDuotone"


class PiFileTextDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTextDuotone"


class PiFileTsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsDuotone"


class PiFileTsxDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsxDuotone"


class PiFileVideoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVideoDuotone"


class PiFileVueDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVueDuotone"


class PiFileXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXDuotone"


class PiFileXlsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXlsDuotone"


class PiFileZipDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileZipDuotone"


class PiFilesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilesDuotone"


class PiFilmReelDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmReelDuotone"


class PiFilmScriptDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmScriptDuotone"


class PiFilmSlateDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmSlateDuotone"


class PiFilmStripDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmStripDuotone"


class PiFingerprintDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintDuotone"


class PiFingerprintSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintSimpleDuotone"


class PiFinnTheHumanDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFinnTheHumanDuotone"


class PiFireDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireDuotone"


class PiFireExtinguisherDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireExtinguisherDuotone"


class PiFireSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireSimpleDuotone"


class PiFirstAidDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidDuotone"


class PiFirstAidKitDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidKitDuotone"


class PiFishDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishDuotone"


class PiFishSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishSimpleDuotone"


class PiFlagBannerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagBannerDuotone"


class PiFlagCheckeredDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagCheckeredDuotone"


class PiFlagDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagDuotone"


class PiFlagPennantDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagPennantDuotone"


class PiFlameDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlameDuotone"


class PiFlashlightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlashlightDuotone"


class PiFlaskDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlaskDuotone"


class PiFloppyDiskBackDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskBackDuotone"


class PiFloppyDiskDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskDuotone"


class PiFlowArrowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowArrowDuotone"


class PiFlowerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerDuotone"


class PiFlowerLotusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerLotusDuotone"


class PiFlowerTulipDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerTulipDuotone"


class PiFlyingSaucerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlyingSaucerDuotone"


class PiFolderDashedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderDashedDuotone"


class PiFolderDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderDuotone"


class PiFolderLockDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderLockDuotone"


class PiFolderMinusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderMinusDuotone"


class PiFolderNotchDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchDuotone"


class PiFolderNotchMinusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchMinusDuotone"


class PiFolderNotchOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchOpenDuotone"


class PiFolderNotchPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchPlusDuotone"


class PiFolderOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderOpenDuotone"


class PiFolderPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderPlusDuotone"


class PiFolderSimpleDashedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleDashedDuotone"


class PiFolderSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleDuotone"


class PiFolderSimpleLockDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleLockDuotone"


class PiFolderSimpleMinusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleMinusDuotone"


class PiFolderSimplePlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimplePlusDuotone"


class PiFolderSimpleStarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleStarDuotone"


class PiFolderSimpleUserDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleUserDuotone"


class PiFolderStarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderStarDuotone"


class PiFolderUserDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderUserDuotone"


class PiFoldersDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFoldersDuotone"


class PiFootballDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootballDuotone"


class PiFootprintsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootprintsDuotone"


class PiForkKnifeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiForkKnifeDuotone"


class PiFrameCornersDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFrameCornersDuotone"


class PiFramerLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFramerLogoDuotone"


class PiFunctionDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunctionDuotone"


class PiFunnelDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelDuotone"


class PiFunnelSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelSimpleDuotone"


class PiGameControllerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGameControllerDuotone"


class PiGarageDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGarageDuotone"


class PiGasCanDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasCanDuotone"


class PiGasPumpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasPumpDuotone"


class PiGaugeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGaugeDuotone"


class PiGavelDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGavelDuotone"


class PiGearDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearDuotone"


class PiGearFineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearFineDuotone"


class PiGearSixDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearSixDuotone"


class PiGenderFemaleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderFemaleDuotone"


class PiGenderIntersexDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderIntersexDuotone"


class PiGenderMaleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderMaleDuotone"


class PiGenderNeuterDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNeuterDuotone"


class PiGenderNonbinaryDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNonbinaryDuotone"


class PiGenderTransgenderDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderTransgenderDuotone"


class PiGhostDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGhostDuotone"


class PiGifDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGifDuotone"


class PiGiftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGiftDuotone"


class PiGitBranchDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitBranchDuotone"


class PiGitCommitDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitCommitDuotone"


class PiGitDiffDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitDiffDuotone"


class PiGitForkDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitForkDuotone"


class PiGitMergeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitMergeDuotone"


class PiGitPullRequestDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitPullRequestDuotone"


class PiGithubLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGithubLogoDuotone"


class PiGitlabLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoDuotone"


class PiGitlabLogoSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoSimpleDuotone"


class PiGlobeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeDuotone"


class PiGlobeHemisphereEastDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereEastDuotone"


class PiGlobeHemisphereWestDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereWestDuotone"


class PiGlobeSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeSimpleDuotone"


class PiGlobeStandDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeStandDuotone"


class PiGogglesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGogglesDuotone"


class PiGoodreadsLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoodreadsLogoDuotone"


class PiGoogleCardboardLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleCardboardLogoDuotone"


class PiGoogleChromeLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleChromeLogoDuotone"


class PiGoogleDriveLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleDriveLogoDuotone"


class PiGoogleLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleLogoDuotone"


class PiGooglePhotosLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePhotosLogoDuotone"


class PiGooglePlayLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePlayLogoDuotone"


class PiGooglePodcastsLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePodcastsLogoDuotone"


class PiGradientDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGradientDuotone"


class PiGraduationCapDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraduationCapDuotone"


class PiGrainsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsDuotone"


class PiGrainsSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsSlashDuotone"


class PiGraphDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraphDuotone"


class PiGridFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridFourDuotone"


class PiGridNineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridNineDuotone"


class PiGuitarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiGuitarDuotone"


class PiHamburgerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHamburgerDuotone"


class PiHammerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHammerDuotone"


class PiHandCoinsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandCoinsDuotone"


class PiHandDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandDuotone"


class PiHandEyeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandEyeDuotone"


class PiHandFistDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandFistDuotone"


class PiHandGrabbingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandGrabbingDuotone"


class PiHandHeartDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandHeartDuotone"


class PiHandPalmDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPalmDuotone"


class PiHandPointingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPointingDuotone"


class PiHandSoapDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSoapDuotone"


class PiHandSwipeLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeLeftDuotone"


class PiHandSwipeRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeRightDuotone"


class PiHandTapDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandTapDuotone"


class PiHandWavingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandWavingDuotone"


class PiHandbagDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagDuotone"


class PiHandbagSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagSimpleDuotone"


class PiHandsClappingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsClappingDuotone"


class PiHandsPrayingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsPrayingDuotone"


class PiHandshakeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandshakeDuotone"


class PiHardDriveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDriveDuotone"


class PiHardDrivesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDrivesDuotone"


class PiHashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashDuotone"


class PiHashStraightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashStraightDuotone"


class PiHeadlightsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadlightsDuotone"


class PiHeadphonesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadphonesDuotone"


class PiHeadsetDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadsetDuotone"


class PiHeartBreakDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartBreakDuotone"


class PiHeartDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartDuotone"


class PiHeartHalfDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartHalfDuotone"


class PiHeartStraightBreakDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightBreakDuotone"


class PiHeartStraightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightDuotone"


class PiHeartbeatDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartbeatDuotone"


class PiHexagonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHexagonDuotone"


class PiHighHeelDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighHeelDuotone"


class PiHighlighterCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighlighterCircleDuotone"


class PiHoodieDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHoodieDuotone"


class PiHorseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHorseDuotone"


class PiHourglassDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassDuotone"


class PiHourglassHighDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassHighDuotone"


class PiHourglassLowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassLowDuotone"


class PiHourglassMediumDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassMediumDuotone"


class PiHourglassSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleDuotone"


class PiHourglassSimpleHighDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleHighDuotone"


class PiHourglassSimpleLowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleLowDuotone"


class PiHourglassSimpleMediumDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleMediumDuotone"


class PiHouseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseDuotone"


class PiHouseLineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseLineDuotone"


class PiHouseSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseSimpleDuotone"


class PiIceCreamDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiIceCreamDuotone"


class PiIdentificationBadgeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationBadgeDuotone"


class PiIdentificationCardDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationCardDuotone"


class PiImageDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageDuotone"


class PiImageSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageSquareDuotone"


class PiImagesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesDuotone"


class PiImagesSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesSquareDuotone"


class PiInfinityDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfinityDuotone"


class PiInfoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfoDuotone"


class PiInstagramLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiInstagramLogoDuotone"


class PiIntersectDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectDuotone"


class PiIntersectSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectSquareDuotone"


class PiIntersectThreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectThreeDuotone"


class PiJeepDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiJeepDuotone"


class PiKanbanDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiKanbanDuotone"


class PiKeyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyDuotone"


class PiKeyReturnDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyReturnDuotone"


class PiKeyboardDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyboardDuotone"


class PiKeyholeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyholeDuotone"


class PiKnifeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiKnifeDuotone"


class PiLadderDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderDuotone"


class PiLadderSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderSimpleDuotone"


class PiLampDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLampDuotone"


class PiLaptopDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLaptopDuotone"


class PiLayoutDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLayoutDuotone"


class PiLeafDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLeafDuotone"


class PiLifebuoyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLifebuoyDuotone"


class PiLightbulbDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbDuotone"


class PiLightbulbFilamentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbFilamentDuotone"


class PiLighthouseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLighthouseDuotone"


class PiLightningADuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningADuotone"


class PiLightningDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningDuotone"


class PiLightningSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningSlashDuotone"


class PiLineSegmentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentDuotone"


class PiLineSegmentsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentsDuotone"


class PiLinkBreakDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkBreakDuotone"


class PiLinkDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkDuotone"


class PiLinkSimpleBreakDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleBreakDuotone"


class PiLinkSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleDuotone"


class PiLinkSimpleHorizontalBreakDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalBreakDuotone"


class PiLinkSimpleHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalDuotone"


class PiLinkedinLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkedinLogoDuotone"


class PiLinuxLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinuxLogoDuotone"


class PiListBulletsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiListBulletsDuotone"


class PiListChecksDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiListChecksDuotone"


class PiListDashesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiListDashesDuotone"


class PiListDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiListDuotone"


class PiListMagnifyingGlassDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiListMagnifyingGlassDuotone"


class PiListNumbersDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiListNumbersDuotone"


class PiListPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiListPlusDuotone"


class PiLockDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockDuotone"


class PiLockKeyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyDuotone"


class PiLockKeyOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyOpenDuotone"


class PiLockLaminatedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedDuotone"


class PiLockLaminatedOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedOpenDuotone"


class PiLockOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockOpenDuotone"


class PiLockSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleDuotone"


class PiLockSimpleOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleOpenDuotone"


class PiLockersDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockersDuotone"


class PiMagicWandDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagicWandDuotone"


class PiMagnetDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetDuotone"


class PiMagnetStraightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetStraightDuotone"


class PiMagnifyingGlassDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassDuotone"


class PiMagnifyingGlassMinusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassMinusDuotone"


class PiMagnifyingGlassPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassPlusDuotone"


class PiMapPinDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinDuotone"


class PiMapPinLineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinLineDuotone"


class PiMapTrifoldDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapTrifoldDuotone"


class PiMarkerCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMarkerCircleDuotone"


class PiMartiniDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMartiniDuotone"


class PiMaskHappyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskHappyDuotone"


class PiMaskSadDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskSadDuotone"


class PiMathOperationsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMathOperationsDuotone"


class PiMedalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalDuotone"


class PiMedalMilitaryDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalMilitaryDuotone"


class PiMediumLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMediumLogoDuotone"


class PiMegaphoneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneDuotone"


class PiMegaphoneSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneSimpleDuotone"


class PiMessengerLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMessengerLogoDuotone"


class PiMetaLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetaLogoDuotone"


class PiMetronomeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetronomeDuotone"


class PiMicrophoneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneDuotone"


class PiMicrophoneSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneSlashDuotone"


class PiMicrophoneStageDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneStageDuotone"


class PiMicrosoftExcelLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftExcelLogoDuotone"


class PiMicrosoftOutlookLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftOutlookLogoDuotone"


class PiMicrosoftPowerpointLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftPowerpointLogoDuotone"


class PiMicrosoftTeamsLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftTeamsLogoDuotone"


class PiMicrosoftWordLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftWordLogoDuotone"


class PiMinusCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusCircleDuotone"


class PiMinusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusDuotone"


class PiMinusSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusSquareDuotone"


class PiMoneyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoneyDuotone"


class PiMonitorDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorDuotone"


class PiMonitorPlayDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorPlayDuotone"


class PiMoonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonDuotone"


class PiMoonStarsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonStarsDuotone"


class PiMopedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedDuotone"


class PiMopedFrontDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedFrontDuotone"


class PiMosqueDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMosqueDuotone"


class PiMotorcycleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMotorcycleDuotone"


class PiMountainsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMountainsDuotone"


class PiMouseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseDuotone"


class PiMouseSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseSimpleDuotone"


class PiMusicNoteDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteDuotone"


class PiMusicNoteSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteSimpleDuotone"


class PiMusicNotesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesDuotone"


class PiMusicNotesPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesPlusDuotone"


class PiMusicNotesSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesSimpleDuotone"


class PiNavigationArrowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNavigationArrowDuotone"


class PiNeedleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNeedleDuotone"


class PiNewspaperClippingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperClippingDuotone"


class PiNewspaperDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperDuotone"


class PiNotchesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotchesDuotone"


class PiNoteBlankDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteBlankDuotone"


class PiNoteDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteDuotone"


class PiNotePencilDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotePencilDuotone"


class PiNotebookDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotebookDuotone"


class PiNotepadDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotepadDuotone"


class PiNotificationDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotificationDuotone"


class PiNotionLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotionLogoDuotone"


class PiNumberCircleEightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleEightDuotone"


class PiNumberCircleFiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFiveDuotone"


class PiNumberCircleFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFourDuotone"


class PiNumberCircleNineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleNineDuotone"


class PiNumberCircleOneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleOneDuotone"


class PiNumberCircleSevenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSevenDuotone"


class PiNumberCircleSixDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSixDuotone"


class PiNumberCircleThreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleThreeDuotone"


class PiNumberCircleTwoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleTwoDuotone"


class PiNumberCircleZeroDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleZeroDuotone"


class PiNumberEightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberEightDuotone"


class PiNumberFiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFiveDuotone"


class PiNumberFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFourDuotone"


class PiNumberNineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberNineDuotone"


class PiNumberOneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberOneDuotone"


class PiNumberSevenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSevenDuotone"


class PiNumberSixDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSixDuotone"


class PiNumberSquareEightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareEightDuotone"


class PiNumberSquareFiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFiveDuotone"


class PiNumberSquareFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFourDuotone"


class PiNumberSquareNineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareNineDuotone"


class PiNumberSquareOneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareOneDuotone"


class PiNumberSquareSevenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSevenDuotone"


class PiNumberSquareSixDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSixDuotone"


class PiNumberSquareThreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareThreeDuotone"


class PiNumberSquareTwoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareTwoDuotone"


class PiNumberSquareZeroDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareZeroDuotone"


class PiNumberThreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberThreeDuotone"


class PiNumberTwoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberTwoDuotone"


class PiNumberZeroDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberZeroDuotone"


class PiNutDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNutDuotone"


class PiNyTimesLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiNyTimesLogoDuotone"


class PiOctagonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiOctagonDuotone"


class PiOfficeChairDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiOfficeChairDuotone"


class PiOptionDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiOptionDuotone"


class PiOrangeSliceDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiOrangeSliceDuotone"


class PiPackageDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPackageDuotone"


class PiPaintBrushBroadDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushBroadDuotone"


class PiPaintBrushDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushDuotone"


class PiPaintBrushHouseholdDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushHouseholdDuotone"


class PiPaintBucketDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBucketDuotone"


class PiPaintRollerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintRollerDuotone"


class PiPaletteDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaletteDuotone"


class PiPantsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPantsDuotone"


class PiPaperPlaneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneDuotone"


class PiPaperPlaneRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneRightDuotone"


class PiPaperPlaneTiltDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneTiltDuotone"


class PiPaperclipDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipDuotone"


class PiPaperclipHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipHorizontalDuotone"


class PiParachuteDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiParachuteDuotone"


class PiParagraphDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiParagraphDuotone"


class PiParallelogramDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiParallelogramDuotone"


class PiParkDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiParkDuotone"


class PiPasswordDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPasswordDuotone"


class PiPathDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPathDuotone"


class PiPatreonLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPatreonLogoDuotone"


class PiPauseCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseCircleDuotone"


class PiPauseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseDuotone"


class PiPawPrintDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPawPrintDuotone"


class PiPaypalLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaypalLogoDuotone"


class PiPeaceDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPeaceDuotone"


class PiPenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenDuotone"


class PiPenNibDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibDuotone"


class PiPenNibStraightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibStraightDuotone"


class PiPencilCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilCircleDuotone"


class PiPencilDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilDuotone"


class PiPencilLineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilLineDuotone"


class PiPencilSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleDuotone"


class PiPencilSimpleLineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleLineDuotone"


class PiPencilSimpleSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleSlashDuotone"


class PiPencilSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSlashDuotone"


class PiPentagramDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPentagramDuotone"


class PiPepperDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPepperDuotone"


class PiPercentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPercentDuotone"


class PiPersonArmsSpreadDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonArmsSpreadDuotone"


class PiPersonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonDuotone"


class PiPersonSimpleBikeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleBikeDuotone"


class PiPersonSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleDuotone"


class PiPersonSimpleRunDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleRunDuotone"


class PiPersonSimpleThrowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleThrowDuotone"


class PiPersonSimpleWalkDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleWalkDuotone"


class PiPerspectiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPerspectiveDuotone"


class PiPhoneCallDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneCallDuotone"


class PiPhoneDisconnectDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneDisconnectDuotone"


class PiPhoneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneDuotone"


class PiPhoneIncomingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneIncomingDuotone"


class PiPhoneOutgoingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneOutgoingDuotone"


class PiPhonePlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhonePlusDuotone"


class PiPhoneSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneSlashDuotone"


class PiPhoneXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneXDuotone"


class PiPhosphorLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhosphorLogoDuotone"


class PiPiDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiDuotone"


class PiPianoKeysDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPianoKeysDuotone"


class PiPictureInPictureDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPictureInPictureDuotone"


class PiPiggyBankDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiggyBankDuotone"


class PiPillDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPillDuotone"


class PiPinterestLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinterestLogoDuotone"


class PiPinwheelDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinwheelDuotone"


class PiPizzaDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPizzaDuotone"


class PiPlaceholderDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaceholderDuotone"


class PiPlanetDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlanetDuotone"


class PiPlantDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlantDuotone"


class PiPlayCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayCircleDuotone"


class PiPlayDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayDuotone"


class PiPlayPauseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayPauseDuotone"


class PiPlaylistDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaylistDuotone"


class PiPlugChargingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugChargingDuotone"


class PiPlugDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugDuotone"


class PiPlugsConnectedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsConnectedDuotone"


class PiPlugsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsDuotone"


class PiPlusCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusCircleDuotone"


class PiPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusDuotone"


class PiPlusMinusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusMinusDuotone"


class PiPlusSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusSquareDuotone"


class PiPokerChipDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPokerChipDuotone"


class PiPoliceCarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPoliceCarDuotone"


class PiPolygonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPolygonDuotone"


class PiPopcornDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPopcornDuotone"


class PiPottedPlantDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPottedPlantDuotone"


class PiPowerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPowerDuotone"


class PiPrescriptionDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrescriptionDuotone"


class PiPresentationChartDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationChartDuotone"


class PiPresentationDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationDuotone"


class PiPrinterDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrinterDuotone"


class PiProhibitDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitDuotone"


class PiProhibitInsetDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitInsetDuotone"


class PiProjectorScreenChartDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenChartDuotone"


class PiProjectorScreenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenDuotone"


class PiPulseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPulseDuotone"


class PiPushPinDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinDuotone"


class PiPushPinSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleDuotone"


class PiPushPinSimpleSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleSlashDuotone"


class PiPushPinSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSlashDuotone"


class PiPuzzlePieceDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPuzzlePieceDuotone"


class PiQrCodeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiQrCodeDuotone"


class PiQuestionDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuestionDuotone"


class PiQueueDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiQueueDuotone"


class PiQuotesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuotesDuotone"


class PiRadicalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadicalDuotone"


class PiRadioButtonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioButtonDuotone"


class PiRadioDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioDuotone"


class PiRadioactiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioactiveDuotone"


class PiRainbowCloudDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowCloudDuotone"


class PiRainbowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowDuotone"


class PiReadCvLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiReadCvLogoDuotone"


class PiReceiptDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptDuotone"


class PiReceiptXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptXDuotone"


class PiRecordDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecordDuotone"


class PiRectangleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRectangleDuotone"


class PiRecycleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecycleDuotone"


class PiRedditLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRedditLogoDuotone"


class PiRepeatDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatDuotone"


class PiRepeatOnceDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatOnceDuotone"


class PiRewindCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindCircleDuotone"


class PiRewindDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindDuotone"


class PiRoadHorizonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRoadHorizonDuotone"


class PiRobotDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRobotDuotone"


class PiRocketDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketDuotone"


class PiRocketLaunchDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketLaunchDuotone"


class PiRowsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRowsDuotone"


class PiRssDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssDuotone"


class PiRssSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssSimpleDuotone"


class PiRugDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRugDuotone"


class PiRulerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiRulerDuotone"


class PiScalesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiScalesDuotone"


class PiScanDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiScanDuotone"


class PiScissorsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiScissorsDuotone"


class PiScooterDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiScooterDuotone"


class PiScreencastDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiScreencastDuotone"


class PiScribbleLoopDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiScribbleLoopDuotone"


class PiScrollDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiScrollDuotone"


class PiSealCheckDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealCheckDuotone"


class PiSealDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealDuotone"


class PiSealQuestionDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealQuestionDuotone"


class PiSealWarningDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealWarningDuotone"


class PiSelectionAllDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionAllDuotone"


class PiSelectionBackgroundDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionBackgroundDuotone"


class PiSelectionDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionDuotone"


class PiSelectionForegroundDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionForegroundDuotone"


class PiSelectionInverseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionInverseDuotone"


class PiSelectionPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionPlusDuotone"


class PiSelectionSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionSlashDuotone"


class PiShapesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShapesDuotone"


class PiShareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareDuotone"


class PiShareFatDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareFatDuotone"


class PiShareNetworkDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareNetworkDuotone"


class PiShieldCheckDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckDuotone"


class PiShieldCheckeredDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckeredDuotone"


class PiShieldChevronDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldChevronDuotone"


class PiShieldDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldDuotone"


class PiShieldPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldPlusDuotone"


class PiShieldSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldSlashDuotone"


class PiShieldStarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldStarDuotone"


class PiShieldWarningDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldWarningDuotone"


class PiShirtFoldedDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShirtFoldedDuotone"


class PiShootingStarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShootingStarDuotone"


class PiShoppingBagDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagDuotone"


class PiShoppingBagOpenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagOpenDuotone"


class PiShoppingCartDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartDuotone"


class PiShoppingCartSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartSimpleDuotone"


class PiShowerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShowerDuotone"


class PiShrimpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShrimpDuotone"


class PiShuffleAngularDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleAngularDuotone"


class PiShuffleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleDuotone"


class PiShuffleSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleSimpleDuotone"


class PiSidebarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarDuotone"


class PiSidebarSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarSimpleDuotone"


class PiSigmaDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSigmaDuotone"


class PiSignInDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignInDuotone"


class PiSignOutDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignOutDuotone"


class PiSignatureDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignatureDuotone"


class PiSignpostDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignpostDuotone"


class PiSimCardDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSimCardDuotone"


class PiSirenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSirenDuotone"


class PiSketchLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSketchLogoDuotone"


class PiSkipBackCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackCircleDuotone"


class PiSkipBackDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackDuotone"


class PiSkipForwardCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardCircleDuotone"


class PiSkipForwardDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardDuotone"


class PiSkullDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkullDuotone"


class PiSlackLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlackLogoDuotone"


class PiSlidersDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersDuotone"


class PiSlidersHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersHorizontalDuotone"


class PiSlideshowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlideshowDuotone"


class PiSmileyAngryDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyAngryDuotone"


class PiSmileyBlankDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyBlankDuotone"


class PiSmileyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyDuotone"


class PiSmileyMehDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyMehDuotone"


class PiSmileyNervousDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyNervousDuotone"


class PiSmileySadDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileySadDuotone"


class PiSmileyStickerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyStickerDuotone"


class PiSmileyWinkDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyWinkDuotone"


class PiSmileyXEyesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyXEyesDuotone"


class PiSnapchatLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnapchatLogoDuotone"


class PiSneakerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerDuotone"


class PiSneakerMoveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerMoveDuotone"


class PiSnowflakeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnowflakeDuotone"


class PiSoccerBallDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoccerBallDuotone"


class PiSortAscendingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortAscendingDuotone"


class PiSortDescendingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortDescendingDuotone"


class PiSoundcloudLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoundcloudLogoDuotone"


class PiSpadeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpadeDuotone"


class PiSparkleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSparkleDuotone"


class PiSpeakerHifiDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHifiDuotone"


class PiSpeakerHighDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHighDuotone"


class PiSpeakerLowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerLowDuotone"


class PiSpeakerNoneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerNoneDuotone"


class PiSpeakerSimpleHighDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleHighDuotone"


class PiSpeakerSimpleLowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleLowDuotone"


class PiSpeakerSimpleNoneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleNoneDuotone"


class PiSpeakerSimpleSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleSlashDuotone"


class PiSpeakerSimpleXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleXDuotone"


class PiSpeakerSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSlashDuotone"


class PiSpeakerXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerXDuotone"


class PiSpinnerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerDuotone"


class PiSpinnerGapDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerGapDuotone"


class PiSpiralDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpiralDuotone"


class PiSplitHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitHorizontalDuotone"


class PiSplitVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitVerticalDuotone"


class PiSpotifyLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpotifyLogoDuotone"


class PiSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareDuotone"


class PiSquareHalfBottomDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfBottomDuotone"


class PiSquareHalfDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfDuotone"


class PiSquareLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareLogoDuotone"


class PiSquareSplitHorizontalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitHorizontalDuotone"


class PiSquareSplitVerticalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitVerticalDuotone"


class PiSquaresFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquaresFourDuotone"


class PiStackDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackDuotone"


class PiStackOverflowLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackOverflowLogoDuotone"


class PiStackSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackSimpleDuotone"


class PiStairsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStairsDuotone"


class PiStampDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStampDuotone"


class PiStarAndCrescentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarAndCrescentDuotone"


class PiStarDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarDuotone"


class PiStarFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarFourDuotone"


class PiStarHalfDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarHalfDuotone"


class PiStarOfDavidDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarOfDavidDuotone"


class PiSteeringWheelDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSteeringWheelDuotone"


class PiStepsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStepsDuotone"


class PiStethoscopeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStethoscopeDuotone"


class PiStickerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStickerDuotone"


class PiStoolDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStoolDuotone"


class PiStopCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopCircleDuotone"


class PiStopDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopDuotone"


class PiStorefrontDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStorefrontDuotone"


class PiStrategyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStrategyDuotone"


class PiStripeLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStripeLogoDuotone"


class PiStudentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiStudentDuotone"


class PiSubtitlesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtitlesDuotone"


class PiSubtractDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractDuotone"


class PiSubtractSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractSquareDuotone"


class PiSuitcaseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseDuotone"


class PiSuitcaseRollingDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseRollingDuotone"


class PiSuitcaseSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseSimpleDuotone"


class PiSunDimDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunDimDuotone"


class PiSunDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunDuotone"


class PiSunHorizonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunHorizonDuotone"


class PiSunglassesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunglassesDuotone"


class PiSwapDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwapDuotone"


class PiSwatchesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwatchesDuotone"


class PiSwimmingPoolDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwimmingPoolDuotone"


class PiSwordDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwordDuotone"


class PiSynagogueDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSynagogueDuotone"


class PiSyringeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSyringeDuotone"


class PiTShirtDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTShirtDuotone"


class PiTableDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTableDuotone"


class PiTabsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTabsDuotone"


class PiTagChevronDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagChevronDuotone"


class PiTagDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagDuotone"


class PiTagSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagSimpleDuotone"


class PiTargetDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTargetDuotone"


class PiTaxiDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTaxiDuotone"


class PiTelegramLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelegramLogoDuotone"


class PiTelevisionDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionDuotone"


class PiTelevisionSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionSimpleDuotone"


class PiTennisBallDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTennisBallDuotone"


class PiTentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTentDuotone"


class PiTerminalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalDuotone"


class PiTerminalWindowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalWindowDuotone"


class PiTestTubeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTestTubeDuotone"


class PiTextAUnderlineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAUnderlineDuotone"


class PiTextAaDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAaDuotone"


class PiTextAlignCenterDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignCenterDuotone"


class PiTextAlignJustifyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignJustifyDuotone"


class PiTextAlignLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignLeftDuotone"


class PiTextAlignRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignRightDuotone"


class PiTextBDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextBDuotone"


class PiTextColumnsDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextColumnsDuotone"


class PiTextHDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHDuotone"


class PiTextHFiveDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFiveDuotone"


class PiTextHFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFourDuotone"


class PiTextHOneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHOneDuotone"


class PiTextHSixDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHSixDuotone"


class PiTextHThreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHThreeDuotone"


class PiTextHTwoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHTwoDuotone"


class PiTextIndentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextIndentDuotone"


class PiTextItalicDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextItalicDuotone"


class PiTextOutdentDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextOutdentDuotone"


class PiTextStrikethroughDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextStrikethroughDuotone"


class PiTextTDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextTDuotone"


class PiTextUnderlineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextUnderlineDuotone"


class PiTextboxDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextboxDuotone"


class PiThermometerColdDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerColdDuotone"


class PiThermometerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerDuotone"


class PiThermometerHotDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerHotDuotone"


class PiThermometerSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerSimpleDuotone"


class PiThumbsDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsDownDuotone"


class PiThumbsUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsUpDuotone"


class PiTicketDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTicketDuotone"


class PiTidalLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTidalLogoDuotone"


class PiTiktokLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTiktokLogoDuotone"


class PiTimerDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTimerDuotone"


class PiTipiDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTipiDuotone"


class PiToggleLeftDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleLeftDuotone"


class PiToggleRightDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleRightDuotone"


class PiToiletDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletDuotone"


class PiToiletPaperDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletPaperDuotone"


class PiToolboxDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiToolboxDuotone"


class PiToothDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiToothDuotone"


class PiToteDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteDuotone"


class PiToteSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteSimpleDuotone"


class PiTrademarkDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkDuotone"


class PiTrademarkRegisteredDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkRegisteredDuotone"


class PiTrafficConeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficConeDuotone"


class PiTrafficSignDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignDuotone"


class PiTrafficSignalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignalDuotone"


class PiTrainDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainDuotone"


class PiTrainRegionalDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainRegionalDuotone"


class PiTrainSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainSimpleDuotone"


class PiTramDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTramDuotone"


class PiTranslateDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTranslateDuotone"


class PiTrashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashDuotone"


class PiTrashSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashSimpleDuotone"


class PiTrayDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrayDuotone"


class PiTreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeDuotone"


class PiTreeEvergreenDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeEvergreenDuotone"


class PiTreePalmDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreePalmDuotone"


class PiTreeStructureDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeStructureDuotone"


class PiTrendDownDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendDownDuotone"


class PiTrendUpDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendUpDuotone"


class PiTriangleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTriangleDuotone"


class PiTrophyDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrophyDuotone"


class PiTruckDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTruckDuotone"


class PiTwitchLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitchLogoDuotone"


class PiTwitterLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitterLogoDuotone"


class PiUmbrellaDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaDuotone"


class PiUmbrellaSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaSimpleDuotone"


class PiUniteDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteDuotone"


class PiUniteSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteSquareDuotone"


class PiUploadDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadDuotone"


class PiUploadSimpleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadSimpleDuotone"


class PiUsbDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsbDuotone"


class PiUserCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleDuotone"


class PiUserCircleGearDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleGearDuotone"


class PiUserCircleMinusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleMinusDuotone"


class PiUserCirclePlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCirclePlusDuotone"


class PiUserDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserDuotone"


class PiUserFocusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserFocusDuotone"


class PiUserGearDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserGearDuotone"


class PiUserListDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserListDuotone"


class PiUserMinusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserMinusDuotone"


class PiUserPlusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserPlusDuotone"


class PiUserRectangleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserRectangleDuotone"


class PiUserSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSquareDuotone"


class PiUserSwitchDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSwitchDuotone"


class PiUsersDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersDuotone"


class PiUsersFourDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersFourDuotone"


class PiUsersThreeDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersThreeDuotone"


class PiVanDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVanDuotone"


class PiVaultDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVaultDuotone"


class PiVibrateDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVibrateDuotone"


class PiVideoCameraDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraDuotone"


class PiVideoCameraSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraSlashDuotone"


class PiVideoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoDuotone"


class PiVignetteDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVignetteDuotone"


class PiVinylRecordDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVinylRecordDuotone"


class PiVirtualRealityDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirtualRealityDuotone"


class PiVirusDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirusDuotone"


class PiVoicemailDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVoicemailDuotone"


class PiVolleyballDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiVolleyballDuotone"


class PiWallDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWallDuotone"


class PiWalletDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWalletDuotone"


class PiWarehouseDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarehouseDuotone"


class PiWarningCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningCircleDuotone"


class PiWarningDiamondDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningDiamondDuotone"


class PiWarningDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningDuotone"


class PiWarningOctagonDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningOctagonDuotone"


class PiWatchDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWatchDuotone"


class PiWaveSawtoothDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSawtoothDuotone"


class PiWaveSineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSineDuotone"


class PiWaveSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSquareDuotone"


class PiWaveTriangleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveTriangleDuotone"


class PiWaveformDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveformDuotone"


class PiWavesDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWavesDuotone"


class PiWebcamDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamDuotone"


class PiWebcamSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamSlashDuotone"


class PiWebhooksLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebhooksLogoDuotone"


class PiWechatLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWechatLogoDuotone"


class PiWhatsappLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWhatsappLogoDuotone"


class PiWheelchairDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairDuotone"


class PiWheelchairMotionDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairMotionDuotone"


class PiWifiHighDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiHighDuotone"


class PiWifiLowDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiLowDuotone"


class PiWifiMediumDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiMediumDuotone"


class PiWifiNoneDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiNoneDuotone"


class PiWifiSlashDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiSlashDuotone"


class PiWifiXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiXDuotone"


class PiWindDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindDuotone"


class PiWindowsLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindowsLogoDuotone"


class PiWineDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWineDuotone"


class PiWrenchDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWrenchDuotone"


class PiXCircleDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiXCircleDuotone"


class PiXDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiXDuotone"


class PiXSquareDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiXSquareDuotone"


class PiYinYangDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiYinYangDuotone"


class PiYoutubeLogoDuotone(rx.Component):
    library = "react-icons/pi"
    tag = "PiYoutubeLogoDuotone"


class PiAddressBookFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAddressBookFill"


class PiAirTrafficControlFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirTrafficControlFill"


class PiAirplaneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneFill"


class PiAirplaneInFlightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneInFlightFill"


class PiAirplaneLandingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneLandingFill"


class PiAirplaneTakeoffFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTakeoffFill"


class PiAirplaneTiltFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTiltFill"


class PiAirplayFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplayFill"


class PiAlarmFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlarmFill"


class PiAlienFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlienFill"


class PiAlignBottomFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomFill"


class PiAlignBottomSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomSimpleFill"


class PiAlignCenterHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalFill"


class PiAlignCenterHorizontalSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalSimpleFill"


class PiAlignCenterVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalFill"


class PiAlignCenterVerticalSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalSimpleFill"


class PiAlignLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftFill"


class PiAlignLeftSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftSimpleFill"


class PiAlignRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightFill"


class PiAlignRightSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightSimpleFill"


class PiAlignTopFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopFill"


class PiAlignTopSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopSimpleFill"


class PiAmazonLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAmazonLogoFill"


class PiAnchorFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorFill"


class PiAnchorSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorSimpleFill"


class PiAndroidLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAndroidLogoFill"


class PiAngularLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAngularLogoFill"


class PiApertureFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiApertureFill"


class PiAppStoreLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppStoreLogoFill"


class PiAppWindowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppWindowFill"


class PiAppleLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppleLogoFill"


class PiApplePodcastsLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiApplePodcastsLogoFill"


class PiArchiveBoxFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveBoxFill"


class PiArchiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveFill"


class PiArchiveTrayFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveTrayFill"


class PiArmchairFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArmchairFill"


class PiArrowArcLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcLeftFill"


class PiArrowArcRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcRightFill"


class PiArrowBendDoubleUpLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpLeftFill"


class PiArrowBendDoubleUpRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpRightFill"


class PiArrowBendDownLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownLeftFill"


class PiArrowBendDownRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownRightFill"


class PiArrowBendLeftDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftDownFill"


class PiArrowBendLeftUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftUpFill"


class PiArrowBendRightDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightDownFill"


class PiArrowBendRightUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightUpFill"


class PiArrowBendUpLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpLeftFill"


class PiArrowBendUpRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpRightFill"


class PiArrowCircleDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownFill"


class PiArrowCircleDownLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownLeftFill"


class PiArrowCircleDownRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownRightFill"


class PiArrowCircleLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleLeftFill"


class PiArrowCircleRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleRightFill"


class PiArrowCircleUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpFill"


class PiArrowCircleUpLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpLeftFill"


class PiArrowCircleUpRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpRightFill"


class PiArrowClockwiseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowClockwiseFill"


class PiArrowCounterClockwiseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCounterClockwiseFill"


class PiArrowDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownFill"


class PiArrowDownLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownLeftFill"


class PiArrowDownRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownRightFill"


class PiArrowElbowDownLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownLeftFill"


class PiArrowElbowDownRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownRightFill"


class PiArrowElbowLeftDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftDownFill"


class PiArrowElbowLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftFill"


class PiArrowElbowLeftUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftUpFill"


class PiArrowElbowRightDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightDownFill"


class PiArrowElbowRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightFill"


class PiArrowElbowRightUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightUpFill"


class PiArrowElbowUpLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpLeftFill"


class PiArrowElbowUpRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpRightFill"


class PiArrowFatDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatDownFill"


class PiArrowFatLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLeftFill"


class PiArrowFatLineDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineDownFill"


class PiArrowFatLineLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineLeftFill"


class PiArrowFatLineRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineRightFill"


class PiArrowFatLineUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineUpFill"


class PiArrowFatLinesDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesDownFill"


class PiArrowFatLinesLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesLeftFill"


class PiArrowFatLinesRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesRightFill"


class PiArrowFatLinesUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesUpFill"


class PiArrowFatRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatRightFill"


class PiArrowFatUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatUpFill"


class PiArrowLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLeftFill"


class PiArrowLineDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownFill"


class PiArrowLineDownLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownLeftFill"


class PiArrowLineDownRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownRightFill"


class PiArrowLineLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineLeftFill"


class PiArrowLineRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineRightFill"


class PiArrowLineUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpFill"


class PiArrowLineUpLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpLeftFill"


class PiArrowLineUpRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpRightFill"


class PiArrowRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowRightFill"


class PiArrowSquareDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownFill"


class PiArrowSquareDownLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownLeftFill"


class PiArrowSquareDownRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownRightFill"


class PiArrowSquareInFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareInFill"


class PiArrowSquareLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareLeftFill"


class PiArrowSquareOutFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareOutFill"


class PiArrowSquareRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareRightFill"


class PiArrowSquareUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpFill"


class PiArrowSquareUpLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpLeftFill"


class PiArrowSquareUpRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpRightFill"


class PiArrowUDownLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownLeftFill"


class PiArrowUDownRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownRightFill"


class PiArrowULeftDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftDownFill"


class PiArrowULeftUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftUpFill"


class PiArrowURightDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightDownFill"


class PiArrowURightUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightUpFill"


class PiArrowUUpLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpLeftFill"


class PiArrowUUpRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpRightFill"


class PiArrowUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpFill"


class PiArrowUpLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpLeftFill"


class PiArrowUpRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpRightFill"


class PiArrowsClockwiseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsClockwiseFill"


class PiArrowsCounterClockwiseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsCounterClockwiseFill"


class PiArrowsDownUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsDownUpFill"


class PiArrowsHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsHorizontalFill"


class PiArrowsInCardinalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInCardinalFill"


class PiArrowsInFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInFill"


class PiArrowsInLineHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineHorizontalFill"


class PiArrowsInLineVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineVerticalFill"


class PiArrowsInSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInSimpleFill"


class PiArrowsLeftRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsLeftRightFill"


class PiArrowsMergeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsMergeFill"


class PiArrowsOutCardinalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutCardinalFill"


class PiArrowsOutFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutFill"


class PiArrowsOutLineHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineHorizontalFill"


class PiArrowsOutLineVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineVerticalFill"


class PiArrowsOutSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutSimpleFill"


class PiArrowsSplitFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsSplitFill"


class PiArrowsVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsVerticalFill"


class PiArticleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleFill"


class PiArticleMediumFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleMediumFill"


class PiArticleNyTimesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleNyTimesFill"


class PiAsteriskFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskFill"


class PiAsteriskSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskSimpleFill"


class PiAtFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtFill"


class PiAtomFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtomFill"


class PiBabyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBabyFill"


class PiBackpackFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackpackFill"


class PiBackspaceFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackspaceFill"


class PiBagFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagFill"


class PiBagSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagSimpleFill"


class PiBalloonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBalloonFill"


class PiBandaidsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBandaidsFill"


class PiBankFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBankFill"


class PiBarbellFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarbellFill"


class PiBarcodeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarcodeFill"


class PiBarricadeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarricadeFill"


class PiBaseballCapFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballCapFill"


class PiBaseballFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballFill"


class PiBasketFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketFill"


class PiBasketballFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketballFill"


class PiBathtubFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBathtubFill"


class PiBatteryChargingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingFill"


class PiBatteryChargingVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingVerticalFill"


class PiBatteryEmptyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryEmptyFill"


class PiBatteryFullFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryFullFill"


class PiBatteryHighFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryHighFill"


class PiBatteryLowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryLowFill"


class PiBatteryMediumFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryMediumFill"


class PiBatteryPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusFill"


class PiBatteryPlusVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusVerticalFill"


class PiBatteryVerticalEmptyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalEmptyFill"


class PiBatteryVerticalFullFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalFullFill"


class PiBatteryVerticalHighFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalHighFill"


class PiBatteryVerticalLowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalLowFill"


class PiBatteryVerticalMediumFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalMediumFill"


class PiBatteryWarningFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningFill"


class PiBatteryWarningVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningVerticalFill"


class PiBedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBedFill"


class PiBeerBottleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerBottleFill"


class PiBeerSteinFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerSteinFill"


class PiBehanceLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBehanceLogoFill"


class PiBellFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellFill"


class PiBellRingingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellRingingFill"


class PiBellSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleFill"


class PiBellSimpleRingingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleRingingFill"


class PiBellSimpleSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleSlashFill"


class PiBellSimpleZFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleZFill"


class PiBellSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSlashFill"


class PiBellZFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellZFill"


class PiBezierCurveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBezierCurveFill"


class PiBicycleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBicycleFill"


class PiBinocularsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBinocularsFill"


class PiBirdFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBirdFill"


class PiBluetoothConnectedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothConnectedFill"


class PiBluetoothFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothFill"


class PiBluetoothSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothSlashFill"


class PiBluetoothXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothXFill"


class PiBoatFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoatFill"


class PiBoneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoneFill"


class PiBookBookmarkFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookBookmarkFill"


class PiBookFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookFill"


class PiBookOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenFill"


class PiBookOpenTextFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenTextFill"


class PiBookmarkFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkFill"


class PiBookmarkSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkSimpleFill"


class PiBookmarksFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksFill"


class PiBookmarksSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksSimpleFill"


class PiBooksFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBooksFill"


class PiBootFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBootFill"


class PiBoundingBoxFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoundingBoxFill"


class PiBowlFoodFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBowlFoodFill"


class PiBracketsAngleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsAngleFill"


class PiBracketsCurlyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsCurlyFill"


class PiBracketsRoundFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsRoundFill"


class PiBracketsSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsSquareFill"


class PiBrainFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrainFill"


class PiBrandyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrandyFill"


class PiBridgeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBridgeFill"


class PiBriefcaseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseFill"


class PiBriefcaseMetalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseMetalFill"


class PiBroadcastFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroadcastFill"


class PiBroomFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroomFill"


class PiBrowserFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowserFill"


class PiBrowsersFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowsersFill"


class PiBugBeetleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugBeetleFill"


class PiBugDroidFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugDroidFill"


class PiBugFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugFill"


class PiBuildingsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBuildingsFill"


class PiBusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiBusFill"


class PiButterflyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiButterflyFill"


class PiCactusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCactusFill"


class PiCakeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCakeFill"


class PiCalculatorFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalculatorFill"


class PiCalendarBlankFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarBlankFill"


class PiCalendarCheckFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarCheckFill"


class PiCalendarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarFill"


class PiCalendarPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarPlusFill"


class PiCalendarXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarXFill"


class PiCallBellFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCallBellFill"


class PiCameraFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraFill"


class PiCameraPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraPlusFill"


class PiCameraRotateFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraRotateFill"


class PiCameraSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraSlashFill"


class PiCampfireFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCampfireFill"


class PiCarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarFill"


class PiCarProfileFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarProfileFill"


class PiCarSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarSimpleFill"


class PiCardholderFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardholderFill"


class PiCardsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardsFill"


class PiCaretCircleDoubleDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleDownFill"


class PiCaretCircleDoubleLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleLeftFill"


class PiCaretCircleDoubleRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleRightFill"


class PiCaretCircleDoubleUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleUpFill"


class PiCaretCircleDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDownFill"


class PiCaretCircleLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleLeftFill"


class PiCaretCircleRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleRightFill"


class PiCaretCircleUpDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpDownFill"


class PiCaretCircleUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpFill"


class PiCaretDoubleDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleDownFill"


class PiCaretDoubleLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleLeftFill"


class PiCaretDoubleRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleRightFill"


class PiCaretDoubleUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleUpFill"


class PiCaretDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDownFill"


class PiCaretLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretLeftFill"


class PiCaretRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretRightFill"


class PiCaretUpDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpDownFill"


class PiCaretUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpFill"


class PiCarrotFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarrotFill"


class PiCassetteTapeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCassetteTapeFill"


class PiCastleTurretFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCastleTurretFill"


class PiCatFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCatFill"


class PiCellSignalFullFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalFullFill"


class PiCellSignalHighFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalHighFill"


class PiCellSignalLowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalLowFill"


class PiCellSignalMediumFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalMediumFill"


class PiCellSignalNoneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalNoneFill"


class PiCellSignalSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalSlashFill"


class PiCellSignalXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalXFill"


class PiCertificateFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCertificateFill"


class PiChairFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChairFill"


class PiChalkboardFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardFill"


class PiChalkboardSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardSimpleFill"


class PiChalkboardTeacherFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardTeacherFill"


class PiChampagneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChampagneFill"


class PiChargingStationFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChargingStationFill"


class PiChartBarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarFill"


class PiChartBarHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarHorizontalFill"


class PiChartDonutFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartDonutFill"


class PiChartLineDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineDownFill"


class PiChartLineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineFill"


class PiChartLineUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineUpFill"


class PiChartPieFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieFill"


class PiChartPieSliceFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieSliceFill"


class PiChartPolarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPolarFill"


class PiChartScatterFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartScatterFill"


class PiChatCenteredDotsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredDotsFill"


class PiChatCenteredFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredFill"


class PiChatCenteredTextFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredTextFill"


class PiChatCircleDotsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleDotsFill"


class PiChatCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleFill"


class PiChatCircleTextFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleTextFill"


class PiChatDotsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatDotsFill"


class PiChatFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatFill"


class PiChatTeardropDotsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropDotsFill"


class PiChatTeardropFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropFill"


class PiChatTeardropTextFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropTextFill"


class PiChatTextFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTextFill"


class PiChatsCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsCircleFill"


class PiChatsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsFill"


class PiChatsTeardropFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsTeardropFill"


class PiCheckCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckCircleFill"


class PiCheckFatFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckFatFill"


class PiCheckFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckFill"


class PiCheckSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareFill"


class PiCheckSquareOffsetFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareOffsetFill"


class PiChecksFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChecksFill"


class PiChurchFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiChurchFill"


class PiCircleDashedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleDashedFill"


class PiCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleFill"


class PiCircleHalfFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfFill"


class PiCircleHalfTiltFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfTiltFill"


class PiCircleNotchFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleNotchFill"


class PiCirclesFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesFourFill"


class PiCirclesThreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreeFill"


class PiCirclesThreePlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreePlusFill"


class PiCircuitryFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircuitryFill"


class PiClipboardFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardFill"


class PiClipboardTextFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardTextFill"


class PiClockAfternoonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockAfternoonFill"


class PiClockClockwiseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockClockwiseFill"


class PiClockCountdownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCountdownFill"


class PiClockCounterClockwiseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCounterClockwiseFill"


class PiClockFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockFill"


class PiClosedCaptioningFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiClosedCaptioningFill"


class PiCloudArrowDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowDownFill"


class PiCloudArrowUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowUpFill"


class PiCloudCheckFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudCheckFill"


class PiCloudFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudFill"


class PiCloudFogFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudFogFill"


class PiCloudLightningFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudLightningFill"


class PiCloudMoonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudMoonFill"


class PiCloudRainFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudRainFill"


class PiCloudSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSlashFill"


class PiCloudSnowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSnowFill"


class PiCloudSunFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSunFill"


class PiCloudWarningFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudWarningFill"


class PiCloudXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudXFill"


class PiClubFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiClubFill"


class PiCoatHangerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoatHangerFill"


class PiCodaLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodaLogoFill"


class PiCodeBlockFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeBlockFill"


class PiCodeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeFill"


class PiCodeSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeSimpleFill"


class PiCodepenLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodepenLogoFill"


class PiCodesandboxLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodesandboxLogoFill"


class PiCoffeeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoffeeFill"


class PiCoinFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinFill"


class PiCoinVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinVerticalFill"


class PiCoinsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinsFill"


class PiColumnsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiColumnsFill"


class PiCommandFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCommandFill"


class PiCompassFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassFill"


class PiCompassToolFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassToolFill"


class PiComputerTowerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiComputerTowerFill"


class PiConfettiFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiConfettiFill"


class PiContactlessPaymentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiContactlessPaymentFill"


class PiControlFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiControlFill"


class PiCookieFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookieFill"


class PiCookingPotFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookingPotFill"


class PiCopyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyFill"


class PiCopySimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopySimpleFill"


class PiCopyleftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyleftFill"


class PiCopyrightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyrightFill"


class PiCornersInFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersInFill"


class PiCornersOutFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersOutFill"


class PiCouchFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCouchFill"


class PiCpuFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCpuFill"


class PiCreditCardFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCreditCardFill"


class PiCropFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCropFill"


class PiCrossFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrossFill"


class PiCrosshairFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairFill"


class PiCrosshairSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairSimpleFill"


class PiCrownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownFill"


class PiCrownSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownSimpleFill"


class PiCubeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeFill"


class PiCubeFocusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeFocusFill"


class PiCubeTransparentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeTransparentFill"


class PiCurrencyBtcFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyBtcFill"


class PiCurrencyCircleDollarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCircleDollarFill"


class PiCurrencyCnyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCnyFill"


class PiCurrencyDollarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarFill"


class PiCurrencyDollarSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarSimpleFill"


class PiCurrencyEthFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEthFill"


class PiCurrencyEurFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEurFill"


class PiCurrencyGbpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyGbpFill"


class PiCurrencyInrFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyInrFill"


class PiCurrencyJpyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyJpyFill"


class PiCurrencyKrwFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKrwFill"


class PiCurrencyKztFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKztFill"


class PiCurrencyNgnFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyNgnFill"


class PiCurrencyRubFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyRubFill"


class PiCursorClickFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorClickFill"


class PiCursorFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorFill"


class PiCursorTextFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorTextFill"


class PiCylinderFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiCylinderFill"


class PiDatabaseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDatabaseFill"


class PiDesktopFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopFill"


class PiDesktopTowerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopTowerFill"


class PiDetectiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDetectiveFill"


class PiDevToLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevToLogoFill"


class PiDeviceMobileCameraFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileCameraFill"


class PiDeviceMobileFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileFill"


class PiDeviceMobileSpeakerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileSpeakerFill"


class PiDeviceTabletCameraFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletCameraFill"


class PiDeviceTabletFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletFill"


class PiDeviceTabletSpeakerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletSpeakerFill"


class PiDevicesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevicesFill"


class PiDiamondFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondFill"


class PiDiamondsFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondsFourFill"


class PiDiceFiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFiveFill"


class PiDiceFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFourFill"


class PiDiceOneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceOneFill"


class PiDiceSixFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceSixFill"


class PiDiceThreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceThreeFill"


class PiDiceTwoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceTwoFill"


class PiDiscFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscFill"


class PiDiscordLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscordLogoFill"


class PiDivideFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDivideFill"


class PiDnaFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDnaFill"


class PiDogFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDogFill"


class PiDoorFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorFill"


class PiDoorOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorOpenFill"


class PiDotFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotFill"


class PiDotOutlineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotOutlineFill"


class PiDotsNineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsNineFill"


class PiDotsSixFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixFill"


class PiDotsSixVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixVerticalFill"


class PiDotsThreeCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleFill"


class PiDotsThreeCircleVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleVerticalFill"


class PiDotsThreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeFill"


class PiDotsThreeOutlineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineFill"


class PiDotsThreeOutlineVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineVerticalFill"


class PiDotsThreeVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeVerticalFill"


class PiDownloadFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadFill"


class PiDownloadSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadSimpleFill"


class PiDressFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDressFill"


class PiDribbbleLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDribbbleLogoFill"


class PiDropFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropFill"


class PiDropHalfBottomFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfBottomFill"


class PiDropHalfFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfFill"


class PiDropboxLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropboxLogoFill"


class PiEarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarFill"


class PiEarSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarSlashFill"


class PiEggCrackFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggCrackFill"


class PiEggFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggFill"


class PiEjectFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectFill"


class PiEjectSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectSimpleFill"


class PiElevatorFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiElevatorFill"


class PiEngineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEngineFill"


class PiEnvelopeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeFill"


class PiEnvelopeOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeOpenFill"


class PiEnvelopeSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleFill"


class PiEnvelopeSimpleOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleOpenFill"


class PiEqualizerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualizerFill"


class PiEqualsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualsFill"


class PiEraserFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEraserFill"


class PiEscalatorDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorDownFill"


class PiEscalatorUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorUpFill"


class PiExamFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiExamFill"


class PiExcludeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeFill"


class PiExcludeSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeSquareFill"


class PiExportFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiExportFill"


class PiEyeClosedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeClosedFill"


class PiEyeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeFill"


class PiEyeSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeSlashFill"


class PiEyedropperFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperFill"


class PiEyedropperSampleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperSampleFill"


class PiEyeglassesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeglassesFill"


class PiFaceMaskFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFaceMaskFill"


class PiFacebookLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFacebookLogoFill"


class PiFactoryFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFactoryFill"


class PiFadersFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersFill"


class PiFadersHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersHorizontalFill"


class PiFanFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFanFill"


class PiFastForwardCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardCircleFill"


class PiFastForwardFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardFill"


class PiFeatherFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFeatherFill"


class PiFigmaLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFigmaLogoFill"


class PiFileArchiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArchiveFill"


class PiFileArrowDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowDownFill"


class PiFileArrowUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowUpFill"


class PiFileAudioFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileAudioFill"


class PiFileCloudFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCloudFill"


class PiFileCodeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCodeFill"


class PiFileCssFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCssFill"


class PiFileCsvFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCsvFill"


class PiFileDashedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDashedFill"


class PiFileDocFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDocFill"


class PiFileFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileFill"


class PiFileHtmlFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileHtmlFill"


class PiFileImageFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileImageFill"


class PiFileJpgFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJpgFill"


class PiFileJsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsFill"


class PiFileJsxFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsxFill"


class PiFileLockFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileLockFill"


class PiFileMagnifyingGlassFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMagnifyingGlassFill"


class PiFileMinusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMinusFill"


class PiFilePdfFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePdfFill"


class PiFilePlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePlusFill"


class PiFilePngFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePngFill"


class PiFilePptFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePptFill"


class PiFileRsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileRsFill"


class PiFileSqlFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSqlFill"


class PiFileSvgFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSvgFill"


class PiFileTextFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTextFill"


class PiFileTsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsFill"


class PiFileTsxFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsxFill"


class PiFileVideoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVideoFill"


class PiFileVueFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVueFill"


class PiFileXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXFill"


class PiFileXlsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXlsFill"


class PiFileZipFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileZipFill"


class PiFilesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilesFill"


class PiFilmReelFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmReelFill"


class PiFilmScriptFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmScriptFill"


class PiFilmSlateFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmSlateFill"


class PiFilmStripFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmStripFill"


class PiFingerprintFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintFill"


class PiFingerprintSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintSimpleFill"


class PiFinnTheHumanFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFinnTheHumanFill"


class PiFireExtinguisherFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireExtinguisherFill"


class PiFireFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireFill"


class PiFireSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireSimpleFill"


class PiFirstAidFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidFill"


class PiFirstAidKitFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidKitFill"


class PiFishFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishFill"


class PiFishSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishSimpleFill"


class PiFlagBannerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagBannerFill"


class PiFlagCheckeredFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagCheckeredFill"


class PiFlagFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagFill"


class PiFlagPennantFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagPennantFill"


class PiFlameFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlameFill"


class PiFlashlightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlashlightFill"


class PiFlaskFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlaskFill"


class PiFloppyDiskBackFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskBackFill"


class PiFloppyDiskFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskFill"


class PiFlowArrowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowArrowFill"


class PiFlowerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerFill"


class PiFlowerLotusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerLotusFill"


class PiFlowerTulipFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerTulipFill"


class PiFlyingSaucerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlyingSaucerFill"


class PiFolderDashedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderDashedFill"


class PiFolderFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderFill"


class PiFolderLockFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderLockFill"


class PiFolderMinusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderMinusFill"


class PiFolderNotchFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchFill"


class PiFolderNotchMinusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchMinusFill"


class PiFolderNotchOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchOpenFill"


class PiFolderNotchPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchPlusFill"


class PiFolderOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderOpenFill"


class PiFolderPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderPlusFill"


class PiFolderSimpleDashedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleDashedFill"


class PiFolderSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleFill"


class PiFolderSimpleLockFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleLockFill"


class PiFolderSimpleMinusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleMinusFill"


class PiFolderSimplePlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimplePlusFill"


class PiFolderSimpleStarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleStarFill"


class PiFolderSimpleUserFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleUserFill"


class PiFolderStarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderStarFill"


class PiFolderUserFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderUserFill"


class PiFoldersFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFoldersFill"


class PiFootballFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootballFill"


class PiFootprintsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootprintsFill"


class PiForkKnifeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiForkKnifeFill"


class PiFrameCornersFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFrameCornersFill"


class PiFramerLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFramerLogoFill"


class PiFunctionFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunctionFill"


class PiFunnelFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelFill"


class PiFunnelSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelSimpleFill"


class PiGameControllerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGameControllerFill"


class PiGarageFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGarageFill"


class PiGasCanFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasCanFill"


class PiGasPumpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasPumpFill"


class PiGaugeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGaugeFill"


class PiGavelFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGavelFill"


class PiGearFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearFill"


class PiGearFineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearFineFill"


class PiGearSixFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearSixFill"


class PiGenderFemaleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderFemaleFill"


class PiGenderIntersexFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderIntersexFill"


class PiGenderMaleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderMaleFill"


class PiGenderNeuterFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNeuterFill"


class PiGenderNonbinaryFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNonbinaryFill"


class PiGenderTransgenderFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderTransgenderFill"


class PiGhostFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGhostFill"


class PiGifFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGifFill"


class PiGiftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGiftFill"


class PiGitBranchFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitBranchFill"


class PiGitCommitFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitCommitFill"


class PiGitDiffFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitDiffFill"


class PiGitForkFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitForkFill"


class PiGitMergeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitMergeFill"


class PiGitPullRequestFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitPullRequestFill"


class PiGithubLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGithubLogoFill"


class PiGitlabLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoFill"


class PiGitlabLogoSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoSimpleFill"


class PiGlobeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeFill"


class PiGlobeHemisphereEastFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereEastFill"


class PiGlobeHemisphereWestFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereWestFill"


class PiGlobeSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeSimpleFill"


class PiGlobeStandFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeStandFill"


class PiGogglesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGogglesFill"


class PiGoodreadsLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoodreadsLogoFill"


class PiGoogleCardboardLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleCardboardLogoFill"


class PiGoogleChromeLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleChromeLogoFill"


class PiGoogleDriveLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleDriveLogoFill"


class PiGoogleLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleLogoFill"


class PiGooglePhotosLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePhotosLogoFill"


class PiGooglePlayLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePlayLogoFill"


class PiGooglePodcastsLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePodcastsLogoFill"


class PiGradientFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGradientFill"


class PiGraduationCapFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraduationCapFill"


class PiGrainsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsFill"


class PiGrainsSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsSlashFill"


class PiGraphFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraphFill"


class PiGridFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridFourFill"


class PiGridNineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridNineFill"


class PiGuitarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiGuitarFill"


class PiHamburgerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHamburgerFill"


class PiHammerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHammerFill"


class PiHandCoinsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandCoinsFill"


class PiHandEyeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandEyeFill"


class PiHandFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandFill"


class PiHandFistFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandFistFill"


class PiHandGrabbingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandGrabbingFill"


class PiHandHeartFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandHeartFill"


class PiHandPalmFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPalmFill"


class PiHandPointingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPointingFill"


class PiHandSoapFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSoapFill"


class PiHandSwipeLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeLeftFill"


class PiHandSwipeRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeRightFill"


class PiHandTapFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandTapFill"


class PiHandWavingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandWavingFill"


class PiHandbagFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagFill"


class PiHandbagSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagSimpleFill"


class PiHandsClappingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsClappingFill"


class PiHandsPrayingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsPrayingFill"


class PiHandshakeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandshakeFill"


class PiHardDriveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDriveFill"


class PiHardDrivesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDrivesFill"


class PiHashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashFill"


class PiHashStraightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashStraightFill"


class PiHeadlightsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadlightsFill"


class PiHeadphonesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadphonesFill"


class PiHeadsetFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadsetFill"


class PiHeartBreakFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartBreakFill"


class PiHeartFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartFill"


class PiHeartHalfFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartHalfFill"


class PiHeartStraightBreakFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightBreakFill"


class PiHeartStraightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightFill"


class PiHeartbeatFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartbeatFill"


class PiHexagonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHexagonFill"


class PiHighHeelFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighHeelFill"


class PiHighlighterCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighlighterCircleFill"


class PiHoodieFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHoodieFill"


class PiHorseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHorseFill"


class PiHourglassFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassFill"


class PiHourglassHighFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassHighFill"


class PiHourglassLowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassLowFill"


class PiHourglassMediumFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassMediumFill"


class PiHourglassSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleFill"


class PiHourglassSimpleHighFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleHighFill"


class PiHourglassSimpleLowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleLowFill"


class PiHourglassSimpleMediumFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleMediumFill"


class PiHouseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseFill"


class PiHouseLineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseLineFill"


class PiHouseSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseSimpleFill"


class PiIceCreamFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiIceCreamFill"


class PiIdentificationBadgeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationBadgeFill"


class PiIdentificationCardFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationCardFill"


class PiImageFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageFill"


class PiImageSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageSquareFill"


class PiImagesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesFill"


class PiImagesSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesSquareFill"


class PiInfinityFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfinityFill"


class PiInfoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfoFill"


class PiInstagramLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiInstagramLogoFill"


class PiIntersectFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectFill"


class PiIntersectSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectSquareFill"


class PiIntersectThreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectThreeFill"


class PiJeepFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiJeepFill"


class PiKanbanFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiKanbanFill"


class PiKeyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyFill"


class PiKeyReturnFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyReturnFill"


class PiKeyboardFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyboardFill"


class PiKeyholeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyholeFill"


class PiKnifeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiKnifeFill"


class PiLadderFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderFill"


class PiLadderSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderSimpleFill"


class PiLampFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLampFill"


class PiLaptopFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLaptopFill"


class PiLayoutFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLayoutFill"


class PiLeafFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLeafFill"


class PiLifebuoyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLifebuoyFill"


class PiLightbulbFilamentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbFilamentFill"


class PiLightbulbFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbFill"


class PiLighthouseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLighthouseFill"


class PiLightningAFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningAFill"


class PiLightningFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningFill"


class PiLightningSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningSlashFill"


class PiLineSegmentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentFill"


class PiLineSegmentsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentsFill"


class PiLinkBreakFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkBreakFill"


class PiLinkFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkFill"


class PiLinkSimpleBreakFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleBreakFill"


class PiLinkSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleFill"


class PiLinkSimpleHorizontalBreakFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalBreakFill"


class PiLinkSimpleHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalFill"


class PiLinkedinLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkedinLogoFill"


class PiLinuxLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinuxLogoFill"


class PiListBulletsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiListBulletsFill"


class PiListChecksFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiListChecksFill"


class PiListDashesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiListDashesFill"


class PiListFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiListFill"


class PiListMagnifyingGlassFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiListMagnifyingGlassFill"


class PiListNumbersFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiListNumbersFill"


class PiListPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiListPlusFill"


class PiLockFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockFill"


class PiLockKeyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyFill"


class PiLockKeyOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyOpenFill"


class PiLockLaminatedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedFill"


class PiLockLaminatedOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedOpenFill"


class PiLockOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockOpenFill"


class PiLockSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleFill"


class PiLockSimpleOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleOpenFill"


class PiLockersFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockersFill"


class PiMagicWandFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagicWandFill"


class PiMagnetFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetFill"


class PiMagnetStraightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetStraightFill"


class PiMagnifyingGlassFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassFill"


class PiMagnifyingGlassMinusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassMinusFill"


class PiMagnifyingGlassPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassPlusFill"


class PiMapPinFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinFill"


class PiMapPinLineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinLineFill"


class PiMapTrifoldFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapTrifoldFill"


class PiMarkerCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMarkerCircleFill"


class PiMartiniFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMartiniFill"


class PiMaskHappyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskHappyFill"


class PiMaskSadFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskSadFill"


class PiMathOperationsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMathOperationsFill"


class PiMedalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalFill"


class PiMedalMilitaryFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalMilitaryFill"


class PiMediumLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMediumLogoFill"


class PiMegaphoneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneFill"


class PiMegaphoneSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneSimpleFill"


class PiMessengerLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMessengerLogoFill"


class PiMetaLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetaLogoFill"


class PiMetronomeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetronomeFill"


class PiMicrophoneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneFill"


class PiMicrophoneSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneSlashFill"


class PiMicrophoneStageFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneStageFill"


class PiMicrosoftExcelLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftExcelLogoFill"


class PiMicrosoftOutlookLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftOutlookLogoFill"


class PiMicrosoftPowerpointLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftPowerpointLogoFill"


class PiMicrosoftTeamsLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftTeamsLogoFill"


class PiMicrosoftWordLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftWordLogoFill"


class PiMinusCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusCircleFill"


class PiMinusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusFill"


class PiMinusSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusSquareFill"


class PiMoneyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoneyFill"


class PiMonitorFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorFill"


class PiMonitorPlayFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorPlayFill"


class PiMoonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonFill"


class PiMoonStarsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonStarsFill"


class PiMopedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedFill"


class PiMopedFrontFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedFrontFill"


class PiMosqueFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMosqueFill"


class PiMotorcycleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMotorcycleFill"


class PiMountainsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMountainsFill"


class PiMouseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseFill"


class PiMouseSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseSimpleFill"


class PiMusicNoteFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteFill"


class PiMusicNoteSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteSimpleFill"


class PiMusicNotesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesFill"


class PiMusicNotesPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesPlusFill"


class PiMusicNotesSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesSimpleFill"


class PiNavigationArrowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNavigationArrowFill"


class PiNeedleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNeedleFill"


class PiNewspaperClippingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperClippingFill"


class PiNewspaperFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperFill"


class PiNotchesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotchesFill"


class PiNoteBlankFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteBlankFill"


class PiNoteFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteFill"


class PiNotePencilFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotePencilFill"


class PiNotebookFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotebookFill"


class PiNotepadFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotepadFill"


class PiNotificationFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotificationFill"


class PiNotionLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotionLogoFill"


class PiNumberCircleEightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleEightFill"


class PiNumberCircleFiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFiveFill"


class PiNumberCircleFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFourFill"


class PiNumberCircleNineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleNineFill"


class PiNumberCircleOneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleOneFill"


class PiNumberCircleSevenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSevenFill"


class PiNumberCircleSixFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSixFill"


class PiNumberCircleThreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleThreeFill"


class PiNumberCircleTwoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleTwoFill"


class PiNumberCircleZeroFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleZeroFill"


class PiNumberEightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberEightFill"


class PiNumberFiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFiveFill"


class PiNumberFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFourFill"


class PiNumberNineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberNineFill"


class PiNumberOneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberOneFill"


class PiNumberSevenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSevenFill"


class PiNumberSixFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSixFill"


class PiNumberSquareEightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareEightFill"


class PiNumberSquareFiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFiveFill"


class PiNumberSquareFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFourFill"


class PiNumberSquareNineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareNineFill"


class PiNumberSquareOneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareOneFill"


class PiNumberSquareSevenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSevenFill"


class PiNumberSquareSixFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSixFill"


class PiNumberSquareThreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareThreeFill"


class PiNumberSquareTwoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareTwoFill"


class PiNumberSquareZeroFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareZeroFill"


class PiNumberThreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberThreeFill"


class PiNumberTwoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberTwoFill"


class PiNumberZeroFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberZeroFill"


class PiNutFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNutFill"


class PiNyTimesLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiNyTimesLogoFill"


class PiOctagonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiOctagonFill"


class PiOfficeChairFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiOfficeChairFill"


class PiOptionFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiOptionFill"


class PiOrangeSliceFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiOrangeSliceFill"


class PiPackageFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPackageFill"


class PiPaintBrushBroadFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushBroadFill"


class PiPaintBrushFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushFill"


class PiPaintBrushHouseholdFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushHouseholdFill"


class PiPaintBucketFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBucketFill"


class PiPaintRollerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintRollerFill"


class PiPaletteFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaletteFill"


class PiPantsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPantsFill"


class PiPaperPlaneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneFill"


class PiPaperPlaneRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneRightFill"


class PiPaperPlaneTiltFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneTiltFill"


class PiPaperclipFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipFill"


class PiPaperclipHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipHorizontalFill"


class PiParachuteFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiParachuteFill"


class PiParagraphFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiParagraphFill"


class PiParallelogramFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiParallelogramFill"


class PiParkFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiParkFill"


class PiPasswordFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPasswordFill"


class PiPathFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPathFill"


class PiPatreonLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPatreonLogoFill"


class PiPauseCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseCircleFill"


class PiPauseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseFill"


class PiPawPrintFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPawPrintFill"


class PiPaypalLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaypalLogoFill"


class PiPeaceFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPeaceFill"


class PiPenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenFill"


class PiPenNibFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibFill"


class PiPenNibStraightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibStraightFill"


class PiPencilCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilCircleFill"


class PiPencilFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilFill"


class PiPencilLineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilLineFill"


class PiPencilSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleFill"


class PiPencilSimpleLineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleLineFill"


class PiPencilSimpleSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleSlashFill"


class PiPencilSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSlashFill"


class PiPentagramFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPentagramFill"


class PiPepperFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPepperFill"


class PiPercentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPercentFill"


class PiPersonArmsSpreadFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonArmsSpreadFill"


class PiPersonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonFill"


class PiPersonSimpleBikeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleBikeFill"


class PiPersonSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleFill"


class PiPersonSimpleRunFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleRunFill"


class PiPersonSimpleThrowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleThrowFill"


class PiPersonSimpleWalkFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleWalkFill"


class PiPerspectiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPerspectiveFill"


class PiPhoneCallFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneCallFill"


class PiPhoneDisconnectFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneDisconnectFill"


class PiPhoneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneFill"


class PiPhoneIncomingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneIncomingFill"


class PiPhoneOutgoingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneOutgoingFill"


class PiPhonePlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhonePlusFill"


class PiPhoneSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneSlashFill"


class PiPhoneXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneXFill"


class PiPhosphorLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhosphorLogoFill"


class PiPiFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiFill"


class PiPianoKeysFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPianoKeysFill"


class PiPictureInPictureFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPictureInPictureFill"


class PiPiggyBankFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiggyBankFill"


class PiPillFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPillFill"


class PiPinterestLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinterestLogoFill"


class PiPinwheelFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinwheelFill"


class PiPizzaFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPizzaFill"


class PiPlaceholderFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaceholderFill"


class PiPlanetFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlanetFill"


class PiPlantFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlantFill"


class PiPlayCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayCircleFill"


class PiPlayFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayFill"


class PiPlayPauseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayPauseFill"


class PiPlaylistFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaylistFill"


class PiPlugChargingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugChargingFill"


class PiPlugFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugFill"


class PiPlugsConnectedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsConnectedFill"


class PiPlugsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsFill"


class PiPlusCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusCircleFill"


class PiPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusFill"


class PiPlusMinusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusMinusFill"


class PiPlusSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusSquareFill"


class PiPokerChipFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPokerChipFill"


class PiPoliceCarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPoliceCarFill"


class PiPolygonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPolygonFill"


class PiPopcornFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPopcornFill"


class PiPottedPlantFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPottedPlantFill"


class PiPowerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPowerFill"


class PiPrescriptionFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrescriptionFill"


class PiPresentationChartFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationChartFill"


class PiPresentationFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationFill"


class PiPrinterFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrinterFill"


class PiProhibitFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitFill"


class PiProhibitInsetFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitInsetFill"


class PiProjectorScreenChartFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenChartFill"


class PiProjectorScreenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenFill"


class PiPulseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPulseFill"


class PiPushPinFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinFill"


class PiPushPinSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleFill"


class PiPushPinSimpleSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleSlashFill"


class PiPushPinSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSlashFill"


class PiPuzzlePieceFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPuzzlePieceFill"


class PiQrCodeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiQrCodeFill"


class PiQuestionFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuestionFill"


class PiQueueFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiQueueFill"


class PiQuotesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuotesFill"


class PiRadicalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadicalFill"


class PiRadioButtonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioButtonFill"


class PiRadioFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioFill"


class PiRadioactiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioactiveFill"


class PiRainbowCloudFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowCloudFill"


class PiRainbowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowFill"


class PiReadCvLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiReadCvLogoFill"


class PiReceiptFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptFill"


class PiReceiptXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptXFill"


class PiRecordFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecordFill"


class PiRectangleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRectangleFill"


class PiRecycleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecycleFill"


class PiRedditLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRedditLogoFill"


class PiRepeatFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatFill"


class PiRepeatOnceFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatOnceFill"


class PiRewindCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindCircleFill"


class PiRewindFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindFill"


class PiRoadHorizonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRoadHorizonFill"


class PiRobotFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRobotFill"


class PiRocketFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketFill"


class PiRocketLaunchFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketLaunchFill"


class PiRowsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRowsFill"


class PiRssFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssFill"


class PiRssSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssSimpleFill"


class PiRugFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRugFill"


class PiRulerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiRulerFill"


class PiScalesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiScalesFill"


class PiScanFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiScanFill"


class PiScissorsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiScissorsFill"


class PiScooterFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiScooterFill"


class PiScreencastFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiScreencastFill"


class PiScribbleLoopFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiScribbleLoopFill"


class PiScrollFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiScrollFill"


class PiSealCheckFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealCheckFill"


class PiSealFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealFill"


class PiSealQuestionFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealQuestionFill"


class PiSealWarningFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealWarningFill"


class PiSelectionAllFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionAllFill"


class PiSelectionBackgroundFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionBackgroundFill"


class PiSelectionFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionFill"


class PiSelectionForegroundFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionForegroundFill"


class PiSelectionInverseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionInverseFill"


class PiSelectionPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionPlusFill"


class PiSelectionSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionSlashFill"


class PiShapesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShapesFill"


class PiShareFatFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareFatFill"


class PiShareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareFill"


class PiShareNetworkFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareNetworkFill"


class PiShieldCheckFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckFill"


class PiShieldCheckeredFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckeredFill"


class PiShieldChevronFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldChevronFill"


class PiShieldFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldFill"


class PiShieldPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldPlusFill"


class PiShieldSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldSlashFill"


class PiShieldStarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldStarFill"


class PiShieldWarningFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldWarningFill"


class PiShirtFoldedFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShirtFoldedFill"


class PiShootingStarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShootingStarFill"


class PiShoppingBagFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagFill"


class PiShoppingBagOpenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagOpenFill"


class PiShoppingCartFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartFill"


class PiShoppingCartSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartSimpleFill"


class PiShowerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShowerFill"


class PiShrimpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShrimpFill"


class PiShuffleAngularFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleAngularFill"


class PiShuffleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleFill"


class PiShuffleSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleSimpleFill"


class PiSidebarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarFill"


class PiSidebarSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarSimpleFill"


class PiSigmaFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSigmaFill"


class PiSignInFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignInFill"


class PiSignOutFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignOutFill"


class PiSignatureFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignatureFill"


class PiSignpostFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignpostFill"


class PiSimCardFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSimCardFill"


class PiSirenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSirenFill"


class PiSketchLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSketchLogoFill"


class PiSkipBackCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackCircleFill"


class PiSkipBackFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackFill"


class PiSkipForwardCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardCircleFill"


class PiSkipForwardFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardFill"


class PiSkullFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkullFill"


class PiSlackLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlackLogoFill"


class PiSlidersFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersFill"


class PiSlidersHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersHorizontalFill"


class PiSlideshowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlideshowFill"


class PiSmileyAngryFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyAngryFill"


class PiSmileyBlankFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyBlankFill"


class PiSmileyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyFill"


class PiSmileyMehFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyMehFill"


class PiSmileyNervousFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyNervousFill"


class PiSmileySadFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileySadFill"


class PiSmileyStickerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyStickerFill"


class PiSmileyWinkFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyWinkFill"


class PiSmileyXEyesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyXEyesFill"


class PiSnapchatLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnapchatLogoFill"


class PiSneakerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerFill"


class PiSneakerMoveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerMoveFill"


class PiSnowflakeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnowflakeFill"


class PiSoccerBallFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoccerBallFill"


class PiSortAscendingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortAscendingFill"


class PiSortDescendingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortDescendingFill"


class PiSoundcloudLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoundcloudLogoFill"


class PiSpadeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpadeFill"


class PiSparkleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSparkleFill"


class PiSpeakerHifiFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHifiFill"


class PiSpeakerHighFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHighFill"


class PiSpeakerLowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerLowFill"


class PiSpeakerNoneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerNoneFill"


class PiSpeakerSimpleHighFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleHighFill"


class PiSpeakerSimpleLowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleLowFill"


class PiSpeakerSimpleNoneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleNoneFill"


class PiSpeakerSimpleSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleSlashFill"


class PiSpeakerSimpleXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleXFill"


class PiSpeakerSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSlashFill"


class PiSpeakerXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerXFill"


class PiSpinnerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerFill"


class PiSpinnerGapFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerGapFill"


class PiSpiralFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpiralFill"


class PiSplitHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitHorizontalFill"


class PiSplitVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitVerticalFill"


class PiSpotifyLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpotifyLogoFill"


class PiSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareFill"


class PiSquareHalfBottomFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfBottomFill"


class PiSquareHalfFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfFill"


class PiSquareLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareLogoFill"


class PiSquareSplitHorizontalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitHorizontalFill"


class PiSquareSplitVerticalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitVerticalFill"


class PiSquaresFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquaresFourFill"


class PiStackFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackFill"


class PiStackOverflowLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackOverflowLogoFill"


class PiStackSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackSimpleFill"


class PiStairsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStairsFill"


class PiStampFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStampFill"


class PiStarAndCrescentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarAndCrescentFill"


class PiStarFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarFill"


class PiStarFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarFourFill"


class PiStarHalfFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarHalfFill"


class PiStarOfDavidFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarOfDavidFill"


class PiSteeringWheelFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSteeringWheelFill"


class PiStepsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStepsFill"


class PiStethoscopeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStethoscopeFill"


class PiStickerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStickerFill"


class PiStoolFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStoolFill"


class PiStopCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopCircleFill"


class PiStopFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopFill"


class PiStorefrontFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStorefrontFill"


class PiStrategyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStrategyFill"


class PiStripeLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStripeLogoFill"


class PiStudentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiStudentFill"


class PiSubtitlesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtitlesFill"


class PiSubtractFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractFill"


class PiSubtractSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractSquareFill"


class PiSuitcaseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseFill"


class PiSuitcaseRollingFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseRollingFill"


class PiSuitcaseSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseSimpleFill"


class PiSunDimFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunDimFill"


class PiSunFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunFill"


class PiSunHorizonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunHorizonFill"


class PiSunglassesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunglassesFill"


class PiSwapFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwapFill"


class PiSwatchesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwatchesFill"


class PiSwimmingPoolFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwimmingPoolFill"


class PiSwordFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwordFill"


class PiSynagogueFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSynagogueFill"


class PiSyringeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiSyringeFill"


class PiTShirtFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTShirtFill"


class PiTableFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTableFill"


class PiTabsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTabsFill"


class PiTagChevronFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagChevronFill"


class PiTagFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagFill"


class PiTagSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagSimpleFill"


class PiTargetFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTargetFill"


class PiTaxiFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTaxiFill"


class PiTelegramLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelegramLogoFill"


class PiTelevisionFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionFill"


class PiTelevisionSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionSimpleFill"


class PiTennisBallFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTennisBallFill"


class PiTentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTentFill"


class PiTerminalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalFill"


class PiTerminalWindowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalWindowFill"


class PiTestTubeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTestTubeFill"


class PiTextAUnderlineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAUnderlineFill"


class PiTextAaFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAaFill"


class PiTextAlignCenterFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignCenterFill"


class PiTextAlignJustifyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignJustifyFill"


class PiTextAlignLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignLeftFill"


class PiTextAlignRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignRightFill"


class PiTextBFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextBFill"


class PiTextColumnsFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextColumnsFill"


class PiTextHFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFill"


class PiTextHFiveFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFiveFill"


class PiTextHFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFourFill"


class PiTextHOneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHOneFill"


class PiTextHSixFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHSixFill"


class PiTextHThreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHThreeFill"


class PiTextHTwoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHTwoFill"


class PiTextIndentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextIndentFill"


class PiTextItalicFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextItalicFill"


class PiTextOutdentFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextOutdentFill"


class PiTextStrikethroughFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextStrikethroughFill"


class PiTextTFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextTFill"


class PiTextUnderlineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextUnderlineFill"


class PiTextboxFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextboxFill"


class PiThermometerColdFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerColdFill"


class PiThermometerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerFill"


class PiThermometerHotFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerHotFill"


class PiThermometerSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerSimpleFill"


class PiThumbsDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsDownFill"


class PiThumbsUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsUpFill"


class PiTicketFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTicketFill"


class PiTidalLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTidalLogoFill"


class PiTiktokLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTiktokLogoFill"


class PiTimerFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTimerFill"


class PiTipiFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTipiFill"


class PiToggleLeftFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleLeftFill"


class PiToggleRightFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleRightFill"


class PiToiletFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletFill"


class PiToiletPaperFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletPaperFill"


class PiToolboxFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiToolboxFill"


class PiToothFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiToothFill"


class PiToteFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteFill"


class PiToteSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteSimpleFill"


class PiTrademarkFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkFill"


class PiTrademarkRegisteredFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkRegisteredFill"


class PiTrafficConeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficConeFill"


class PiTrafficSignFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignFill"


class PiTrafficSignalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignalFill"


class PiTrainFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainFill"


class PiTrainRegionalFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainRegionalFill"


class PiTrainSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainSimpleFill"


class PiTramFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTramFill"


class PiTranslateFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTranslateFill"


class PiTrashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashFill"


class PiTrashSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashSimpleFill"


class PiTrayFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrayFill"


class PiTreeEvergreenFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeEvergreenFill"


class PiTreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeFill"


class PiTreePalmFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreePalmFill"


class PiTreeStructureFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeStructureFill"


class PiTrendDownFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendDownFill"


class PiTrendUpFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendUpFill"


class PiTriangleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTriangleFill"


class PiTrophyFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrophyFill"


class PiTruckFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTruckFill"


class PiTwitchLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitchLogoFill"


class PiTwitterLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitterLogoFill"


class PiUmbrellaFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaFill"


class PiUmbrellaSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaSimpleFill"


class PiUniteFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteFill"


class PiUniteSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteSquareFill"


class PiUploadFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadFill"


class PiUploadSimpleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadSimpleFill"


class PiUsbFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsbFill"


class PiUserCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleFill"


class PiUserCircleGearFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleGearFill"


class PiUserCircleMinusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleMinusFill"


class PiUserCirclePlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCirclePlusFill"


class PiUserFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserFill"


class PiUserFocusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserFocusFill"


class PiUserGearFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserGearFill"


class PiUserListFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserListFill"


class PiUserMinusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserMinusFill"


class PiUserPlusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserPlusFill"


class PiUserRectangleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserRectangleFill"


class PiUserSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSquareFill"


class PiUserSwitchFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSwitchFill"


class PiUsersFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersFill"


class PiUsersFourFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersFourFill"


class PiUsersThreeFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersThreeFill"


class PiVanFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVanFill"


class PiVaultFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVaultFill"


class PiVibrateFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVibrateFill"


class PiVideoCameraFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraFill"


class PiVideoCameraSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraSlashFill"


class PiVideoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoFill"


class PiVignetteFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVignetteFill"


class PiVinylRecordFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVinylRecordFill"


class PiVirtualRealityFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirtualRealityFill"


class PiVirusFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirusFill"


class PiVoicemailFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVoicemailFill"


class PiVolleyballFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiVolleyballFill"


class PiWallFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWallFill"


class PiWalletFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWalletFill"


class PiWarehouseFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarehouseFill"


class PiWarningCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningCircleFill"


class PiWarningDiamondFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningDiamondFill"


class PiWarningFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningFill"


class PiWarningOctagonFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningOctagonFill"


class PiWatchFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWatchFill"


class PiWaveSawtoothFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSawtoothFill"


class PiWaveSineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSineFill"


class PiWaveSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSquareFill"


class PiWaveTriangleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveTriangleFill"


class PiWaveformFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveformFill"


class PiWavesFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWavesFill"


class PiWebcamFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamFill"


class PiWebcamSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamSlashFill"


class PiWebhooksLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebhooksLogoFill"


class PiWechatLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWechatLogoFill"


class PiWhatsappLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWhatsappLogoFill"


class PiWheelchairFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairFill"


class PiWheelchairMotionFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairMotionFill"


class PiWifiHighFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiHighFill"


class PiWifiLowFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiLowFill"


class PiWifiMediumFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiMediumFill"


class PiWifiNoneFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiNoneFill"


class PiWifiSlashFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiSlashFill"


class PiWifiXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiXFill"


class PiWindFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindFill"


class PiWindowsLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindowsLogoFill"


class PiWineFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWineFill"


class PiWrenchFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiWrenchFill"


class PiXCircleFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiXCircleFill"


class PiXFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiXFill"


class PiXSquareFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiXSquareFill"


class PiYinYangFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiYinYangFill"


class PiYoutubeLogoFill(rx.Component):
    library = "react-icons/pi"
    tag = "PiYoutubeLogoFill"


class PiAddressBookLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAddressBookLight"


class PiAirTrafficControlLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirTrafficControlLight"


class PiAirplaneInFlightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneInFlightLight"


class PiAirplaneLandingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneLandingLight"


class PiAirplaneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneLight"


class PiAirplaneTakeoffLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTakeoffLight"


class PiAirplaneTiltLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTiltLight"


class PiAirplayLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplayLight"


class PiAlarmLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlarmLight"


class PiAlienLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlienLight"


class PiAlignBottomLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomLight"


class PiAlignBottomSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomSimpleLight"


class PiAlignCenterHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalLight"


class PiAlignCenterHorizontalSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalSimpleLight"


class PiAlignCenterVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalLight"


class PiAlignCenterVerticalSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalSimpleLight"


class PiAlignLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftLight"


class PiAlignLeftSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftSimpleLight"


class PiAlignRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightLight"


class PiAlignRightSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightSimpleLight"


class PiAlignTopLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopLight"


class PiAlignTopSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopSimpleLight"


class PiAmazonLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAmazonLogoLight"


class PiAnchorLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorLight"


class PiAnchorSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorSimpleLight"


class PiAndroidLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAndroidLogoLight"


class PiAngularLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAngularLogoLight"


class PiApertureLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiApertureLight"


class PiAppStoreLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppStoreLogoLight"


class PiAppWindowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppWindowLight"


class PiAppleLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppleLogoLight"


class PiApplePodcastsLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiApplePodcastsLogoLight"


class PiArchiveBoxLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveBoxLight"


class PiArchiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveLight"


class PiArchiveTrayLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveTrayLight"


class PiArmchairLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArmchairLight"


class PiArrowArcLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcLeftLight"


class PiArrowArcRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcRightLight"


class PiArrowBendDoubleUpLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpLeftLight"


class PiArrowBendDoubleUpRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpRightLight"


class PiArrowBendDownLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownLeftLight"


class PiArrowBendDownRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownRightLight"


class PiArrowBendLeftDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftDownLight"


class PiArrowBendLeftUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftUpLight"


class PiArrowBendRightDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightDownLight"


class PiArrowBendRightUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightUpLight"


class PiArrowBendUpLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpLeftLight"


class PiArrowBendUpRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpRightLight"


class PiArrowCircleDownLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownLeftLight"


class PiArrowCircleDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownLight"


class PiArrowCircleDownRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownRightLight"


class PiArrowCircleLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleLeftLight"


class PiArrowCircleRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleRightLight"


class PiArrowCircleUpLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpLeftLight"


class PiArrowCircleUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpLight"


class PiArrowCircleUpRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpRightLight"


class PiArrowClockwiseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowClockwiseLight"


class PiArrowCounterClockwiseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCounterClockwiseLight"


class PiArrowDownLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownLeftLight"


class PiArrowDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownLight"


class PiArrowDownRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownRightLight"


class PiArrowElbowDownLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownLeftLight"


class PiArrowElbowDownRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownRightLight"


class PiArrowElbowLeftDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftDownLight"


class PiArrowElbowLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftLight"


class PiArrowElbowLeftUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftUpLight"


class PiArrowElbowRightDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightDownLight"


class PiArrowElbowRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightLight"


class PiArrowElbowRightUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightUpLight"


class PiArrowElbowUpLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpLeftLight"


class PiArrowElbowUpRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpRightLight"


class PiArrowFatDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatDownLight"


class PiArrowFatLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLeftLight"


class PiArrowFatLineDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineDownLight"


class PiArrowFatLineLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineLeftLight"


class PiArrowFatLineRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineRightLight"


class PiArrowFatLineUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineUpLight"


class PiArrowFatLinesDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesDownLight"


class PiArrowFatLinesLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesLeftLight"


class PiArrowFatLinesRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesRightLight"


class PiArrowFatLinesUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesUpLight"


class PiArrowFatRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatRightLight"


class PiArrowFatUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatUpLight"


class PiArrowLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLeftLight"


class PiArrowLineDownLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownLeftLight"


class PiArrowLineDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownLight"


class PiArrowLineDownRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownRightLight"


class PiArrowLineLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineLeftLight"


class PiArrowLineRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineRightLight"


class PiArrowLineUpLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpLeftLight"


class PiArrowLineUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpLight"


class PiArrowLineUpRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpRightLight"


class PiArrowRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowRightLight"


class PiArrowSquareDownLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownLeftLight"


class PiArrowSquareDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownLight"


class PiArrowSquareDownRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownRightLight"


class PiArrowSquareInLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareInLight"


class PiArrowSquareLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareLeftLight"


class PiArrowSquareOutLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareOutLight"


class PiArrowSquareRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareRightLight"


class PiArrowSquareUpLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpLeftLight"


class PiArrowSquareUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpLight"


class PiArrowSquareUpRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpRightLight"


class PiArrowUDownLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownLeftLight"


class PiArrowUDownRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownRightLight"


class PiArrowULeftDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftDownLight"


class PiArrowULeftUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftUpLight"


class PiArrowURightDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightDownLight"


class PiArrowURightUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightUpLight"


class PiArrowUUpLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpLeftLight"


class PiArrowUUpRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpRightLight"


class PiArrowUpLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpLeftLight"


class PiArrowUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpLight"


class PiArrowUpRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpRightLight"


class PiArrowsClockwiseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsClockwiseLight"


class PiArrowsCounterClockwiseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsCounterClockwiseLight"


class PiArrowsDownUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsDownUpLight"


class PiArrowsHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsHorizontalLight"


class PiArrowsInCardinalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInCardinalLight"


class PiArrowsInLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLight"


class PiArrowsInLineHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineHorizontalLight"


class PiArrowsInLineVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineVerticalLight"


class PiArrowsInSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInSimpleLight"


class PiArrowsLeftRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsLeftRightLight"


class PiArrowsMergeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsMergeLight"


class PiArrowsOutCardinalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutCardinalLight"


class PiArrowsOutLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLight"


class PiArrowsOutLineHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineHorizontalLight"


class PiArrowsOutLineVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineVerticalLight"


class PiArrowsOutSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutSimpleLight"


class PiArrowsSplitLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsSplitLight"


class PiArrowsVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsVerticalLight"


class PiArticleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleLight"


class PiArticleMediumLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleMediumLight"


class PiArticleNyTimesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleNyTimesLight"


class PiAsteriskLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskLight"


class PiAsteriskSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskSimpleLight"


class PiAtLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtLight"


class PiAtomLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtomLight"


class PiBabyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBabyLight"


class PiBackpackLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackpackLight"


class PiBackspaceLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackspaceLight"


class PiBagLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagLight"


class PiBagSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagSimpleLight"


class PiBalloonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBalloonLight"


class PiBandaidsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBandaidsLight"


class PiBankLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBankLight"


class PiBarbellLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarbellLight"


class PiBarcodeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarcodeLight"


class PiBarricadeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarricadeLight"


class PiBaseballCapLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballCapLight"


class PiBaseballLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballLight"


class PiBasketLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketLight"


class PiBasketballLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketballLight"


class PiBathtubLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBathtubLight"


class PiBatteryChargingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingLight"


class PiBatteryChargingVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingVerticalLight"


class PiBatteryEmptyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryEmptyLight"


class PiBatteryFullLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryFullLight"


class PiBatteryHighLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryHighLight"


class PiBatteryLowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryLowLight"


class PiBatteryMediumLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryMediumLight"


class PiBatteryPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusLight"


class PiBatteryPlusVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusVerticalLight"


class PiBatteryVerticalEmptyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalEmptyLight"


class PiBatteryVerticalFullLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalFullLight"


class PiBatteryVerticalHighLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalHighLight"


class PiBatteryVerticalLowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalLowLight"


class PiBatteryVerticalMediumLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalMediumLight"


class PiBatteryWarningLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningLight"


class PiBatteryWarningVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningVerticalLight"


class PiBedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBedLight"


class PiBeerBottleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerBottleLight"


class PiBeerSteinLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerSteinLight"


class PiBehanceLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBehanceLogoLight"


class PiBellLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellLight"


class PiBellRingingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellRingingLight"


class PiBellSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleLight"


class PiBellSimpleRingingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleRingingLight"


class PiBellSimpleSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleSlashLight"


class PiBellSimpleZLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleZLight"


class PiBellSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSlashLight"


class PiBellZLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellZLight"


class PiBezierCurveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBezierCurveLight"


class PiBicycleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBicycleLight"


class PiBinocularsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBinocularsLight"


class PiBirdLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBirdLight"


class PiBluetoothConnectedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothConnectedLight"


class PiBluetoothLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothLight"


class PiBluetoothSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothSlashLight"


class PiBluetoothXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothXLight"


class PiBoatLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoatLight"


class PiBoneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoneLight"


class PiBookBookmarkLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookBookmarkLight"


class PiBookLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookLight"


class PiBookOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenLight"


class PiBookOpenTextLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenTextLight"


class PiBookmarkLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkLight"


class PiBookmarkSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkSimpleLight"


class PiBookmarksLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksLight"


class PiBookmarksSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksSimpleLight"


class PiBooksLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBooksLight"


class PiBootLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBootLight"


class PiBoundingBoxLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoundingBoxLight"


class PiBowlFoodLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBowlFoodLight"


class PiBracketsAngleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsAngleLight"


class PiBracketsCurlyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsCurlyLight"


class PiBracketsRoundLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsRoundLight"


class PiBracketsSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsSquareLight"


class PiBrainLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrainLight"


class PiBrandyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrandyLight"


class PiBridgeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBridgeLight"


class PiBriefcaseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseLight"


class PiBriefcaseMetalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseMetalLight"


class PiBroadcastLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroadcastLight"


class PiBroomLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroomLight"


class PiBrowserLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowserLight"


class PiBrowsersLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowsersLight"


class PiBugBeetleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugBeetleLight"


class PiBugDroidLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugDroidLight"


class PiBugLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugLight"


class PiBuildingsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBuildingsLight"


class PiBusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiBusLight"


class PiButterflyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiButterflyLight"


class PiCactusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCactusLight"


class PiCakeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCakeLight"


class PiCalculatorLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalculatorLight"


class PiCalendarBlankLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarBlankLight"


class PiCalendarCheckLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarCheckLight"


class PiCalendarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarLight"


class PiCalendarPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarPlusLight"


class PiCalendarXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarXLight"


class PiCallBellLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCallBellLight"


class PiCameraLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraLight"


class PiCameraPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraPlusLight"


class PiCameraRotateLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraRotateLight"


class PiCameraSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraSlashLight"


class PiCampfireLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCampfireLight"


class PiCarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarLight"


class PiCarProfileLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarProfileLight"


class PiCarSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarSimpleLight"


class PiCardholderLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardholderLight"


class PiCardsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardsLight"


class PiCaretCircleDoubleDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleDownLight"


class PiCaretCircleDoubleLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleLeftLight"


class PiCaretCircleDoubleRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleRightLight"


class PiCaretCircleDoubleUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleUpLight"


class PiCaretCircleDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDownLight"


class PiCaretCircleLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleLeftLight"


class PiCaretCircleRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleRightLight"


class PiCaretCircleUpDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpDownLight"


class PiCaretCircleUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpLight"


class PiCaretDoubleDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleDownLight"


class PiCaretDoubleLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleLeftLight"


class PiCaretDoubleRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleRightLight"


class PiCaretDoubleUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleUpLight"


class PiCaretDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDownLight"


class PiCaretLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretLeftLight"


class PiCaretRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretRightLight"


class PiCaretUpDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpDownLight"


class PiCaretUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpLight"


class PiCarrotLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarrotLight"


class PiCassetteTapeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCassetteTapeLight"


class PiCastleTurretLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCastleTurretLight"


class PiCatLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCatLight"


class PiCellSignalFullLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalFullLight"


class PiCellSignalHighLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalHighLight"


class PiCellSignalLowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalLowLight"


class PiCellSignalMediumLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalMediumLight"


class PiCellSignalNoneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalNoneLight"


class PiCellSignalSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalSlashLight"


class PiCellSignalXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalXLight"


class PiCertificateLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCertificateLight"


class PiChairLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChairLight"


class PiChalkboardLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardLight"


class PiChalkboardSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardSimpleLight"


class PiChalkboardTeacherLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardTeacherLight"


class PiChampagneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChampagneLight"


class PiChargingStationLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChargingStationLight"


class PiChartBarHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarHorizontalLight"


class PiChartBarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarLight"


class PiChartDonutLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartDonutLight"


class PiChartLineDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineDownLight"


class PiChartLineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineLight"


class PiChartLineUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineUpLight"


class PiChartPieLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieLight"


class PiChartPieSliceLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieSliceLight"


class PiChartPolarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPolarLight"


class PiChartScatterLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartScatterLight"


class PiChatCenteredDotsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredDotsLight"


class PiChatCenteredLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredLight"


class PiChatCenteredTextLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredTextLight"


class PiChatCircleDotsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleDotsLight"


class PiChatCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleLight"


class PiChatCircleTextLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleTextLight"


class PiChatDotsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatDotsLight"


class PiChatLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatLight"


class PiChatTeardropDotsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropDotsLight"


class PiChatTeardropLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropLight"


class PiChatTeardropTextLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropTextLight"


class PiChatTextLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTextLight"


class PiChatsCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsCircleLight"


class PiChatsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsLight"


class PiChatsTeardropLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsTeardropLight"


class PiCheckCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckCircleLight"


class PiCheckFatLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckFatLight"


class PiCheckLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckLight"


class PiCheckSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareLight"


class PiCheckSquareOffsetLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareOffsetLight"


class PiChecksLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChecksLight"


class PiChurchLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiChurchLight"


class PiCircleDashedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleDashedLight"


class PiCircleHalfLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfLight"


class PiCircleHalfTiltLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfTiltLight"


class PiCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleLight"


class PiCircleNotchLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleNotchLight"


class PiCirclesFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesFourLight"


class PiCirclesThreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreeLight"


class PiCirclesThreePlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreePlusLight"


class PiCircuitryLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircuitryLight"


class PiClipboardLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardLight"


class PiClipboardTextLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardTextLight"


class PiClockAfternoonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockAfternoonLight"


class PiClockClockwiseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockClockwiseLight"


class PiClockCountdownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCountdownLight"


class PiClockCounterClockwiseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCounterClockwiseLight"


class PiClockLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockLight"


class PiClosedCaptioningLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiClosedCaptioningLight"


class PiCloudArrowDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowDownLight"


class PiCloudArrowUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowUpLight"


class PiCloudCheckLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudCheckLight"


class PiCloudFogLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudFogLight"


class PiCloudLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudLight"


class PiCloudLightningLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudLightningLight"


class PiCloudMoonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudMoonLight"


class PiCloudRainLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudRainLight"


class PiCloudSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSlashLight"


class PiCloudSnowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSnowLight"


class PiCloudSunLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSunLight"


class PiCloudWarningLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudWarningLight"


class PiCloudXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudXLight"


class PiClubLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiClubLight"


class PiCoatHangerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoatHangerLight"


class PiCodaLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodaLogoLight"


class PiCodeBlockLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeBlockLight"


class PiCodeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeLight"


class PiCodeSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeSimpleLight"


class PiCodepenLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodepenLogoLight"


class PiCodesandboxLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodesandboxLogoLight"


class PiCoffeeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoffeeLight"


class PiCoinLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinLight"


class PiCoinVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinVerticalLight"


class PiCoinsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinsLight"


class PiColumnsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiColumnsLight"


class PiCommandLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCommandLight"


class PiCompassLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassLight"


class PiCompassToolLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassToolLight"


class PiComputerTowerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiComputerTowerLight"


class PiConfettiLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiConfettiLight"


class PiContactlessPaymentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiContactlessPaymentLight"


class PiControlLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiControlLight"


class PiCookieLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookieLight"


class PiCookingPotLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookingPotLight"


class PiCopyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyLight"


class PiCopySimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopySimpleLight"


class PiCopyleftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyleftLight"


class PiCopyrightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyrightLight"


class PiCornersInLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersInLight"


class PiCornersOutLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersOutLight"


class PiCouchLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCouchLight"


class PiCpuLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCpuLight"


class PiCreditCardLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCreditCardLight"


class PiCropLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCropLight"


class PiCrossLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrossLight"


class PiCrosshairLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairLight"


class PiCrosshairSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairSimpleLight"


class PiCrownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownLight"


class PiCrownSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownSimpleLight"


class PiCubeFocusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeFocusLight"


class PiCubeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeLight"


class PiCubeTransparentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeTransparentLight"


class PiCurrencyBtcLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyBtcLight"


class PiCurrencyCircleDollarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCircleDollarLight"


class PiCurrencyCnyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCnyLight"


class PiCurrencyDollarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarLight"


class PiCurrencyDollarSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarSimpleLight"


class PiCurrencyEthLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEthLight"


class PiCurrencyEurLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEurLight"


class PiCurrencyGbpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyGbpLight"


class PiCurrencyInrLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyInrLight"


class PiCurrencyJpyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyJpyLight"


class PiCurrencyKrwLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKrwLight"


class PiCurrencyKztLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKztLight"


class PiCurrencyNgnLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyNgnLight"


class PiCurrencyRubLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyRubLight"


class PiCursorClickLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorClickLight"


class PiCursorLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorLight"


class PiCursorTextLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorTextLight"


class PiCylinderLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCylinderLight"


class PiDatabaseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDatabaseLight"


class PiDesktopLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopLight"


class PiDesktopTowerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopTowerLight"


class PiDetectiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDetectiveLight"


class PiDevToLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevToLogoLight"


class PiDeviceMobileCameraLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileCameraLight"


class PiDeviceMobileLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileLight"


class PiDeviceMobileSpeakerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileSpeakerLight"


class PiDeviceTabletCameraLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletCameraLight"


class PiDeviceTabletLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletLight"


class PiDeviceTabletSpeakerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletSpeakerLight"


class PiDevicesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevicesLight"


class PiDiamondLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondLight"


class PiDiamondsFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondsFourLight"


class PiDiceFiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFiveLight"


class PiDiceFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFourLight"


class PiDiceOneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceOneLight"


class PiDiceSixLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceSixLight"


class PiDiceThreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceThreeLight"


class PiDiceTwoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceTwoLight"


class PiDiscLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscLight"


class PiDiscordLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscordLogoLight"


class PiDivideLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDivideLight"


class PiDnaLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDnaLight"


class PiDogLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDogLight"


class PiDoorLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorLight"


class PiDoorOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorOpenLight"


class PiDotLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotLight"


class PiDotOutlineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotOutlineLight"


class PiDotsNineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsNineLight"


class PiDotsSixLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixLight"


class PiDotsSixVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixVerticalLight"


class PiDotsThreeCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleLight"


class PiDotsThreeCircleVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleVerticalLight"


class PiDotsThreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeLight"


class PiDotsThreeOutlineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineLight"


class PiDotsThreeOutlineVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineVerticalLight"


class PiDotsThreeVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeVerticalLight"


class PiDownloadLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadLight"


class PiDownloadSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadSimpleLight"


class PiDressLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDressLight"


class PiDribbbleLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDribbbleLogoLight"


class PiDropHalfBottomLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfBottomLight"


class PiDropHalfLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfLight"


class PiDropLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropLight"


class PiDropboxLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropboxLogoLight"


class PiEarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarLight"


class PiEarSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarSlashLight"


class PiEggCrackLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggCrackLight"


class PiEggLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggLight"


class PiEjectLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectLight"


class PiEjectSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectSimpleLight"


class PiElevatorLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiElevatorLight"


class PiEngineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEngineLight"


class PiEnvelopeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeLight"


class PiEnvelopeOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeOpenLight"


class PiEnvelopeSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleLight"


class PiEnvelopeSimpleOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleOpenLight"


class PiEqualizerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualizerLight"


class PiEqualsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualsLight"


class PiEraserLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEraserLight"


class PiEscalatorDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorDownLight"


class PiEscalatorUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorUpLight"


class PiExamLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiExamLight"


class PiExcludeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeLight"


class PiExcludeSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeSquareLight"


class PiExportLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiExportLight"


class PiEyeClosedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeClosedLight"


class PiEyeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeLight"


class PiEyeSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeSlashLight"


class PiEyedropperLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperLight"


class PiEyedropperSampleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperSampleLight"


class PiEyeglassesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeglassesLight"


class PiFaceMaskLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFaceMaskLight"


class PiFacebookLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFacebookLogoLight"


class PiFactoryLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFactoryLight"


class PiFadersHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersHorizontalLight"


class PiFadersLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersLight"


class PiFanLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFanLight"


class PiFastForwardCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardCircleLight"


class PiFastForwardLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardLight"


class PiFeatherLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFeatherLight"


class PiFigmaLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFigmaLogoLight"


class PiFileArchiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArchiveLight"


class PiFileArrowDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowDownLight"


class PiFileArrowUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowUpLight"


class PiFileAudioLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileAudioLight"


class PiFileCloudLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCloudLight"


class PiFileCodeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCodeLight"


class PiFileCssLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCssLight"


class PiFileCsvLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCsvLight"


class PiFileDashedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDashedLight"


class PiFileDocLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDocLight"


class PiFileHtmlLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileHtmlLight"


class PiFileImageLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileImageLight"


class PiFileJpgLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJpgLight"


class PiFileJsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsLight"


class PiFileJsxLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsxLight"


class PiFileLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileLight"


class PiFileLockLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileLockLight"


class PiFileMagnifyingGlassLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMagnifyingGlassLight"


class PiFileMinusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMinusLight"


class PiFilePdfLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePdfLight"


class PiFilePlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePlusLight"


class PiFilePngLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePngLight"


class PiFilePptLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePptLight"


class PiFileRsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileRsLight"


class PiFileSqlLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSqlLight"


class PiFileSvgLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSvgLight"


class PiFileTextLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTextLight"


class PiFileTsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsLight"


class PiFileTsxLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsxLight"


class PiFileVideoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVideoLight"


class PiFileVueLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVueLight"


class PiFileXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXLight"


class PiFileXlsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXlsLight"


class PiFileZipLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileZipLight"


class PiFilesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilesLight"


class PiFilmReelLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmReelLight"


class PiFilmScriptLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmScriptLight"


class PiFilmSlateLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmSlateLight"


class PiFilmStripLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmStripLight"


class PiFingerprintLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintLight"


class PiFingerprintSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintSimpleLight"


class PiFinnTheHumanLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFinnTheHumanLight"


class PiFireExtinguisherLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireExtinguisherLight"


class PiFireLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireLight"


class PiFireSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireSimpleLight"


class PiFirstAidKitLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidKitLight"


class PiFirstAidLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidLight"


class PiFishLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishLight"


class PiFishSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishSimpleLight"


class PiFlagBannerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagBannerLight"


class PiFlagCheckeredLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagCheckeredLight"


class PiFlagLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagLight"


class PiFlagPennantLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagPennantLight"


class PiFlameLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlameLight"


class PiFlashlightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlashlightLight"


class PiFlaskLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlaskLight"


class PiFloppyDiskBackLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskBackLight"


class PiFloppyDiskLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskLight"


class PiFlowArrowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowArrowLight"


class PiFlowerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerLight"


class PiFlowerLotusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerLotusLight"


class PiFlowerTulipLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerTulipLight"


class PiFlyingSaucerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlyingSaucerLight"


class PiFolderDashedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderDashedLight"


class PiFolderLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderLight"


class PiFolderLockLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderLockLight"


class PiFolderMinusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderMinusLight"


class PiFolderNotchLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchLight"


class PiFolderNotchMinusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchMinusLight"


class PiFolderNotchOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchOpenLight"


class PiFolderNotchPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchPlusLight"


class PiFolderOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderOpenLight"


class PiFolderPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderPlusLight"


class PiFolderSimpleDashedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleDashedLight"


class PiFolderSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleLight"


class PiFolderSimpleLockLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleLockLight"


class PiFolderSimpleMinusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleMinusLight"


class PiFolderSimplePlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimplePlusLight"


class PiFolderSimpleStarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleStarLight"


class PiFolderSimpleUserLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleUserLight"


class PiFolderStarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderStarLight"


class PiFolderUserLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderUserLight"


class PiFoldersLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFoldersLight"


class PiFootballLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootballLight"


class PiFootprintsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootprintsLight"


class PiForkKnifeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiForkKnifeLight"


class PiFrameCornersLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFrameCornersLight"


class PiFramerLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFramerLogoLight"


class PiFunctionLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunctionLight"


class PiFunnelLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelLight"


class PiFunnelSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelSimpleLight"


class PiGameControllerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGameControllerLight"


class PiGarageLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGarageLight"


class PiGasCanLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasCanLight"


class PiGasPumpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasPumpLight"


class PiGaugeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGaugeLight"


class PiGavelLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGavelLight"


class PiGearFineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearFineLight"


class PiGearLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearLight"


class PiGearSixLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearSixLight"


class PiGenderFemaleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderFemaleLight"


class PiGenderIntersexLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderIntersexLight"


class PiGenderMaleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderMaleLight"


class PiGenderNeuterLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNeuterLight"


class PiGenderNonbinaryLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNonbinaryLight"


class PiGenderTransgenderLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderTransgenderLight"


class PiGhostLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGhostLight"


class PiGifLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGifLight"


class PiGiftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGiftLight"


class PiGitBranchLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitBranchLight"


class PiGitCommitLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitCommitLight"


class PiGitDiffLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitDiffLight"


class PiGitForkLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitForkLight"


class PiGitMergeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitMergeLight"


class PiGitPullRequestLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitPullRequestLight"


class PiGithubLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGithubLogoLight"


class PiGitlabLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoLight"


class PiGitlabLogoSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoSimpleLight"


class PiGlobeHemisphereEastLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereEastLight"


class PiGlobeHemisphereWestLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereWestLight"


class PiGlobeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeLight"


class PiGlobeSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeSimpleLight"


class PiGlobeStandLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeStandLight"


class PiGogglesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGogglesLight"


class PiGoodreadsLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoodreadsLogoLight"


class PiGoogleCardboardLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleCardboardLogoLight"


class PiGoogleChromeLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleChromeLogoLight"


class PiGoogleDriveLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleDriveLogoLight"


class PiGoogleLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleLogoLight"


class PiGooglePhotosLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePhotosLogoLight"


class PiGooglePlayLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePlayLogoLight"


class PiGooglePodcastsLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePodcastsLogoLight"


class PiGradientLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGradientLight"


class PiGraduationCapLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraduationCapLight"


class PiGrainsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsLight"


class PiGrainsSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsSlashLight"


class PiGraphLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraphLight"


class PiGridFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridFourLight"


class PiGridNineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridNineLight"


class PiGuitarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiGuitarLight"


class PiHamburgerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHamburgerLight"


class PiHammerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHammerLight"


class PiHandCoinsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandCoinsLight"


class PiHandEyeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandEyeLight"


class PiHandFistLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandFistLight"


class PiHandGrabbingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandGrabbingLight"


class PiHandHeartLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandHeartLight"


class PiHandLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandLight"


class PiHandPalmLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPalmLight"


class PiHandPointingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPointingLight"


class PiHandSoapLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSoapLight"


class PiHandSwipeLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeLeftLight"


class PiHandSwipeRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeRightLight"


class PiHandTapLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandTapLight"


class PiHandWavingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandWavingLight"


class PiHandbagLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagLight"


class PiHandbagSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagSimpleLight"


class PiHandsClappingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsClappingLight"


class PiHandsPrayingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsPrayingLight"


class PiHandshakeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandshakeLight"


class PiHardDriveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDriveLight"


class PiHardDrivesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDrivesLight"


class PiHashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashLight"


class PiHashStraightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashStraightLight"


class PiHeadlightsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadlightsLight"


class PiHeadphonesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadphonesLight"


class PiHeadsetLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadsetLight"


class PiHeartBreakLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartBreakLight"


class PiHeartHalfLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartHalfLight"


class PiHeartLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartLight"


class PiHeartStraightBreakLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightBreakLight"


class PiHeartStraightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightLight"


class PiHeartbeatLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartbeatLight"


class PiHexagonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHexagonLight"


class PiHighHeelLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighHeelLight"


class PiHighlighterCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighlighterCircleLight"


class PiHoodieLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHoodieLight"


class PiHorseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHorseLight"


class PiHourglassHighLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassHighLight"


class PiHourglassLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassLight"


class PiHourglassLowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassLowLight"


class PiHourglassMediumLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassMediumLight"


class PiHourglassSimpleHighLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleHighLight"


class PiHourglassSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleLight"


class PiHourglassSimpleLowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleLowLight"


class PiHourglassSimpleMediumLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleMediumLight"


class PiHouseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseLight"


class PiHouseLineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseLineLight"


class PiHouseSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseSimpleLight"


class PiIceCreamLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiIceCreamLight"


class PiIdentificationBadgeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationBadgeLight"


class PiIdentificationCardLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationCardLight"


class PiImageLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageLight"


class PiImageSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageSquareLight"


class PiImagesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesLight"


class PiImagesSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesSquareLight"


class PiInfinityLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfinityLight"


class PiInfoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfoLight"


class PiInstagramLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiInstagramLogoLight"


class PiIntersectLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectLight"


class PiIntersectSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectSquareLight"


class PiIntersectThreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectThreeLight"


class PiJeepLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiJeepLight"


class PiKanbanLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiKanbanLight"


class PiKeyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyLight"


class PiKeyReturnLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyReturnLight"


class PiKeyboardLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyboardLight"


class PiKeyholeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyholeLight"


class PiKnifeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiKnifeLight"


class PiLadderLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderLight"


class PiLadderSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderSimpleLight"


class PiLampLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLampLight"


class PiLaptopLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLaptopLight"


class PiLayoutLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLayoutLight"


class PiLeafLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLeafLight"


class PiLifebuoyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLifebuoyLight"


class PiLightbulbFilamentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbFilamentLight"


class PiLightbulbLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbLight"


class PiLighthouseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLighthouseLight"


class PiLightningALight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningALight"


class PiLightningLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningLight"


class PiLightningSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningSlashLight"


class PiLineSegmentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentLight"


class PiLineSegmentsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentsLight"


class PiLinkBreakLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkBreakLight"


class PiLinkLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkLight"


class PiLinkSimpleBreakLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleBreakLight"


class PiLinkSimpleHorizontalBreakLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalBreakLight"


class PiLinkSimpleHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalLight"


class PiLinkSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleLight"


class PiLinkedinLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkedinLogoLight"


class PiLinuxLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinuxLogoLight"


class PiListBulletsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiListBulletsLight"


class PiListChecksLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiListChecksLight"


class PiListDashesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiListDashesLight"


class PiListLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiListLight"


class PiListMagnifyingGlassLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiListMagnifyingGlassLight"


class PiListNumbersLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiListNumbersLight"


class PiListPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiListPlusLight"


class PiLockKeyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyLight"


class PiLockKeyOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyOpenLight"


class PiLockLaminatedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedLight"


class PiLockLaminatedOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedOpenLight"


class PiLockLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLight"


class PiLockOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockOpenLight"


class PiLockSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleLight"


class PiLockSimpleOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleOpenLight"


class PiLockersLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockersLight"


class PiMagicWandLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagicWandLight"


class PiMagnetLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetLight"


class PiMagnetStraightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetStraightLight"


class PiMagnifyingGlassLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassLight"


class PiMagnifyingGlassMinusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassMinusLight"


class PiMagnifyingGlassPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassPlusLight"


class PiMapPinLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinLight"


class PiMapPinLineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinLineLight"


class PiMapTrifoldLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapTrifoldLight"


class PiMarkerCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMarkerCircleLight"


class PiMartiniLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMartiniLight"


class PiMaskHappyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskHappyLight"


class PiMaskSadLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskSadLight"


class PiMathOperationsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMathOperationsLight"


class PiMedalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalLight"


class PiMedalMilitaryLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalMilitaryLight"


class PiMediumLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMediumLogoLight"


class PiMegaphoneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneLight"


class PiMegaphoneSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneSimpleLight"


class PiMessengerLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMessengerLogoLight"


class PiMetaLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetaLogoLight"


class PiMetronomeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetronomeLight"


class PiMicrophoneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneLight"


class PiMicrophoneSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneSlashLight"


class PiMicrophoneStageLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneStageLight"


class PiMicrosoftExcelLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftExcelLogoLight"


class PiMicrosoftOutlookLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftOutlookLogoLight"


class PiMicrosoftPowerpointLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftPowerpointLogoLight"


class PiMicrosoftTeamsLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftTeamsLogoLight"


class PiMicrosoftWordLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftWordLogoLight"


class PiMinusCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusCircleLight"


class PiMinusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusLight"


class PiMinusSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusSquareLight"


class PiMoneyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoneyLight"


class PiMonitorLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorLight"


class PiMonitorPlayLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorPlayLight"


class PiMoonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonLight"


class PiMoonStarsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonStarsLight"


class PiMopedFrontLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedFrontLight"


class PiMopedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedLight"


class PiMosqueLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMosqueLight"


class PiMotorcycleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMotorcycleLight"


class PiMountainsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMountainsLight"


class PiMouseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseLight"


class PiMouseSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseSimpleLight"


class PiMusicNoteLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteLight"


class PiMusicNoteSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteSimpleLight"


class PiMusicNotesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesLight"


class PiMusicNotesPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesPlusLight"


class PiMusicNotesSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesSimpleLight"


class PiNavigationArrowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNavigationArrowLight"


class PiNeedleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNeedleLight"


class PiNewspaperClippingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperClippingLight"


class PiNewspaperLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperLight"


class PiNotchesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotchesLight"


class PiNoteBlankLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteBlankLight"


class PiNoteLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteLight"


class PiNotePencilLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotePencilLight"


class PiNotebookLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotebookLight"


class PiNotepadLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotepadLight"


class PiNotificationLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotificationLight"


class PiNotionLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotionLogoLight"


class PiNumberCircleEightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleEightLight"


class PiNumberCircleFiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFiveLight"


class PiNumberCircleFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFourLight"


class PiNumberCircleNineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleNineLight"


class PiNumberCircleOneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleOneLight"


class PiNumberCircleSevenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSevenLight"


class PiNumberCircleSixLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSixLight"


class PiNumberCircleThreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleThreeLight"


class PiNumberCircleTwoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleTwoLight"


class PiNumberCircleZeroLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleZeroLight"


class PiNumberEightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberEightLight"


class PiNumberFiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFiveLight"


class PiNumberFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFourLight"


class PiNumberNineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberNineLight"


class PiNumberOneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberOneLight"


class PiNumberSevenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSevenLight"


class PiNumberSixLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSixLight"


class PiNumberSquareEightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareEightLight"


class PiNumberSquareFiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFiveLight"


class PiNumberSquareFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFourLight"


class PiNumberSquareNineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareNineLight"


class PiNumberSquareOneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareOneLight"


class PiNumberSquareSevenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSevenLight"


class PiNumberSquareSixLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSixLight"


class PiNumberSquareThreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareThreeLight"


class PiNumberSquareTwoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareTwoLight"


class PiNumberSquareZeroLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareZeroLight"


class PiNumberThreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberThreeLight"


class PiNumberTwoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberTwoLight"


class PiNumberZeroLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberZeroLight"


class PiNutLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNutLight"


class PiNyTimesLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNyTimesLogoLight"


class PiOctagonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiOctagonLight"


class PiOfficeChairLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiOfficeChairLight"


class PiOptionLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiOptionLight"


class PiOrangeSliceLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiOrangeSliceLight"


class PiPackageLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPackageLight"


class PiPaintBrushBroadLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushBroadLight"


class PiPaintBrushHouseholdLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushHouseholdLight"


class PiPaintBrushLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushLight"


class PiPaintBucketLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBucketLight"


class PiPaintRollerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintRollerLight"


class PiPaletteLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaletteLight"


class PiPantsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPantsLight"


class PiPaperPlaneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneLight"


class PiPaperPlaneRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneRightLight"


class PiPaperPlaneTiltLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneTiltLight"


class PiPaperclipHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipHorizontalLight"


class PiPaperclipLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipLight"


class PiParachuteLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiParachuteLight"


class PiParagraphLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiParagraphLight"


class PiParallelogramLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiParallelogramLight"


class PiParkLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiParkLight"


class PiPasswordLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPasswordLight"


class PiPathLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPathLight"


class PiPatreonLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPatreonLogoLight"


class PiPauseCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseCircleLight"


class PiPauseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseLight"


class PiPawPrintLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPawPrintLight"


class PiPaypalLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaypalLogoLight"


class PiPeaceLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPeaceLight"


class PiPenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenLight"


class PiPenNibLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibLight"


class PiPenNibStraightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibStraightLight"


class PiPencilCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilCircleLight"


class PiPencilLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilLight"


class PiPencilLineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilLineLight"


class PiPencilSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleLight"


class PiPencilSimpleLineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleLineLight"


class PiPencilSimpleSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleSlashLight"


class PiPencilSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSlashLight"


class PiPentagramLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPentagramLight"


class PiPepperLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPepperLight"


class PiPercentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPercentLight"


class PiPersonArmsSpreadLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonArmsSpreadLight"


class PiPersonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonLight"


class PiPersonSimpleBikeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleBikeLight"


class PiPersonSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleLight"


class PiPersonSimpleRunLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleRunLight"


class PiPersonSimpleThrowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleThrowLight"


class PiPersonSimpleWalkLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleWalkLight"


class PiPerspectiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPerspectiveLight"


class PiPhoneCallLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneCallLight"


class PiPhoneDisconnectLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneDisconnectLight"


class PiPhoneIncomingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneIncomingLight"


class PiPhoneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneLight"


class PiPhoneOutgoingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneOutgoingLight"


class PiPhonePlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhonePlusLight"


class PiPhoneSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneSlashLight"


class PiPhoneXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneXLight"


class PiPhosphorLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhosphorLogoLight"


class PiPiLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiLight"


class PiPianoKeysLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPianoKeysLight"


class PiPictureInPictureLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPictureInPictureLight"


class PiPiggyBankLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiggyBankLight"


class PiPillLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPillLight"


class PiPinterestLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinterestLogoLight"


class PiPinwheelLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinwheelLight"


class PiPizzaLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPizzaLight"


class PiPlaceholderLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaceholderLight"


class PiPlanetLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlanetLight"


class PiPlantLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlantLight"


class PiPlayCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayCircleLight"


class PiPlayLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayLight"


class PiPlayPauseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayPauseLight"


class PiPlaylistLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaylistLight"


class PiPlugChargingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugChargingLight"


class PiPlugLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugLight"


class PiPlugsConnectedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsConnectedLight"


class PiPlugsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsLight"


class PiPlusCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusCircleLight"


class PiPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusLight"


class PiPlusMinusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusMinusLight"


class PiPlusSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusSquareLight"


class PiPokerChipLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPokerChipLight"


class PiPoliceCarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPoliceCarLight"


class PiPolygonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPolygonLight"


class PiPopcornLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPopcornLight"


class PiPottedPlantLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPottedPlantLight"


class PiPowerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPowerLight"


class PiPrescriptionLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrescriptionLight"


class PiPresentationChartLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationChartLight"


class PiPresentationLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationLight"


class PiPrinterLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrinterLight"


class PiProhibitInsetLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitInsetLight"


class PiProhibitLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitLight"


class PiProjectorScreenChartLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenChartLight"


class PiProjectorScreenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenLight"


class PiPulseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPulseLight"


class PiPushPinLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinLight"


class PiPushPinSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleLight"


class PiPushPinSimpleSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleSlashLight"


class PiPushPinSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSlashLight"


class PiPuzzlePieceLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPuzzlePieceLight"


class PiQrCodeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiQrCodeLight"


class PiQuestionLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuestionLight"


class PiQueueLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiQueueLight"


class PiQuotesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuotesLight"


class PiRadicalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadicalLight"


class PiRadioButtonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioButtonLight"


class PiRadioLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioLight"


class PiRadioactiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioactiveLight"


class PiRainbowCloudLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowCloudLight"


class PiRainbowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowLight"


class PiReadCvLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiReadCvLogoLight"


class PiReceiptLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptLight"


class PiReceiptXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptXLight"


class PiRecordLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecordLight"


class PiRectangleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRectangleLight"


class PiRecycleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecycleLight"


class PiRedditLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRedditLogoLight"


class PiRepeatLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatLight"


class PiRepeatOnceLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatOnceLight"


class PiRewindCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindCircleLight"


class PiRewindLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindLight"


class PiRoadHorizonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRoadHorizonLight"


class PiRobotLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRobotLight"


class PiRocketLaunchLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketLaunchLight"


class PiRocketLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketLight"


class PiRowsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRowsLight"


class PiRssLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssLight"


class PiRssSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssSimpleLight"


class PiRugLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRugLight"


class PiRulerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiRulerLight"


class PiScalesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiScalesLight"


class PiScanLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiScanLight"


class PiScissorsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiScissorsLight"


class PiScooterLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiScooterLight"


class PiScreencastLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiScreencastLight"


class PiScribbleLoopLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiScribbleLoopLight"


class PiScrollLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiScrollLight"


class PiSealCheckLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealCheckLight"


class PiSealLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealLight"


class PiSealQuestionLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealQuestionLight"


class PiSealWarningLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealWarningLight"


class PiSelectionAllLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionAllLight"


class PiSelectionBackgroundLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionBackgroundLight"


class PiSelectionForegroundLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionForegroundLight"


class PiSelectionInverseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionInverseLight"


class PiSelectionLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionLight"


class PiSelectionPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionPlusLight"


class PiSelectionSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionSlashLight"


class PiShapesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShapesLight"


class PiShareFatLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareFatLight"


class PiShareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareLight"


class PiShareNetworkLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareNetworkLight"


class PiShieldCheckLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckLight"


class PiShieldCheckeredLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckeredLight"


class PiShieldChevronLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldChevronLight"


class PiShieldLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldLight"


class PiShieldPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldPlusLight"


class PiShieldSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldSlashLight"


class PiShieldStarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldStarLight"


class PiShieldWarningLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldWarningLight"


class PiShirtFoldedLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShirtFoldedLight"


class PiShootingStarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShootingStarLight"


class PiShoppingBagLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagLight"


class PiShoppingBagOpenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagOpenLight"


class PiShoppingCartLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartLight"


class PiShoppingCartSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartSimpleLight"


class PiShowerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShowerLight"


class PiShrimpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShrimpLight"


class PiShuffleAngularLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleAngularLight"


class PiShuffleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleLight"


class PiShuffleSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleSimpleLight"


class PiSidebarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarLight"


class PiSidebarSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarSimpleLight"


class PiSigmaLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSigmaLight"


class PiSignInLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignInLight"


class PiSignOutLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignOutLight"


class PiSignatureLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignatureLight"


class PiSignpostLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignpostLight"


class PiSimCardLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSimCardLight"


class PiSirenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSirenLight"


class PiSketchLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSketchLogoLight"


class PiSkipBackCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackCircleLight"


class PiSkipBackLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackLight"


class PiSkipForwardCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardCircleLight"


class PiSkipForwardLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardLight"


class PiSkullLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkullLight"


class PiSlackLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlackLogoLight"


class PiSlidersHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersHorizontalLight"


class PiSlidersLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersLight"


class PiSlideshowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlideshowLight"


class PiSmileyAngryLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyAngryLight"


class PiSmileyBlankLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyBlankLight"


class PiSmileyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyLight"


class PiSmileyMehLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyMehLight"


class PiSmileyNervousLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyNervousLight"


class PiSmileySadLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileySadLight"


class PiSmileyStickerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyStickerLight"


class PiSmileyWinkLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyWinkLight"


class PiSmileyXEyesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyXEyesLight"


class PiSnapchatLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnapchatLogoLight"


class PiSneakerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerLight"


class PiSneakerMoveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerMoveLight"


class PiSnowflakeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnowflakeLight"


class PiSoccerBallLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoccerBallLight"


class PiSortAscendingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortAscendingLight"


class PiSortDescendingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortDescendingLight"


class PiSoundcloudLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoundcloudLogoLight"


class PiSpadeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpadeLight"


class PiSparkleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSparkleLight"


class PiSpeakerHifiLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHifiLight"


class PiSpeakerHighLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHighLight"


class PiSpeakerLowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerLowLight"


class PiSpeakerNoneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerNoneLight"


class PiSpeakerSimpleHighLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleHighLight"


class PiSpeakerSimpleLowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleLowLight"


class PiSpeakerSimpleNoneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleNoneLight"


class PiSpeakerSimpleSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleSlashLight"


class PiSpeakerSimpleXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleXLight"


class PiSpeakerSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSlashLight"


class PiSpeakerXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerXLight"


class PiSpinnerGapLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerGapLight"


class PiSpinnerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerLight"


class PiSpiralLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpiralLight"


class PiSplitHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitHorizontalLight"


class PiSplitVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitVerticalLight"


class PiSpotifyLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpotifyLogoLight"


class PiSquareHalfBottomLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfBottomLight"


class PiSquareHalfLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfLight"


class PiSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareLight"


class PiSquareLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareLogoLight"


class PiSquareSplitHorizontalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitHorizontalLight"


class PiSquareSplitVerticalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitVerticalLight"


class PiSquaresFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquaresFourLight"


class PiStackLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackLight"


class PiStackOverflowLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackOverflowLogoLight"


class PiStackSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackSimpleLight"


class PiStairsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStairsLight"


class PiStampLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStampLight"


class PiStarAndCrescentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarAndCrescentLight"


class PiStarFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarFourLight"


class PiStarHalfLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarHalfLight"


class PiStarLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarLight"


class PiStarOfDavidLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarOfDavidLight"


class PiSteeringWheelLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSteeringWheelLight"


class PiStepsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStepsLight"


class PiStethoscopeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStethoscopeLight"


class PiStickerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStickerLight"


class PiStoolLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStoolLight"


class PiStopCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopCircleLight"


class PiStopLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopLight"


class PiStorefrontLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStorefrontLight"


class PiStrategyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStrategyLight"


class PiStripeLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStripeLogoLight"


class PiStudentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiStudentLight"


class PiSubtitlesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtitlesLight"


class PiSubtractLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractLight"


class PiSubtractSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractSquareLight"


class PiSuitcaseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseLight"


class PiSuitcaseRollingLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseRollingLight"


class PiSuitcaseSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseSimpleLight"


class PiSunDimLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunDimLight"


class PiSunHorizonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunHorizonLight"


class PiSunLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunLight"


class PiSunglassesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunglassesLight"


class PiSwapLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwapLight"


class PiSwatchesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwatchesLight"


class PiSwimmingPoolLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwimmingPoolLight"


class PiSwordLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwordLight"


class PiSynagogueLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSynagogueLight"


class PiSyringeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiSyringeLight"


class PiTShirtLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTShirtLight"


class PiTableLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTableLight"


class PiTabsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTabsLight"


class PiTagChevronLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagChevronLight"


class PiTagLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagLight"


class PiTagSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagSimpleLight"


class PiTargetLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTargetLight"


class PiTaxiLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTaxiLight"


class PiTelegramLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelegramLogoLight"


class PiTelevisionLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionLight"


class PiTelevisionSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionSimpleLight"


class PiTennisBallLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTennisBallLight"


class PiTentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTentLight"


class PiTerminalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalLight"


class PiTerminalWindowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalWindowLight"


class PiTestTubeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTestTubeLight"


class PiTextAUnderlineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAUnderlineLight"


class PiTextAaLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAaLight"


class PiTextAlignCenterLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignCenterLight"


class PiTextAlignJustifyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignJustifyLight"


class PiTextAlignLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignLeftLight"


class PiTextAlignRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignRightLight"


class PiTextBLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextBLight"


class PiTextColumnsLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextColumnsLight"


class PiTextHFiveLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFiveLight"


class PiTextHFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFourLight"


class PiTextHLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHLight"


class PiTextHOneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHOneLight"


class PiTextHSixLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHSixLight"


class PiTextHThreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHThreeLight"


class PiTextHTwoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHTwoLight"


class PiTextIndentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextIndentLight"


class PiTextItalicLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextItalicLight"


class PiTextOutdentLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextOutdentLight"


class PiTextStrikethroughLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextStrikethroughLight"


class PiTextTLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextTLight"


class PiTextUnderlineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextUnderlineLight"


class PiTextboxLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextboxLight"


class PiThermometerColdLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerColdLight"


class PiThermometerHotLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerHotLight"


class PiThermometerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerLight"


class PiThermometerSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerSimpleLight"


class PiThumbsDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsDownLight"


class PiThumbsUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsUpLight"


class PiTicketLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTicketLight"


class PiTidalLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTidalLogoLight"


class PiTiktokLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTiktokLogoLight"


class PiTimerLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTimerLight"


class PiTipiLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTipiLight"


class PiToggleLeftLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleLeftLight"


class PiToggleRightLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleRightLight"


class PiToiletLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletLight"


class PiToiletPaperLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletPaperLight"


class PiToolboxLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiToolboxLight"


class PiToothLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiToothLight"


class PiToteLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteLight"


class PiToteSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteSimpleLight"


class PiTrademarkLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkLight"


class PiTrademarkRegisteredLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkRegisteredLight"


class PiTrafficConeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficConeLight"


class PiTrafficSignLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignLight"


class PiTrafficSignalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignalLight"


class PiTrainLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainLight"


class PiTrainRegionalLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainRegionalLight"


class PiTrainSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainSimpleLight"


class PiTramLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTramLight"


class PiTranslateLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTranslateLight"


class PiTrashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashLight"


class PiTrashSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashSimpleLight"


class PiTrayLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrayLight"


class PiTreeEvergreenLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeEvergreenLight"


class PiTreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeLight"


class PiTreePalmLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreePalmLight"


class PiTreeStructureLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeStructureLight"


class PiTrendDownLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendDownLight"


class PiTrendUpLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendUpLight"


class PiTriangleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTriangleLight"


class PiTrophyLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrophyLight"


class PiTruckLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTruckLight"


class PiTwitchLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitchLogoLight"


class PiTwitterLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitterLogoLight"


class PiUmbrellaLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaLight"


class PiUmbrellaSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaSimpleLight"


class PiUniteLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteLight"


class PiUniteSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteSquareLight"


class PiUploadLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadLight"


class PiUploadSimpleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadSimpleLight"


class PiUsbLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsbLight"


class PiUserCircleGearLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleGearLight"


class PiUserCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleLight"


class PiUserCircleMinusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleMinusLight"


class PiUserCirclePlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCirclePlusLight"


class PiUserFocusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserFocusLight"


class PiUserGearLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserGearLight"


class PiUserLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserLight"


class PiUserListLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserListLight"


class PiUserMinusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserMinusLight"


class PiUserPlusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserPlusLight"


class PiUserRectangleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserRectangleLight"


class PiUserSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSquareLight"


class PiUserSwitchLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSwitchLight"


class PiUsersFourLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersFourLight"


class PiUsersLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersLight"


class PiUsersThreeLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersThreeLight"


class PiVanLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVanLight"


class PiVaultLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVaultLight"


class PiVibrateLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVibrateLight"


class PiVideoCameraLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraLight"


class PiVideoCameraSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraSlashLight"


class PiVideoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoLight"


class PiVignetteLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVignetteLight"


class PiVinylRecordLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVinylRecordLight"


class PiVirtualRealityLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirtualRealityLight"


class PiVirusLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirusLight"


class PiVoicemailLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVoicemailLight"


class PiVolleyballLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiVolleyballLight"


class PiWallLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWallLight"


class PiWalletLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWalletLight"


class PiWarehouseLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarehouseLight"


class PiWarningCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningCircleLight"


class PiWarningDiamondLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningDiamondLight"


class PiWarningLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningLight"


class PiWarningOctagonLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningOctagonLight"


class PiWatchLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWatchLight"


class PiWaveSawtoothLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSawtoothLight"


class PiWaveSineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSineLight"


class PiWaveSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSquareLight"


class PiWaveTriangleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveTriangleLight"


class PiWaveformLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveformLight"


class PiWavesLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWavesLight"


class PiWebcamLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamLight"


class PiWebcamSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamSlashLight"


class PiWebhooksLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebhooksLogoLight"


class PiWechatLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWechatLogoLight"


class PiWhatsappLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWhatsappLogoLight"


class PiWheelchairLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairLight"


class PiWheelchairMotionLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairMotionLight"


class PiWifiHighLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiHighLight"


class PiWifiLowLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiLowLight"


class PiWifiMediumLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiMediumLight"


class PiWifiNoneLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiNoneLight"


class PiWifiSlashLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiSlashLight"


class PiWifiXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiXLight"


class PiWindLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindLight"


class PiWindowsLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindowsLogoLight"


class PiWineLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWineLight"


class PiWrenchLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiWrenchLight"


class PiXCircleLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiXCircleLight"


class PiXLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiXLight"


class PiXSquareLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiXSquareLight"


class PiYinYangLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiYinYangLight"


class PiYoutubeLogoLight(rx.Component):
    library = "react-icons/pi"
    tag = "PiYoutubeLogoLight"


class PiAddressBook(rx.Component):
    library = "react-icons/pi"
    tag = "PiAddressBook"


class PiAirTrafficControl(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirTrafficControl"


class PiAirplaneInFlight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneInFlight"


class PiAirplaneLanding(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneLanding"


class PiAirplaneTakeoff(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTakeoff"


class PiAirplaneTilt(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTilt"


class PiAirplane(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplane"


class PiAirplay(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplay"


class PiAlarm(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlarm"


class PiAlien(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlien"


class PiAlignBottomSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomSimple"


class PiAlignBottom(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottom"


class PiAlignCenterHorizontalSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalSimple"


class PiAlignCenterHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontal"


class PiAlignCenterVerticalSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalSimple"


class PiAlignCenterVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVertical"


class PiAlignLeftSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftSimple"


class PiAlignLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeft"


class PiAlignRightSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightSimple"


class PiAlignRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRight"


class PiAlignTopSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopSimple"


class PiAlignTop(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTop"


class PiAmazonLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiAmazonLogo"


class PiAnchorSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorSimple"


class PiAnchor(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchor"


class PiAndroidLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiAndroidLogo"


class PiAngularLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiAngularLogo"


class PiAperture(rx.Component):
    library = "react-icons/pi"
    tag = "PiAperture"


class PiAppStoreLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppStoreLogo"


class PiAppWindow(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppWindow"


class PiAppleLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppleLogo"


class PiApplePodcastsLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiApplePodcastsLogo"


class PiArchiveBox(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveBox"


class PiArchiveTray(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveTray"


class PiArchive(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchive"


class PiArmchair(rx.Component):
    library = "react-icons/pi"
    tag = "PiArmchair"


class PiArrowArcLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcLeft"


class PiArrowArcRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcRight"


class PiArrowBendDoubleUpLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpLeft"


class PiArrowBendDoubleUpRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpRight"


class PiArrowBendDownLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownLeft"


class PiArrowBendDownRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownRight"


class PiArrowBendLeftDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftDown"


class PiArrowBendLeftUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftUp"


class PiArrowBendRightDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightDown"


class PiArrowBendRightUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightUp"


class PiArrowBendUpLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpLeft"


class PiArrowBendUpRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpRight"


class PiArrowCircleDownLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownLeft"


class PiArrowCircleDownRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownRight"


class PiArrowCircleDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDown"


class PiArrowCircleLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleLeft"


class PiArrowCircleRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleRight"


class PiArrowCircleUpLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpLeft"


class PiArrowCircleUpRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpRight"


class PiArrowCircleUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUp"


class PiArrowClockwise(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowClockwise"


class PiArrowCounterClockwise(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCounterClockwise"


class PiArrowDownLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownLeft"


class PiArrowDownRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownRight"


class PiArrowDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDown"


class PiArrowElbowDownLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownLeft"


class PiArrowElbowDownRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownRight"


class PiArrowElbowLeftDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftDown"


class PiArrowElbowLeftUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftUp"


class PiArrowElbowLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeft"


class PiArrowElbowRightDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightDown"


class PiArrowElbowRightUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightUp"


class PiArrowElbowRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRight"


class PiArrowElbowUpLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpLeft"


class PiArrowElbowUpRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpRight"


class PiArrowFatDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatDown"


class PiArrowFatLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLeft"


class PiArrowFatLineDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineDown"


class PiArrowFatLineLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineLeft"


class PiArrowFatLineRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineRight"


class PiArrowFatLineUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineUp"


class PiArrowFatLinesDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesDown"


class PiArrowFatLinesLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesLeft"


class PiArrowFatLinesRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesRight"


class PiArrowFatLinesUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesUp"


class PiArrowFatRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatRight"


class PiArrowFatUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatUp"


class PiArrowLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLeft"


class PiArrowLineDownLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownLeft"


class PiArrowLineDownRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownRight"


class PiArrowLineDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDown"


class PiArrowLineLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineLeft"


class PiArrowLineRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineRight"


class PiArrowLineUpLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpLeft"


class PiArrowLineUpRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpRight"


class PiArrowLineUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUp"


class PiArrowRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowRight"


class PiArrowSquareDownLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownLeft"


class PiArrowSquareDownRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownRight"


class PiArrowSquareDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDown"


class PiArrowSquareIn(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareIn"


class PiArrowSquareLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareLeft"


class PiArrowSquareOut(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareOut"


class PiArrowSquareRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareRight"


class PiArrowSquareUpLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpLeft"


class PiArrowSquareUpRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpRight"


class PiArrowSquareUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUp"


class PiArrowUDownLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownLeft"


class PiArrowUDownRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownRight"


class PiArrowULeftDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftDown"


class PiArrowULeftUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftUp"


class PiArrowURightDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightDown"


class PiArrowURightUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightUp"


class PiArrowUUpLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpLeft"


class PiArrowUUpRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpRight"


class PiArrowUpLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpLeft"


class PiArrowUpRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpRight"


class PiArrowUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUp"


class PiArrowsClockwise(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsClockwise"


class PiArrowsCounterClockwise(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsCounterClockwise"


class PiArrowsDownUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsDownUp"


class PiArrowsHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsHorizontal"


class PiArrowsInCardinal(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInCardinal"


class PiArrowsInLineHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineHorizontal"


class PiArrowsInLineVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineVertical"


class PiArrowsInSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInSimple"


class PiArrowsIn(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsIn"


class PiArrowsLeftRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsLeftRight"


class PiArrowsMerge(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsMerge"


class PiArrowsOutCardinal(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutCardinal"


class PiArrowsOutLineHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineHorizontal"


class PiArrowsOutLineVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineVertical"


class PiArrowsOutSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutSimple"


class PiArrowsOut(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOut"


class PiArrowsSplit(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsSplit"


class PiArrowsVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsVertical"


class PiArticleMedium(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleMedium"


class PiArticleNyTimes(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleNyTimes"


class PiArticle(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticle"


class PiAsteriskSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskSimple"


class PiAsterisk(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsterisk"


class PiAt(rx.Component):
    library = "react-icons/pi"
    tag = "PiAt"


class PiAtom(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtom"


class PiBaby(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaby"


class PiBackpack(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackpack"


class PiBackspace(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackspace"


class PiBagSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagSimple"


class PiBag(rx.Component):
    library = "react-icons/pi"
    tag = "PiBag"


class PiBalloon(rx.Component):
    library = "react-icons/pi"
    tag = "PiBalloon"


class PiBandaids(rx.Component):
    library = "react-icons/pi"
    tag = "PiBandaids"


class PiBank(rx.Component):
    library = "react-icons/pi"
    tag = "PiBank"


class PiBarbell(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarbell"


class PiBarcode(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarcode"


class PiBarricade(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarricade"


class PiBaseballCap(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballCap"


class PiBaseball(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseball"


class PiBasket(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasket"


class PiBasketball(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketball"


class PiBathtub(rx.Component):
    library = "react-icons/pi"
    tag = "PiBathtub"


class PiBatteryChargingVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingVertical"


class PiBatteryCharging(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryCharging"


class PiBatteryEmpty(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryEmpty"


class PiBatteryFull(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryFull"


class PiBatteryHigh(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryHigh"


class PiBatteryLow(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryLow"


class PiBatteryMedium(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryMedium"


class PiBatteryPlusVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusVertical"


class PiBatteryPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlus"


class PiBatteryVerticalEmpty(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalEmpty"


class PiBatteryVerticalFull(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalFull"


class PiBatteryVerticalHigh(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalHigh"


class PiBatteryVerticalLow(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalLow"


class PiBatteryVerticalMedium(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalMedium"


class PiBatteryWarningVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningVertical"


class PiBatteryWarning(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarning"


class PiBed(rx.Component):
    library = "react-icons/pi"
    tag = "PiBed"


class PiBeerBottle(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerBottle"


class PiBeerStein(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerStein"


class PiBehanceLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiBehanceLogo"


class PiBellRinging(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellRinging"


class PiBellSimpleRinging(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleRinging"


class PiBellSimpleSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleSlash"


class PiBellSimpleZ(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleZ"


class PiBellSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimple"


class PiBellSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSlash"


class PiBellZ(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellZ"


class PiBell(rx.Component):
    library = "react-icons/pi"
    tag = "PiBell"


class PiBezierCurve(rx.Component):
    library = "react-icons/pi"
    tag = "PiBezierCurve"


class PiBicycle(rx.Component):
    library = "react-icons/pi"
    tag = "PiBicycle"


class PiBinoculars(rx.Component):
    library = "react-icons/pi"
    tag = "PiBinoculars"


class PiBird(rx.Component):
    library = "react-icons/pi"
    tag = "PiBird"


class PiBluetoothConnected(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothConnected"


class PiBluetoothSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothSlash"


class PiBluetoothX(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothX"


class PiBluetooth(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetooth"


class PiBoat(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoat"


class PiBone(rx.Component):
    library = "react-icons/pi"
    tag = "PiBone"


class PiBookBookmark(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookBookmark"


class PiBookOpenText(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenText"


class PiBookOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpen"


class PiBook(rx.Component):
    library = "react-icons/pi"
    tag = "PiBook"


class PiBookmarkSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkSimple"


class PiBookmark(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmark"


class PiBookmarksSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksSimple"


class PiBookmarks(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarks"


class PiBooks(rx.Component):
    library = "react-icons/pi"
    tag = "PiBooks"


class PiBoot(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoot"


class PiBoundingBox(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoundingBox"


class PiBowlFood(rx.Component):
    library = "react-icons/pi"
    tag = "PiBowlFood"


class PiBracketsAngle(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsAngle"


class PiBracketsCurly(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsCurly"


class PiBracketsRound(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsRound"


class PiBracketsSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsSquare"


class PiBrain(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrain"


class PiBrandy(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrandy"


class PiBridge(rx.Component):
    library = "react-icons/pi"
    tag = "PiBridge"


class PiBriefcaseMetal(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseMetal"


class PiBriefcase(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcase"


class PiBroadcast(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroadcast"


class PiBroom(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroom"


class PiBrowser(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowser"


class PiBrowsers(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowsers"


class PiBugBeetle(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugBeetle"


class PiBugDroid(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugDroid"


class PiBug(rx.Component):
    library = "react-icons/pi"
    tag = "PiBug"


class PiBuildings(rx.Component):
    library = "react-icons/pi"
    tag = "PiBuildings"


class PiBus(rx.Component):
    library = "react-icons/pi"
    tag = "PiBus"


class PiButterfly(rx.Component):
    library = "react-icons/pi"
    tag = "PiButterfly"


class PiCactus(rx.Component):
    library = "react-icons/pi"
    tag = "PiCactus"


class PiCake(rx.Component):
    library = "react-icons/pi"
    tag = "PiCake"


class PiCalculator(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalculator"


class PiCalendarBlank(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarBlank"


class PiCalendarCheck(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarCheck"


class PiCalendarPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarPlus"


class PiCalendarX(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarX"


class PiCalendar(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendar"


class PiCallBell(rx.Component):
    library = "react-icons/pi"
    tag = "PiCallBell"


class PiCameraPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraPlus"


class PiCameraRotate(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraRotate"


class PiCameraSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraSlash"


class PiCamera(rx.Component):
    library = "react-icons/pi"
    tag = "PiCamera"


class PiCampfire(rx.Component):
    library = "react-icons/pi"
    tag = "PiCampfire"


class PiCarProfile(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarProfile"


class PiCarSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarSimple"


class PiCar(rx.Component):
    library = "react-icons/pi"
    tag = "PiCar"


class PiCardholder(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardholder"


class PiCards(rx.Component):
    library = "react-icons/pi"
    tag = "PiCards"


class PiCaretCircleDoubleDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleDown"


class PiCaretCircleDoubleLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleLeft"


class PiCaretCircleDoubleRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleRight"


class PiCaretCircleDoubleUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleUp"


class PiCaretCircleDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDown"


class PiCaretCircleLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleLeft"


class PiCaretCircleRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleRight"


class PiCaretCircleUpDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpDown"


class PiCaretCircleUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUp"


class PiCaretDoubleDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleDown"


class PiCaretDoubleLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleLeft"


class PiCaretDoubleRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleRight"


class PiCaretDoubleUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleUp"


class PiCaretDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDown"


class PiCaretLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretLeft"


class PiCaretRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretRight"


class PiCaretUpDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpDown"


class PiCaretUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUp"


class PiCarrot(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarrot"


class PiCassetteTape(rx.Component):
    library = "react-icons/pi"
    tag = "PiCassetteTape"


class PiCastleTurret(rx.Component):
    library = "react-icons/pi"
    tag = "PiCastleTurret"


class PiCat(rx.Component):
    library = "react-icons/pi"
    tag = "PiCat"


class PiCellSignalFull(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalFull"


class PiCellSignalHigh(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalHigh"


class PiCellSignalLow(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalLow"


class PiCellSignalMedium(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalMedium"


class PiCellSignalNone(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalNone"


class PiCellSignalSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalSlash"


class PiCellSignalX(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalX"


class PiCertificate(rx.Component):
    library = "react-icons/pi"
    tag = "PiCertificate"


class PiChair(rx.Component):
    library = "react-icons/pi"
    tag = "PiChair"


class PiChalkboardSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardSimple"


class PiChalkboardTeacher(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardTeacher"


class PiChalkboard(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboard"


class PiChampagne(rx.Component):
    library = "react-icons/pi"
    tag = "PiChampagne"


class PiChargingStation(rx.Component):
    library = "react-icons/pi"
    tag = "PiChargingStation"


class PiChartBarHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarHorizontal"


class PiChartBar(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBar"


class PiChartDonut(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartDonut"


class PiChartLineDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineDown"


class PiChartLineUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineUp"


class PiChartLine(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLine"


class PiChartPieSlice(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieSlice"


class PiChartPie(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPie"


class PiChartPolar(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPolar"


class PiChartScatter(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartScatter"


class PiChatCenteredDots(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredDots"


class PiChatCenteredText(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredText"


class PiChatCentered(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCentered"


class PiChatCircleDots(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleDots"


class PiChatCircleText(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleText"


class PiChatCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircle"


class PiChatDots(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatDots"


class PiChatTeardropDots(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropDots"


class PiChatTeardropText(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropText"


class PiChatTeardrop(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardrop"


class PiChatText(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatText"


class PiChat(rx.Component):
    library = "react-icons/pi"
    tag = "PiChat"


class PiChatsCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsCircle"


class PiChatsTeardrop(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsTeardrop"


class PiChats(rx.Component):
    library = "react-icons/pi"
    tag = "PiChats"


class PiCheckCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckCircle"


class PiCheckFat(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckFat"


class PiCheckSquareOffset(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareOffset"


class PiCheckSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquare"


class PiCheck(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheck"


class PiChecks(rx.Component):
    library = "react-icons/pi"
    tag = "PiChecks"


class PiChurch(rx.Component):
    library = "react-icons/pi"
    tag = "PiChurch"


class PiCircleDashed(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleDashed"


class PiCircleHalfTilt(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfTilt"


class PiCircleHalf(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalf"


class PiCircleNotch(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleNotch"


class PiCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircle"


class PiCirclesFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesFour"


class PiCirclesThreePlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreePlus"


class PiCirclesThree(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThree"


class PiCircuitry(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircuitry"


class PiClipboardText(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardText"


class PiClipboard(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboard"


class PiClockAfternoon(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockAfternoon"


class PiClockClockwise(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockClockwise"


class PiClockCountdown(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCountdown"


class PiClockCounterClockwise(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCounterClockwise"


class PiClock(rx.Component):
    library = "react-icons/pi"
    tag = "PiClock"


class PiClosedCaptioning(rx.Component):
    library = "react-icons/pi"
    tag = "PiClosedCaptioning"


class PiCloudArrowDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowDown"


class PiCloudArrowUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowUp"


class PiCloudCheck(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudCheck"


class PiCloudFog(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudFog"


class PiCloudLightning(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudLightning"


class PiCloudMoon(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudMoon"


class PiCloudRain(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudRain"


class PiCloudSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSlash"


class PiCloudSnow(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSnow"


class PiCloudSun(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSun"


class PiCloudWarning(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudWarning"


class PiCloudX(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudX"


class PiCloud(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloud"


class PiClub(rx.Component):
    library = "react-icons/pi"
    tag = "PiClub"


class PiCoatHanger(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoatHanger"


class PiCodaLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodaLogo"


class PiCodeBlock(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeBlock"


class PiCodeSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeSimple"


class PiCode(rx.Component):
    library = "react-icons/pi"
    tag = "PiCode"


class PiCodepenLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodepenLogo"


class PiCodesandboxLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodesandboxLogo"


class PiCoffee(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoffee"


class PiCoinVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinVertical"


class PiCoin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoin"


class PiCoins(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoins"


class PiColumns(rx.Component):
    library = "react-icons/pi"
    tag = "PiColumns"


class PiCommand(rx.Component):
    library = "react-icons/pi"
    tag = "PiCommand"


class PiCompassTool(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassTool"


class PiCompass(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompass"


class PiComputerTower(rx.Component):
    library = "react-icons/pi"
    tag = "PiComputerTower"


class PiConfetti(rx.Component):
    library = "react-icons/pi"
    tag = "PiConfetti"


class PiContactlessPayment(rx.Component):
    library = "react-icons/pi"
    tag = "PiContactlessPayment"


class PiControl(rx.Component):
    library = "react-icons/pi"
    tag = "PiControl"


class PiCookie(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookie"


class PiCookingPot(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookingPot"


class PiCopySimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopySimple"


class PiCopy(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopy"


class PiCopyleft(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyleft"


class PiCopyright(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyright"


class PiCornersIn(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersIn"


class PiCornersOut(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersOut"


class PiCouch(rx.Component):
    library = "react-icons/pi"
    tag = "PiCouch"


class PiCpu(rx.Component):
    library = "react-icons/pi"
    tag = "PiCpu"


class PiCreditCard(rx.Component):
    library = "react-icons/pi"
    tag = "PiCreditCard"


class PiCrop(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrop"


class PiCross(rx.Component):
    library = "react-icons/pi"
    tag = "PiCross"


class PiCrosshairSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairSimple"


class PiCrosshair(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshair"


class PiCrownSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownSimple"


class PiCrown(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrown"


class PiCubeFocus(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeFocus"


class PiCubeTransparent(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeTransparent"


class PiCube(rx.Component):
    library = "react-icons/pi"
    tag = "PiCube"


class PiCurrencyBtc(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyBtc"


class PiCurrencyCircleDollar(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCircleDollar"


class PiCurrencyCny(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCny"


class PiCurrencyDollarSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarSimple"


class PiCurrencyDollar(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollar"


class PiCurrencyEth(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEth"


class PiCurrencyEur(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEur"


class PiCurrencyGbp(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyGbp"


class PiCurrencyInr(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyInr"


class PiCurrencyJpy(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyJpy"


class PiCurrencyKrw(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKrw"


class PiCurrencyKzt(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKzt"


class PiCurrencyNgn(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyNgn"


class PiCurrencyRub(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyRub"


class PiCursorClick(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorClick"


class PiCursorText(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorText"


class PiCursor(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursor"


class PiCylinder(rx.Component):
    library = "react-icons/pi"
    tag = "PiCylinder"


class PiDatabase(rx.Component):
    library = "react-icons/pi"
    tag = "PiDatabase"


class PiDesktopTower(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopTower"


class PiDesktop(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktop"


class PiDetective(rx.Component):
    library = "react-icons/pi"
    tag = "PiDetective"


class PiDevToLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevToLogo"


class PiDeviceMobileCamera(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileCamera"


class PiDeviceMobileSpeaker(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileSpeaker"


class PiDeviceMobile(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobile"


class PiDeviceTabletCamera(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletCamera"


class PiDeviceTabletSpeaker(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletSpeaker"


class PiDeviceTablet(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTablet"


class PiDevices(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevices"


class PiDiamond(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamond"


class PiDiamondsFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondsFour"


class PiDiceFive(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFive"


class PiDiceFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFour"


class PiDiceOne(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceOne"


class PiDiceSix(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceSix"


class PiDiceThree(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceThree"


class PiDiceTwo(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceTwo"


class PiDisc(rx.Component):
    library = "react-icons/pi"
    tag = "PiDisc"


class PiDiscordLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscordLogo"


class PiDivide(rx.Component):
    library = "react-icons/pi"
    tag = "PiDivide"


class PiDna(rx.Component):
    library = "react-icons/pi"
    tag = "PiDna"


class PiDog(rx.Component):
    library = "react-icons/pi"
    tag = "PiDog"


class PiDoorOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorOpen"


class PiDoor(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoor"


class PiDotOutline(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotOutline"


class PiDot(rx.Component):
    library = "react-icons/pi"
    tag = "PiDot"


class PiDotsNine(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsNine"


class PiDotsSixVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixVertical"


class PiDotsSix(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSix"


class PiDotsThreeCircleVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleVertical"


class PiDotsThreeCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircle"


class PiDotsThreeOutlineVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineVertical"


class PiDotsThreeOutline(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutline"


class PiDotsThreeVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeVertical"


class PiDotsThree(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThree"


class PiDownloadSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadSimple"


class PiDownload(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownload"


class PiDress(rx.Component):
    library = "react-icons/pi"
    tag = "PiDress"


class PiDribbbleLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiDribbbleLogo"


class PiDropHalfBottom(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfBottom"


class PiDropHalf(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalf"


class PiDrop(rx.Component):
    library = "react-icons/pi"
    tag = "PiDrop"


class PiDropboxLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropboxLogo"


class PiEarSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarSlash"


class PiEar(rx.Component):
    library = "react-icons/pi"
    tag = "PiEar"


class PiEggCrack(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggCrack"


class PiEgg(rx.Component):
    library = "react-icons/pi"
    tag = "PiEgg"


class PiEjectSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectSimple"


class PiEject(rx.Component):
    library = "react-icons/pi"
    tag = "PiEject"


class PiElevator(rx.Component):
    library = "react-icons/pi"
    tag = "PiElevator"


class PiEngine(rx.Component):
    library = "react-icons/pi"
    tag = "PiEngine"


class PiEnvelopeOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeOpen"


class PiEnvelopeSimpleOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleOpen"


class PiEnvelopeSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimple"


class PiEnvelope(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelope"


class PiEqualizer(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualizer"


class PiEquals(rx.Component):
    library = "react-icons/pi"
    tag = "PiEquals"


class PiEraser(rx.Component):
    library = "react-icons/pi"
    tag = "PiEraser"


class PiEscalatorDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorDown"


class PiEscalatorUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorUp"


class PiExam(rx.Component):
    library = "react-icons/pi"
    tag = "PiExam"


class PiExcludeSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeSquare"


class PiExclude(rx.Component):
    library = "react-icons/pi"
    tag = "PiExclude"


class PiExport(rx.Component):
    library = "react-icons/pi"
    tag = "PiExport"


class PiEyeClosed(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeClosed"


class PiEyeSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeSlash"


class PiEye(rx.Component):
    library = "react-icons/pi"
    tag = "PiEye"


class PiEyedropperSample(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperSample"


class PiEyedropper(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropper"


class PiEyeglasses(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeglasses"


class PiFaceMask(rx.Component):
    library = "react-icons/pi"
    tag = "PiFaceMask"


class PiFacebookLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiFacebookLogo"


class PiFactory(rx.Component):
    library = "react-icons/pi"
    tag = "PiFactory"


class PiFadersHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersHorizontal"


class PiFaders(rx.Component):
    library = "react-icons/pi"
    tag = "PiFaders"


class PiFan(rx.Component):
    library = "react-icons/pi"
    tag = "PiFan"


class PiFastForwardCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardCircle"


class PiFastForward(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForward"


class PiFeather(rx.Component):
    library = "react-icons/pi"
    tag = "PiFeather"


class PiFigmaLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiFigmaLogo"


class PiFileArchive(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArchive"


class PiFileArrowDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowDown"


class PiFileArrowUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowUp"


class PiFileAudio(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileAudio"


class PiFileCloud(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCloud"


class PiFileCode(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCode"


class PiFileCss(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCss"


class PiFileCsv(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCsv"


class PiFileDashed(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDashed"


class PiFileDoc(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDoc"


class PiFileHtml(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileHtml"


class PiFileImage(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileImage"


class PiFileJpg(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJpg"


class PiFileJs(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJs"


class PiFileJsx(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsx"


class PiFileLock(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileLock"


class PiFileMagnifyingGlass(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMagnifyingGlass"


class PiFileMinus(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMinus"


class PiFilePdf(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePdf"


class PiFilePlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePlus"


class PiFilePng(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePng"


class PiFilePpt(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePpt"


class PiFileRs(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileRs"


class PiFileSql(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSql"


class PiFileSvg(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSvg"


class PiFileText(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileText"


class PiFileTs(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTs"


class PiFileTsx(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsx"


class PiFileVideo(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVideo"


class PiFileVue(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVue"


class PiFileX(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileX"


class PiFileXls(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXls"


class PiFileZip(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileZip"


class PiFile(rx.Component):
    library = "react-icons/pi"
    tag = "PiFile"


class PiFiles(rx.Component):
    library = "react-icons/pi"
    tag = "PiFiles"


class PiFilmReel(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmReel"


class PiFilmScript(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmScript"


class PiFilmSlate(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmSlate"


class PiFilmStrip(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmStrip"


class PiFingerprintSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintSimple"


class PiFingerprint(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprint"


class PiFinnTheHuman(rx.Component):
    library = "react-icons/pi"
    tag = "PiFinnTheHuman"


class PiFireExtinguisher(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireExtinguisher"


class PiFireSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireSimple"


class PiFire(rx.Component):
    library = "react-icons/pi"
    tag = "PiFire"


class PiFirstAidKit(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidKit"


class PiFirstAid(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAid"


class PiFishSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishSimple"


class PiFish(rx.Component):
    library = "react-icons/pi"
    tag = "PiFish"


class PiFlagBanner(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagBanner"


class PiFlagCheckered(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagCheckered"


class PiFlagPennant(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagPennant"


class PiFlag(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlag"


class PiFlame(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlame"


class PiFlashlight(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlashlight"


class PiFlask(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlask"


class PiFloppyDiskBack(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskBack"


class PiFloppyDisk(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDisk"


class PiFlowArrow(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowArrow"


class PiFlowerLotus(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerLotus"


class PiFlowerTulip(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerTulip"


class PiFlower(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlower"


class PiFlyingSaucer(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlyingSaucer"


class PiFolderDashed(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderDashed"


class PiFolderLock(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderLock"


class PiFolderMinus(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderMinus"


class PiFolderNotchMinus(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchMinus"


class PiFolderNotchOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchOpen"


class PiFolderNotchPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchPlus"


class PiFolderNotch(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotch"


class PiFolderOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderOpen"


class PiFolderPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderPlus"


class PiFolderSimpleDashed(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleDashed"


class PiFolderSimpleLock(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleLock"


class PiFolderSimpleMinus(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleMinus"


class PiFolderSimplePlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimplePlus"


class PiFolderSimpleStar(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleStar"


class PiFolderSimpleUser(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleUser"


class PiFolderSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimple"


class PiFolderStar(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderStar"


class PiFolderUser(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderUser"


class PiFolder(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolder"


class PiFolders(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolders"


class PiFootball(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootball"


class PiFootprints(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootprints"


class PiForkKnife(rx.Component):
    library = "react-icons/pi"
    tag = "PiForkKnife"


class PiFrameCorners(rx.Component):
    library = "react-icons/pi"
    tag = "PiFrameCorners"


class PiFramerLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiFramerLogo"


class PiFunction(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunction"


class PiFunnelSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelSimple"


class PiFunnel(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnel"


class PiGameController(rx.Component):
    library = "react-icons/pi"
    tag = "PiGameController"


class PiGarage(rx.Component):
    library = "react-icons/pi"
    tag = "PiGarage"


class PiGasCan(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasCan"


class PiGasPump(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasPump"


class PiGauge(rx.Component):
    library = "react-icons/pi"
    tag = "PiGauge"


class PiGavel(rx.Component):
    library = "react-icons/pi"
    tag = "PiGavel"


class PiGearFine(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearFine"


class PiGearSix(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearSix"


class PiGear(rx.Component):
    library = "react-icons/pi"
    tag = "PiGear"


class PiGenderFemale(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderFemale"


class PiGenderIntersex(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderIntersex"


class PiGenderMale(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderMale"


class PiGenderNeuter(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNeuter"


class PiGenderNonbinary(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNonbinary"


class PiGenderTransgender(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderTransgender"


class PiGhost(rx.Component):
    library = "react-icons/pi"
    tag = "PiGhost"


class PiGif(rx.Component):
    library = "react-icons/pi"
    tag = "PiGif"


class PiGift(rx.Component):
    library = "react-icons/pi"
    tag = "PiGift"


class PiGitBranch(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitBranch"


class PiGitCommit(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitCommit"


class PiGitDiff(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitDiff"


class PiGitFork(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitFork"


class PiGitMerge(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitMerge"


class PiGitPullRequest(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitPullRequest"


class PiGithubLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGithubLogo"


class PiGitlabLogoSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoSimple"


class PiGitlabLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogo"


class PiGlobeHemisphereEast(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereEast"


class PiGlobeHemisphereWest(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereWest"


class PiGlobeSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeSimple"


class PiGlobeStand(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeStand"


class PiGlobe(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobe"


class PiGoggles(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoggles"


class PiGoodreadsLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoodreadsLogo"


class PiGoogleCardboardLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleCardboardLogo"


class PiGoogleChromeLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleChromeLogo"


class PiGoogleDriveLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleDriveLogo"


class PiGoogleLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleLogo"


class PiGooglePhotosLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePhotosLogo"


class PiGooglePlayLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePlayLogo"


class PiGooglePodcastsLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePodcastsLogo"


class PiGradient(rx.Component):
    library = "react-icons/pi"
    tag = "PiGradient"


class PiGraduationCap(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraduationCap"


class PiGrainsSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsSlash"


class PiGrains(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrains"


class PiGraph(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraph"


class PiGridFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridFour"


class PiGridNine(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridNine"


class PiGuitar(rx.Component):
    library = "react-icons/pi"
    tag = "PiGuitar"


class PiHamburger(rx.Component):
    library = "react-icons/pi"
    tag = "PiHamburger"


class PiHammer(rx.Component):
    library = "react-icons/pi"
    tag = "PiHammer"


class PiHandCoins(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandCoins"


class PiHandEye(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandEye"


class PiHandFist(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandFist"


class PiHandGrabbing(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandGrabbing"


class PiHandHeart(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandHeart"


class PiHandPalm(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPalm"


class PiHandPointing(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPointing"


class PiHandSoap(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSoap"


class PiHandSwipeLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeLeft"


class PiHandSwipeRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeRight"


class PiHandTap(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandTap"


class PiHandWaving(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandWaving"


class PiHand(rx.Component):
    library = "react-icons/pi"
    tag = "PiHand"


class PiHandbagSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagSimple"


class PiHandbag(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbag"


class PiHandsClapping(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsClapping"


class PiHandsPraying(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsPraying"


class PiHandshake(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandshake"


class PiHardDrive(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDrive"


class PiHardDrives(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDrives"


class PiHashStraight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashStraight"


class PiHash(rx.Component):
    library = "react-icons/pi"
    tag = "PiHash"


class PiHeadlights(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadlights"


class PiHeadphones(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadphones"


class PiHeadset(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadset"


class PiHeartBreak(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartBreak"


class PiHeartHalf(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartHalf"


class PiHeartStraightBreak(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightBreak"


class PiHeartStraight(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraight"


class PiHeart(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeart"


class PiHeartbeat(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartbeat"


class PiHexagon(rx.Component):
    library = "react-icons/pi"
    tag = "PiHexagon"


class PiHighHeel(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighHeel"


class PiHighlighterCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighlighterCircle"


class PiHoodie(rx.Component):
    library = "react-icons/pi"
    tag = "PiHoodie"


class PiHorse(rx.Component):
    library = "react-icons/pi"
    tag = "PiHorse"


class PiHourglassHigh(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassHigh"


class PiHourglassLow(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassLow"


class PiHourglassMedium(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassMedium"


class PiHourglassSimpleHigh(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleHigh"


class PiHourglassSimpleLow(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleLow"


class PiHourglassSimpleMedium(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleMedium"


class PiHourglassSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimple"


class PiHourglass(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglass"


class PiHouseLine(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseLine"


class PiHouseSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseSimple"


class PiHouse(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouse"


class PiIceCream(rx.Component):
    library = "react-icons/pi"
    tag = "PiIceCream"


class PiIdentificationBadge(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationBadge"


class PiIdentificationCard(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationCard"


class PiImageSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageSquare"


class PiImage(rx.Component):
    library = "react-icons/pi"
    tag = "PiImage"


class PiImagesSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesSquare"


class PiImages(rx.Component):
    library = "react-icons/pi"
    tag = "PiImages"


class PiInfinity(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfinity"


class PiInfo(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfo"


class PiInstagramLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiInstagramLogo"


class PiIntersectSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectSquare"


class PiIntersectThree(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectThree"


class PiIntersect(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersect"


class PiJeep(rx.Component):
    library = "react-icons/pi"
    tag = "PiJeep"


class PiKanban(rx.Component):
    library = "react-icons/pi"
    tag = "PiKanban"


class PiKeyReturn(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyReturn"


class PiKey(rx.Component):
    library = "react-icons/pi"
    tag = "PiKey"


class PiKeyboard(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyboard"


class PiKeyhole(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyhole"


class PiKnife(rx.Component):
    library = "react-icons/pi"
    tag = "PiKnife"


class PiLadderSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderSimple"


class PiLadder(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadder"


class PiLamp(rx.Component):
    library = "react-icons/pi"
    tag = "PiLamp"


class PiLaptop(rx.Component):
    library = "react-icons/pi"
    tag = "PiLaptop"


class PiLayout(rx.Component):
    library = "react-icons/pi"
    tag = "PiLayout"


class PiLeaf(rx.Component):
    library = "react-icons/pi"
    tag = "PiLeaf"


class PiLifebuoy(rx.Component):
    library = "react-icons/pi"
    tag = "PiLifebuoy"


class PiLightbulbFilament(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbFilament"


class PiLightbulb(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulb"


class PiLighthouse(rx.Component):
    library = "react-icons/pi"
    tag = "PiLighthouse"


class PiLightningA(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningA"


class PiLightningSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningSlash"


class PiLightning(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightning"


class PiLineSegment(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegment"


class PiLineSegments(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegments"


class PiLinkBreak(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkBreak"


class PiLinkSimpleBreak(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleBreak"


class PiLinkSimpleHorizontalBreak(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalBreak"


class PiLinkSimpleHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontal"


class PiLinkSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimple"


class PiLink(rx.Component):
    library = "react-icons/pi"
    tag = "PiLink"


class PiLinkedinLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkedinLogo"


class PiLinuxLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinuxLogo"


class PiListBullets(rx.Component):
    library = "react-icons/pi"
    tag = "PiListBullets"


class PiListChecks(rx.Component):
    library = "react-icons/pi"
    tag = "PiListChecks"


class PiListDashes(rx.Component):
    library = "react-icons/pi"
    tag = "PiListDashes"


class PiListMagnifyingGlass(rx.Component):
    library = "react-icons/pi"
    tag = "PiListMagnifyingGlass"


class PiListNumbers(rx.Component):
    library = "react-icons/pi"
    tag = "PiListNumbers"


class PiListPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiListPlus"


class PiList(rx.Component):
    library = "react-icons/pi"
    tag = "PiList"


class PiLockKeyOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyOpen"


class PiLockKey(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKey"


class PiLockLaminatedOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedOpen"


class PiLockLaminated(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminated"


class PiLockOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockOpen"


class PiLockSimpleOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleOpen"


class PiLockSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimple"


class PiLock(rx.Component):
    library = "react-icons/pi"
    tag = "PiLock"


class PiLockers(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockers"


class PiMagicWand(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagicWand"


class PiMagnetStraight(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetStraight"


class PiMagnet(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnet"


class PiMagnifyingGlassMinus(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassMinus"


class PiMagnifyingGlassPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassPlus"


class PiMagnifyingGlass(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlass"


class PiMapPinLine(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinLine"


class PiMapPin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPin"


class PiMapTrifold(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapTrifold"


class PiMarkerCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiMarkerCircle"


class PiMartini(rx.Component):
    library = "react-icons/pi"
    tag = "PiMartini"


class PiMaskHappy(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskHappy"


class PiMaskSad(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskSad"


class PiMathOperations(rx.Component):
    library = "react-icons/pi"
    tag = "PiMathOperations"


class PiMedalMilitary(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalMilitary"


class PiMedal(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedal"


class PiMediumLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiMediumLogo"


class PiMegaphoneSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneSimple"


class PiMegaphone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphone"


class PiMessengerLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiMessengerLogo"


class PiMetaLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetaLogo"


class PiMetronome(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetronome"


class PiMicrophoneSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneSlash"


class PiMicrophoneStage(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneStage"


class PiMicrophone(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophone"


class PiMicrosoftExcelLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftExcelLogo"


class PiMicrosoftOutlookLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftOutlookLogo"


class PiMicrosoftPowerpointLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftPowerpointLogo"


class PiMicrosoftTeamsLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftTeamsLogo"


class PiMicrosoftWordLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftWordLogo"


class PiMinusCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusCircle"


class PiMinusSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusSquare"


class PiMinus(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinus"


class PiMoney(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoney"


class PiMonitorPlay(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorPlay"


class PiMonitor(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitor"


class PiMoonStars(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonStars"


class PiMoon(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoon"


class PiMopedFront(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedFront"


class PiMoped(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoped"


class PiMosque(rx.Component):
    library = "react-icons/pi"
    tag = "PiMosque"


class PiMotorcycle(rx.Component):
    library = "react-icons/pi"
    tag = "PiMotorcycle"


class PiMountains(rx.Component):
    library = "react-icons/pi"
    tag = "PiMountains"


class PiMouseSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseSimple"


class PiMouse(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouse"


class PiMusicNoteSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteSimple"


class PiMusicNote(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNote"


class PiMusicNotesPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesPlus"


class PiMusicNotesSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesSimple"


class PiMusicNotes(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotes"


class PiNavigationArrow(rx.Component):
    library = "react-icons/pi"
    tag = "PiNavigationArrow"


class PiNeedle(rx.Component):
    library = "react-icons/pi"
    tag = "PiNeedle"


class PiNewspaperClipping(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperClipping"


class PiNewspaper(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaper"


class PiNotches(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotches"


class PiNoteBlank(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteBlank"


class PiNotePencil(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotePencil"


class PiNote(rx.Component):
    library = "react-icons/pi"
    tag = "PiNote"


class PiNotebook(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotebook"


class PiNotepad(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotepad"


class PiNotification(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotification"


class PiNotionLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotionLogo"


class PiNumberCircleEight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleEight"


class PiNumberCircleFive(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFive"


class PiNumberCircleFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFour"


class PiNumberCircleNine(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleNine"


class PiNumberCircleOne(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleOne"


class PiNumberCircleSeven(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSeven"


class PiNumberCircleSix(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSix"


class PiNumberCircleThree(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleThree"


class PiNumberCircleTwo(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleTwo"


class PiNumberCircleZero(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleZero"


class PiNumberEight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberEight"


class PiNumberFive(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFive"


class PiNumberFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFour"


class PiNumberNine(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberNine"


class PiNumberOne(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberOne"


class PiNumberSeven(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSeven"


class PiNumberSix(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSix"


class PiNumberSquareEight(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareEight"


class PiNumberSquareFive(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFive"


class PiNumberSquareFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFour"


class PiNumberSquareNine(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareNine"


class PiNumberSquareOne(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareOne"


class PiNumberSquareSeven(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSeven"


class PiNumberSquareSix(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSix"


class PiNumberSquareThree(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareThree"


class PiNumberSquareTwo(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareTwo"


class PiNumberSquareZero(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareZero"


class PiNumberThree(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberThree"


class PiNumberTwo(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberTwo"


class PiNumberZero(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberZero"


class PiNut(rx.Component):
    library = "react-icons/pi"
    tag = "PiNut"


class PiNyTimesLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiNyTimesLogo"


class PiOctagon(rx.Component):
    library = "react-icons/pi"
    tag = "PiOctagon"


class PiOfficeChair(rx.Component):
    library = "react-icons/pi"
    tag = "PiOfficeChair"


class PiOption(rx.Component):
    library = "react-icons/pi"
    tag = "PiOption"


class PiOrangeSlice(rx.Component):
    library = "react-icons/pi"
    tag = "PiOrangeSlice"


class PiPackage(rx.Component):
    library = "react-icons/pi"
    tag = "PiPackage"


class PiPaintBrushBroad(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushBroad"


class PiPaintBrushHousehold(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushHousehold"


class PiPaintBrush(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrush"


class PiPaintBucket(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBucket"


class PiPaintRoller(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintRoller"


class PiPalette(rx.Component):
    library = "react-icons/pi"
    tag = "PiPalette"


class PiPants(rx.Component):
    library = "react-icons/pi"
    tag = "PiPants"


class PiPaperPlaneRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneRight"


class PiPaperPlaneTilt(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneTilt"


class PiPaperPlane(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlane"


class PiPaperclipHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipHorizontal"


class PiPaperclip(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclip"


class PiParachute(rx.Component):
    library = "react-icons/pi"
    tag = "PiParachute"


class PiParagraph(rx.Component):
    library = "react-icons/pi"
    tag = "PiParagraph"


class PiParallelogram(rx.Component):
    library = "react-icons/pi"
    tag = "PiParallelogram"


class PiPark(rx.Component):
    library = "react-icons/pi"
    tag = "PiPark"


class PiPassword(rx.Component):
    library = "react-icons/pi"
    tag = "PiPassword"


class PiPath(rx.Component):
    library = "react-icons/pi"
    tag = "PiPath"


class PiPatreonLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiPatreonLogo"


class PiPauseCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseCircle"


class PiPause(rx.Component):
    library = "react-icons/pi"
    tag = "PiPause"


class PiPawPrint(rx.Component):
    library = "react-icons/pi"
    tag = "PiPawPrint"


class PiPaypalLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaypalLogo"


class PiPeace(rx.Component):
    library = "react-icons/pi"
    tag = "PiPeace"


class PiPenNibStraight(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibStraight"


class PiPenNib(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNib"


class PiPen(rx.Component):
    library = "react-icons/pi"
    tag = "PiPen"


class PiPencilCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilCircle"


class PiPencilLine(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilLine"


class PiPencilSimpleLine(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleLine"


class PiPencilSimpleSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleSlash"


class PiPencilSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimple"


class PiPencilSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSlash"


class PiPencil(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencil"


class PiPentagram(rx.Component):
    library = "react-icons/pi"
    tag = "PiPentagram"


class PiPepper(rx.Component):
    library = "react-icons/pi"
    tag = "PiPepper"


class PiPercent(rx.Component):
    library = "react-icons/pi"
    tag = "PiPercent"


class PiPersonArmsSpread(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonArmsSpread"


class PiPersonSimpleBike(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleBike"


class PiPersonSimpleRun(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleRun"


class PiPersonSimpleThrow(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleThrow"


class PiPersonSimpleWalk(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleWalk"


class PiPersonSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimple"


class PiPerson(rx.Component):
    library = "react-icons/pi"
    tag = "PiPerson"


class PiPerspective(rx.Component):
    library = "react-icons/pi"
    tag = "PiPerspective"


class PiPhoneCall(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneCall"


class PiPhoneDisconnect(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneDisconnect"


class PiPhoneIncoming(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneIncoming"


class PiPhoneOutgoing(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneOutgoing"


class PiPhonePlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhonePlus"


class PiPhoneSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneSlash"


class PiPhoneX(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneX"


class PiPhone(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhone"


class PiPhosphorLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhosphorLogo"


class PiPi(rx.Component):
    library = "react-icons/pi"
    tag = "PiPi"


class PiPianoKeys(rx.Component):
    library = "react-icons/pi"
    tag = "PiPianoKeys"


class PiPictureInPicture(rx.Component):
    library = "react-icons/pi"
    tag = "PiPictureInPicture"


class PiPiggyBank(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiggyBank"


class PiPill(rx.Component):
    library = "react-icons/pi"
    tag = "PiPill"


class PiPinterestLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinterestLogo"


class PiPinwheel(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinwheel"


class PiPizza(rx.Component):
    library = "react-icons/pi"
    tag = "PiPizza"


class PiPlaceholder(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaceholder"


class PiPlanet(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlanet"


class PiPlant(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlant"


class PiPlayCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayCircle"


class PiPlayPause(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayPause"


class PiPlay(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlay"


class PiPlaylist(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaylist"


class PiPlugCharging(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugCharging"


class PiPlug(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlug"


class PiPlugsConnected(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsConnected"


class PiPlugs(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugs"


class PiPlusCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusCircle"


class PiPlusMinus(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusMinus"


class PiPlusSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusSquare"


class PiPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlus"


class PiPokerChip(rx.Component):
    library = "react-icons/pi"
    tag = "PiPokerChip"


class PiPoliceCar(rx.Component):
    library = "react-icons/pi"
    tag = "PiPoliceCar"


class PiPolygon(rx.Component):
    library = "react-icons/pi"
    tag = "PiPolygon"


class PiPopcorn(rx.Component):
    library = "react-icons/pi"
    tag = "PiPopcorn"


class PiPottedPlant(rx.Component):
    library = "react-icons/pi"
    tag = "PiPottedPlant"


class PiPower(rx.Component):
    library = "react-icons/pi"
    tag = "PiPower"


class PiPrescription(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrescription"


class PiPresentationChart(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationChart"


class PiPresentation(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentation"


class PiPrinter(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrinter"


class PiProhibitInset(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitInset"


class PiProhibit(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibit"


class PiProjectorScreenChart(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenChart"


class PiProjectorScreen(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreen"


class PiPulse(rx.Component):
    library = "react-icons/pi"
    tag = "PiPulse"


class PiPushPinSimpleSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleSlash"


class PiPushPinSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimple"


class PiPushPinSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSlash"


class PiPushPin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPin"


class PiPuzzlePiece(rx.Component):
    library = "react-icons/pi"
    tag = "PiPuzzlePiece"


class PiQrCode(rx.Component):
    library = "react-icons/pi"
    tag = "PiQrCode"


class PiQuestion(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuestion"


class PiQueue(rx.Component):
    library = "react-icons/pi"
    tag = "PiQueue"


class PiQuotes(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuotes"


class PiRadical(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadical"


class PiRadioButton(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioButton"


class PiRadio(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadio"


class PiRadioactive(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioactive"


class PiRainbowCloud(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowCloud"


class PiRainbow(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbow"


class PiReadCvLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiReadCvLogo"


class PiReceiptX(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptX"


class PiReceipt(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceipt"


class PiRecord(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecord"


class PiRectangle(rx.Component):
    library = "react-icons/pi"
    tag = "PiRectangle"


class PiRecycle(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecycle"


class PiRedditLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiRedditLogo"


class PiRepeatOnce(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatOnce"


class PiRepeat(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeat"


class PiRewindCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindCircle"


class PiRewind(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewind"


class PiRoadHorizon(rx.Component):
    library = "react-icons/pi"
    tag = "PiRoadHorizon"


class PiRobot(rx.Component):
    library = "react-icons/pi"
    tag = "PiRobot"


class PiRocketLaunch(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketLaunch"


class PiRocket(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocket"


class PiRows(rx.Component):
    library = "react-icons/pi"
    tag = "PiRows"


class PiRssSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssSimple"


class PiRss(rx.Component):
    library = "react-icons/pi"
    tag = "PiRss"


class PiRug(rx.Component):
    library = "react-icons/pi"
    tag = "PiRug"


class PiRuler(rx.Component):
    library = "react-icons/pi"
    tag = "PiRuler"


class PiScales(rx.Component):
    library = "react-icons/pi"
    tag = "PiScales"


class PiScan(rx.Component):
    library = "react-icons/pi"
    tag = "PiScan"


class PiScissors(rx.Component):
    library = "react-icons/pi"
    tag = "PiScissors"


class PiScooter(rx.Component):
    library = "react-icons/pi"
    tag = "PiScooter"


class PiScreencast(rx.Component):
    library = "react-icons/pi"
    tag = "PiScreencast"


class PiScribbleLoop(rx.Component):
    library = "react-icons/pi"
    tag = "PiScribbleLoop"


class PiScroll(rx.Component):
    library = "react-icons/pi"
    tag = "PiScroll"


class PiSealCheck(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealCheck"


class PiSealQuestion(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealQuestion"


class PiSealWarning(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealWarning"


class PiSeal(rx.Component):
    library = "react-icons/pi"
    tag = "PiSeal"


class PiSelectionAll(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionAll"


class PiSelectionBackground(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionBackground"


class PiSelectionForeground(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionForeground"


class PiSelectionInverse(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionInverse"


class PiSelectionPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionPlus"


class PiSelectionSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionSlash"


class PiSelection(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelection"


class PiShapes(rx.Component):
    library = "react-icons/pi"
    tag = "PiShapes"


class PiShareFat(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareFat"


class PiShareNetwork(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareNetwork"


class PiShare(rx.Component):
    library = "react-icons/pi"
    tag = "PiShare"


class PiShieldCheck(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheck"


class PiShieldCheckered(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckered"


class PiShieldChevron(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldChevron"


class PiShieldPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldPlus"


class PiShieldSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldSlash"


class PiShieldStar(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldStar"


class PiShieldWarning(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldWarning"


class PiShield(rx.Component):
    library = "react-icons/pi"
    tag = "PiShield"


class PiShirtFolded(rx.Component):
    library = "react-icons/pi"
    tag = "PiShirtFolded"


class PiShootingStar(rx.Component):
    library = "react-icons/pi"
    tag = "PiShootingStar"


class PiShoppingBagOpen(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagOpen"


class PiShoppingBag(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBag"


class PiShoppingCartSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartSimple"


class PiShoppingCart(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCart"


class PiShower(rx.Component):
    library = "react-icons/pi"
    tag = "PiShower"


class PiShrimp(rx.Component):
    library = "react-icons/pi"
    tag = "PiShrimp"


class PiShuffleAngular(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleAngular"


class PiShuffleSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleSimple"


class PiShuffle(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffle"


class PiSidebarSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarSimple"


class PiSidebar(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebar"


class PiSigma(rx.Component):
    library = "react-icons/pi"
    tag = "PiSigma"


class PiSignIn(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignIn"


class PiSignOut(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignOut"


class PiSignature(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignature"


class PiSignpost(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignpost"


class PiSimCard(rx.Component):
    library = "react-icons/pi"
    tag = "PiSimCard"


class PiSiren(rx.Component):
    library = "react-icons/pi"
    tag = "PiSiren"


class PiSketchLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiSketchLogo"


class PiSkipBackCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackCircle"


class PiSkipBack(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBack"


class PiSkipForwardCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardCircle"


class PiSkipForward(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForward"


class PiSkull(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkull"


class PiSlackLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlackLogo"


class PiSlidersHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersHorizontal"


class PiSliders(rx.Component):
    library = "react-icons/pi"
    tag = "PiSliders"


class PiSlideshow(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlideshow"


class PiSmileyAngry(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyAngry"


class PiSmileyBlank(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyBlank"


class PiSmileyMeh(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyMeh"


class PiSmileyNervous(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyNervous"


class PiSmileySad(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileySad"


class PiSmileySticker(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileySticker"


class PiSmileyWink(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyWink"


class PiSmileyXEyes(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyXEyes"


class PiSmiley(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmiley"


class PiSnapchatLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnapchatLogo"


class PiSneakerMove(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerMove"


class PiSneaker(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneaker"


class PiSnowflake(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnowflake"


class PiSoccerBall(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoccerBall"


class PiSortAscending(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortAscending"


class PiSortDescending(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortDescending"


class PiSoundcloudLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoundcloudLogo"


class PiSpade(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpade"


class PiSparkle(rx.Component):
    library = "react-icons/pi"
    tag = "PiSparkle"


class PiSpeakerHifi(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHifi"


class PiSpeakerHigh(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHigh"


class PiSpeakerLow(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerLow"


class PiSpeakerNone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerNone"


class PiSpeakerSimpleHigh(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleHigh"


class PiSpeakerSimpleLow(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleLow"


class PiSpeakerSimpleNone(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleNone"


class PiSpeakerSimpleSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleSlash"


class PiSpeakerSimpleX(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleX"


class PiSpeakerSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSlash"


class PiSpeakerX(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerX"


class PiSpinnerGap(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerGap"


class PiSpinner(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinner"


class PiSpiral(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpiral"


class PiSplitHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitHorizontal"


class PiSplitVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitVertical"


class PiSpotifyLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpotifyLogo"


class PiSquareHalfBottom(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfBottom"


class PiSquareHalf(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalf"


class PiSquareLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareLogo"


class PiSquareSplitHorizontal(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitHorizontal"


class PiSquareSplitVertical(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitVertical"


class PiSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquare"


class PiSquaresFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquaresFour"


class PiStackOverflowLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackOverflowLogo"


class PiStackSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackSimple"


class PiStack(rx.Component):
    library = "react-icons/pi"
    tag = "PiStack"


class PiStairs(rx.Component):
    library = "react-icons/pi"
    tag = "PiStairs"


class PiStamp(rx.Component):
    library = "react-icons/pi"
    tag = "PiStamp"


class PiStarAndCrescent(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarAndCrescent"


class PiStarFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarFour"


class PiStarHalf(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarHalf"


class PiStarOfDavid(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarOfDavid"


class PiStar(rx.Component):
    library = "react-icons/pi"
    tag = "PiStar"


class PiSteeringWheel(rx.Component):
    library = "react-icons/pi"
    tag = "PiSteeringWheel"


class PiSteps(rx.Component):
    library = "react-icons/pi"
    tag = "PiSteps"


class PiStethoscope(rx.Component):
    library = "react-icons/pi"
    tag = "PiStethoscope"


class PiSticker(rx.Component):
    library = "react-icons/pi"
    tag = "PiSticker"


class PiStool(rx.Component):
    library = "react-icons/pi"
    tag = "PiStool"


class PiStopCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopCircle"


class PiStop(rx.Component):
    library = "react-icons/pi"
    tag = "PiStop"


class PiStorefront(rx.Component):
    library = "react-icons/pi"
    tag = "PiStorefront"


class PiStrategy(rx.Component):
    library = "react-icons/pi"
    tag = "PiStrategy"


class PiStripeLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiStripeLogo"


class PiStudent(rx.Component):
    library = "react-icons/pi"
    tag = "PiStudent"


class PiSubtitles(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtitles"


class PiSubtractSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractSquare"


class PiSubtract(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtract"


class PiSuitcaseRolling(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseRolling"


class PiSuitcaseSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseSimple"


class PiSuitcase(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcase"


class PiSunDim(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunDim"


class PiSunHorizon(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunHorizon"


class PiSun(rx.Component):
    library = "react-icons/pi"
    tag = "PiSun"


class PiSunglasses(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunglasses"


class PiSwap(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwap"


class PiSwatches(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwatches"


class PiSwimmingPool(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwimmingPool"


class PiSword(rx.Component):
    library = "react-icons/pi"
    tag = "PiSword"


class PiSynagogue(rx.Component):
    library = "react-icons/pi"
    tag = "PiSynagogue"


class PiSyringe(rx.Component):
    library = "react-icons/pi"
    tag = "PiSyringe"


class PiTShirt(rx.Component):
    library = "react-icons/pi"
    tag = "PiTShirt"


class PiTable(rx.Component):
    library = "react-icons/pi"
    tag = "PiTable"


class PiTabs(rx.Component):
    library = "react-icons/pi"
    tag = "PiTabs"


class PiTagChevron(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagChevron"


class PiTagSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagSimple"


class PiTag(rx.Component):
    library = "react-icons/pi"
    tag = "PiTag"


class PiTarget(rx.Component):
    library = "react-icons/pi"
    tag = "PiTarget"


class PiTaxi(rx.Component):
    library = "react-icons/pi"
    tag = "PiTaxi"


class PiTelegramLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelegramLogo"


class PiTelevisionSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionSimple"


class PiTelevision(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevision"


class PiTennisBall(rx.Component):
    library = "react-icons/pi"
    tag = "PiTennisBall"


class PiTent(rx.Component):
    library = "react-icons/pi"
    tag = "PiTent"


class PiTerminalWindow(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalWindow"


class PiTerminal(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminal"


class PiTestTube(rx.Component):
    library = "react-icons/pi"
    tag = "PiTestTube"


class PiTextAUnderline(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAUnderline"


class PiTextAa(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAa"


class PiTextAlignCenter(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignCenter"


class PiTextAlignJustify(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignJustify"


class PiTextAlignLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignLeft"


class PiTextAlignRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignRight"


class PiTextB(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextB"


class PiTextColumns(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextColumns"


class PiTextHFive(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFive"


class PiTextHFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFour"


class PiTextHOne(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHOne"


class PiTextHSix(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHSix"


class PiTextHThree(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHThree"


class PiTextHTwo(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHTwo"


class PiTextH(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextH"


class PiTextIndent(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextIndent"


class PiTextItalic(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextItalic"


class PiTextOutdent(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextOutdent"


class PiTextStrikethrough(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextStrikethrough"


class PiTextT(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextT"


class PiTextUnderline(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextUnderline"


class PiTextbox(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextbox"


class PiThermometerCold(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerCold"


class PiThermometerHot(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerHot"


class PiThermometerSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerSimple"


class PiThermometer(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometer"


class PiThumbsDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsDown"


class PiThumbsUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsUp"


class PiTicket(rx.Component):
    library = "react-icons/pi"
    tag = "PiTicket"


class PiTidalLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiTidalLogo"


class PiTiktokLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiTiktokLogo"


class PiTimer(rx.Component):
    library = "react-icons/pi"
    tag = "PiTimer"


class PiTipi(rx.Component):
    library = "react-icons/pi"
    tag = "PiTipi"


class PiToggleLeft(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleLeft"


class PiToggleRight(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleRight"


class PiToiletPaper(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletPaper"


class PiToilet(rx.Component):
    library = "react-icons/pi"
    tag = "PiToilet"


class PiToolbox(rx.Component):
    library = "react-icons/pi"
    tag = "PiToolbox"


class PiTooth(rx.Component):
    library = "react-icons/pi"
    tag = "PiTooth"


class PiToteSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteSimple"


class PiTote(rx.Component):
    library = "react-icons/pi"
    tag = "PiTote"


class PiTrademarkRegistered(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkRegistered"


class PiTrademark(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademark"


class PiTrafficCone(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficCone"


class PiTrafficSign(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSign"


class PiTrafficSignal(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignal"


class PiTrainRegional(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainRegional"


class PiTrainSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainSimple"


class PiTrain(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrain"


class PiTram(rx.Component):
    library = "react-icons/pi"
    tag = "PiTram"


class PiTranslate(rx.Component):
    library = "react-icons/pi"
    tag = "PiTranslate"


class PiTrashSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashSimple"


class PiTrash(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrash"


class PiTray(rx.Component):
    library = "react-icons/pi"
    tag = "PiTray"


class PiTreeEvergreen(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeEvergreen"


class PiTreePalm(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreePalm"


class PiTreeStructure(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeStructure"


class PiTree(rx.Component):
    library = "react-icons/pi"
    tag = "PiTree"


class PiTrendDown(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendDown"


class PiTrendUp(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendUp"


class PiTriangle(rx.Component):
    library = "react-icons/pi"
    tag = "PiTriangle"


class PiTrophy(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrophy"


class PiTruck(rx.Component):
    library = "react-icons/pi"
    tag = "PiTruck"


class PiTwitchLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitchLogo"


class PiTwitterLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitterLogo"


class PiUmbrellaSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaSimple"


class PiUmbrella(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrella"


class PiUniteSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteSquare"


class PiUnite(rx.Component):
    library = "react-icons/pi"
    tag = "PiUnite"


class PiUploadSimple(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadSimple"


class PiUpload(rx.Component):
    library = "react-icons/pi"
    tag = "PiUpload"


class PiUsb(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsb"


class PiUserCircleGear(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleGear"


class PiUserCircleMinus(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleMinus"


class PiUserCirclePlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCirclePlus"


class PiUserCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircle"


class PiUserFocus(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserFocus"


class PiUserGear(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserGear"


class PiUserList(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserList"


class PiUserMinus(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserMinus"


class PiUserPlus(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserPlus"


class PiUserRectangle(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserRectangle"


class PiUserSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSquare"


class PiUserSwitch(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSwitch"


class PiUser(rx.Component):
    library = "react-icons/pi"
    tag = "PiUser"


class PiUsersFour(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersFour"


class PiUsersThree(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersThree"


class PiUsers(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsers"


class PiVan(rx.Component):
    library = "react-icons/pi"
    tag = "PiVan"


class PiVault(rx.Component):
    library = "react-icons/pi"
    tag = "PiVault"


class PiVibrate(rx.Component):
    library = "react-icons/pi"
    tag = "PiVibrate"


class PiVideoCameraSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraSlash"


class PiVideoCamera(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCamera"


class PiVideo(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideo"


class PiVignette(rx.Component):
    library = "react-icons/pi"
    tag = "PiVignette"


class PiVinylRecord(rx.Component):
    library = "react-icons/pi"
    tag = "PiVinylRecord"


class PiVirtualReality(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirtualReality"


class PiVirus(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirus"


class PiVoicemail(rx.Component):
    library = "react-icons/pi"
    tag = "PiVoicemail"


class PiVolleyball(rx.Component):
    library = "react-icons/pi"
    tag = "PiVolleyball"


class PiWall(rx.Component):
    library = "react-icons/pi"
    tag = "PiWall"


class PiWallet(rx.Component):
    library = "react-icons/pi"
    tag = "PiWallet"


class PiWarehouse(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarehouse"


class PiWarningCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningCircle"


class PiWarningDiamond(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningDiamond"


class PiWarningOctagon(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningOctagon"


class PiWarning(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarning"


class PiWatch(rx.Component):
    library = "react-icons/pi"
    tag = "PiWatch"


class PiWaveSawtooth(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSawtooth"


class PiWaveSine(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSine"


class PiWaveSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSquare"


class PiWaveTriangle(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveTriangle"


class PiWaveform(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveform"


class PiWaves(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaves"


class PiWebcamSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamSlash"


class PiWebcam(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcam"


class PiWebhooksLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebhooksLogo"


class PiWechatLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiWechatLogo"


class PiWhatsappLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiWhatsappLogo"


class PiWheelchairMotion(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairMotion"


class PiWheelchair(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchair"


class PiWifiHigh(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiHigh"


class PiWifiLow(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiLow"


class PiWifiMedium(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiMedium"


class PiWifiNone(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiNone"


class PiWifiSlash(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiSlash"


class PiWifiX(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiX"


class PiWind(rx.Component):
    library = "react-icons/pi"
    tag = "PiWind"


class PiWindowsLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindowsLogo"


class PiWine(rx.Component):
    library = "react-icons/pi"
    tag = "PiWine"


class PiWrench(rx.Component):
    library = "react-icons/pi"
    tag = "PiWrench"


class PiXCircle(rx.Component):
    library = "react-icons/pi"
    tag = "PiXCircle"


class PiXSquare(rx.Component):
    library = "react-icons/pi"
    tag = "PiXSquare"


class PiX(rx.Component):
    library = "react-icons/pi"
    tag = "PiX"


class PiYinYang(rx.Component):
    library = "react-icons/pi"
    tag = "PiYinYang"


class PiYoutubeLogo(rx.Component):
    library = "react-icons/pi"
    tag = "PiYoutubeLogo"


class PiAddressBookThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAddressBookThin"


class PiAirTrafficControlThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirTrafficControlThin"


class PiAirplaneInFlightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneInFlightThin"


class PiAirplaneLandingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneLandingThin"


class PiAirplaneTakeoffThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTakeoffThin"


class PiAirplaneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneThin"


class PiAirplaneTiltThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplaneTiltThin"


class PiAirplayThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAirplayThin"


class PiAlarmThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlarmThin"


class PiAlienThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlienThin"


class PiAlignBottomSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomSimpleThin"


class PiAlignBottomThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignBottomThin"


class PiAlignCenterHorizontalSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalSimpleThin"


class PiAlignCenterHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterHorizontalThin"


class PiAlignCenterVerticalSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalSimpleThin"


class PiAlignCenterVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignCenterVerticalThin"


class PiAlignLeftSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftSimpleThin"


class PiAlignLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignLeftThin"


class PiAlignRightSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightSimpleThin"


class PiAlignRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignRightThin"


class PiAlignTopSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopSimpleThin"


class PiAlignTopThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAlignTopThin"


class PiAmazonLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAmazonLogoThin"


class PiAnchorSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorSimpleThin"


class PiAnchorThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAnchorThin"


class PiAndroidLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAndroidLogoThin"


class PiAngularLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAngularLogoThin"


class PiApertureThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiApertureThin"


class PiAppStoreLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppStoreLogoThin"


class PiAppWindowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppWindowThin"


class PiAppleLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAppleLogoThin"


class PiApplePodcastsLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiApplePodcastsLogoThin"


class PiArchiveBoxThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveBoxThin"


class PiArchiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveThin"


class PiArchiveTrayThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArchiveTrayThin"


class PiArmchairThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArmchairThin"


class PiArrowArcLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcLeftThin"


class PiArrowArcRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowArcRightThin"


class PiArrowBendDoubleUpLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpLeftThin"


class PiArrowBendDoubleUpRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDoubleUpRightThin"


class PiArrowBendDownLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownLeftThin"


class PiArrowBendDownRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendDownRightThin"


class PiArrowBendLeftDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftDownThin"


class PiArrowBendLeftUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendLeftUpThin"


class PiArrowBendRightDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightDownThin"


class PiArrowBendRightUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendRightUpThin"


class PiArrowBendUpLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpLeftThin"


class PiArrowBendUpRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowBendUpRightThin"


class PiArrowCircleDownLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownLeftThin"


class PiArrowCircleDownRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownRightThin"


class PiArrowCircleDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleDownThin"


class PiArrowCircleLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleLeftThin"


class PiArrowCircleRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleRightThin"


class PiArrowCircleUpLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpLeftThin"


class PiArrowCircleUpRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpRightThin"


class PiArrowCircleUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCircleUpThin"


class PiArrowClockwiseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowClockwiseThin"


class PiArrowCounterClockwiseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowCounterClockwiseThin"


class PiArrowDownLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownLeftThin"


class PiArrowDownRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownRightThin"


class PiArrowDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowDownThin"


class PiArrowElbowDownLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownLeftThin"


class PiArrowElbowDownRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowDownRightThin"


class PiArrowElbowLeftDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftDownThin"


class PiArrowElbowLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftThin"


class PiArrowElbowLeftUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowLeftUpThin"


class PiArrowElbowRightDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightDownThin"


class PiArrowElbowRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightThin"


class PiArrowElbowRightUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowRightUpThin"


class PiArrowElbowUpLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpLeftThin"


class PiArrowElbowUpRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowElbowUpRightThin"


class PiArrowFatDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatDownThin"


class PiArrowFatLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLeftThin"


class PiArrowFatLineDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineDownThin"


class PiArrowFatLineLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineLeftThin"


class PiArrowFatLineRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineRightThin"


class PiArrowFatLineUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLineUpThin"


class PiArrowFatLinesDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesDownThin"


class PiArrowFatLinesLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesLeftThin"


class PiArrowFatLinesRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesRightThin"


class PiArrowFatLinesUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatLinesUpThin"


class PiArrowFatRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatRightThin"


class PiArrowFatUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowFatUpThin"


class PiArrowLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLeftThin"


class PiArrowLineDownLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownLeftThin"


class PiArrowLineDownRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownRightThin"


class PiArrowLineDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineDownThin"


class PiArrowLineLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineLeftThin"


class PiArrowLineRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineRightThin"


class PiArrowLineUpLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpLeftThin"


class PiArrowLineUpRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpRightThin"


class PiArrowLineUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowLineUpThin"


class PiArrowRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowRightThin"


class PiArrowSquareDownLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownLeftThin"


class PiArrowSquareDownRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownRightThin"


class PiArrowSquareDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareDownThin"


class PiArrowSquareInThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareInThin"


class PiArrowSquareLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareLeftThin"


class PiArrowSquareOutThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareOutThin"


class PiArrowSquareRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareRightThin"


class PiArrowSquareUpLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpLeftThin"


class PiArrowSquareUpRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpRightThin"


class PiArrowSquareUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowSquareUpThin"


class PiArrowUDownLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownLeftThin"


class PiArrowUDownRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUDownRightThin"


class PiArrowULeftDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftDownThin"


class PiArrowULeftUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowULeftUpThin"


class PiArrowURightDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightDownThin"


class PiArrowURightUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowURightUpThin"


class PiArrowUUpLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpLeftThin"


class PiArrowUUpRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUUpRightThin"


class PiArrowUpLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpLeftThin"


class PiArrowUpRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpRightThin"


class PiArrowUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowUpThin"


class PiArrowsClockwiseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsClockwiseThin"


class PiArrowsCounterClockwiseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsCounterClockwiseThin"


class PiArrowsDownUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsDownUpThin"


class PiArrowsHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsHorizontalThin"


class PiArrowsInCardinalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInCardinalThin"


class PiArrowsInLineHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineHorizontalThin"


class PiArrowsInLineVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInLineVerticalThin"


class PiArrowsInSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInSimpleThin"


class PiArrowsInThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsInThin"


class PiArrowsLeftRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsLeftRightThin"


class PiArrowsMergeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsMergeThin"


class PiArrowsOutCardinalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutCardinalThin"


class PiArrowsOutLineHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineHorizontalThin"


class PiArrowsOutLineVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutLineVerticalThin"


class PiArrowsOutSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutSimpleThin"


class PiArrowsOutThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsOutThin"


class PiArrowsSplitThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsSplitThin"


class PiArrowsVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArrowsVerticalThin"


class PiArticleMediumThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleMediumThin"


class PiArticleNyTimesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleNyTimesThin"


class PiArticleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiArticleThin"


class PiAsteriskSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskSimpleThin"


class PiAsteriskThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAsteriskThin"


class PiAtThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtThin"


class PiAtomThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiAtomThin"


class PiBabyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBabyThin"


class PiBackpackThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackpackThin"


class PiBackspaceThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBackspaceThin"


class PiBagSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagSimpleThin"


class PiBagThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBagThin"


class PiBalloonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBalloonThin"


class PiBandaidsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBandaidsThin"


class PiBankThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBankThin"


class PiBarbellThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarbellThin"


class PiBarcodeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarcodeThin"


class PiBarricadeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBarricadeThin"


class PiBaseballCapThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballCapThin"


class PiBaseballThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBaseballThin"


class PiBasketThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketThin"


class PiBasketballThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBasketballThin"


class PiBathtubThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBathtubThin"


class PiBatteryChargingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingThin"


class PiBatteryChargingVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryChargingVerticalThin"


class PiBatteryEmptyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryEmptyThin"


class PiBatteryFullThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryFullThin"


class PiBatteryHighThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryHighThin"


class PiBatteryLowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryLowThin"


class PiBatteryMediumThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryMediumThin"


class PiBatteryPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusThin"


class PiBatteryPlusVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryPlusVerticalThin"


class PiBatteryVerticalEmptyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalEmptyThin"


class PiBatteryVerticalFullThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalFullThin"


class PiBatteryVerticalHighThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalHighThin"


class PiBatteryVerticalLowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalLowThin"


class PiBatteryVerticalMediumThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryVerticalMediumThin"


class PiBatteryWarningThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningThin"


class PiBatteryWarningVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBatteryWarningVerticalThin"


class PiBedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBedThin"


class PiBeerBottleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerBottleThin"


class PiBeerSteinThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBeerSteinThin"


class PiBehanceLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBehanceLogoThin"


class PiBellRingingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellRingingThin"


class PiBellSimpleRingingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleRingingThin"


class PiBellSimpleSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleSlashThin"


class PiBellSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleThin"


class PiBellSimpleZThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSimpleZThin"


class PiBellSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellSlashThin"


class PiBellThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellThin"


class PiBellZThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBellZThin"


class PiBezierCurveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBezierCurveThin"


class PiBicycleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBicycleThin"


class PiBinocularsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBinocularsThin"


class PiBirdThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBirdThin"


class PiBluetoothConnectedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothConnectedThin"


class PiBluetoothSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothSlashThin"


class PiBluetoothThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothThin"


class PiBluetoothXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBluetoothXThin"


class PiBoatThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoatThin"


class PiBoneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoneThin"


class PiBookBookmarkThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookBookmarkThin"


class PiBookOpenTextThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenTextThin"


class PiBookOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookOpenThin"


class PiBookThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookThin"


class PiBookmarkSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkSimpleThin"


class PiBookmarkThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarkThin"


class PiBookmarksSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksSimpleThin"


class PiBookmarksThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBookmarksThin"


class PiBooksThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBooksThin"


class PiBootThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBootThin"


class PiBoundingBoxThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBoundingBoxThin"


class PiBowlFoodThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBowlFoodThin"


class PiBracketsAngleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsAngleThin"


class PiBracketsCurlyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsCurlyThin"


class PiBracketsRoundThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsRoundThin"


class PiBracketsSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBracketsSquareThin"


class PiBrainThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrainThin"


class PiBrandyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrandyThin"


class PiBridgeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBridgeThin"


class PiBriefcaseMetalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseMetalThin"


class PiBriefcaseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBriefcaseThin"


class PiBroadcastThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroadcastThin"


class PiBroomThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBroomThin"


class PiBrowserThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowserThin"


class PiBrowsersThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBrowsersThin"


class PiBugBeetleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugBeetleThin"


class PiBugDroidThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugDroidThin"


class PiBugThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBugThin"


class PiBuildingsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBuildingsThin"


class PiBusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiBusThin"


class PiButterflyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiButterflyThin"


class PiCactusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCactusThin"


class PiCakeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCakeThin"


class PiCalculatorThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalculatorThin"


class PiCalendarBlankThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarBlankThin"


class PiCalendarCheckThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarCheckThin"


class PiCalendarPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarPlusThin"


class PiCalendarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarThin"


class PiCalendarXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCalendarXThin"


class PiCallBellThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCallBellThin"


class PiCameraPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraPlusThin"


class PiCameraRotateThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraRotateThin"


class PiCameraSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraSlashThin"


class PiCameraThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCameraThin"


class PiCampfireThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCampfireThin"


class PiCarProfileThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarProfileThin"


class PiCarSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarSimpleThin"


class PiCarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarThin"


class PiCardholderThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardholderThin"


class PiCardsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCardsThin"


class PiCaretCircleDoubleDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleDownThin"


class PiCaretCircleDoubleLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleLeftThin"


class PiCaretCircleDoubleRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleRightThin"


class PiCaretCircleDoubleUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDoubleUpThin"


class PiCaretCircleDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleDownThin"


class PiCaretCircleLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleLeftThin"


class PiCaretCircleRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleRightThin"


class PiCaretCircleUpDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpDownThin"


class PiCaretCircleUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretCircleUpThin"


class PiCaretDoubleDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleDownThin"


class PiCaretDoubleLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleLeftThin"


class PiCaretDoubleRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleRightThin"


class PiCaretDoubleUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDoubleUpThin"


class PiCaretDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretDownThin"


class PiCaretLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretLeftThin"


class PiCaretRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretRightThin"


class PiCaretUpDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpDownThin"


class PiCaretUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCaretUpThin"


class PiCarrotThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCarrotThin"


class PiCassetteTapeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCassetteTapeThin"


class PiCastleTurretThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCastleTurretThin"


class PiCatThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCatThin"


class PiCellSignalFullThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalFullThin"


class PiCellSignalHighThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalHighThin"


class PiCellSignalLowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalLowThin"


class PiCellSignalMediumThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalMediumThin"


class PiCellSignalNoneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalNoneThin"


class PiCellSignalSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalSlashThin"


class PiCellSignalXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCellSignalXThin"


class PiCertificateThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCertificateThin"


class PiChairThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChairThin"


class PiChalkboardSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardSimpleThin"


class PiChalkboardTeacherThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardTeacherThin"


class PiChalkboardThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChalkboardThin"


class PiChampagneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChampagneThin"


class PiChargingStationThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChargingStationThin"


class PiChartBarHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarHorizontalThin"


class PiChartBarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartBarThin"


class PiChartDonutThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartDonutThin"


class PiChartLineDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineDownThin"


class PiChartLineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineThin"


class PiChartLineUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartLineUpThin"


class PiChartPieSliceThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieSliceThin"


class PiChartPieThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPieThin"


class PiChartPolarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartPolarThin"


class PiChartScatterThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChartScatterThin"


class PiChatCenteredDotsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredDotsThin"


class PiChatCenteredTextThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredTextThin"


class PiChatCenteredThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCenteredThin"


class PiChatCircleDotsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleDotsThin"


class PiChatCircleTextThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleTextThin"


class PiChatCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatCircleThin"


class PiChatDotsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatDotsThin"


class PiChatTeardropDotsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropDotsThin"


class PiChatTeardropTextThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropTextThin"


class PiChatTeardropThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTeardropThin"


class PiChatTextThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatTextThin"


class PiChatThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatThin"


class PiChatsCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsCircleThin"


class PiChatsTeardropThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsTeardropThin"


class PiChatsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChatsThin"


class PiCheckCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckCircleThin"


class PiCheckFatThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckFatThin"


class PiCheckSquareOffsetThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareOffsetThin"


class PiCheckSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckSquareThin"


class PiCheckThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCheckThin"


class PiChecksThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChecksThin"


class PiChurchThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiChurchThin"


class PiCircleDashedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleDashedThin"


class PiCircleHalfThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfThin"


class PiCircleHalfTiltThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleHalfTiltThin"


class PiCircleNotchThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleNotchThin"


class PiCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircleThin"


class PiCirclesFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesFourThin"


class PiCirclesThreePlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreePlusThin"


class PiCirclesThreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCirclesThreeThin"


class PiCircuitryThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCircuitryThin"


class PiClipboardTextThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardTextThin"


class PiClipboardThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiClipboardThin"


class PiClockAfternoonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockAfternoonThin"


class PiClockClockwiseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockClockwiseThin"


class PiClockCountdownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCountdownThin"


class PiClockCounterClockwiseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockCounterClockwiseThin"


class PiClockThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiClockThin"


class PiClosedCaptioningThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiClosedCaptioningThin"


class PiCloudArrowDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowDownThin"


class PiCloudArrowUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudArrowUpThin"


class PiCloudCheckThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudCheckThin"


class PiCloudFogThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudFogThin"


class PiCloudLightningThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudLightningThin"


class PiCloudMoonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudMoonThin"


class PiCloudRainThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudRainThin"


class PiCloudSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSlashThin"


class PiCloudSnowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSnowThin"


class PiCloudSunThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudSunThin"


class PiCloudThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudThin"


class PiCloudWarningThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudWarningThin"


class PiCloudXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCloudXThin"


class PiClubThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiClubThin"


class PiCoatHangerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoatHangerThin"


class PiCodaLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodaLogoThin"


class PiCodeBlockThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeBlockThin"


class PiCodeSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeSimpleThin"


class PiCodeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodeThin"


class PiCodepenLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodepenLogoThin"


class PiCodesandboxLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCodesandboxLogoThin"


class PiCoffeeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoffeeThin"


class PiCoinThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinThin"


class PiCoinVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinVerticalThin"


class PiCoinsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCoinsThin"


class PiColumnsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiColumnsThin"


class PiCommandThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCommandThin"


class PiCompassThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassThin"


class PiCompassToolThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCompassToolThin"


class PiComputerTowerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiComputerTowerThin"


class PiConfettiThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiConfettiThin"


class PiContactlessPaymentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiContactlessPaymentThin"


class PiControlThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiControlThin"


class PiCookieThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookieThin"


class PiCookingPotThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCookingPotThin"


class PiCopySimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopySimpleThin"


class PiCopyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyThin"


class PiCopyleftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyleftThin"


class PiCopyrightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCopyrightThin"


class PiCornersInThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersInThin"


class PiCornersOutThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCornersOutThin"


class PiCouchThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCouchThin"


class PiCpuThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCpuThin"


class PiCreditCardThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCreditCardThin"


class PiCropThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCropThin"


class PiCrossThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrossThin"


class PiCrosshairSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairSimpleThin"


class PiCrosshairThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrosshairThin"


class PiCrownSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownSimpleThin"


class PiCrownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCrownThin"


class PiCubeFocusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeFocusThin"


class PiCubeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeThin"


class PiCubeTransparentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCubeTransparentThin"


class PiCurrencyBtcThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyBtcThin"


class PiCurrencyCircleDollarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCircleDollarThin"


class PiCurrencyCnyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyCnyThin"


class PiCurrencyDollarSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarSimpleThin"


class PiCurrencyDollarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyDollarThin"


class PiCurrencyEthThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEthThin"


class PiCurrencyEurThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyEurThin"


class PiCurrencyGbpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyGbpThin"


class PiCurrencyInrThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyInrThin"


class PiCurrencyJpyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyJpyThin"


class PiCurrencyKrwThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKrwThin"


class PiCurrencyKztThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyKztThin"


class PiCurrencyNgnThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyNgnThin"


class PiCurrencyRubThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCurrencyRubThin"


class PiCursorClickThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorClickThin"


class PiCursorTextThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorTextThin"


class PiCursorThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCursorThin"


class PiCylinderThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiCylinderThin"


class PiDatabaseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDatabaseThin"


class PiDesktopThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopThin"


class PiDesktopTowerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDesktopTowerThin"


class PiDetectiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDetectiveThin"


class PiDevToLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevToLogoThin"


class PiDeviceMobileCameraThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileCameraThin"


class PiDeviceMobileSpeakerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileSpeakerThin"


class PiDeviceMobileThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceMobileThin"


class PiDeviceTabletCameraThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletCameraThin"


class PiDeviceTabletSpeakerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletSpeakerThin"


class PiDeviceTabletThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDeviceTabletThin"


class PiDevicesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDevicesThin"


class PiDiamondThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondThin"


class PiDiamondsFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiamondsFourThin"


class PiDiceFiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFiveThin"


class PiDiceFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceFourThin"


class PiDiceOneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceOneThin"


class PiDiceSixThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceSixThin"


class PiDiceThreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceThreeThin"


class PiDiceTwoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiceTwoThin"


class PiDiscThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscThin"


class PiDiscordLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDiscordLogoThin"


class PiDivideThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDivideThin"


class PiDnaThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDnaThin"


class PiDogThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDogThin"


class PiDoorOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorOpenThin"


class PiDoorThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDoorThin"


class PiDotOutlineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotOutlineThin"


class PiDotThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotThin"


class PiDotsNineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsNineThin"


class PiDotsSixThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixThin"


class PiDotsSixVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsSixVerticalThin"


class PiDotsThreeCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleThin"


class PiDotsThreeCircleVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeCircleVerticalThin"


class PiDotsThreeOutlineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineThin"


class PiDotsThreeOutlineVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeOutlineVerticalThin"


class PiDotsThreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeThin"


class PiDotsThreeVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDotsThreeVerticalThin"


class PiDownloadSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadSimpleThin"


class PiDownloadThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDownloadThin"


class PiDressThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDressThin"


class PiDribbbleLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDribbbleLogoThin"


class PiDropHalfBottomThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfBottomThin"


class PiDropHalfThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropHalfThin"


class PiDropThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropThin"


class PiDropboxLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiDropboxLogoThin"


class PiEarSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarSlashThin"


class PiEarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEarThin"


class PiEggCrackThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggCrackThin"


class PiEggThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEggThin"


class PiEjectSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectSimpleThin"


class PiEjectThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEjectThin"


class PiElevatorThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiElevatorThin"


class PiEngineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEngineThin"


class PiEnvelopeOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeOpenThin"


class PiEnvelopeSimpleOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleOpenThin"


class PiEnvelopeSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeSimpleThin"


class PiEnvelopeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEnvelopeThin"


class PiEqualizerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualizerThin"


class PiEqualsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEqualsThin"


class PiEraserThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEraserThin"


class PiEscalatorDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorDownThin"


class PiEscalatorUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEscalatorUpThin"


class PiExamThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiExamThin"


class PiExcludeSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeSquareThin"


class PiExcludeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiExcludeThin"


class PiExportThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiExportThin"


class PiEyeClosedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeClosedThin"


class PiEyeSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeSlashThin"


class PiEyeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeThin"


class PiEyedropperSampleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperSampleThin"


class PiEyedropperThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyedropperThin"


class PiEyeglassesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiEyeglassesThin"


class PiFaceMaskThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFaceMaskThin"


class PiFacebookLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFacebookLogoThin"


class PiFactoryThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFactoryThin"


class PiFadersHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersHorizontalThin"


class PiFadersThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFadersThin"


class PiFanThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFanThin"


class PiFastForwardCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardCircleThin"


class PiFastForwardThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFastForwardThin"


class PiFeatherThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFeatherThin"


class PiFigmaLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFigmaLogoThin"


class PiFileArchiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArchiveThin"


class PiFileArrowDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowDownThin"


class PiFileArrowUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileArrowUpThin"


class PiFileAudioThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileAudioThin"


class PiFileCloudThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCloudThin"


class PiFileCodeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCodeThin"


class PiFileCssThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCssThin"


class PiFileCsvThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileCsvThin"


class PiFileDashedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDashedThin"


class PiFileDocThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileDocThin"


class PiFileHtmlThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileHtmlThin"


class PiFileImageThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileImageThin"


class PiFileJpgThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJpgThin"


class PiFileJsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsThin"


class PiFileJsxThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileJsxThin"


class PiFileLockThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileLockThin"


class PiFileMagnifyingGlassThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMagnifyingGlassThin"


class PiFileMinusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileMinusThin"


class PiFilePdfThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePdfThin"


class PiFilePlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePlusThin"


class PiFilePngThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePngThin"


class PiFilePptThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilePptThin"


class PiFileRsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileRsThin"


class PiFileSqlThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSqlThin"


class PiFileSvgThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileSvgThin"


class PiFileTextThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTextThin"


class PiFileThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileThin"


class PiFileTsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsThin"


class PiFileTsxThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileTsxThin"


class PiFileVideoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVideoThin"


class PiFileVueThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileVueThin"


class PiFileXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXThin"


class PiFileXlsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileXlsThin"


class PiFileZipThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFileZipThin"


class PiFilesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilesThin"


class PiFilmReelThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmReelThin"


class PiFilmScriptThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmScriptThin"


class PiFilmSlateThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmSlateThin"


class PiFilmStripThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFilmStripThin"


class PiFingerprintSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintSimpleThin"


class PiFingerprintThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFingerprintThin"


class PiFinnTheHumanThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFinnTheHumanThin"


class PiFireExtinguisherThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireExtinguisherThin"


class PiFireSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireSimpleThin"


class PiFireThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFireThin"


class PiFirstAidKitThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidKitThin"


class PiFirstAidThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFirstAidThin"


class PiFishSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishSimpleThin"


class PiFishThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFishThin"


class PiFlagBannerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagBannerThin"


class PiFlagCheckeredThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagCheckeredThin"


class PiFlagPennantThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagPennantThin"


class PiFlagThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlagThin"


class PiFlameThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlameThin"


class PiFlashlightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlashlightThin"


class PiFlaskThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlaskThin"


class PiFloppyDiskBackThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskBackThin"


class PiFloppyDiskThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFloppyDiskThin"


class PiFlowArrowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowArrowThin"


class PiFlowerLotusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerLotusThin"


class PiFlowerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerThin"


class PiFlowerTulipThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlowerTulipThin"


class PiFlyingSaucerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFlyingSaucerThin"


class PiFolderDashedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderDashedThin"


class PiFolderLockThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderLockThin"


class PiFolderMinusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderMinusThin"


class PiFolderNotchMinusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchMinusThin"


class PiFolderNotchOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchOpenThin"


class PiFolderNotchPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchPlusThin"


class PiFolderNotchThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderNotchThin"


class PiFolderOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderOpenThin"


class PiFolderPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderPlusThin"


class PiFolderSimpleDashedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleDashedThin"


class PiFolderSimpleLockThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleLockThin"


class PiFolderSimpleMinusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleMinusThin"


class PiFolderSimplePlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimplePlusThin"


class PiFolderSimpleStarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleStarThin"


class PiFolderSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleThin"


class PiFolderSimpleUserThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderSimpleUserThin"


class PiFolderStarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderStarThin"


class PiFolderThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderThin"


class PiFolderUserThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFolderUserThin"


class PiFoldersThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFoldersThin"


class PiFootballThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootballThin"


class PiFootprintsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFootprintsThin"


class PiForkKnifeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiForkKnifeThin"


class PiFrameCornersThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFrameCornersThin"


class PiFramerLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFramerLogoThin"


class PiFunctionThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunctionThin"


class PiFunnelSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelSimpleThin"


class PiFunnelThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiFunnelThin"


class PiGameControllerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGameControllerThin"


class PiGarageThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGarageThin"


class PiGasCanThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasCanThin"


class PiGasPumpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGasPumpThin"


class PiGaugeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGaugeThin"


class PiGavelThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGavelThin"


class PiGearFineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearFineThin"


class PiGearSixThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearSixThin"


class PiGearThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGearThin"


class PiGenderFemaleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderFemaleThin"


class PiGenderIntersexThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderIntersexThin"


class PiGenderMaleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderMaleThin"


class PiGenderNeuterThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNeuterThin"


class PiGenderNonbinaryThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderNonbinaryThin"


class PiGenderTransgenderThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGenderTransgenderThin"


class PiGhostThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGhostThin"


class PiGifThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGifThin"


class PiGiftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGiftThin"


class PiGitBranchThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitBranchThin"


class PiGitCommitThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitCommitThin"


class PiGitDiffThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitDiffThin"


class PiGitForkThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitForkThin"


class PiGitMergeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitMergeThin"


class PiGitPullRequestThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitPullRequestThin"


class PiGithubLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGithubLogoThin"


class PiGitlabLogoSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoSimpleThin"


class PiGitlabLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGitlabLogoThin"


class PiGlobeHemisphereEastThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereEastThin"


class PiGlobeHemisphereWestThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeHemisphereWestThin"


class PiGlobeSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeSimpleThin"


class PiGlobeStandThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeStandThin"


class PiGlobeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGlobeThin"


class PiGogglesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGogglesThin"


class PiGoodreadsLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoodreadsLogoThin"


class PiGoogleCardboardLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleCardboardLogoThin"


class PiGoogleChromeLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleChromeLogoThin"


class PiGoogleDriveLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleDriveLogoThin"


class PiGoogleLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGoogleLogoThin"


class PiGooglePhotosLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePhotosLogoThin"


class PiGooglePlayLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePlayLogoThin"


class PiGooglePodcastsLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGooglePodcastsLogoThin"


class PiGradientThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGradientThin"


class PiGraduationCapThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraduationCapThin"


class PiGrainsSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsSlashThin"


class PiGrainsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGrainsThin"


class PiGraphThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGraphThin"


class PiGridFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridFourThin"


class PiGridNineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGridNineThin"


class PiGuitarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiGuitarThin"


class PiHamburgerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHamburgerThin"


class PiHammerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHammerThin"


class PiHandCoinsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandCoinsThin"


class PiHandEyeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandEyeThin"


class PiHandFistThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandFistThin"


class PiHandGrabbingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandGrabbingThin"


class PiHandHeartThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandHeartThin"


class PiHandPalmThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPalmThin"


class PiHandPointingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandPointingThin"


class PiHandSoapThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSoapThin"


class PiHandSwipeLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeLeftThin"


class PiHandSwipeRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandSwipeRightThin"


class PiHandTapThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandTapThin"


class PiHandThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandThin"


class PiHandWavingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandWavingThin"


class PiHandbagSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagSimpleThin"


class PiHandbagThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandbagThin"


class PiHandsClappingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsClappingThin"


class PiHandsPrayingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandsPrayingThin"


class PiHandshakeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHandshakeThin"


class PiHardDriveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDriveThin"


class PiHardDrivesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHardDrivesThin"


class PiHashStraightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashStraightThin"


class PiHashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHashThin"


class PiHeadlightsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadlightsThin"


class PiHeadphonesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadphonesThin"


class PiHeadsetThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeadsetThin"


class PiHeartBreakThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartBreakThin"


class PiHeartHalfThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartHalfThin"


class PiHeartStraightBreakThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightBreakThin"


class PiHeartStraightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartStraightThin"


class PiHeartThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartThin"


class PiHeartbeatThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHeartbeatThin"


class PiHexagonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHexagonThin"


class PiHighHeelThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighHeelThin"


class PiHighlighterCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHighlighterCircleThin"


class PiHoodieThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHoodieThin"


class PiHorseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHorseThin"


class PiHourglassHighThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassHighThin"


class PiHourglassLowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassLowThin"


class PiHourglassMediumThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassMediumThin"


class PiHourglassSimpleHighThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleHighThin"


class PiHourglassSimpleLowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleLowThin"


class PiHourglassSimpleMediumThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleMediumThin"


class PiHourglassSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassSimpleThin"


class PiHourglassThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHourglassThin"


class PiHouseLineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseLineThin"


class PiHouseSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseSimpleThin"


class PiHouseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiHouseThin"


class PiIceCreamThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiIceCreamThin"


class PiIdentificationBadgeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationBadgeThin"


class PiIdentificationCardThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiIdentificationCardThin"


class PiImageSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageSquareThin"


class PiImageThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiImageThin"


class PiImagesSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesSquareThin"


class PiImagesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiImagesThin"


class PiInfinityThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfinityThin"


class PiInfoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiInfoThin"


class PiInstagramLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiInstagramLogoThin"


class PiIntersectSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectSquareThin"


class PiIntersectThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectThin"


class PiIntersectThreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiIntersectThreeThin"


class PiJeepThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiJeepThin"


class PiKanbanThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiKanbanThin"


class PiKeyReturnThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyReturnThin"


class PiKeyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyThin"


class PiKeyboardThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyboardThin"


class PiKeyholeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiKeyholeThin"


class PiKnifeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiKnifeThin"


class PiLadderSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderSimpleThin"


class PiLadderThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLadderThin"


class PiLampThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLampThin"


class PiLaptopThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLaptopThin"


class PiLayoutThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLayoutThin"


class PiLeafThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLeafThin"


class PiLifebuoyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLifebuoyThin"


class PiLightbulbFilamentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbFilamentThin"


class PiLightbulbThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightbulbThin"


class PiLighthouseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLighthouseThin"


class PiLightningAThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningAThin"


class PiLightningSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningSlashThin"


class PiLightningThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLightningThin"


class PiLineSegmentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentThin"


class PiLineSegmentsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLineSegmentsThin"


class PiLinkBreakThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkBreakThin"


class PiLinkSimpleBreakThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleBreakThin"


class PiLinkSimpleHorizontalBreakThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalBreakThin"


class PiLinkSimpleHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleHorizontalThin"


class PiLinkSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkSimpleThin"


class PiLinkThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkThin"


class PiLinkedinLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinkedinLogoThin"


class PiLinuxLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLinuxLogoThin"


class PiListBulletsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiListBulletsThin"


class PiListChecksThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiListChecksThin"


class PiListDashesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiListDashesThin"


class PiListMagnifyingGlassThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiListMagnifyingGlassThin"


class PiListNumbersThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiListNumbersThin"


class PiListPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiListPlusThin"


class PiListThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiListThin"


class PiLockKeyOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyOpenThin"


class PiLockKeyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockKeyThin"


class PiLockLaminatedOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedOpenThin"


class PiLockLaminatedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockLaminatedThin"


class PiLockOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockOpenThin"


class PiLockSimpleOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleOpenThin"


class PiLockSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockSimpleThin"


class PiLockThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockThin"


class PiLockersThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiLockersThin"


class PiMagicWandThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagicWandThin"


class PiMagnetStraightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetStraightThin"


class PiMagnetThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnetThin"


class PiMagnifyingGlassMinusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassMinusThin"


class PiMagnifyingGlassPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassPlusThin"


class PiMagnifyingGlassThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMagnifyingGlassThin"


class PiMapPinLineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinLineThin"


class PiMapPinThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapPinThin"


class PiMapTrifoldThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMapTrifoldThin"


class PiMarkerCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMarkerCircleThin"


class PiMartiniThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMartiniThin"


class PiMaskHappyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskHappyThin"


class PiMaskSadThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMaskSadThin"


class PiMathOperationsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMathOperationsThin"


class PiMedalMilitaryThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalMilitaryThin"


class PiMedalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMedalThin"


class PiMediumLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMediumLogoThin"


class PiMegaphoneSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneSimpleThin"


class PiMegaphoneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMegaphoneThin"


class PiMessengerLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMessengerLogoThin"


class PiMetaLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetaLogoThin"


class PiMetronomeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMetronomeThin"


class PiMicrophoneSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneSlashThin"


class PiMicrophoneStageThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneStageThin"


class PiMicrophoneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrophoneThin"


class PiMicrosoftExcelLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftExcelLogoThin"


class PiMicrosoftOutlookLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftOutlookLogoThin"


class PiMicrosoftPowerpointLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftPowerpointLogoThin"


class PiMicrosoftTeamsLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftTeamsLogoThin"


class PiMicrosoftWordLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMicrosoftWordLogoThin"


class PiMinusCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusCircleThin"


class PiMinusSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusSquareThin"


class PiMinusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMinusThin"


class PiMoneyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoneyThin"


class PiMonitorPlayThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorPlayThin"


class PiMonitorThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMonitorThin"


class PiMoonStarsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonStarsThin"


class PiMoonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMoonThin"


class PiMopedFrontThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedFrontThin"


class PiMopedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMopedThin"


class PiMosqueThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMosqueThin"


class PiMotorcycleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMotorcycleThin"


class PiMountainsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMountainsThin"


class PiMouseSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseSimpleThin"


class PiMouseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMouseThin"


class PiMusicNoteSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteSimpleThin"


class PiMusicNoteThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNoteThin"


class PiMusicNotesPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesPlusThin"


class PiMusicNotesSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesSimpleThin"


class PiMusicNotesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiMusicNotesThin"


class PiNavigationArrowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNavigationArrowThin"


class PiNeedleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNeedleThin"


class PiNewspaperClippingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperClippingThin"


class PiNewspaperThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNewspaperThin"


class PiNotchesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotchesThin"


class PiNoteBlankThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteBlankThin"


class PiNotePencilThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotePencilThin"


class PiNoteThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNoteThin"


class PiNotebookThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotebookThin"


class PiNotepadThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotepadThin"


class PiNotificationThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotificationThin"


class PiNotionLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNotionLogoThin"


class PiNumberCircleEightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleEightThin"


class PiNumberCircleFiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFiveThin"


class PiNumberCircleFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleFourThin"


class PiNumberCircleNineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleNineThin"


class PiNumberCircleOneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleOneThin"


class PiNumberCircleSevenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSevenThin"


class PiNumberCircleSixThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleSixThin"


class PiNumberCircleThreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleThreeThin"


class PiNumberCircleTwoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleTwoThin"


class PiNumberCircleZeroThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberCircleZeroThin"


class PiNumberEightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberEightThin"


class PiNumberFiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFiveThin"


class PiNumberFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberFourThin"


class PiNumberNineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberNineThin"


class PiNumberOneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberOneThin"


class PiNumberSevenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSevenThin"


class PiNumberSixThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSixThin"


class PiNumberSquareEightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareEightThin"


class PiNumberSquareFiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFiveThin"


class PiNumberSquareFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareFourThin"


class PiNumberSquareNineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareNineThin"


class PiNumberSquareOneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareOneThin"


class PiNumberSquareSevenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSevenThin"


class PiNumberSquareSixThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareSixThin"


class PiNumberSquareThreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareThreeThin"


class PiNumberSquareTwoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareTwoThin"


class PiNumberSquareZeroThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberSquareZeroThin"


class PiNumberThreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberThreeThin"


class PiNumberTwoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberTwoThin"


class PiNumberZeroThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNumberZeroThin"


class PiNutThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNutThin"


class PiNyTimesLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiNyTimesLogoThin"


class PiOctagonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiOctagonThin"


class PiOfficeChairThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiOfficeChairThin"


class PiOptionThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiOptionThin"


class PiOrangeSliceThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiOrangeSliceThin"


class PiPackageThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPackageThin"


class PiPaintBrushBroadThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushBroadThin"


class PiPaintBrushHouseholdThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushHouseholdThin"


class PiPaintBrushThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBrushThin"


class PiPaintBucketThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintBucketThin"


class PiPaintRollerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaintRollerThin"


class PiPaletteThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaletteThin"


class PiPantsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPantsThin"


class PiPaperPlaneRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneRightThin"


class PiPaperPlaneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneThin"


class PiPaperPlaneTiltThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperPlaneTiltThin"


class PiPaperclipHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipHorizontalThin"


class PiPaperclipThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaperclipThin"


class PiParachuteThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiParachuteThin"


class PiParagraphThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiParagraphThin"


class PiParallelogramThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiParallelogramThin"


class PiParkThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiParkThin"


class PiPasswordThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPasswordThin"


class PiPathThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPathThin"


class PiPatreonLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPatreonLogoThin"


class PiPauseCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseCircleThin"


class PiPauseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPauseThin"


class PiPawPrintThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPawPrintThin"


class PiPaypalLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPaypalLogoThin"


class PiPeaceThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPeaceThin"


class PiPenNibStraightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibStraightThin"


class PiPenNibThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenNibThin"


class PiPenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPenThin"


class PiPencilCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilCircleThin"


class PiPencilLineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilLineThin"


class PiPencilSimpleLineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleLineThin"


class PiPencilSimpleSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleSlashThin"


class PiPencilSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSimpleThin"


class PiPencilSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilSlashThin"


class PiPencilThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPencilThin"


class PiPentagramThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPentagramThin"


class PiPepperThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPepperThin"


class PiPercentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPercentThin"


class PiPersonArmsSpreadThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonArmsSpreadThin"


class PiPersonSimpleBikeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleBikeThin"


class PiPersonSimpleRunThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleRunThin"


class PiPersonSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleThin"


class PiPersonSimpleThrowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleThrowThin"


class PiPersonSimpleWalkThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonSimpleWalkThin"


class PiPersonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPersonThin"


class PiPerspectiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPerspectiveThin"


class PiPhoneCallThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneCallThin"


class PiPhoneDisconnectThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneDisconnectThin"


class PiPhoneIncomingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneIncomingThin"


class PiPhoneOutgoingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneOutgoingThin"


class PiPhonePlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhonePlusThin"


class PiPhoneSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneSlashThin"


class PiPhoneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneThin"


class PiPhoneXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhoneXThin"


class PiPhosphorLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPhosphorLogoThin"


class PiPiThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiThin"


class PiPianoKeysThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPianoKeysThin"


class PiPictureInPictureThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPictureInPictureThin"


class PiPiggyBankThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPiggyBankThin"


class PiPillThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPillThin"


class PiPinterestLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinterestLogoThin"


class PiPinwheelThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPinwheelThin"


class PiPizzaThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPizzaThin"


class PiPlaceholderThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaceholderThin"


class PiPlanetThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlanetThin"


class PiPlantThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlantThin"


class PiPlayCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayCircleThin"


class PiPlayPauseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayPauseThin"


class PiPlayThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlayThin"


class PiPlaylistThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlaylistThin"


class PiPlugChargingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugChargingThin"


class PiPlugThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugThin"


class PiPlugsConnectedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsConnectedThin"


class PiPlugsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlugsThin"


class PiPlusCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusCircleThin"


class PiPlusMinusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusMinusThin"


class PiPlusSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusSquareThin"


class PiPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPlusThin"


class PiPokerChipThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPokerChipThin"


class PiPoliceCarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPoliceCarThin"


class PiPolygonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPolygonThin"


class PiPopcornThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPopcornThin"


class PiPottedPlantThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPottedPlantThin"


class PiPowerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPowerThin"


class PiPrescriptionThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrescriptionThin"


class PiPresentationChartThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationChartThin"


class PiPresentationThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPresentationThin"


class PiPrinterThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPrinterThin"


class PiProhibitInsetThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitInsetThin"


class PiProhibitThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiProhibitThin"


class PiProjectorScreenChartThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenChartThin"


class PiProjectorScreenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiProjectorScreenThin"


class PiPulseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPulseThin"


class PiPushPinSimpleSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleSlashThin"


class PiPushPinSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSimpleThin"


class PiPushPinSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinSlashThin"


class PiPushPinThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPushPinThin"


class PiPuzzlePieceThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiPuzzlePieceThin"


class PiQrCodeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiQrCodeThin"


class PiQuestionThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuestionThin"


class PiQueueThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiQueueThin"


class PiQuotesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiQuotesThin"


class PiRadicalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadicalThin"


class PiRadioButtonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioButtonThin"


class PiRadioThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioThin"


class PiRadioactiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRadioactiveThin"


class PiRainbowCloudThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowCloudThin"


class PiRainbowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRainbowThin"


class PiReadCvLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiReadCvLogoThin"


class PiReceiptThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptThin"


class PiReceiptXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiReceiptXThin"


class PiRecordThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecordThin"


class PiRectangleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRectangleThin"


class PiRecycleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRecycleThin"


class PiRedditLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRedditLogoThin"


class PiRepeatOnceThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatOnceThin"


class PiRepeatThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRepeatThin"


class PiRewindCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindCircleThin"


class PiRewindThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRewindThin"


class PiRoadHorizonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRoadHorizonThin"


class PiRobotThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRobotThin"


class PiRocketLaunchThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketLaunchThin"


class PiRocketThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRocketThin"


class PiRowsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRowsThin"


class PiRssSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssSimpleThin"


class PiRssThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRssThin"


class PiRugThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRugThin"


class PiRulerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiRulerThin"


class PiScalesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiScalesThin"


class PiScanThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiScanThin"


class PiScissorsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiScissorsThin"


class PiScooterThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiScooterThin"


class PiScreencastThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiScreencastThin"


class PiScribbleLoopThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiScribbleLoopThin"


class PiScrollThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiScrollThin"


class PiSealCheckThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealCheckThin"


class PiSealQuestionThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealQuestionThin"


class PiSealThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealThin"


class PiSealWarningThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSealWarningThin"


class PiSelectionAllThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionAllThin"


class PiSelectionBackgroundThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionBackgroundThin"


class PiSelectionForegroundThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionForegroundThin"


class PiSelectionInverseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionInverseThin"


class PiSelectionPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionPlusThin"


class PiSelectionSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionSlashThin"


class PiSelectionThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSelectionThin"


class PiShapesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShapesThin"


class PiShareFatThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareFatThin"


class PiShareNetworkThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareNetworkThin"


class PiShareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShareThin"


class PiShieldCheckThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckThin"


class PiShieldCheckeredThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldCheckeredThin"


class PiShieldChevronThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldChevronThin"


class PiShieldPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldPlusThin"


class PiShieldSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldSlashThin"


class PiShieldStarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldStarThin"


class PiShieldThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldThin"


class PiShieldWarningThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShieldWarningThin"


class PiShirtFoldedThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShirtFoldedThin"


class PiShootingStarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShootingStarThin"


class PiShoppingBagOpenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagOpenThin"


class PiShoppingBagThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingBagThin"


class PiShoppingCartSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartSimpleThin"


class PiShoppingCartThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShoppingCartThin"


class PiShowerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShowerThin"


class PiShrimpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShrimpThin"


class PiShuffleAngularThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleAngularThin"


class PiShuffleSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleSimpleThin"


class PiShuffleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiShuffleThin"


class PiSidebarSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarSimpleThin"


class PiSidebarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSidebarThin"


class PiSigmaThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSigmaThin"


class PiSignInThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignInThin"


class PiSignOutThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignOutThin"


class PiSignatureThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignatureThin"


class PiSignpostThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSignpostThin"


class PiSimCardThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSimCardThin"


class PiSirenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSirenThin"


class PiSketchLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSketchLogoThin"


class PiSkipBackCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackCircleThin"


class PiSkipBackThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipBackThin"


class PiSkipForwardCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardCircleThin"


class PiSkipForwardThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkipForwardThin"


class PiSkullThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSkullThin"


class PiSlackLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlackLogoThin"


class PiSlidersHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersHorizontalThin"


class PiSlidersThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlidersThin"


class PiSlideshowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSlideshowThin"


class PiSmileyAngryThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyAngryThin"


class PiSmileyBlankThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyBlankThin"


class PiSmileyMehThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyMehThin"


class PiSmileyNervousThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyNervousThin"


class PiSmileySadThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileySadThin"


class PiSmileyStickerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyStickerThin"


class PiSmileyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyThin"


class PiSmileyWinkThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyWinkThin"


class PiSmileyXEyesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSmileyXEyesThin"


class PiSnapchatLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnapchatLogoThin"


class PiSneakerMoveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerMoveThin"


class PiSneakerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSneakerThin"


class PiSnowflakeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSnowflakeThin"


class PiSoccerBallThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoccerBallThin"


class PiSortAscendingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortAscendingThin"


class PiSortDescendingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSortDescendingThin"


class PiSoundcloudLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSoundcloudLogoThin"


class PiSpadeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpadeThin"


class PiSparkleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSparkleThin"


class PiSpeakerHifiThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHifiThin"


class PiSpeakerHighThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerHighThin"


class PiSpeakerLowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerLowThin"


class PiSpeakerNoneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerNoneThin"


class PiSpeakerSimpleHighThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleHighThin"


class PiSpeakerSimpleLowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleLowThin"


class PiSpeakerSimpleNoneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleNoneThin"


class PiSpeakerSimpleSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleSlashThin"


class PiSpeakerSimpleXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSimpleXThin"


class PiSpeakerSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerSlashThin"


class PiSpeakerXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpeakerXThin"


class PiSpinnerGapThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerGapThin"


class PiSpinnerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpinnerThin"


class PiSpiralThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpiralThin"


class PiSplitHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitHorizontalThin"


class PiSplitVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSplitVerticalThin"


class PiSpotifyLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSpotifyLogoThin"


class PiSquareHalfBottomThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfBottomThin"


class PiSquareHalfThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareHalfThin"


class PiSquareLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareLogoThin"


class PiSquareSplitHorizontalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitHorizontalThin"


class PiSquareSplitVerticalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareSplitVerticalThin"


class PiSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquareThin"


class PiSquaresFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSquaresFourThin"


class PiStackOverflowLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackOverflowLogoThin"


class PiStackSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackSimpleThin"


class PiStackThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStackThin"


class PiStairsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStairsThin"


class PiStampThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStampThin"


class PiStarAndCrescentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarAndCrescentThin"


class PiStarFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarFourThin"


class PiStarHalfThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarHalfThin"


class PiStarOfDavidThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarOfDavidThin"


class PiStarThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStarThin"


class PiSteeringWheelThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSteeringWheelThin"


class PiStepsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStepsThin"


class PiStethoscopeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStethoscopeThin"


class PiStickerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStickerThin"


class PiStoolThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStoolThin"


class PiStopCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopCircleThin"


class PiStopThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStopThin"


class PiStorefrontThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStorefrontThin"


class PiStrategyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStrategyThin"


class PiStripeLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStripeLogoThin"


class PiStudentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiStudentThin"


class PiSubtitlesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtitlesThin"


class PiSubtractSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractSquareThin"


class PiSubtractThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSubtractThin"


class PiSuitcaseRollingThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseRollingThin"


class PiSuitcaseSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseSimpleThin"


class PiSuitcaseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSuitcaseThin"


class PiSunDimThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunDimThin"


class PiSunHorizonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunHorizonThin"


class PiSunThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunThin"


class PiSunglassesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSunglassesThin"


class PiSwapThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwapThin"


class PiSwatchesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwatchesThin"


class PiSwimmingPoolThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwimmingPoolThin"


class PiSwordThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSwordThin"


class PiSynagogueThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSynagogueThin"


class PiSyringeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiSyringeThin"


class PiTShirtThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTShirtThin"


class PiTableThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTableThin"


class PiTabsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTabsThin"


class PiTagChevronThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagChevronThin"


class PiTagSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagSimpleThin"


class PiTagThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTagThin"


class PiTargetThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTargetThin"


class PiTaxiThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTaxiThin"


class PiTelegramLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelegramLogoThin"


class PiTelevisionSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionSimpleThin"


class PiTelevisionThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTelevisionThin"


class PiTennisBallThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTennisBallThin"


class PiTentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTentThin"


class PiTerminalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalThin"


class PiTerminalWindowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTerminalWindowThin"


class PiTestTubeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTestTubeThin"


class PiTextAUnderlineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAUnderlineThin"


class PiTextAaThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAaThin"


class PiTextAlignCenterThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignCenterThin"


class PiTextAlignJustifyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignJustifyThin"


class PiTextAlignLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignLeftThin"


class PiTextAlignRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextAlignRightThin"


class PiTextBThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextBThin"


class PiTextColumnsThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextColumnsThin"


class PiTextHFiveThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFiveThin"


class PiTextHFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHFourThin"


class PiTextHOneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHOneThin"


class PiTextHSixThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHSixThin"


class PiTextHThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHThin"


class PiTextHThreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHThreeThin"


class PiTextHTwoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextHTwoThin"


class PiTextIndentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextIndentThin"


class PiTextItalicThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextItalicThin"


class PiTextOutdentThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextOutdentThin"


class PiTextStrikethroughThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextStrikethroughThin"


class PiTextTThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextTThin"


class PiTextUnderlineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextUnderlineThin"


class PiTextboxThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTextboxThin"


class PiThermometerColdThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerColdThin"


class PiThermometerHotThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerHotThin"


class PiThermometerSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerSimpleThin"


class PiThermometerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiThermometerThin"


class PiThumbsDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsDownThin"


class PiThumbsUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiThumbsUpThin"


class PiTicketThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTicketThin"


class PiTidalLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTidalLogoThin"


class PiTiktokLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTiktokLogoThin"


class PiTimerThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTimerThin"


class PiTipiThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTipiThin"


class PiToggleLeftThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleLeftThin"


class PiToggleRightThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiToggleRightThin"


class PiToiletPaperThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletPaperThin"


class PiToiletThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiToiletThin"


class PiToolboxThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiToolboxThin"


class PiToothThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiToothThin"


class PiToteSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteSimpleThin"


class PiToteThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiToteThin"


class PiTrademarkRegisteredThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkRegisteredThin"


class PiTrademarkThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrademarkThin"


class PiTrafficConeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficConeThin"


class PiTrafficSignThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignThin"


class PiTrafficSignalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrafficSignalThin"


class PiTrainRegionalThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainRegionalThin"


class PiTrainSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainSimpleThin"


class PiTrainThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrainThin"


class PiTramThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTramThin"


class PiTranslateThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTranslateThin"


class PiTrashSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashSimpleThin"


class PiTrashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrashThin"


class PiTrayThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrayThin"


class PiTreeEvergreenThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeEvergreenThin"


class PiTreePalmThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreePalmThin"


class PiTreeStructureThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeStructureThin"


class PiTreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTreeThin"


class PiTrendDownThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendDownThin"


class PiTrendUpThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrendUpThin"


class PiTriangleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTriangleThin"


class PiTrophyThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTrophyThin"


class PiTruckThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTruckThin"


class PiTwitchLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitchLogoThin"


class PiTwitterLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiTwitterLogoThin"


class PiUmbrellaSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaSimpleThin"


class PiUmbrellaThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUmbrellaThin"


class PiUniteSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteSquareThin"


class PiUniteThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUniteThin"


class PiUploadSimpleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadSimpleThin"


class PiUploadThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUploadThin"


class PiUsbThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsbThin"


class PiUserCircleGearThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleGearThin"


class PiUserCircleMinusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleMinusThin"


class PiUserCirclePlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCirclePlusThin"


class PiUserCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserCircleThin"


class PiUserFocusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserFocusThin"


class PiUserGearThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserGearThin"


class PiUserListThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserListThin"


class PiUserMinusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserMinusThin"


class PiUserPlusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserPlusThin"


class PiUserRectangleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserRectangleThin"


class PiUserSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSquareThin"


class PiUserSwitchThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserSwitchThin"


class PiUserThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUserThin"


class PiUsersFourThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersFourThin"


class PiUsersThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersThin"


class PiUsersThreeThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiUsersThreeThin"


class PiVanThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVanThin"


class PiVaultThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVaultThin"


class PiVibrateThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVibrateThin"


class PiVideoCameraSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraSlashThin"


class PiVideoCameraThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoCameraThin"


class PiVideoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVideoThin"


class PiVignetteThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVignetteThin"


class PiVinylRecordThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVinylRecordThin"


class PiVirtualRealityThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirtualRealityThin"


class PiVirusThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVirusThin"


class PiVoicemailThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVoicemailThin"


class PiVolleyballThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiVolleyballThin"


class PiWallThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWallThin"


class PiWalletThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWalletThin"


class PiWarehouseThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarehouseThin"


class PiWarningCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningCircleThin"


class PiWarningDiamondThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningDiamondThin"


class PiWarningOctagonThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningOctagonThin"


class PiWarningThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWarningThin"


class PiWatchThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWatchThin"


class PiWaveSawtoothThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSawtoothThin"


class PiWaveSineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSineThin"


class PiWaveSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveSquareThin"


class PiWaveTriangleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveTriangleThin"


class PiWaveformThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWaveformThin"


class PiWavesThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWavesThin"


class PiWebcamSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamSlashThin"


class PiWebcamThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebcamThin"


class PiWebhooksLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWebhooksLogoThin"


class PiWechatLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWechatLogoThin"


class PiWhatsappLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWhatsappLogoThin"


class PiWheelchairMotionThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairMotionThin"


class PiWheelchairThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWheelchairThin"


class PiWifiHighThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiHighThin"


class PiWifiLowThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiLowThin"


class PiWifiMediumThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiMediumThin"


class PiWifiNoneThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiNoneThin"


class PiWifiSlashThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiSlashThin"


class PiWifiXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWifiXThin"


class PiWindThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindThin"


class PiWindowsLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWindowsLogoThin"


class PiWineThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWineThin"


class PiWrenchThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiWrenchThin"


class PiXCircleThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiXCircleThin"


class PiXSquareThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiXSquareThin"


class PiXThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiXThin"


class PiYinYangThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiYinYangThin"


class PiYoutubeLogoThin(rx.Component):
    library = "react-icons/pi"
    tag = "PiYoutubeLogoThin"


