import reflex as rx

class Gi3DGlasses(rx.Component):
    library = "react-icons/gi"
    tag = "Gi3DGlasses"


class Gi3DHammer(rx.Component):
    library = "react-icons/gi"
    tag = "Gi3DHammer"


class Gi3DMeeple(rx.Component):
    library = "react-icons/gi"
    tag = "Gi3DMeeple"


class Gi3DStairs(rx.Component):
    library = "react-icons/gi"
    tag = "Gi3DStairs"


class GiAbacus(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbacus"


class GiAbbotMeeple(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbbotMeeple"


class GiAbdominalArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbdominalArmor"


class GiAbstract001(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract001"


class GiAbstract002(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract002"


class GiAbstract003(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract003"


class GiAbstract004(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract004"


class GiAbstract005(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract005"


class GiAbstract006(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract006"


class GiAbstract007(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract007"


class GiAbstract008(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract008"


class GiAbstract009(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract009"


class GiAbstract010(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract010"


class GiAbstract011(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract011"


class GiAbstract012(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract012"


class GiAbstract013(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract013"


class GiAbstract014(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract014"


class GiAbstract015(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract015"


class GiAbstract016(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract016"


class GiAbstract017(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract017"


class GiAbstract018(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract018"


class GiAbstract019(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract019"


class GiAbstract020(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract020"


class GiAbstract021(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract021"


class GiAbstract022(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract022"


class GiAbstract023(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract023"


class GiAbstract024(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract024"


class GiAbstract025(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract025"


class GiAbstract026(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract026"


class GiAbstract027(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract027"


class GiAbstract028(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract028"


class GiAbstract029(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract029"


class GiAbstract030(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract030"


class GiAbstract031(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract031"


class GiAbstract032(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract032"


class GiAbstract033(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract033"


class GiAbstract034(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract034"


class GiAbstract035(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract035"


class GiAbstract036(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract036"


class GiAbstract037(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract037"


class GiAbstract038(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract038"


class GiAbstract039(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract039"


class GiAbstract040(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract040"


class GiAbstract041(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract041"


class GiAbstract042(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract042"


class GiAbstract043(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract043"


class GiAbstract044(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract044"


class GiAbstract045(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract045"


class GiAbstract046(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract046"


class GiAbstract047(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract047"


class GiAbstract048(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract048"


class GiAbstract049(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract049"


class GiAbstract050(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract050"


class GiAbstract051(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract051"


class GiAbstract052(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract052"


class GiAbstract053(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract053"


class GiAbstract054(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract054"


class GiAbstract055(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract055"


class GiAbstract056(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract056"


class GiAbstract057(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract057"


class GiAbstract058(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract058"


class GiAbstract059(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract059"


class GiAbstract060(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract060"


class GiAbstract061(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract061"


class GiAbstract062(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract062"


class GiAbstract063(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract063"


class GiAbstract064(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract064"


class GiAbstract065(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract065"


class GiAbstract066(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract066"


class GiAbstract067(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract067"


class GiAbstract068(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract068"


class GiAbstract069(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract069"


class GiAbstract070(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract070"


class GiAbstract071(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract071"


class GiAbstract072(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract072"


class GiAbstract073(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract073"


class GiAbstract074(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract074"


class GiAbstract075(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract075"


class GiAbstract076(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract076"


class GiAbstract077(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract077"


class GiAbstract078(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract078"


class GiAbstract079(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract079"


class GiAbstract080(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract080"


class GiAbstract081(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract081"


class GiAbstract082(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract082"


class GiAbstract083(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract083"


class GiAbstract084(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract084"


class GiAbstract085(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract085"


class GiAbstract086(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract086"


class GiAbstract087(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract087"


class GiAbstract088(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract088"


class GiAbstract089(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract089"


class GiAbstract090(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract090"


class GiAbstract091(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract091"


class GiAbstract092(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract092"


class GiAbstract093(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract093"


class GiAbstract094(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract094"


class GiAbstract095(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract095"


class GiAbstract096(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract096"


class GiAbstract097(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract097"


class GiAbstract098(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract098"


class GiAbstract099(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract099"


class GiAbstract100(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract100"


class GiAbstract101(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract101"


class GiAbstract102(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract102"


class GiAbstract103(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract103"


class GiAbstract104(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract104"


class GiAbstract105(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract105"


class GiAbstract106(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract106"


class GiAbstract107(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract107"


class GiAbstract108(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract108"


class GiAbstract109(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract109"


class GiAbstract110(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract110"


class GiAbstract111(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract111"


class GiAbstract112(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract112"


class GiAbstract113(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract113"


class GiAbstract114(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract114"


class GiAbstract115(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract115"


class GiAbstract116(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract116"


class GiAbstract117(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract117"


class GiAbstract118(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract118"


class GiAbstract119(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract119"


class GiAbstract120(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract120"


class GiAbstract121(rx.Component):
    library = "react-icons/gi"
    tag = "GiAbstract121"


class GiAccordion(rx.Component):
    library = "react-icons/gi"
    tag = "GiAccordion"


class GiAce(rx.Component):
    library = "react-icons/gi"
    tag = "GiAce"


class GiAchievement(rx.Component):
    library = "react-icons/gi"
    tag = "GiAchievement"


class GiAchillesHeel(rx.Component):
    library = "react-icons/gi"
    tag = "GiAchillesHeel"


class GiAcidBlob(rx.Component):
    library = "react-icons/gi"
    tag = "GiAcidBlob"


class GiAcidTube(rx.Component):
    library = "react-icons/gi"
    tag = "GiAcidTube"


class GiAcid(rx.Component):
    library = "react-icons/gi"
    tag = "GiAcid"


class GiAcorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiAcorn"


class GiAcousticMegaphone(rx.Component):
    library = "react-icons/gi"
    tag = "GiAcousticMegaphone"


class GiAcrobatic(rx.Component):
    library = "react-icons/gi"
    tag = "GiAcrobatic"


class GiAerialSignal(rx.Component):
    library = "react-icons/gi"
    tag = "GiAerialSignal"


class GiAerodynamicHarpoon(rx.Component):
    library = "react-icons/gi"
    tag = "GiAerodynamicHarpoon"


class GiAerosol(rx.Component):
    library = "react-icons/gi"
    tag = "GiAerosol"


class GiAfrica(rx.Component):
    library = "react-icons/gi"
    tag = "GiAfrica"


class GiAfterburn(rx.Component):
    library = "react-icons/gi"
    tag = "GiAfterburn"


class GiAgave(rx.Component):
    library = "react-icons/gi"
    tag = "GiAgave"


class GiAges(rx.Component):
    library = "react-icons/gi"
    tag = "GiAges"


class GiAirBalloon(rx.Component):
    library = "react-icons/gi"
    tag = "GiAirBalloon"


class GiAirForce(rx.Component):
    library = "react-icons/gi"
    tag = "GiAirForce"


class GiAirMan(rx.Component):
    library = "react-icons/gi"
    tag = "GiAirMan"


class GiAirZigzag(rx.Component):
    library = "react-icons/gi"
    tag = "GiAirZigzag"


class GiAirplaneArrival(rx.Component):
    library = "react-icons/gi"
    tag = "GiAirplaneArrival"


class GiAirplaneDeparture(rx.Component):
    library = "react-icons/gi"
    tag = "GiAirplaneDeparture"


class GiAirplane(rx.Component):
    library = "react-icons/gi"
    tag = "GiAirplane"


class GiAirtightHatch(rx.Component):
    library = "react-icons/gi"
    tag = "GiAirtightHatch"


class GiAk47(rx.Component):
    library = "react-icons/gi"
    tag = "GiAk47"


class GiAk47U(rx.Component):
    library = "react-icons/gi"
    tag = "GiAk47U"


class GiAkhet(rx.Component):
    library = "react-icons/gi"
    tag = "GiAkhet"


class GiAlarmClock(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlarmClock"


class GiAlgae(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlgae"


class GiAlgeria(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlgeria"


class GiAlienBug(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlienBug"


class GiAlienEgg(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlienEgg"


class GiAlienFire(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlienFire"


class GiAlienSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlienSkull"


class GiAlienStare(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlienStare"


class GiAllForOne(rx.Component):
    library = "react-icons/gi"
    tag = "GiAllForOne"


class GiAllSeeingEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiAllSeeingEye"


class GiAlliedStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlliedStar"


class GiAlligatorClip(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlligatorClip"


class GiAlmond(rx.Component):
    library = "react-icons/gi"
    tag = "GiAlmond"


class GiAmberMosquito(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmberMosquito"


class GiAmbulance(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmbulance"


class GiAmericanFootballBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmericanFootballBall"


class GiAmericanFootballHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmericanFootballHelmet"


class GiAmericanFootballPlayer(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmericanFootballPlayer"


class GiAmericanShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmericanShield"


class GiAmethyst(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmethyst"


class GiAmmoBox(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmmoBox"


class GiAmmoniteFossil(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmmoniteFossil"


class GiAmmonite(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmmonite"


class GiAmphora(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmphora"


class GiAmpleDress(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmpleDress"


class GiAmplitude(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmplitude"


class GiAmputation(rx.Component):
    library = "react-icons/gi"
    tag = "GiAmputation"


class GiAnarchy(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnarchy"


class GiAnatomy(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnatomy"


class GiAnchor(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnchor"


class GiAncientColumns(rx.Component):
    library = "react-icons/gi"
    tag = "GiAncientColumns"


class GiAncientRuins(rx.Component):
    library = "react-icons/gi"
    tag = "GiAncientRuins"


class GiAncientScrew(rx.Component):
    library = "react-icons/gi"
    tag = "GiAncientScrew"


class GiAncientSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiAncientSword"


class GiAndroidMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiAndroidMask"


class GiAndromedaChain(rx.Component):
    library = "react-icons/gi"
    tag = "GiAndromedaChain"


class GiAngelOutfit(rx.Component):
    library = "react-icons/gi"
    tag = "GiAngelOutfit"


class GiAngelWings(rx.Component):
    library = "react-icons/gi"
    tag = "GiAngelWings"


class GiAnglerFish(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnglerFish"


class GiAngola(rx.Component):
    library = "react-icons/gi"
    tag = "GiAngola"


class GiAngryEyes(rx.Component):
    library = "react-icons/gi"
    tag = "GiAngryEyes"


class GiAngularSpider(rx.Component):
    library = "react-icons/gi"
    tag = "GiAngularSpider"


class GiAnimalHide(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnimalHide"


class GiAnimalSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnimalSkull"


class GiAnkh(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnkh"


class GiAnnexation(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnnexation"


class GiAnt(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnt"


class GiAntarctica(rx.Component):
    library = "react-icons/gi"
    tag = "GiAntarctica"


class GiAnteater(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnteater"


class GiAnthem(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnthem"


class GiAntiAircraftGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiAntiAircraftGun"


class GiAntibody(rx.Component):
    library = "react-icons/gi"
    tag = "GiAntibody"


class GiAnticlockwiseRotation(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnticlockwiseRotation"


class GiAnts(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnts"


class GiAnubis(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnubis"


class GiAnvilImpact(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnvilImpact"


class GiAnvil(rx.Component):
    library = "react-icons/gi"
    tag = "GiAnvil"


class GiApc(rx.Component):
    library = "react-icons/gi"
    tag = "GiApc"


class GiApolloCapsule(rx.Component):
    library = "react-icons/gi"
    tag = "GiApolloCapsule"


class GiApothecary(rx.Component):
    library = "react-icons/gi"
    tag = "GiApothecary"


class GiAppleCore(rx.Component):
    library = "react-icons/gi"
    tag = "GiAppleCore"


class GiAppleMaggot(rx.Component):
    library = "react-icons/gi"
    tag = "GiAppleMaggot"


class GiAppleSeeds(rx.Component):
    library = "react-icons/gi"
    tag = "GiAppleSeeds"


class GiAquarium(rx.Component):
    library = "react-icons/gi"
    tag = "GiAquarium"


class GiAquarius(rx.Component):
    library = "react-icons/gi"
    tag = "GiAquarius"


class GiAqueduct(rx.Component):
    library = "react-icons/gi"
    tag = "GiAqueduct"


class GiArabicDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiArabicDoor"


class GiArcTriomphe(rx.Component):
    library = "react-icons/gi"
    tag = "GiArcTriomphe"


class GiArchBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiArchBridge"


class GiArchaeopteryxFossil(rx.Component):
    library = "react-icons/gi"
    tag = "GiArchaeopteryxFossil"


class GiArcher(rx.Component):
    library = "react-icons/gi"
    tag = "GiArcher"


class GiArcheryTarget(rx.Component):
    library = "react-icons/gi"
    tag = "GiArcheryTarget"


class GiArchitectMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiArchitectMask"


class GiArchiveRegister(rx.Component):
    library = "react-icons/gi"
    tag = "GiArchiveRegister"


class GiArchiveResearch(rx.Component):
    library = "react-icons/gi"
    tag = "GiArchiveResearch"


class GiArcingBolt(rx.Component):
    library = "react-icons/gi"
    tag = "GiArcingBolt"


class GiArena(rx.Component):
    library = "react-icons/gi"
    tag = "GiArena"


class GiAries(rx.Component):
    library = "react-icons/gi"
    tag = "GiAries"


class GiArmBandage(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmBandage"


class GiArmSling(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmSling"


class GiArm(rx.Component):
    library = "react-icons/gi"
    tag = "GiArm"


class GiArmadilloTail(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmadilloTail"


class GiArmadillo(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmadillo"


class GiArmorDowngrade(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmorDowngrade"


class GiArmorPunch(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmorPunch"


class GiArmorUpgrade(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmorUpgrade"


class GiArmorVest(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmorVest"


class GiArmoredBoomerang(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmoredBoomerang"


class GiArmoredPants(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmoredPants"


class GiArmouredShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiArmouredShell"


class GiArrest(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrest"


class GiArrowCluster(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrowCluster"


class GiArrowCursor(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrowCursor"


class GiArrowDunk(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrowDunk"


class GiArrowFlights(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrowFlights"


class GiArrowScope(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrowScope"


class GiArrowWings(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrowWings"


class GiArrowed(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrowed"


class GiArrowhead(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrowhead"


class GiArrowsShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiArrowsShield"


class GiArson(rx.Component):
    library = "react-icons/gi"
    tag = "GiArson"


class GiArtificialHive(rx.Component):
    library = "react-icons/gi"
    tag = "GiArtificialHive"


class GiArtificialIntelligence(rx.Component):
    library = "react-icons/gi"
    tag = "GiArtificialIntelligence"


class GiArtilleryShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiArtilleryShell"


class GiAscendingBlock(rx.Component):
    library = "react-icons/gi"
    tag = "GiAscendingBlock"


class GiAsianLantern(rx.Component):
    library = "react-icons/gi"
    tag = "GiAsianLantern"


class GiAsparagus(rx.Component):
    library = "react-icons/gi"
    tag = "GiAsparagus"


class GiAspergillum(rx.Component):
    library = "react-icons/gi"
    tag = "GiAspergillum"


class GiAssassinPocket(rx.Component):
    library = "react-icons/gi"
    tag = "GiAssassinPocket"


class GiAsteroid(rx.Component):
    library = "react-icons/gi"
    tag = "GiAsteroid"


class GiAstrolabe(rx.Component):
    library = "react-icons/gi"
    tag = "GiAstrolabe"


class GiAstronautHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiAstronautHelmet"


class GiAtSea(rx.Component):
    library = "react-icons/gi"
    tag = "GiAtSea"


class GiAtlas(rx.Component):
    library = "react-icons/gi"
    tag = "GiAtlas"


class GiAtomCore(rx.Component):
    library = "react-icons/gi"
    tag = "GiAtomCore"


class GiAtom(rx.Component):
    library = "react-icons/gi"
    tag = "GiAtom"


class GiAtomicSlashes(rx.Component):
    library = "react-icons/gi"
    tag = "GiAtomicSlashes"


class GiAttachedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiAttachedShield"


class GiAubergine(rx.Component):
    library = "react-icons/gi"
    tag = "GiAubergine"


class GiAudioCassette(rx.Component):
    library = "react-icons/gi"
    tag = "GiAudioCassette"


class GiAura(rx.Component):
    library = "react-icons/gi"
    tag = "GiAura"


class GiAustralia(rx.Component):
    library = "react-icons/gi"
    tag = "GiAustralia"


class GiAutoRepair(rx.Component):
    library = "react-icons/gi"
    tag = "GiAutoRepair"


class GiAutogun(rx.Component):
    library = "react-icons/gi"
    tag = "GiAutogun"


class GiAutomaticSas(rx.Component):
    library = "react-icons/gi"
    tag = "GiAutomaticSas"


class GiAvocado(rx.Component):
    library = "react-icons/gi"
    tag = "GiAvocado"


class GiAvoidance(rx.Component):
    library = "react-icons/gi"
    tag = "GiAvoidance"


class GiAwareness(rx.Component):
    library = "react-icons/gi"
    tag = "GiAwareness"


class GiAxeInLog(rx.Component):
    library = "react-icons/gi"
    tag = "GiAxeInLog"


class GiAxeInStump(rx.Component):
    library = "react-icons/gi"
    tag = "GiAxeInStump"


class GiAxeSwing(rx.Component):
    library = "react-icons/gi"
    tag = "GiAxeSwing"


class GiAxeSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiAxeSword"


class GiAxolotl(rx.Component):
    library = "react-icons/gi"
    tag = "GiAxolotl"


class GiAztecCalendarSun(rx.Component):
    library = "react-icons/gi"
    tag = "GiAztecCalendarSun"


class GiAzulFlake(rx.Component):
    library = "react-icons/gi"
    tag = "GiAzulFlake"


class GiBabyBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiBabyBottle"


class GiBabyFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiBabyFace"


class GiBabyfootPlayers(rx.Component):
    library = "react-icons/gi"
    tag = "GiBabyfootPlayers"


class GiBackForth(rx.Component):
    library = "react-icons/gi"
    tag = "GiBackForth"


class GiBackPain(rx.Component):
    library = "react-icons/gi"
    tag = "GiBackPain"


class GiBackboneShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiBackboneShell"


class GiBackgammon(rx.Component):
    library = "react-icons/gi"
    tag = "GiBackgammon"


class GiBackpack(rx.Component):
    library = "react-icons/gi"
    tag = "GiBackpack"


class GiBackstab(rx.Component):
    library = "react-icons/gi"
    tag = "GiBackstab"


class GiBackup(rx.Component):
    library = "react-icons/gi"
    tag = "GiBackup"


class GiBackwardTime(rx.Component):
    library = "react-icons/gi"
    tag = "GiBackwardTime"


class GiBacon(rx.Component):
    library = "react-icons/gi"
    tag = "GiBacon"


class GiBadBreath(rx.Component):
    library = "react-icons/gi"
    tag = "GiBadBreath"


class GiBadGnome(rx.Component):
    library = "react-icons/gi"
    tag = "GiBadGnome"


class GiBagpipes(rx.Component):
    library = "react-icons/gi"
    tag = "GiBagpipes"


class GiBalaclava(rx.Component):
    library = "react-icons/gi"
    tag = "GiBalaclava"


class GiBalkenkreuz(rx.Component):
    library = "react-icons/gi"
    tag = "GiBalkenkreuz"


class GiBallGlow(rx.Component):
    library = "react-icons/gi"
    tag = "GiBallGlow"


class GiBallHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiBallHeart"


class GiBallPyramid(rx.Component):
    library = "react-icons/gi"
    tag = "GiBallPyramid"


class GiBallerinaShoes(rx.Component):
    library = "react-icons/gi"
    tag = "GiBallerinaShoes"


class GiBallista(rx.Component):
    library = "react-icons/gi"
    tag = "GiBallista"


class GiBalloonDog(rx.Component):
    library = "react-icons/gi"
    tag = "GiBalloonDog"


class GiBalloons(rx.Component):
    library = "react-icons/gi"
    tag = "GiBalloons"


class GiBambooFountain(rx.Component):
    library = "react-icons/gi"
    tag = "GiBambooFountain"


class GiBamboo(rx.Component):
    library = "react-icons/gi"
    tag = "GiBamboo"


class GiBananaBunch(rx.Component):
    library = "react-icons/gi"
    tag = "GiBananaBunch"


class GiBananaPeel(rx.Component):
    library = "react-icons/gi"
    tag = "GiBananaPeel"


class GiBananaPeeled(rx.Component):
    library = "react-icons/gi"
    tag = "GiBananaPeeled"


class GiBanana(rx.Component):
    library = "react-icons/gi"
    tag = "GiBanana"


class GiBandageRoll(rx.Component):
    library = "react-icons/gi"
    tag = "GiBandageRoll"


class GiBandaged(rx.Component):
    library = "react-icons/gi"
    tag = "GiBandaged"


class GiBandana(rx.Component):
    library = "react-icons/gi"
    tag = "GiBandana"


class GiBandit(rx.Component):
    library = "react-icons/gi"
    tag = "GiBandit"


class GiBangingGavel(rx.Component):
    library = "react-icons/gi"
    tag = "GiBangingGavel"


class GiBanjo(rx.Component):
    library = "react-icons/gi"
    tag = "GiBanjo"


class GiBank(rx.Component):
    library = "react-icons/gi"
    tag = "GiBank"


class GiBanknote(rx.Component):
    library = "react-icons/gi"
    tag = "GiBanknote"


class GiBaobab(rx.Component):
    library = "react-icons/gi"
    tag = "GiBaobab"


class GiBarStool(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarStool"


class GiBarbarian(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbarian"


class GiBarbecue(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbecue"


class GiBarbedArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbedArrow"


class GiBarbedCoil(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbedCoil"


class GiBarbedNails(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbedNails"


class GiBarbedSpear(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbedSpear"


class GiBarbedStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbedStar"


class GiBarbedSun(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbedSun"


class GiBarbedWire(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbedWire"


class GiBarbute(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarbute"


class GiBarefoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarefoot"


class GiBarn(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarn"


class GiBarracksTent(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarracksTent"


class GiBarracks(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarracks"


class GiBarrelLeak(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarrelLeak"


class GiBarrel(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarrel"


class GiBarricade(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarricade"


class GiBarrier(rx.Component):
    library = "react-icons/gi"
    tag = "GiBarrier"


class GiBaseDome(rx.Component):
    library = "react-icons/gi"
    tag = "GiBaseDome"


class GiBaseballBat(rx.Component):
    library = "react-icons/gi"
    tag = "GiBaseballBat"


class GiBaseballGlove(rx.Component):
    library = "react-icons/gi"
    tag = "GiBaseballGlove"


class GiBasket(rx.Component):
    library = "react-icons/gi"
    tag = "GiBasket"


class GiBasketballBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiBasketballBall"


class GiBasketballBasket(rx.Component):
    library = "react-icons/gi"
    tag = "GiBasketballBasket"


class GiBasketballJersey(rx.Component):
    library = "react-icons/gi"
    tag = "GiBasketballJersey"


class GiBassetHoundHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiBassetHoundHead"


class GiBassoon(rx.Component):
    library = "react-icons/gi"
    tag = "GiBassoon"


class GiBastet(rx.Component):
    library = "react-icons/gi"
    tag = "GiBastet"


class GiBatBlade(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatBlade"


class GiBatLeth(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatLeth"


class GiBatMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatMask"


class GiBatWing(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatWing"


class GiBat(rx.Component):
    library = "react-icons/gi"
    tag = "GiBat"


class GiBathtub(rx.Component):
    library = "react-icons/gi"
    tag = "GiBathtub"


class GiBaton(rx.Component):
    library = "react-icons/gi"
    tag = "GiBaton"


class GiBatteredAxe(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatteredAxe"


class GiBatteries(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatteries"


class GiBattery0(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattery0"


class GiBattery100(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattery100"


class GiBattery25(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattery25"


class GiBattery50(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattery50"


class GiBattery75(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattery75"


class GiBatteryMinus(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatteryMinus"


class GiBatteryPackAlt(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatteryPackAlt"


class GiBatteryPack(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatteryPack"


class GiBatteryPlus(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatteryPlus"


class GiBattleAxe(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattleAxe"


class GiBattleGear(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattleGear"


class GiBattleMech(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattleMech"


class GiBattleTank(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattleTank"


class GiBattleship(rx.Component):
    library = "react-icons/gi"
    tag = "GiBattleship"


class GiBatwingEmblem(rx.Component):
    library = "react-icons/gi"
    tag = "GiBatwingEmblem"


class GiBayonet(rx.Component):
    library = "react-icons/gi"
    tag = "GiBayonet"


class GiBeachBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeachBag"


class GiBeachBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeachBall"


class GiBeachBucket(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeachBucket"


class GiBeamSatellite(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeamSatellite"


class GiBeamWake(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeamWake"


class GiBeamsAura(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeamsAura"


class GiBeanstalk(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeanstalk"


class GiBearFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiBearFace"


class GiBearHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiBearHead"


class GiBeard(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeard"


class GiBeastEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeastEye"


class GiBeaver(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeaver"


class GiBedLamp(rx.Component):
    library = "react-icons/gi"
    tag = "GiBedLamp"


class GiBed(rx.Component):
    library = "react-icons/gi"
    tag = "GiBed"


class GiBee(rx.Component):
    library = "react-icons/gi"
    tag = "GiBee"


class GiBeech(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeech"


class GiBeehive(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeehive"


class GiBeerBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeerBottle"


class GiBeerHorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeerHorn"


class GiBeerStein(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeerStein"


class GiBeet(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeet"


class GiBeetleShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeetleShell"


class GiBehold(rx.Component):
    library = "react-icons/gi"
    tag = "GiBehold"


class GiBelgium(rx.Component):
    library = "react-icons/gi"
    tag = "GiBelgium"


class GiBellPepper(rx.Component):
    library = "react-icons/gi"
    tag = "GiBellPepper"


class GiBellShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiBellShield"


class GiBellows(rx.Component):
    library = "react-icons/gi"
    tag = "GiBellows"


class GiBeltArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeltArmor"


class GiBeltBuckles(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeltBuckles"


class GiBelt(rx.Component):
    library = "react-icons/gi"
    tag = "GiBelt"


class GiBerriesBowl(rx.Component):
    library = "react-icons/gi"
    tag = "GiBerriesBowl"


class GiBerryBush(rx.Component):
    library = "react-icons/gi"
    tag = "GiBerryBush"


class GiBestialFangs(rx.Component):
    library = "react-icons/gi"
    tag = "GiBestialFangs"


class GiBeveledStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiBeveledStar"


class GiBiceps(rx.Component):
    library = "react-icons/gi"
    tag = "GiBiceps"


class GiBigDiamondRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiBigDiamondRing"


class GiBigEgg(rx.Component):
    library = "react-icons/gi"
    tag = "GiBigEgg"


class GiBigGear(rx.Component):
    library = "react-icons/gi"
    tag = "GiBigGear"


class GiBigWave(rx.Component):
    library = "react-icons/gi"
    tag = "GiBigWave"


class GiBilledCap(rx.Component):
    library = "react-icons/gi"
    tag = "GiBilledCap"


class GiBindle(rx.Component):
    library = "react-icons/gi"
    tag = "GiBindle"


class GiBinoculars(rx.Component):
    library = "react-icons/gi"
    tag = "GiBinoculars"


class GiBiohazard(rx.Component):
    library = "react-icons/gi"
    tag = "GiBiohazard"


class GiBiplane(rx.Component):
    library = "react-icons/gi"
    tag = "GiBiplane"


class GiBirchTrees(rx.Component):
    library = "react-icons/gi"
    tag = "GiBirchTrees"


class GiBirdCage(rx.Component):
    library = "react-icons/gi"
    tag = "GiBirdCage"


class GiBirdClaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiBirdClaw"


class GiBirdHouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiBirdHouse"


class GiBirdLimb(rx.Component):
    library = "react-icons/gi"
    tag = "GiBirdLimb"


class GiBirdMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiBirdMask"


class GiBirdTwitter(rx.Component):
    library = "react-icons/gi"
    tag = "GiBirdTwitter"


class GiBison(rx.Component):
    library = "react-icons/gi"
    tag = "GiBison"


class GiBlackBar(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackBar"


class GiBlackBelt(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackBelt"


class GiBlackBook(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackBook"


class GiBlackBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackBridge"


class GiBlackFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackFlag"


class GiBlackHandShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackHandShield"


class GiBlackHoleBolas(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackHoleBolas"


class GiBlackKnightHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackKnightHelm"


class GiBlackSea(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackSea"


class GiBlackball(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackball"


class GiBlackcurrant(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlackcurrant"


class GiBlacksmith(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlacksmith"


class GiBladeBite(rx.Component):
    library = "react-icons/gi"
    tag = "GiBladeBite"


class GiBladeDrag(rx.Component):
    library = "react-icons/gi"
    tag = "GiBladeDrag"


class GiBladeFall(rx.Component):
    library = "react-icons/gi"
    tag = "GiBladeFall"


class GiBlast(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlast"


class GiBlaster(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlaster"


class GiBleedingEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiBleedingEye"


class GiBleedingHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiBleedingHeart"


class GiBleedingWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiBleedingWound"


class GiBlender(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlender"


class GiBlindfold(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlindfold"


class GiBlockHouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlockHouse"


class GiBlood(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlood"


class GiBloodyStash(rx.Component):
    library = "react-icons/gi"
    tag = "GiBloodyStash"


class GiBloodySword(rx.Component):
    library = "react-icons/gi"
    tag = "GiBloodySword"


class GiBlunderbuss(rx.Component):
    library = "react-icons/gi"
    tag = "GiBlunderbuss"


class GiBo(rx.Component):
    library = "react-icons/gi"
    tag = "GiBo"


class GiBoarEnsign(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoarEnsign"


class GiBoarTusks(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoarTusks"


class GiBoar(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoar"


class GiBoatEngine(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoatEngine"


class GiBoatFishing(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoatFishing"


class GiBoatHorizon(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoatHorizon"


class GiBoatPropeller(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoatPropeller"


class GiBoba(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoba"


class GiBodyBalance(rx.Component):
    library = "react-icons/gi"
    tag = "GiBodyBalance"


class GiBodyHeight(rx.Component):
    library = "react-icons/gi"
    tag = "GiBodyHeight"


class GiBodySwapping(rx.Component):
    library = "react-icons/gi"
    tag = "GiBodySwapping"


class GiBoilingBubbles(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoilingBubbles"


class GiBokChoy(rx.Component):
    library = "react-icons/gi"
    tag = "GiBokChoy"


class GiBolas(rx.Component):
    library = "react-icons/gi"
    tag = "GiBolas"


class GiBolivia(rx.Component):
    library = "react-icons/gi"
    tag = "GiBolivia"


class GiBoltBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoltBomb"


class GiBoltCutter(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoltCutter"


class GiBoltDrop(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoltDrop"


class GiBoltEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoltEye"


class GiBoltSaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoltSaw"


class GiBoltShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoltShield"


class GiBoltSpellCast(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoltSpellCast"


class GiBolterGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiBolterGun"


class GiBomber(rx.Component):
    library = "react-icons/gi"
    tag = "GiBomber"


class GiBombingRun(rx.Component):
    library = "react-icons/gi"
    tag = "GiBombingRun"


class GiBoneGnawer(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoneGnawer"


class GiBoneKnife(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoneKnife"


class GiBoneMace(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoneMace"


class GiBonsaiTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiBonsaiTree"


class GiBookAura(rx.Component):
    library = "react-icons/gi"
    tag = "GiBookAura"


class GiBookCover(rx.Component):
    library = "react-icons/gi"
    tag = "GiBookCover"


class GiBookPile(rx.Component):
    library = "react-icons/gi"
    tag = "GiBookPile"


class GiBookStorm(rx.Component):
    library = "react-icons/gi"
    tag = "GiBookStorm"


class GiBookmark(rx.Component):
    library = "react-icons/gi"
    tag = "GiBookmark"


class GiBookmarklet(rx.Component):
    library = "react-icons/gi"
    tag = "GiBookmarklet"


class GiBookshelf(rx.Component):
    library = "react-icons/gi"
    tag = "GiBookshelf"


class GiBoombox(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoombox"


class GiBoomerangCross(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoomerangCross"


class GiBoomerangSun(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoomerangSun"


class GiBoomerang(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoomerang"


class GiBootKick(rx.Component):
    library = "react-icons/gi"
    tag = "GiBootKick"


class GiBootPrints(rx.Component):
    library = "react-icons/gi"
    tag = "GiBootPrints"


class GiBootStomp(rx.Component):
    library = "react-icons/gi"
    tag = "GiBootStomp"


class GiBoots(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoots"


class GiBooze(rx.Component):
    library = "react-icons/gi"
    tag = "GiBooze"


class GiBorderedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiBorderedShield"


class GiBossKey(rx.Component):
    library = "react-icons/gi"
    tag = "GiBossKey"


class GiBottleCap(rx.Component):
    library = "react-icons/gi"
    tag = "GiBottleCap"


class GiBottleVapors(rx.Component):
    library = "react-icons/gi"
    tag = "GiBottleVapors"


class GiBottledBolt(rx.Component):
    library = "react-icons/gi"
    tag = "GiBottledBolt"


class GiBottledShadow(rx.Component):
    library = "react-icons/gi"
    tag = "GiBottledShadow"


class GiBottomRight3DArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiBottomRight3DArrow"


class GiBoulderDash(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoulderDash"


class GiBouncingSpring(rx.Component):
    library = "react-icons/gi"
    tag = "GiBouncingSpring"


class GiBouncingSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiBouncingSword"


class GiBowArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowArrow"


class GiBowString(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowString"


class GiBowTieRibbon(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowTieRibbon"


class GiBowTie(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowTie"


class GiBowels(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowels"


class GiBowenKnot(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowenKnot"


class GiBowieKnife(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowieKnife"


class GiBowlOfRice(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowlOfRice"


class GiBowlSpiral(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowlSpiral"


class GiBowlingAlley(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowlingAlley"


class GiBowlingPin(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowlingPin"


class GiBowlingPropulsion(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowlingPropulsion"


class GiBowlingStrike(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowlingStrike"


class GiBowman(rx.Component):
    library = "react-icons/gi"
    tag = "GiBowman"


class GiBoxCutter(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoxCutter"


class GiBoxTrap(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoxTrap"


class GiBoxUnpacking(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoxUnpacking"


class GiBoxingGloveSurprise(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoxingGloveSurprise"


class GiBoxingGlove(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoxingGlove"


class GiBoxingRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiBoxingRing"


class GiBracer(rx.Component):
    library = "react-icons/gi"
    tag = "GiBracer"


class GiBracers(rx.Component):
    library = "react-icons/gi"
    tag = "GiBracers"


class GiBrainDump(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrainDump"


class GiBrainFreeze(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrainFreeze"


class GiBrainLeak(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrainLeak"


class GiBrainStem(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrainStem"


class GiBrainTentacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrainTentacle"


class GiBrain(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrain"


class GiBrainstorm(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrainstorm"


class GiBranchArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiBranchArrow"


class GiBrandyBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrandyBottle"


class GiBrasero(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrasero"


class GiBrassEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrassEye"


class GiBrassKnuckles(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrassKnuckles"


class GiBrazilFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrazilFlag"


class GiBrazil(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrazil"


class GiBreadSlice(rx.Component):
    library = "react-icons/gi"
    tag = "GiBreadSlice"


class GiBread(rx.Component):
    library = "react-icons/gi"
    tag = "GiBread"


class GiBreakingChain(rx.Component):
    library = "react-icons/gi"
    tag = "GiBreakingChain"


class GiBreastplate(rx.Component):
    library = "react-icons/gi"
    tag = "GiBreastplate"


class GiBrickPile(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrickPile"


class GiBrickWall(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrickWall"


class GiBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiBridge"


class GiBriefcase(rx.Component):
    library = "react-icons/gi"
    tag = "GiBriefcase"


class GiBrightExplosion(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrightExplosion"


class GiBroadDagger(rx.Component):
    library = "react-icons/gi"
    tag = "GiBroadDagger"


class GiBroadheadArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiBroadheadArrow"


class GiBroadsword(rx.Component):
    library = "react-icons/gi"
    tag = "GiBroadsword"


class GiBroccoli(rx.Component):
    library = "react-icons/gi"
    tag = "GiBroccoli"


class GiBrodieHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrodieHelmet"


class GiBrokenArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenArrow"


class GiBrokenAxe(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenAxe"


class GiBrokenBone(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenBone"


class GiBrokenBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenBottle"


class GiBrokenHeartZone(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenHeartZone"


class GiBrokenHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenHeart"


class GiBrokenPottery(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenPottery"


class GiBrokenRibbon(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenRibbon"


class GiBrokenShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenShield"


class GiBrokenSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenSkull"


class GiBrokenTablet(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenTablet"


class GiBrokenWall(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrokenWall"


class GiBroom(rx.Component):
    library = "react-icons/gi"
    tag = "GiBroom"


class GiBrutalHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrutalHelm"


class GiBrute(rx.Component):
    library = "react-icons/gi"
    tag = "GiBrute"


class GiBubbleField(rx.Component):
    library = "react-icons/gi"
    tag = "GiBubbleField"


class GiBubbles(rx.Component):
    library = "react-icons/gi"
    tag = "GiBubbles"


class GiBubblingBeam(rx.Component):
    library = "react-icons/gi"
    tag = "GiBubblingBeam"


class GiBubblingBowl(rx.Component):
    library = "react-icons/gi"
    tag = "GiBubblingBowl"


class GiBubblingFlask(rx.Component):
    library = "react-icons/gi"
    tag = "GiBubblingFlask"


class GiBud(rx.Component):
    library = "react-icons/gi"
    tag = "GiBud"


class GiBuffaloHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiBuffaloHead"


class GiBugNet(rx.Component):
    library = "react-icons/gi"
    tag = "GiBugNet"


class GiBugleCall(rx.Component):
    library = "react-icons/gi"
    tag = "GiBugleCall"


class GiBulb(rx.Component):
    library = "react-icons/gi"
    tag = "GiBulb"


class GiBulgaria(rx.Component):
    library = "react-icons/gi"
    tag = "GiBulgaria"


class GiBullHorns(rx.Component):
    library = "react-icons/gi"
    tag = "GiBullHorns"


class GiBull(rx.Component):
    library = "react-icons/gi"
    tag = "GiBull"


class GiBulldozer(rx.Component):
    library = "react-icons/gi"
    tag = "GiBulldozer"


class GiBulletBill(rx.Component):
    library = "react-icons/gi"
    tag = "GiBulletBill"


class GiBulletImpacts(rx.Component):
    library = "react-icons/gi"
    tag = "GiBulletImpacts"


class GiBullets(rx.Component):
    library = "react-icons/gi"
    tag = "GiBullets"


class GiBullseye(rx.Component):
    library = "react-icons/gi"
    tag = "GiBullseye"


class GiBullyMinion(rx.Component):
    library = "react-icons/gi"
    tag = "GiBullyMinion"


class GiBundleGrenade(rx.Component):
    library = "react-icons/gi"
    tag = "GiBundleGrenade"


class GiBunkBeds(rx.Component):
    library = "react-icons/gi"
    tag = "GiBunkBeds"


class GiBunkerAssault(rx.Component):
    library = "react-icons/gi"
    tag = "GiBunkerAssault"


class GiBunker(rx.Component):
    library = "react-icons/gi"
    tag = "GiBunker"


class GiBunnySlippers(rx.Component):
    library = "react-icons/gi"
    tag = "GiBunnySlippers"


class GiBuoy(rx.Component):
    library = "react-icons/gi"
    tag = "GiBuoy"


class GiBurn(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurn"


class GiBurningBlobs(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningBlobs"


class GiBurningBook(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningBook"


class GiBurningDot(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningDot"


class GiBurningEmbers(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningEmbers"


class GiBurningEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningEye"


class GiBurningForest(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningForest"


class GiBurningMeteor(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningMeteor"


class GiBurningPassion(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningPassion"


class GiBurningRoundShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningRoundShot"


class GiBurningSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningSkull"


class GiBurningTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurningTree"


class GiBurstBlob(rx.Component):
    library = "react-icons/gi"
    tag = "GiBurstBlob"


class GiBusDoors(rx.Component):
    library = "react-icons/gi"
    tag = "GiBusDoors"


class GiBusStop(rx.Component):
    library = "react-icons/gi"
    tag = "GiBusStop"


class GiBus(rx.Component):
    library = "react-icons/gi"
    tag = "GiBus"


class GiButterToast(rx.Component):
    library = "react-icons/gi"
    tag = "GiButterToast"


class GiButter(rx.Component):
    library = "react-icons/gi"
    tag = "GiButter"


class GiButterflyFlower(rx.Component):
    library = "react-icons/gi"
    tag = "GiButterflyFlower"


class GiButterflyKnife(rx.Component):
    library = "react-icons/gi"
    tag = "GiButterflyKnife"


class GiButterflyWarning(rx.Component):
    library = "react-icons/gi"
    tag = "GiButterflyWarning"


class GiButterfly(rx.Component):
    library = "react-icons/gi"
    tag = "GiButterfly"


class GiButtonFinger(rx.Component):
    library = "react-icons/gi"
    tag = "GiButtonFinger"


class GiBuyCard(rx.Component):
    library = "react-icons/gi"
    tag = "GiBuyCard"


class GiByzantinTemple(rx.Component):
    library = "react-icons/gi"
    tag = "GiByzantinTemple"


class GiC96(rx.Component):
    library = "react-icons/gi"
    tag = "GiC96"


class GiCabbage(rx.Component):
    library = "react-icons/gi"
    tag = "GiCabbage"


class GiCableStayedBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiCableStayedBridge"


class GiCactusPot(rx.Component):
    library = "react-icons/gi"
    tag = "GiCactusPot"


class GiCactusTap(rx.Component):
    library = "react-icons/gi"
    tag = "GiCactusTap"


class GiCactus(rx.Component):
    library = "react-icons/gi"
    tag = "GiCactus"


class GiCadillacHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiCadillacHelm"


class GiCaduceus(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaduceus"


class GiCaesar(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaesar"


class GiCage(rx.Component):
    library = "react-icons/gi"
    tag = "GiCage"


class GiCagedBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiCagedBall"


class GiCakeSlice(rx.Component):
    library = "react-icons/gi"
    tag = "GiCakeSlice"


class GiCalavera(rx.Component):
    library = "react-icons/gi"
    tag = "GiCalavera"


class GiCalculator(rx.Component):
    library = "react-icons/gi"
    tag = "GiCalculator"


class GiCaldera(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaldera"


class GiCalendarHalfYear(rx.Component):
    library = "react-icons/gi"
    tag = "GiCalendarHalfYear"


class GiCalendar(rx.Component):
    library = "react-icons/gi"
    tag = "GiCalendar"


class GiCaltrops(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaltrops"


class GiCamargueCross(rx.Component):
    library = "react-icons/gi"
    tag = "GiCamargueCross"


class GiCambodia(rx.Component):
    library = "react-icons/gi"
    tag = "GiCambodia"


class GiCamelHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiCamelHead"


class GiCamel(rx.Component):
    library = "react-icons/gi"
    tag = "GiCamel"


class GiCampCookingPot(rx.Component):
    library = "react-icons/gi"
    tag = "GiCampCookingPot"


class GiCampfire(rx.Component):
    library = "react-icons/gi"
    tag = "GiCampfire"


class GiCampingTent(rx.Component):
    library = "react-icons/gi"
    tag = "GiCampingTent"


class GiCancel(rx.Component):
    library = "react-icons/gi"
    tag = "GiCancel"


class GiCancer(rx.Component):
    library = "react-icons/gi"
    tag = "GiCancer"


class GiCandleFlame(rx.Component):
    library = "react-icons/gi"
    tag = "GiCandleFlame"


class GiCandleHolder(rx.Component):
    library = "react-icons/gi"
    tag = "GiCandleHolder"


class GiCandleLight(rx.Component):
    library = "react-icons/gi"
    tag = "GiCandleLight"


class GiCandleSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiCandleSkull"


class GiCandlebright(rx.Component):
    library = "react-icons/gi"
    tag = "GiCandlebright"


class GiCandles(rx.Component):
    library = "react-icons/gi"
    tag = "GiCandles"


class GiCandlestickPhone(rx.Component):
    library = "react-icons/gi"
    tag = "GiCandlestickPhone"


class GiCandyCanes(rx.Component):
    library = "react-icons/gi"
    tag = "GiCandyCanes"


class GiCannedFish(rx.Component):
    library = "react-icons/gi"
    tag = "GiCannedFish"


class GiCannister(rx.Component):
    library = "react-icons/gi"
    tag = "GiCannister"


class GiCannonBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiCannonBall"


class GiCannonShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiCannonShot"


class GiCannon(rx.Component):
    library = "react-icons/gi"
    tag = "GiCannon"


class GiCanoe(rx.Component):
    library = "react-icons/gi"
    tag = "GiCanoe"


class GiCantua(rx.Component):
    library = "react-icons/gi"
    tag = "GiCantua"


class GiCapeArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiCapeArmor"


class GiCape(rx.Component):
    library = "react-icons/gi"
    tag = "GiCape"


class GiCapitol(rx.Component):
    library = "react-icons/gi"
    tag = "GiCapitol"


class GiCapricorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiCapricorn"


class GiCaptainHatProfile(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaptainHatProfile"


class GiCapybara(rx.Component):
    library = "react-icons/gi"
    tag = "GiCapybara"


class GiCarBattery(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarBattery"


class GiCarDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarDoor"


class GiCarKey(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarKey"


class GiCarSeat(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarSeat"


class GiCarWheel(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarWheel"


class GiCarabiner(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarabiner"


class GiCarambola(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarambola"


class GiCaravan(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaravan"


class GiCaravel(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaravel"


class GiCard10Clubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard10Clubs"


class GiCard10Diamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard10Diamonds"


class GiCard10Hearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard10Hearts"


class GiCard10Spades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard10Spades"


class GiCard2Clubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard2Clubs"


class GiCard2Diamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard2Diamonds"


class GiCard2Hearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard2Hearts"


class GiCard2Spades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard2Spades"


class GiCard3Clubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard3Clubs"


class GiCard3Diamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard3Diamonds"


class GiCard3Hearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard3Hearts"


class GiCard3Spades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard3Spades"


class GiCard4Clubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard4Clubs"


class GiCard4Diamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard4Diamonds"


class GiCard4Hearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard4Hearts"


class GiCard4Spades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard4Spades"


class GiCard5Clubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard5Clubs"


class GiCard5Diamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard5Diamonds"


class GiCard5Hearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard5Hearts"


class GiCard5Spades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard5Spades"


class GiCard6Clubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard6Clubs"


class GiCard6Diamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard6Diamonds"


class GiCard6Hearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard6Hearts"


class GiCard6Spades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard6Spades"


class GiCard7Clubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard7Clubs"


class GiCard7Diamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard7Diamonds"


class GiCard7Hearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard7Hearts"


class GiCard7Spades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard7Spades"


class GiCard8Clubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard8Clubs"


class GiCard8Diamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard8Diamonds"


class GiCard8Hearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard8Hearts"


class GiCard8Spades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard8Spades"


class GiCard9Clubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard9Clubs"


class GiCard9Diamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard9Diamonds"


class GiCard9Hearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard9Hearts"


class GiCard9Spades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCard9Spades"


class GiCardAceClubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardAceClubs"


class GiCardAceDiamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardAceDiamonds"


class GiCardAceHearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardAceHearts"


class GiCardAceSpades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardAceSpades"


class GiCardBurn(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardBurn"


class GiCardDiscard(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardDiscard"


class GiCardDraw(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardDraw"


class GiCardExchange(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardExchange"


class GiCardJackClubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardJackClubs"


class GiCardJackDiamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardJackDiamonds"


class GiCardJackHearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardJackHearts"


class GiCardJackSpades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardJackSpades"


class GiCardJoker(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardJoker"


class GiCardKingClubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardKingClubs"


class GiCardKingDiamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardKingDiamonds"


class GiCardKingHearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardKingHearts"


class GiCardKingSpades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardKingSpades"


class GiCardPick(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardPick"


class GiCardPickup(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardPickup"


class GiCardPlay(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardPlay"


class GiCardQueenClubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardQueenClubs"


class GiCardQueenDiamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardQueenDiamonds"


class GiCardQueenHearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardQueenHearts"


class GiCardQueenSpades(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardQueenSpades"


class GiCardRandom(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardRandom"


class GiCardboardBoxClosed(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardboardBoxClosed"


class GiCardboardBox(rx.Component):
    library = "react-icons/gi"
    tag = "GiCardboardBox"


class GiCargoCrane(rx.Component):
    library = "react-icons/gi"
    tag = "GiCargoCrane"


class GiCargoCrate(rx.Component):
    library = "react-icons/gi"
    tag = "GiCargoCrate"


class GiCargoShip(rx.Component):
    library = "react-icons/gi"
    tag = "GiCargoShip"


class GiCarillon(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarillon"


class GiCarnivalMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarnivalMask"


class GiCarnivoreMouth(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarnivoreMouth"


class GiCarnivorousPlant(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarnivorousPlant"


class GiCarnyx(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarnyx"


class GiCarousel(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarousel"


class GiCarpetBombing(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarpetBombing"


class GiCarrier(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarrier"


class GiCarrion(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarrion"


class GiCarrot(rx.Component):
    library = "react-icons/gi"
    tag = "GiCarrot"


class GiCartwheel(rx.Component):
    library = "react-icons/gi"
    tag = "GiCartwheel"


class GiCash(rx.Component):
    library = "react-icons/gi"
    tag = "GiCash"


class GiCassowaryHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiCassowaryHead"


class GiCastleRuins(rx.Component):
    library = "react-icons/gi"
    tag = "GiCastleRuins"


class GiCastle(rx.Component):
    library = "react-icons/gi"
    tag = "GiCastle"


class GiCat(rx.Component):
    library = "react-icons/gi"
    tag = "GiCat"


class GiCatapult(rx.Component):
    library = "react-icons/gi"
    tag = "GiCatapult"


class GiCatch(rx.Component):
    library = "react-icons/gi"
    tag = "GiCatch"


class GiCaterpillar(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaterpillar"


class GiCauldron(rx.Component):
    library = "react-icons/gi"
    tag = "GiCauldron"


class GiCavalry(rx.Component):
    library = "react-icons/gi"
    tag = "GiCavalry"


class GiCaveEntrance(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaveEntrance"


class GiCaveman(rx.Component):
    library = "react-icons/gi"
    tag = "GiCaveman"


class GiCctvCamera(rx.Component):
    library = "react-icons/gi"
    tag = "GiCctvCamera"


class GiCeilingBarnacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiCeilingBarnacle"


class GiCeilingLight(rx.Component):
    library = "react-icons/gi"
    tag = "GiCeilingLight"


class GiCelebrationFire(rx.Component):
    library = "react-icons/gi"
    tag = "GiCelebrationFire"


class GiCellarBarrels(rx.Component):
    library = "react-icons/gi"
    tag = "GiCellarBarrels"


class GiCementShoes(rx.Component):
    library = "react-icons/gi"
    tag = "GiCementShoes"


class GiCentaurHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiCentaurHeart"


class GiCentaur(rx.Component):
    library = "react-icons/gi"
    tag = "GiCentaur"


class GiCentipede(rx.Component):
    library = "react-icons/gi"
    tag = "GiCentipede"


class GiCenturionHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiCenturionHelmet"


class GiCeremonialMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiCeremonialMask"


class GiChainLightning(rx.Component):
    library = "react-icons/gi"
    tag = "GiChainLightning"


class GiChainMail(rx.Component):
    library = "react-icons/gi"
    tag = "GiChainMail"


class GiChainedArrowHeads(rx.Component):
    library = "react-icons/gi"
    tag = "GiChainedArrowHeads"


class GiChainedHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiChainedHeart"


class GiChaingun(rx.Component):
    library = "react-icons/gi"
    tag = "GiChaingun"


class GiChainsaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiChainsaw"


class GiChakram(rx.Component):
    library = "react-icons/gi"
    tag = "GiChakram"


class GiChaliceDrops(rx.Component):
    library = "react-icons/gi"
    tag = "GiChaliceDrops"


class GiChalkOutlineMurder(rx.Component):
    library = "react-icons/gi"
    tag = "GiChalkOutlineMurder"


class GiChameleonGlyph(rx.Component):
    library = "react-icons/gi"
    tag = "GiChameleonGlyph"


class GiChampagneCork(rx.Component):
    library = "react-icons/gi"
    tag = "GiChampagneCork"


class GiChampions(rx.Component):
    library = "react-icons/gi"
    tag = "GiChampions"


class GiChanterelles(rx.Component):
    library = "react-icons/gi"
    tag = "GiChanterelles"


class GiCharacter(rx.Component):
    library = "react-icons/gi"
    tag = "GiCharacter"


class GiCharcuterie(rx.Component):
    library = "react-icons/gi"
    tag = "GiCharcuterie"


class GiChargedArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiChargedArrow"


class GiChargingBull(rx.Component):
    library = "react-icons/gi"
    tag = "GiChargingBull"


class GiCharging(rx.Component):
    library = "react-icons/gi"
    tag = "GiCharging"


class GiChariot(rx.Component):
    library = "react-icons/gi"
    tag = "GiChariot"


class GiCharm(rx.Component):
    library = "react-icons/gi"
    tag = "GiCharm"


class GiChart(rx.Component):
    library = "react-icons/gi"
    tag = "GiChart"


class GiChatBubble(rx.Component):
    library = "react-icons/gi"
    tag = "GiChatBubble"


class GiCheckMark(rx.Component):
    library = "react-icons/gi"
    tag = "GiCheckMark"


class GiCheckboxTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiCheckboxTree"


class GiCheckedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiCheckedShield"


class GiCheckeredDiamond(rx.Component):
    library = "react-icons/gi"
    tag = "GiCheckeredDiamond"


class GiCheckeredFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiCheckeredFlag"


class GiChecklist(rx.Component):
    library = "react-icons/gi"
    tag = "GiChecklist"


class GiCheerful(rx.Component):
    library = "react-icons/gi"
    tag = "GiCheerful"


class GiCheeseWedge(rx.Component):
    library = "react-icons/gi"
    tag = "GiCheeseWedge"


class GiChefToque(rx.Component):
    library = "react-icons/gi"
    tag = "GiChefToque"


class GiChelseaBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiChelseaBoot"


class GiChemicalArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiChemicalArrow"


class GiChemicalBolt(rx.Component):
    library = "react-icons/gi"
    tag = "GiChemicalBolt"


class GiChemicalDrop(rx.Component):
    library = "react-icons/gi"
    tag = "GiChemicalDrop"


class GiChemicalTank(rx.Component):
    library = "react-icons/gi"
    tag = "GiChemicalTank"


class GiCherish(rx.Component):
    library = "react-icons/gi"
    tag = "GiCherish"


class GiCherry(rx.Component):
    library = "react-icons/gi"
    tag = "GiCherry"


class GiChessBishop(rx.Component):
    library = "react-icons/gi"
    tag = "GiChessBishop"


class GiChessKing(rx.Component):
    library = "react-icons/gi"
    tag = "GiChessKing"


class GiChessKnight(rx.Component):
    library = "react-icons/gi"
    tag = "GiChessKnight"


class GiChessPawn(rx.Component):
    library = "react-icons/gi"
    tag = "GiChessPawn"


class GiChessQueen(rx.Component):
    library = "react-icons/gi"
    tag = "GiChessQueen"


class GiChessRook(rx.Component):
    library = "react-icons/gi"
    tag = "GiChessRook"


class GiChestArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiChestArmor"


class GiChest(rx.Component):
    library = "react-icons/gi"
    tag = "GiChest"


class GiChestnutLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiChestnutLeaf"


class GiChewedHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiChewedHeart"


class GiChewedSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiChewedSkull"


class GiChickenLeg(rx.Component):
    library = "react-icons/gi"
    tag = "GiChickenLeg"


class GiChickenOven(rx.Component):
    library = "react-icons/gi"
    tag = "GiChickenOven"


class GiChicken(rx.Component):
    library = "react-icons/gi"
    tag = "GiChicken"


class GiChiliPepper(rx.Component):
    library = "react-icons/gi"
    tag = "GiChiliPepper"


class GiChimney(rx.Component):
    library = "react-icons/gi"
    tag = "GiChimney"


class GiChipsBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiChipsBag"


class GiChisel(rx.Component):
    library = "react-icons/gi"
    tag = "GiChisel"


class GiChocolateBar(rx.Component):
    library = "react-icons/gi"
    tag = "GiChocolateBar"


class GiChoice(rx.Component):
    library = "react-icons/gi"
    tag = "GiChoice"


class GiChoppedSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiChoppedSkull"


class GiChopsticks(rx.Component):
    library = "react-icons/gi"
    tag = "GiChopsticks"


class GiChurch(rx.Component):
    library = "react-icons/gi"
    tag = "GiChurch"


class GiCigale(rx.Component):
    library = "react-icons/gi"
    tag = "GiCigale"


class GiCigar(rx.Component):
    library = "react-icons/gi"
    tag = "GiCigar"


class GiCigarette(rx.Component):
    library = "react-icons/gi"
    tag = "GiCigarette"


class GiCircleCage(rx.Component):
    library = "react-icons/gi"
    tag = "GiCircleCage"


class GiCircleClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiCircleClaws"


class GiCircleForest(rx.Component):
    library = "react-icons/gi"
    tag = "GiCircleForest"


class GiCircleSparks(rx.Component):
    library = "react-icons/gi"
    tag = "GiCircleSparks"


class GiCircle(rx.Component):
    library = "react-icons/gi"
    tag = "GiCircle"


class GiCirclingFish(rx.Component):
    library = "react-icons/gi"
    tag = "GiCirclingFish"


class GiCircuitry(rx.Component):
    library = "react-icons/gi"
    tag = "GiCircuitry"


class GiCircularSaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiCircularSaw"


class GiCircularSawblade(rx.Component):
    library = "react-icons/gi"
    tag = "GiCircularSawblade"


class GiCityCar(rx.Component):
    library = "react-icons/gi"
    tag = "GiCityCar"


class GiClamp(rx.Component):
    library = "react-icons/gi"
    tag = "GiClamp"


class GiClapperboard(rx.Component):
    library = "react-icons/gi"
    tag = "GiClapperboard"


class GiClarinet(rx.Component):
    library = "react-icons/gi"
    tag = "GiClarinet"


class GiClassicalKnowledge(rx.Component):
    library = "react-icons/gi"
    tag = "GiClassicalKnowledge"


class GiClawHammer(rx.Component):
    library = "react-icons/gi"
    tag = "GiClawHammer"


class GiClawSlashes(rx.Component):
    library = "react-icons/gi"
    tag = "GiClawSlashes"


class GiClawString(rx.Component):
    library = "react-icons/gi"
    tag = "GiClawString"


class GiClaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiClaw"


class GiClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiClaws"


class GiClayBrick(rx.Component):
    library = "react-icons/gi"
    tag = "GiClayBrick"


class GiClaymoreExplosive(rx.Component):
    library = "react-icons/gi"
    tag = "GiClaymoreExplosive"


class GiCleaver(rx.Component):
    library = "react-icons/gi"
    tag = "GiCleaver"


class GiCleopatra(rx.Component):
    library = "react-icons/gi"
    tag = "GiCleopatra"


class GiClick(rx.Component):
    library = "react-icons/gi"
    tag = "GiClick"


class GiCliffCrossing(rx.Component):
    library = "react-icons/gi"
    tag = "GiCliffCrossing"


class GiCloakDagger(rx.Component):
    library = "react-icons/gi"
    tag = "GiCloakDagger"


class GiCloak(rx.Component):
    library = "react-icons/gi"
    tag = "GiCloak"


class GiClockwiseRotation(rx.Component):
    library = "react-icons/gi"
    tag = "GiClockwiseRotation"


class GiClockwork(rx.Component):
    library = "react-icons/gi"
    tag = "GiClockwork"


class GiClosedBarbute(rx.Component):
    library = "react-icons/gi"
    tag = "GiClosedBarbute"


class GiClosedDoors(rx.Component):
    library = "react-icons/gi"
    tag = "GiClosedDoors"


class GiClothJar(rx.Component):
    library = "react-icons/gi"
    tag = "GiClothJar"


class GiClothes(rx.Component):
    library = "react-icons/gi"
    tag = "GiClothes"


class GiClothesline(rx.Component):
    library = "react-icons/gi"
    tag = "GiClothesline"


class GiClothespin(rx.Component):
    library = "react-icons/gi"
    tag = "GiClothespin"


class GiCloudDownload(rx.Component):
    library = "react-icons/gi"
    tag = "GiCloudDownload"


class GiCloudRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiCloudRing"


class GiCloudUpload(rx.Component):
    library = "react-icons/gi"
    tag = "GiCloudUpload"


class GiCloudyFork(rx.Component):
    library = "react-icons/gi"
    tag = "GiCloudyFork"


class GiClout(rx.Component):
    library = "react-icons/gi"
    tag = "GiClout"


class GiCloverSpiked(rx.Component):
    library = "react-icons/gi"
    tag = "GiCloverSpiked"


class GiClover(rx.Component):
    library = "react-icons/gi"
    tag = "GiClover"


class GiClown(rx.Component):
    library = "react-icons/gi"
    tag = "GiClown"


class GiClownfish(rx.Component):
    library = "react-icons/gi"
    tag = "GiClownfish"


class GiClubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiClubs"


class GiClusterBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiClusterBomb"


class GiCoaDeJima(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoaDeJima"


class GiCoalPile(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoalPile"


class GiCoalWagon(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoalWagon"


class GiCobra(rx.Component):
    library = "react-icons/gi"
    tag = "GiCobra"


class GiCobweb(rx.Component):
    library = "react-icons/gi"
    tag = "GiCobweb"


class GiCoconuts(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoconuts"


class GiCoffeeBeans(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoffeeBeans"


class GiCoffeeCup(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoffeeCup"


class GiCoffeeMug(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoffeeMug"


class GiCoffeePot(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoffeePot"


class GiCoffin(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoffin"


class GiCogLock(rx.Component):
    library = "react-icons/gi"
    tag = "GiCogLock"


class GiCog(rx.Component):
    library = "react-icons/gi"
    tag = "GiCog"


class GiCogsplosion(rx.Component):
    library = "react-icons/gi"
    tag = "GiCogsplosion"


class GiCoiledNail(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoiledNail"


class GiCoilingCurl(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoilingCurl"


class GiCoinflip(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoinflip"


class GiCoinsPile(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoinsPile"


class GiCoins(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoins"


class GiColdHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiColdHeart"


class GiColiseum(rx.Component):
    library = "react-icons/gi"
    tag = "GiColiseum"


class GiColombia(rx.Component):
    library = "react-icons/gi"
    tag = "GiColombia"


class GiColombianStatue(rx.Component):
    library = "react-icons/gi"
    tag = "GiColombianStatue"


class GiColtM1911(rx.Component):
    library = "react-icons/gi"
    tag = "GiColtM1911"


class GiColumnVase(rx.Component):
    library = "react-icons/gi"
    tag = "GiColumnVase"


class GiComa(rx.Component):
    library = "react-icons/gi"
    tag = "GiComa"


class GiComb(rx.Component):
    library = "react-icons/gi"
    tag = "GiComb"


class GiCombinationLock(rx.Component):
    library = "react-icons/gi"
    tag = "GiCombinationLock"


class GiCometSpark(rx.Component):
    library = "react-icons/gi"
    tag = "GiCometSpark"


class GiCommercialAirplane(rx.Component):
    library = "react-icons/gi"
    tag = "GiCommercialAirplane"


class GiCompactDisc(rx.Component):
    library = "react-icons/gi"
    tag = "GiCompactDisc"


class GiCompanionCube(rx.Component):
    library = "react-icons/gi"
    tag = "GiCompanionCube"


class GiCompass(rx.Component):
    library = "react-icons/gi"
    tag = "GiCompass"


class GiComputerFan(rx.Component):
    library = "react-icons/gi"
    tag = "GiComputerFan"


class GiComputing(rx.Component):
    library = "react-icons/gi"
    tag = "GiComputing"


class GiConcentrationOrb(rx.Component):
    library = "react-icons/gi"
    tag = "GiConcentrationOrb"


class GiConcentricCrescents(rx.Component):
    library = "react-icons/gi"
    tag = "GiConcentricCrescents"


class GiConcreteBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiConcreteBag"


class GiCondorEmblem(rx.Component):
    library = "react-icons/gi"
    tag = "GiCondorEmblem"


class GiCondyluraSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiCondyluraSkull"


class GiConfirmed(rx.Component):
    library = "react-icons/gi"
    tag = "GiConfirmed"


class GiConfrontation(rx.Component):
    library = "react-icons/gi"
    tag = "GiConfrontation"


class GiCongress(rx.Component):
    library = "react-icons/gi"
    tag = "GiCongress"


class GiConqueror(rx.Component):
    library = "react-icons/gi"
    tag = "GiConqueror"


class GiConsoleController(rx.Component):
    library = "react-icons/gi"
    tag = "GiConsoleController"


class GiContortionist(rx.Component):
    library = "react-icons/gi"
    tag = "GiContortionist"


class GiContract(rx.Component):
    library = "react-icons/gi"
    tag = "GiContract"


class GiControlTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiControlTower"


class GiConvergenceTarget(rx.Component):
    library = "react-icons/gi"
    tag = "GiConvergenceTarget"


class GiConversation(rx.Component):
    library = "react-icons/gi"
    tag = "GiConversation"


class GiConverseShoe(rx.Component):
    library = "react-icons/gi"
    tag = "GiConverseShoe"


class GiConvict(rx.Component):
    library = "react-icons/gi"
    tag = "GiConvict"


class GiConvince(rx.Component):
    library = "react-icons/gi"
    tag = "GiConvince"


class GiConwayLifeGlider(rx.Component):
    library = "react-icons/gi"
    tag = "GiConwayLifeGlider"


class GiCook(rx.Component):
    library = "react-icons/gi"
    tag = "GiCook"


class GiCookie(rx.Component):
    library = "react-icons/gi"
    tag = "GiCookie"


class GiCookingGlove(rx.Component):
    library = "react-icons/gi"
    tag = "GiCookingGlove"


class GiCookingPot(rx.Component):
    library = "react-icons/gi"
    tag = "GiCookingPot"


class GiCoolSpices(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoolSpices"


class GiCooler(rx.Component):
    library = "react-icons/gi"
    tag = "GiCooler"


class GiCootieCatcher(rx.Component):
    library = "react-icons/gi"
    tag = "GiCootieCatcher"


class GiCoral(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoral"


class GiCorkHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiCorkHat"


class GiCorkedTube(rx.Component):
    library = "react-icons/gi"
    tag = "GiCorkedTube"


class GiCorkscrew(rx.Component):
    library = "react-icons/gi"
    tag = "GiCorkscrew"


class GiCorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiCorn"


class GiCornerExplosion(rx.Component):
    library = "react-icons/gi"
    tag = "GiCornerExplosion"


class GiCornerFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiCornerFlag"


class GiCornucopia(rx.Component):
    library = "react-icons/gi"
    tag = "GiCornucopia"


class GiCoronation(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoronation"


class GiCorporal(rx.Component):
    library = "react-icons/gi"
    tag = "GiCorporal"


class GiCorset(rx.Component):
    library = "react-icons/gi"
    tag = "GiCorset"


class GiCorsica(rx.Component):
    library = "react-icons/gi"
    tag = "GiCorsica"


class GiCosmicEgg(rx.Component):
    library = "react-icons/gi"
    tag = "GiCosmicEgg"


class GiCottonFlower(rx.Component):
    library = "react-icons/gi"
    tag = "GiCottonFlower"


class GiCoveredJar(rx.Component):
    library = "react-icons/gi"
    tag = "GiCoveredJar"


class GiCow(rx.Component):
    library = "react-icons/gi"
    tag = "GiCow"


class GiCowboyBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiCowboyBoot"


class GiCowboyHolster(rx.Component):
    library = "react-icons/gi"
    tag = "GiCowboyHolster"


class GiCowled(rx.Component):
    library = "react-icons/gi"
    tag = "GiCowled"


class GiCpuShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiCpuShot"


class GiCpu(rx.Component):
    library = "react-icons/gi"
    tag = "GiCpu"


class GiCrabClaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrabClaw"


class GiCrab(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrab"


class GiCrackedAlienSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrackedAlienSkull"


class GiCrackedBallDunk(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrackedBallDunk"


class GiCrackedDisc(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrackedDisc"


class GiCrackedGlass(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrackedGlass"


class GiCrackedHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrackedHelm"


class GiCrackedMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrackedMask"


class GiCrackedSaber(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrackedSaber"


class GiCrackedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrackedShield"


class GiCrafting(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrafting"


class GiCrags(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrags"


class GiCrane(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrane"


class GiCreditsCurrency(rx.Component):
    library = "react-icons/gi"
    tag = "GiCreditsCurrency"


class GiCrenelCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrenelCrown"


class GiCrenulatedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrenulatedShield"


class GiCrescentBlade(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrescentBlade"


class GiCrescentStaff(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrescentStaff"


class GiCrestedHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrestedHelmet"


class GiCricketBat(rx.Component):
    library = "react-icons/gi"
    tag = "GiCricketBat"


class GiCricket(rx.Component):
    library = "react-icons/gi"
    tag = "GiCricket"


class GiCrimeSceneTape(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrimeSceneTape"


class GiCrocJaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrocJaws"


class GiCrocSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrocSword"


class GiCroissant(rx.Component):
    library = "react-icons/gi"
    tag = "GiCroissant"


class GiCroissantsPupil(rx.Component):
    library = "react-icons/gi"
    tag = "GiCroissantsPupil"


class GiCrookFlail(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrookFlail"


class GiCrossFlare(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossFlare"


class GiCrossMark(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossMark"


class GiCrossShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossShield"


class GiCrossbow(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossbow"


class GiCrosscutSaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrosscutSaw"


class GiCrossedAirFlows(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossedAirFlows"


class GiCrossedAxes(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossedAxes"


class GiCrossedBones(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossedBones"


class GiCrossedChains(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossedChains"


class GiCrossedClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossedClaws"


class GiCrossedPistols(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossedPistols"


class GiCrossedSabres(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossedSabres"


class GiCrossedSlashes(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossedSlashes"


class GiCrossedSwords(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossedSwords"


class GiCrosshairArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrosshairArrow"


class GiCrosshair(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrosshair"


class GiCrossroad(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrossroad"


class GiCrowDive(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrowDive"


class GiCrowNest(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrowNest"


class GiCrowbar(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrowbar"


class GiCrownCoin(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrownCoin"


class GiCrownOfThorns(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrownOfThorns"


class GiCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrown"


class GiCrownedExplosion(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrownedExplosion"


class GiCrownedHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrownedHeart"


class GiCrownedSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrownedSkull"


class GiCrucifix(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrucifix"


class GiCruiser(rx.Component):
    library = "react-icons/gi"
    tag = "GiCruiser"


class GiCrumblingBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrumblingBall"


class GiCrush(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrush"


class GiCryoChamber(rx.Component):
    library = "react-icons/gi"
    tag = "GiCryoChamber"


class GiCryptEntrance(rx.Component):
    library = "react-icons/gi"
    tag = "GiCryptEntrance"


class GiCrystalBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalBall"


class GiCrystalBars(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalBars"


class GiCrystalCluster(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalCluster"


class GiCrystalEarrings(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalEarrings"


class GiCrystalEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalEye"


class GiCrystalGrowth(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalGrowth"


class GiCrystalShine(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalShine"


class GiCrystalShrine(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalShrine"


class GiCrystalWand(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalWand"


class GiCrystalize(rx.Component):
    library = "react-icons/gi"
    tag = "GiCrystalize"


class GiCuauhtli(rx.Component):
    library = "react-icons/gi"
    tag = "GiCuauhtli"


class GiCube(rx.Component):
    library = "react-icons/gi"
    tag = "GiCube"


class GiCubeforce(rx.Component):
    library = "react-icons/gi"
    tag = "GiCubeforce"


class GiCubes(rx.Component):
    library = "react-icons/gi"
    tag = "GiCubes"


class GiCuckooClock(rx.Component):
    library = "react-icons/gi"
    tag = "GiCuckooClock"


class GiCultist(rx.Component):
    library = "react-icons/gi"
    tag = "GiCultist"


class GiCupcake(rx.Component):
    library = "react-icons/gi"
    tag = "GiCupcake"


class GiCupidonArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiCupidonArrow"


class GiCurledLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiCurledLeaf"


class GiCurledTentacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiCurledTentacle"


class GiCurlingStone(rx.Component):
    library = "react-icons/gi"
    tag = "GiCurlingStone"


class GiCurlingVines(rx.Component):
    library = "react-icons/gi"
    tag = "GiCurlingVines"


class GiCurlyMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiCurlyMask"


class GiCurlyWing(rx.Component):
    library = "react-icons/gi"
    tag = "GiCurlyWing"


class GiCursedStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiCursedStar"


class GiCurvyKnife(rx.Component):
    library = "react-icons/gi"
    tag = "GiCurvyKnife"


class GiCustodianHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiCustodianHelmet"


class GiCutDiamond(rx.Component):
    library = "react-icons/gi"
    tag = "GiCutDiamond"


class GiCutLemon(rx.Component):
    library = "react-icons/gi"
    tag = "GiCutLemon"


class GiCutPalm(rx.Component):
    library = "react-icons/gi"
    tag = "GiCutPalm"


class GiCyberEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiCyberEye"


class GiCyborgFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiCyborgFace"


class GiCycle(rx.Component):
    library = "react-icons/gi"
    tag = "GiCycle"


class GiCycling(rx.Component):
    library = "react-icons/gi"
    tag = "GiCycling"


class GiCyclops(rx.Component):
    library = "react-icons/gi"
    tag = "GiCyclops"


class GiCzSkorpion(rx.Component):
    library = "react-icons/gi"
    tag = "GiCzSkorpion"


class GiD10(rx.Component):
    library = "react-icons/gi"
    tag = "GiD10"


class GiD12(rx.Component):
    library = "react-icons/gi"
    tag = "GiD12"


class GiD4(rx.Component):
    library = "react-icons/gi"
    tag = "GiD4"


class GiDaemonPull(rx.Component):
    library = "react-icons/gi"
    tag = "GiDaemonPull"


class GiDaemonSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiDaemonSkull"


class GiDaggerRose(rx.Component):
    library = "react-icons/gi"
    tag = "GiDaggerRose"


class GiDaggers(rx.Component):
    library = "react-icons/gi"
    tag = "GiDaggers"


class GiDaisy(rx.Component):
    library = "react-icons/gi"
    tag = "GiDaisy"


class GiDam(rx.Component):
    library = "react-icons/gi"
    tag = "GiDam"


class GiDamagedHouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiDamagedHouse"


class GiDandelionFlower(rx.Component):
    library = "react-icons/gi"
    tag = "GiDandelionFlower"


class GiDango(rx.Component):
    library = "react-icons/gi"
    tag = "GiDango"


class GiDarkSquad(rx.Component):
    library = "react-icons/gi"
    tag = "GiDarkSquad"


class GiDart(rx.Component):
    library = "react-icons/gi"
    tag = "GiDart"


class GiDatabase(rx.Component):
    library = "react-icons/gi"
    tag = "GiDatabase"


class GiDeadEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeadEye"


class GiDeadHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeadHead"


class GiDeadWood(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeadWood"


class GiDeadlyStrike(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeadlyStrike"


class GiDeathJuice(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeathJuice"


class GiDeathNote(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeathNote"


class GiDeathSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeathSkull"


class GiDeathStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeathStar"


class GiDeathZone(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeathZone"


class GiDeathcab(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeathcab"


class GiDecapitation(rx.Component):
    library = "react-icons/gi"
    tag = "GiDecapitation"


class GiDeerHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeerHead"


class GiDeerTrack(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeerTrack"


class GiDeer(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeer"


class GiDefenseSatellite(rx.Component):
    library = "react-icons/gi"
    tag = "GiDefenseSatellite"


class GiDefensiveWall(rx.Component):
    library = "react-icons/gi"
    tag = "GiDefensiveWall"


class GiDefibrilate(rx.Component):
    library = "react-icons/gi"
    tag = "GiDefibrilate"


class GiDekuTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiDekuTree"


class GiDelicatePerfume(rx.Component):
    library = "react-icons/gi"
    tag = "GiDelicatePerfume"


class GiDelighted(rx.Component):
    library = "react-icons/gi"
    tag = "GiDelighted"


class GiDeliveryDrone(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeliveryDrone"


class GiDemolish(rx.Component):
    library = "react-icons/gi"
    tag = "GiDemolish"


class GiDervishSwords(rx.Component):
    library = "react-icons/gi"
    tag = "GiDervishSwords"


class GiDesertEagle(rx.Component):
    library = "react-icons/gi"
    tag = "GiDesertEagle"


class GiDesertSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiDesertSkull"


class GiDesert(rx.Component):
    library = "react-icons/gi"
    tag = "GiDesert"


class GiDeshretRedCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeshretRedCrown"


class GiDeskLamp(rx.Component):
    library = "react-icons/gi"
    tag = "GiDeskLamp"


class GiDesk(rx.Component):
    library = "react-icons/gi"
    tag = "GiDesk"


class GiDespair(rx.Component):
    library = "react-icons/gi"
    tag = "GiDespair"


class GiDetonator(rx.Component):
    library = "react-icons/gi"
    tag = "GiDetonator"


class GiDetour(rx.Component):
    library = "react-icons/gi"
    tag = "GiDetour"


class GiDevilMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiDevilMask"


class GiDew(rx.Component):
    library = "react-icons/gi"
    tag = "GiDew"


class GiDiabloSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiabloSkull"


class GiDiagram(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiagram"


class GiDialPadlock(rx.Component):
    library = "react-icons/gi"
    tag = "GiDialPadlock"


class GiDiamondHard(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiamondHard"


class GiDiamondHilt(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiamondHilt"


class GiDiamondRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiamondRing"


class GiDiamondTrophy(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiamondTrophy"


class GiDiamondsSmile(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiamondsSmile"


class GiDiamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiamonds"


class GiDiceEightFacesEight(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceEightFacesEight"


class GiDiceFire(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceFire"


class GiDiceShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceShield"


class GiDiceSixFacesFive(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceSixFacesFive"


class GiDiceSixFacesFour(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceSixFacesFour"


class GiDiceSixFacesOne(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceSixFacesOne"


class GiDiceSixFacesSix(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceSixFacesSix"


class GiDiceSixFacesThree(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceSixFacesThree"


class GiDiceSixFacesTwo(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceSixFacesTwo"


class GiDiceTarget(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceTarget"


class GiDiceTwentyFacesOne(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceTwentyFacesOne"


class GiDiceTwentyFacesTwenty(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiceTwentyFacesTwenty"


class GiDigDug(rx.Component):
    library = "react-icons/gi"
    tag = "GiDigDug"


class GiDigHole(rx.Component):
    library = "react-icons/gi"
    tag = "GiDigHole"


class GiDigitalTrace(rx.Component):
    library = "react-icons/gi"
    tag = "GiDigitalTrace"


class GiDimetrodon(rx.Component):
    library = "react-icons/gi"
    tag = "GiDimetrodon"


class GiDinosaurBones(rx.Component):
    library = "react-icons/gi"
    tag = "GiDinosaurBones"


class GiDinosaurEgg(rx.Component):
    library = "react-icons/gi"
    tag = "GiDinosaurEgg"


class GiDinosaurRex(rx.Component):
    library = "react-icons/gi"
    tag = "GiDinosaurRex"


class GiDiplodocus(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiplodocus"


class GiDiploma(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiploma"


class GiDirectionSign(rx.Component):
    library = "react-icons/gi"
    tag = "GiDirectionSign"


class GiDirectionSigns(rx.Component):
    library = "react-icons/gi"
    tag = "GiDirectionSigns"


class GiDirectorChair(rx.Component):
    library = "react-icons/gi"
    tag = "GiDirectorChair"


class GiDirewolf(rx.Component):
    library = "react-icons/gi"
    tag = "GiDirewolf"


class GiDiscGolfBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiscGolfBag"


class GiDiscGolfBasket(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiscGolfBasket"


class GiDisc(rx.Component):
    library = "react-icons/gi"
    tag = "GiDisc"


class GiDiscobolus(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiscobolus"


class GiDiscussion(rx.Component):
    library = "react-icons/gi"
    tag = "GiDiscussion"


class GiDisintegrate(rx.Component):
    library = "react-icons/gi"
    tag = "GiDisintegrate"


class GiDistraction(rx.Component):
    library = "react-icons/gi"
    tag = "GiDistraction"


class GiDistressSignal(rx.Component):
    library = "react-icons/gi"
    tag = "GiDistressSignal"


class GiDivergence(rx.Component):
    library = "react-icons/gi"
    tag = "GiDivergence"


class GiDivert(rx.Component):
    library = "react-icons/gi"
    tag = "GiDivert"


class GiDividedSpiral(rx.Component):
    library = "react-icons/gi"
    tag = "GiDividedSpiral"


class GiDividedSquare(rx.Component):
    library = "react-icons/gi"
    tag = "GiDividedSquare"


class GiDivingDagger(rx.Component):
    library = "react-icons/gi"
    tag = "GiDivingDagger"


class GiDivingHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiDivingHelmet"


class GiDjedPillar(rx.Component):
    library = "react-icons/gi"
    tag = "GiDjedPillar"


class GiDjembe(rx.Component):
    library = "react-icons/gi"
    tag = "GiDjembe"


class GiDjinn(rx.Component):
    library = "react-icons/gi"
    tag = "GiDjinn"


class GiDna1(rx.Component):
    library = "react-icons/gi"
    tag = "GiDna1"


class GiDna2(rx.Component):
    library = "react-icons/gi"
    tag = "GiDna2"


class GiDoctorFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoctorFace"


class GiDodge(rx.Component):
    library = "react-icons/gi"
    tag = "GiDodge"


class GiDodging(rx.Component):
    library = "react-icons/gi"
    tag = "GiDodging"


class GiDogBowl(rx.Component):
    library = "react-icons/gi"
    tag = "GiDogBowl"


class GiDogHouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiDogHouse"


class GiDolmen(rx.Component):
    library = "react-icons/gi"
    tag = "GiDolmen"


class GiDolphin(rx.Component):
    library = "react-icons/gi"
    tag = "GiDolphin"


class GiDominoMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiDominoMask"


class GiDominoTiles(rx.Component):
    library = "react-icons/gi"
    tag = "GiDominoTiles"


class GiDonerKebab(rx.Component):
    library = "react-icons/gi"
    tag = "GiDonerKebab"


class GiDonkey(rx.Component):
    library = "react-icons/gi"
    tag = "GiDonkey"


class GiDonut(rx.Component):
    library = "react-icons/gi"
    tag = "GiDonut"


class GiDoorHandle(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoorHandle"


class GiDoorRingHandle(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoorRingHandle"


class GiDoorWatcher(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoorWatcher"


class GiDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoor"


class GiDoorway(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoorway"


class GiDorsalScales(rx.Component):
    library = "react-icons/gi"
    tag = "GiDorsalScales"


class GiDoubleDiaphragm(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubleDiaphragm"


class GiDoubleDragon(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubleDragon"


class GiDoubleFaceMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubleFaceMask"


class GiDoubleFish(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubleFish"


class GiDoubleNecklace(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubleNecklace"


class GiDoubleQuaver(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubleQuaver"


class GiDoubleRingedOrb(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubleRingedOrb"


class GiDoubleShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubleShot"


class GiDoubleStreetLights(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubleStreetLights"


class GiDoubled(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoubled"


class GiDoughRoller(rx.Component):
    library = "react-icons/gi"
    tag = "GiDoughRoller"


class GiDove(rx.Component):
    library = "react-icons/gi"
    tag = "GiDove"


class GiDozen(rx.Component):
    library = "react-icons/gi"
    tag = "GiDozen"


class GiDragonBalls(rx.Component):
    library = "react-icons/gi"
    tag = "GiDragonBalls"


class GiDragonBreath(rx.Component):
    library = "react-icons/gi"
    tag = "GiDragonBreath"


class GiDragonHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiDragonHead"


class GiDragonOrb(rx.Component):
    library = "react-icons/gi"
    tag = "GiDragonOrb"


class GiDragonShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiDragonShield"


class GiDragonSpiral(rx.Component):
    library = "react-icons/gi"
    tag = "GiDragonSpiral"


class GiDragonfly(rx.Component):
    library = "react-icons/gi"
    tag = "GiDragonfly"


class GiDrakkarDragon(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrakkarDragon"


class GiDrakkar(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrakkar"


class GiDramaMasks(rx.Component):
    library = "react-icons/gi"
    tag = "GiDramaMasks"


class GiDrawbridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrawbridge"


class GiDreadSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiDreadSkull"


class GiDread(rx.Component):
    library = "react-icons/gi"
    tag = "GiDread"


class GiDreadnought(rx.Component):
    library = "react-icons/gi"
    tag = "GiDreadnought"


class GiDreamCatcher(rx.Component):
    library = "react-icons/gi"
    tag = "GiDreamCatcher"


class GiDress(rx.Component):
    library = "react-icons/gi"
    tag = "GiDress"


class GiDrill(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrill"


class GiDrinkMe(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrinkMe"


class GiDrinking(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrinking"


class GiDrippingBlade(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrippingBlade"


class GiDrippingGoo(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrippingGoo"


class GiDrippingHoney(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrippingHoney"


class GiDrippingKnife(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrippingKnife"


class GiDrippingStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrippingStar"


class GiDrippingStone(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrippingStone"


class GiDrippingSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrippingSword"


class GiDrippingTube(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrippingTube"


class GiDropEarrings(rx.Component):
    library = "react-icons/gi"
    tag = "GiDropEarrings"


class GiDropWeapon(rx.Component):
    library = "react-icons/gi"
    tag = "GiDropWeapon"


class GiDrop(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrop"


class GiDropletSplash(rx.Component):
    library = "react-icons/gi"
    tag = "GiDropletSplash"


class GiDroplets(rx.Component):
    library = "react-icons/gi"
    tag = "GiDroplets"


class GiDrowning(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrowning"


class GiDrumKit(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrumKit"


class GiDrum(rx.Component):
    library = "react-icons/gi"
    tag = "GiDrum"


class GiDualityMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiDualityMask"


class GiDuality(rx.Component):
    library = "react-icons/gi"
    tag = "GiDuality"


class GiDuckPalm(rx.Component):
    library = "react-icons/gi"
    tag = "GiDuckPalm"


class GiDuck(rx.Component):
    library = "react-icons/gi"
    tag = "GiDuck"


class GiDuel(rx.Component):
    library = "react-icons/gi"
    tag = "GiDuel"


class GiDuffelBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiDuffelBag"


class GiDumplingBao(rx.Component):
    library = "react-icons/gi"
    tag = "GiDumplingBao"


class GiDumpling(rx.Component):
    library = "react-icons/gi"
    tag = "GiDumpling"


class GiDunceCap(rx.Component):
    library = "react-icons/gi"
    tag = "GiDunceCap"


class GiDungeonGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiDungeonGate"


class GiDungeonLight(rx.Component):
    library = "react-icons/gi"
    tag = "GiDungeonLight"


class GiDuration(rx.Component):
    library = "react-icons/gi"
    tag = "GiDuration"


class GiDustCloud(rx.Component):
    library = "react-icons/gi"
    tag = "GiDustCloud"


class GiDutchBike(rx.Component):
    library = "react-icons/gi"
    tag = "GiDutchBike"


class GiDwarfFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiDwarfFace"


class GiDwarfHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiDwarfHelmet"


class GiDwarfKing(rx.Component):
    library = "react-icons/gi"
    tag = "GiDwarfKing"


class GiDwennimmen(rx.Component):
    library = "react-icons/gi"
    tag = "GiDwennimmen"


class GiDynamite(rx.Component):
    library = "react-icons/gi"
    tag = "GiDynamite"


class GiEagleEmblem(rx.Component):
    library = "react-icons/gi"
    tag = "GiEagleEmblem"


class GiEagleHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiEagleHead"


class GiEarbuds(rx.Component):
    library = "react-icons/gi"
    tag = "GiEarbuds"


class GiEarrings(rx.Component):
    library = "react-icons/gi"
    tag = "GiEarrings"


class GiEarthAfricaEurope(rx.Component):
    library = "react-icons/gi"
    tag = "GiEarthAfricaEurope"


class GiEarthAmerica(rx.Component):
    library = "react-icons/gi"
    tag = "GiEarthAmerica"


class GiEarthAsiaOceania(rx.Component):
    library = "react-icons/gi"
    tag = "GiEarthAsiaOceania"


class GiEarthCrack(rx.Component):
    library = "react-icons/gi"
    tag = "GiEarthCrack"


class GiEarthSpit(rx.Component):
    library = "react-icons/gi"
    tag = "GiEarthSpit"


class GiEarthWorm(rx.Component):
    library = "react-icons/gi"
    tag = "GiEarthWorm"


class GiEarwig(rx.Component):
    library = "react-icons/gi"
    tag = "GiEarwig"


class GiEasel(rx.Component):
    library = "react-icons/gi"
    tag = "GiEasel"


class GiEasterEgg(rx.Component):
    library = "react-icons/gi"
    tag = "GiEasterEgg"


class GiEatingPelican(rx.Component):
    library = "react-icons/gi"
    tag = "GiEatingPelican"


class GiEating(rx.Component):
    library = "react-icons/gi"
    tag = "GiEating"


class GiEchoRipples(rx.Component):
    library = "react-icons/gi"
    tag = "GiEchoRipples"


class GiEclipseFlare(rx.Component):
    library = "react-icons/gi"
    tag = "GiEclipseFlare"


class GiEclipseSaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiEclipseSaw"


class GiEclipse(rx.Component):
    library = "react-icons/gi"
    tag = "GiEclipse"


class GiEcology(rx.Component):
    library = "react-icons/gi"
    tag = "GiEcology"


class GiEdgeCrack(rx.Component):
    library = "react-icons/gi"
    tag = "GiEdgeCrack"


class GiEdgedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiEdgedShield"


class GiEel(rx.Component):
    library = "react-icons/gi"
    tag = "GiEel"


class GiEggClutch(rx.Component):
    library = "react-icons/gi"
    tag = "GiEggClutch"


class GiEggDefense(rx.Component):
    library = "react-icons/gi"
    tag = "GiEggDefense"


class GiEggEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiEggEye"


class GiEggPod(rx.Component):
    library = "react-icons/gi"
    tag = "GiEggPod"


class GiEgypt(rx.Component):
    library = "react-icons/gi"
    tag = "GiEgypt"


class GiEgyptianBird(rx.Component):
    library = "react-icons/gi"
    tag = "GiEgyptianBird"


class GiEgyptianProfile(rx.Component):
    library = "react-icons/gi"
    tag = "GiEgyptianProfile"


class GiEgyptianPyramids(rx.Component):
    library = "react-icons/gi"
    tag = "GiEgyptianPyramids"


class GiEgyptianSphinx(rx.Component):
    library = "react-icons/gi"
    tag = "GiEgyptianSphinx"


class GiEgyptianTemple(rx.Component):
    library = "react-icons/gi"
    tag = "GiEgyptianTemple"


class GiEgyptianUrns(rx.Component):
    library = "react-icons/gi"
    tag = "GiEgyptianUrns"


class GiEgyptianWalk(rx.Component):
    library = "react-icons/gi"
    tag = "GiEgyptianWalk"


class GiEightBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiEightBall"


class GiElbowPad(rx.Component):
    library = "react-icons/gi"
    tag = "GiElbowPad"


class GiElderberry(rx.Component):
    library = "react-icons/gi"
    tag = "GiElderberry"


class GiElectricWhip(rx.Component):
    library = "react-icons/gi"
    tag = "GiElectricWhip"


class GiElectric(rx.Component):
    library = "react-icons/gi"
    tag = "GiElectric"


class GiElectricalCrescent(rx.Component):
    library = "react-icons/gi"
    tag = "GiElectricalCrescent"


class GiElectricalResistance(rx.Component):
    library = "react-icons/gi"
    tag = "GiElectricalResistance"


class GiElectricalSocket(rx.Component):
    library = "react-icons/gi"
    tag = "GiElectricalSocket"


class GiElephantHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiElephantHead"


class GiElephant(rx.Component):
    library = "react-icons/gi"
    tag = "GiElephant"


class GiElevator(rx.Component):
    library = "react-icons/gi"
    tag = "GiElevator"


class GiElfEar(rx.Component):
    library = "react-icons/gi"
    tag = "GiElfEar"


class GiElfHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiElfHelmet"


class GiElvenCastle(rx.Component):
    library = "react-icons/gi"
    tag = "GiElvenCastle"


class GiEmberShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmberShot"


class GiEmbrassedEnergy(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmbrassedEnergy"


class GiEmbryo(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmbryo"


class GiEmeraldNecklace(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmeraldNecklace"


class GiEmerald(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmerald"


class GiEmptyChessboard(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmptyChessboard"


class GiEmptyHourglass(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmptyHourglass"


class GiEmptyMetalBucketHandle(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmptyMetalBucketHandle"


class GiEmptyMetalBucket(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmptyMetalBucket"


class GiEmptyWoodBucketHandle(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmptyWoodBucketHandle"


class GiEmptyWoodBucket(rx.Component):
    library = "react-icons/gi"
    tag = "GiEmptyWoodBucket"


class GiEncirclement(rx.Component):
    library = "react-icons/gi"
    tag = "GiEncirclement"


class GiEnergise(rx.Component):
    library = "react-icons/gi"
    tag = "GiEnergise"


class GiEnergyArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiEnergyArrow"


class GiEnergyBreath(rx.Component):
    library = "react-icons/gi"
    tag = "GiEnergyBreath"


class GiEnergyShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiEnergyShield"


class GiEnergySword(rx.Component):
    library = "react-icons/gi"
    tag = "GiEnergySword"


class GiEnergyTank(rx.Component):
    library = "react-icons/gi"
    tag = "GiEnergyTank"


class GiEngagementRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiEngagementRing"


class GiEnlightenment(rx.Component):
    library = "react-icons/gi"
    tag = "GiEnlightenment"


class GiEnrage(rx.Component):
    library = "react-icons/gi"
    tag = "GiEnrage"


class GiEntMouth(rx.Component):
    library = "react-icons/gi"
    tag = "GiEntMouth"


class GiEntangledTyphoon(rx.Component):
    library = "react-icons/gi"
    tag = "GiEntangledTyphoon"


class GiEntryDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiEntryDoor"


class GiEnvelope(rx.Component):
    library = "react-icons/gi"
    tag = "GiEnvelope"


class GiErlenmeyer(rx.Component):
    library = "react-icons/gi"
    tag = "GiErlenmeyer"


class GiErmine(rx.Component):
    library = "react-icons/gi"
    tag = "GiErmine"


class GiEruption(rx.Component):
    library = "react-icons/gi"
    tag = "GiEruption"


class GiEscalator(rx.Component):
    library = "react-icons/gi"
    tag = "GiEscalator"


class GiEskimo(rx.Component):
    library = "react-icons/gi"
    tag = "GiEskimo"


class GiEternalLove(rx.Component):
    library = "react-icons/gi"
    tag = "GiEternalLove"


class GiEuropeanFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiEuropeanFlag"


class GiEvasion(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvasion"


class GiEvilBat(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilBat"


class GiEvilBook(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilBook"


class GiEvilBud(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilBud"


class GiEvilComet(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilComet"


class GiEvilEyes(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilEyes"


class GiEvilFork(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilFork"


class GiEvilHand(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilHand"


class GiEvilLove(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilLove"


class GiEvilMinion(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilMinion"


class GiEvilMoon(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilMoon"


class GiEvilTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilTower"


class GiEvilTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilTree"


class GiEvilWings(rx.Component):
    library = "react-icons/gi"
    tag = "GiEvilWings"


class GiExecutionerHood(rx.Component):
    library = "react-icons/gi"
    tag = "GiExecutionerHood"


class GiExitDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiExitDoor"


class GiExpand(rx.Component):
    library = "react-icons/gi"
    tag = "GiExpand"


class GiExpandedRays(rx.Component):
    library = "react-icons/gi"
    tag = "GiExpandedRays"


class GiExpander(rx.Component):
    library = "react-icons/gi"
    tag = "GiExpander"


class GiExpense(rx.Component):
    library = "react-icons/gi"
    tag = "GiExpense"


class GiExplodingPlanet(rx.Component):
    library = "react-icons/gi"
    tag = "GiExplodingPlanet"


class GiExplosionRays(rx.Component):
    library = "react-icons/gi"
    tag = "GiExplosionRays"


class GiExplosiveMaterials(rx.Component):
    library = "react-icons/gi"
    tag = "GiExplosiveMaterials"


class GiExplosiveMeeting(rx.Component):
    library = "react-icons/gi"
    tag = "GiExplosiveMeeting"


class GiExtraLucid(rx.Component):
    library = "react-icons/gi"
    tag = "GiExtraLucid"


class GiExtraTime(rx.Component):
    library = "react-icons/gi"
    tag = "GiExtraTime"


class GiExtractionOrb(rx.Component):
    library = "react-icons/gi"
    tag = "GiExtractionOrb"


class GiEyeOfHorus(rx.Component):
    library = "react-icons/gi"
    tag = "GiEyeOfHorus"


class GiEyeShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiEyeShield"


class GiEyeTarget(rx.Component):
    library = "react-icons/gi"
    tag = "GiEyeTarget"


class GiEyeball(rx.Component):
    library = "react-icons/gi"
    tag = "GiEyeball"


class GiEyedropper(rx.Component):
    library = "react-icons/gi"
    tag = "GiEyedropper"


class GiEyelashes(rx.Component):
    library = "react-icons/gi"
    tag = "GiEyelashes"


class GiEyepatch(rx.Component):
    library = "react-icons/gi"
    tag = "GiEyepatch"


class GiEyestalk(rx.Component):
    library = "react-icons/gi"
    tag = "GiEyestalk"


class GiFClef(rx.Component):
    library = "react-icons/gi"
    tag = "GiFClef"


class GiF1Car(rx.Component):
    library = "react-icons/gi"
    tag = "GiF1Car"


class GiFaceToFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiFaceToFace"


class GiFactoryArm(rx.Component):
    library = "react-icons/gi"
    tag = "GiFactoryArm"


class GiFactory(rx.Component):
    library = "react-icons/gi"
    tag = "GiFactory"


class GiFairyWand(rx.Component):
    library = "react-icons/gi"
    tag = "GiFairyWand"


class GiFairyWings(rx.Component):
    library = "react-icons/gi"
    tag = "GiFairyWings"


class GiFairy(rx.Component):
    library = "react-icons/gi"
    tag = "GiFairy"


class GiFalconMoon(rx.Component):
    library = "react-icons/gi"
    tag = "GiFalconMoon"


class GiFallDown(rx.Component):
    library = "react-icons/gi"
    tag = "GiFallDown"


class GiFallingBlob(rx.Component):
    library = "react-icons/gi"
    tag = "GiFallingBlob"


class GiFallingBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiFallingBomb"


class GiFallingBoulder(rx.Component):
    library = "react-icons/gi"
    tag = "GiFallingBoulder"


class GiFallingEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiFallingEye"


class GiFallingLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiFallingLeaf"


class GiFallingOvoid(rx.Component):
    library = "react-icons/gi"
    tag = "GiFallingOvoid"


class GiFallingRocks(rx.Component):
    library = "react-icons/gi"
    tag = "GiFallingRocks"


class GiFallingStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiFallingStar"


class GiFalling(rx.Component):
    library = "react-icons/gi"
    tag = "GiFalling"


class GiFalloutShelter(rx.Component):
    library = "react-icons/gi"
    tag = "GiFalloutShelter"


class GiFamas(rx.Component):
    library = "react-icons/gi"
    tag = "GiFamas"


class GiFamilyHouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiFamilyHouse"


class GiFamilyTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiFamilyTree"


class GiFangedSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiFangedSkull"


class GiFangsCircle(rx.Component):
    library = "react-icons/gi"
    tag = "GiFangsCircle"


class GiFangs(rx.Component):
    library = "react-icons/gi"
    tag = "GiFangs"


class GiFarmTractor(rx.Component):
    library = "react-icons/gi"
    tag = "GiFarmTractor"


class GiFarmer(rx.Component):
    library = "react-icons/gi"
    tag = "GiFarmer"


class GiFastArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiFastArrow"


class GiFastBackwardButton(rx.Component):
    library = "react-icons/gi"
    tag = "GiFastBackwardButton"


class GiFastForwardButton(rx.Component):
    library = "react-icons/gi"
    tag = "GiFastForwardButton"


class GiFastNoodles(rx.Component):
    library = "react-icons/gi"
    tag = "GiFastNoodles"


class GiFat(rx.Component):
    library = "react-icons/gi"
    tag = "GiFat"


class GiFeatherNecklace(rx.Component):
    library = "react-icons/gi"
    tag = "GiFeatherNecklace"


class GiFeatherWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiFeatherWound"


class GiFeather(rx.Component):
    library = "react-icons/gi"
    tag = "GiFeather"


class GiFeatheredWing(rx.Component):
    library = "react-icons/gi"
    tag = "GiFeatheredWing"


class GiFedora(rx.Component):
    library = "react-icons/gi"
    tag = "GiFedora"


class GiFeline(rx.Component):
    library = "react-icons/gi"
    tag = "GiFeline"


class GiFemaleLegs(rx.Component):
    library = "react-icons/gi"
    tag = "GiFemaleLegs"


class GiFemaleVampire(rx.Component):
    library = "react-icons/gi"
    tag = "GiFemaleVampire"


class GiFemale(rx.Component):
    library = "react-icons/gi"
    tag = "GiFemale"


class GiFencer(rx.Component):
    library = "react-icons/gi"
    tag = "GiFencer"


class GiFern(rx.Component):
    library = "react-icons/gi"
    tag = "GiFern"


class GiFertilizerBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiFertilizerBag"


class GiFetus(rx.Component):
    library = "react-icons/gi"
    tag = "GiFetus"


class GiFez(rx.Component):
    library = "react-icons/gi"
    tag = "GiFez"


class GiFieldGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiFieldGun"


class GiField(rx.Component):
    library = "react-icons/gi"
    tag = "GiField"


class GiFigurehead(rx.Component):
    library = "react-icons/gi"
    tag = "GiFigurehead"


class GiFiles(rx.Component):
    library = "react-icons/gi"
    tag = "GiFiles"


class GiFilmProjector(rx.Component):
    library = "react-icons/gi"
    tag = "GiFilmProjector"


class GiFilmSpool(rx.Component):
    library = "react-icons/gi"
    tag = "GiFilmSpool"


class GiFilmStrip(rx.Component):
    library = "react-icons/gi"
    tag = "GiFilmStrip"


class GiFinch(rx.Component):
    library = "react-icons/gi"
    tag = "GiFinch"


class GiFingerPrint(rx.Component):
    library = "react-icons/gi"
    tag = "GiFingerPrint"


class GiFingernail(rx.Component):
    library = "react-icons/gi"
    tag = "GiFingernail"


class GiFingersCrossed(rx.Component):
    library = "react-icons/gi"
    tag = "GiFingersCrossed"


class GiFinishLine(rx.Component):
    library = "react-icons/gi"
    tag = "GiFinishLine"


class GiFireAce(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireAce"


class GiFireAxe(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireAxe"


class GiFireBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireBomb"


class GiFireBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireBottle"


class GiFireBowl(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireBowl"


class GiFireBreath(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireBreath"


class GiFireDash(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireDash"


class GiFireExtinguisher(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireExtinguisher"


class GiFireFlower(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireFlower"


class GiFireGem(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireGem"


class GiFirePunch(rx.Component):
    library = "react-icons/gi"
    tag = "GiFirePunch"


class GiFireRay(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireRay"


class GiFireRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireRing"


class GiFireShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireShield"


class GiFireShrine(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireShrine"


class GiFireSilhouette(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireSilhouette"


class GiFireSpellCast(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireSpellCast"


class GiFireTail(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireTail"


class GiFireWave(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireWave"


class GiFireZone(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireZone"


class GiFire(rx.Component):
    library = "react-icons/gi"
    tag = "GiFire"


class GiFireball(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireball"


class GiFireflake(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireflake"


class GiFireplace(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireplace"


class GiFirewall(rx.Component):
    library = "react-icons/gi"
    tag = "GiFirewall"


class GiFireworkRocket(rx.Component):
    library = "react-icons/gi"
    tag = "GiFireworkRocket"


class GiFirstAidKit(rx.Component):
    library = "react-icons/gi"
    tag = "GiFirstAidKit"


class GiFishBucket(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishBucket"


class GiFishCooked(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishCooked"


class GiFishCorpse(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishCorpse"


class GiFishEggs(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishEggs"


class GiFishEscape(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishEscape"


class GiFishMonster(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishMonster"


class GiFishScales(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishScales"


class GiFishSmoking(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishSmoking"


class GiFishbone(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishbone"


class GiFishhookFork(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishhookFork"


class GiFishingBoat(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishingBoat"


class GiFishingHook(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishingHook"


class GiFishingJig(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishingJig"


class GiFishingLure(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishingLure"


class GiFishingNet(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishingNet"


class GiFishingPole(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishingPole"


class GiFishingSpoon(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishingSpoon"


class GiFishing(rx.Component):
    library = "react-icons/gi"
    tag = "GiFishing"


class GiFission(rx.Component):
    library = "react-icons/gi"
    tag = "GiFission"


class GiFist(rx.Component):
    library = "react-icons/gi"
    tag = "GiFist"


class GiFizzingFlask(rx.Component):
    library = "react-icons/gi"
    tag = "GiFizzingFlask"


class GiFlagObjective(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlagObjective"


class GiFlail(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlail"


class GiFlake(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlake"


class GiFlameClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlameClaws"


class GiFlameSpin(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlameSpin"


class GiFlameTunnel(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlameTunnel"


class GiFlame(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlame"


class GiFlamedLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlamedLeaf"


class GiFlamer(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlamer"


class GiFlamethrowerSoldier(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlamethrowerSoldier"


class GiFlamethrower(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlamethrower"


class GiFlamingArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlamingArrow"


class GiFlamingClaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlamingClaw"


class GiFlamingSheet(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlamingSheet"


class GiFlamingTrident(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlamingTrident"


class GiFlamingo(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlamingo"


class GiFlangedMace(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlangedMace"


class GiFlashGrenade(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlashGrenade"


class GiFlashlight(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlashlight"


class GiFlatHammer(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlatHammer"


class GiFlatPawPrint(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlatPawPrint"


class GiFlatPlatform(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlatPlatform"


class GiFlatStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlatStar"


class GiFlatTire(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlatTire"


class GiFlatbedCovered(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlatbedCovered"


class GiFlatbed(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlatbed"


class GiFlatfish(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlatfish"


class GiFlax(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlax"


class GiFleshyMass(rx.Component):
    library = "react-icons/gi"
    tag = "GiFleshyMass"


class GiFleurDeLys(rx.Component):
    library = "react-icons/gi"
    tag = "GiFleurDeLys"


class GiFlexibleLamp(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlexibleLamp"


class GiFlexibleStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlexibleStar"


class GiFlintSpark(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlintSpark"


class GiFlipFlops(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlipFlops"


class GiFloatingCrystal(rx.Component):
    library = "react-icons/gi"
    tag = "GiFloatingCrystal"


class GiFloatingGhost(rx.Component):
    library = "react-icons/gi"
    tag = "GiFloatingGhost"


class GiFloatingPlatforms(rx.Component):
    library = "react-icons/gi"
    tag = "GiFloatingPlatforms"


class GiFloatingTentacles(rx.Component):
    library = "react-icons/gi"
    tag = "GiFloatingTentacles"


class GiFlood(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlood"


class GiFloorHatch(rx.Component):
    library = "react-icons/gi"
    tag = "GiFloorHatch"


class GiFloorPolisher(rx.Component):
    library = "react-icons/gi"
    tag = "GiFloorPolisher"


class GiFlour(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlour"


class GiFlowerEmblem(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlowerEmblem"


class GiFlowerHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlowerHat"


class GiFlowerPot(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlowerPot"


class GiFlowerStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlowerStar"


class GiFlowerTwirl(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlowerTwirl"


class GiFlowers(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlowers"


class GiFluffyCloud(rx.Component):
    library = "react-icons/gi"
    tag = "GiFluffyCloud"


class GiFluffyFlame(rx.Component):
    library = "react-icons/gi"
    tag = "GiFluffyFlame"


class GiFluffySwirl(rx.Component):
    library = "react-icons/gi"
    tag = "GiFluffySwirl"


class GiFluffyTrefoil(rx.Component):
    library = "react-icons/gi"
    tag = "GiFluffyTrefoil"


class GiFluffyWing(rx.Component):
    library = "react-icons/gi"
    tag = "GiFluffyWing"


class GiFlute(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlute"


class GiFly(rx.Component):
    library = "react-icons/gi"
    tag = "GiFly"


class GiFlyingBeetle(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlyingBeetle"


class GiFlyingDagger(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlyingDagger"


class GiFlyingFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlyingFlag"


class GiFlyingFox(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlyingFox"


class GiFlyingShuriken(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlyingShuriken"


class GiFlyingTarget(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlyingTarget"


class GiFlyingTrout(rx.Component):
    library = "react-icons/gi"
    tag = "GiFlyingTrout"


class GiFnFal(rx.Component):
    library = "react-icons/gi"
    tag = "GiFnFal"


class GiFoam(rx.Component):
    library = "react-icons/gi"
    tag = "GiFoam"


class GiFoamyDisc(rx.Component):
    library = "react-icons/gi"
    tag = "GiFoamyDisc"


class GiFocusedLightning(rx.Component):
    library = "react-icons/gi"
    tag = "GiFocusedLightning"


class GiFogLight(rx.Component):
    library = "react-icons/gi"
    tag = "GiFogLight"


class GiFog(rx.Component):
    library = "react-icons/gi"
    tag = "GiFog"


class GiFoldedPaper(rx.Component):
    library = "react-icons/gi"
    tag = "GiFoldedPaper"


class GiFomorian(rx.Component):
    library = "react-icons/gi"
    tag = "GiFomorian"


class GiFoodChain(rx.Component):
    library = "react-icons/gi"
    tag = "GiFoodChain"


class GiFoodTruck(rx.Component):
    library = "react-icons/gi"
    tag = "GiFoodTruck"


class GiFootPlaster(rx.Component):
    library = "react-icons/gi"
    tag = "GiFootPlaster"


class GiFootTrip(rx.Component):
    library = "react-icons/gi"
    tag = "GiFootTrip"


class GiFootprint(rx.Component):
    library = "react-icons/gi"
    tag = "GiFootprint"


class GiFootsteps(rx.Component):
    library = "react-icons/gi"
    tag = "GiFootsteps"


class GiFootyField(rx.Component):
    library = "react-icons/gi"
    tag = "GiFootyField"


class GiForearm(rx.Component):
    library = "react-icons/gi"
    tag = "GiForearm"


class GiForestCamp(rx.Component):
    library = "react-icons/gi"
    tag = "GiForestCamp"


class GiForestEntrance(rx.Component):
    library = "react-icons/gi"
    tag = "GiForestEntrance"


class GiForest(rx.Component):
    library = "react-icons/gi"
    tag = "GiForest"


class GiForkKnifeSpoon(rx.Component):
    library = "react-icons/gi"
    tag = "GiForkKnifeSpoon"


class GiForklift(rx.Component):
    library = "react-icons/gi"
    tag = "GiForklift"


class GiForwardField(rx.Component):
    library = "react-icons/gi"
    tag = "GiForwardField"


class GiForwardSun(rx.Component):
    library = "react-icons/gi"
    tag = "GiForwardSun"


class GiFossil(rx.Component):
    library = "react-icons/gi"
    tag = "GiFossil"


class GiFoundryBucket(rx.Component):
    library = "react-icons/gi"
    tag = "GiFoundryBucket"


class GiFountainPen(rx.Component):
    library = "react-icons/gi"
    tag = "GiFountainPen"


class GiFountain(rx.Component):
    library = "react-icons/gi"
    tag = "GiFountain"


class GiFoxHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiFoxHead"


class GiFoxTail(rx.Component):
    library = "react-icons/gi"
    tag = "GiFoxTail"


class GiFox(rx.Component):
    library = "react-icons/gi"
    tag = "GiFox"


class GiFragmentedMeteor(rx.Component):
    library = "react-icons/gi"
    tag = "GiFragmentedMeteor"


class GiFragmentedSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiFragmentedSword"


class GiFragrance(rx.Component):
    library = "react-icons/gi"
    tag = "GiFragrance"


class GiFrance(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrance"


class GiFrankensteinCreature(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrankensteinCreature"


class GiFrayedArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrayedArrow"


class GiFreedomDove(rx.Component):
    library = "react-icons/gi"
    tag = "GiFreedomDove"


class GiFreemasonry(rx.Component):
    library = "react-icons/gi"
    tag = "GiFreemasonry"


class GiFrenchFries(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrenchFries"


class GiFrenchHorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrenchHorn"


class GiFriedEggs(rx.Component):
    library = "react-icons/gi"
    tag = "GiFriedEggs"


class GiFriedFish(rx.Component):
    library = "react-icons/gi"
    tag = "GiFriedFish"


class GiFrisbee(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrisbee"


class GiFroeAndMallet(rx.Component):
    library = "react-icons/gi"
    tag = "GiFroeAndMallet"


class GiFrogFoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrogFoot"


class GiFrogPrince(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrogPrince"


class GiFrog(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrog"


class GiFrontTeeth(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrontTeeth"


class GiFrontalLobe(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrontalLobe"


class GiFrostfire(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrostfire"


class GiFrozenArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrozenArrow"


class GiFrozenBlock(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrozenBlock"


class GiFrozenBody(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrozenBody"


class GiFrozenOrb(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrozenOrb"


class GiFrozenRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiFrozenRing"


class GiFruitBowl(rx.Component):
    library = "react-icons/gi"
    tag = "GiFruitBowl"


class GiFruitTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiFruitTree"


class GiFruiting(rx.Component):
    library = "react-icons/gi"
    tag = "GiFruiting"


class GiFuelTank(rx.Component):
    library = "react-icons/gi"
    tag = "GiFuelTank"


class GiFuji(rx.Component):
    library = "react-icons/gi"
    tag = "GiFuji"


class GiFulguroPunch(rx.Component):
    library = "react-icons/gi"
    tag = "GiFulguroPunch"


class GiFullFolder(rx.Component):
    library = "react-icons/gi"
    tag = "GiFullFolder"


class GiFullMetalBucketHandle(rx.Component):
    library = "react-icons/gi"
    tag = "GiFullMetalBucketHandle"


class GiFullMetalBucket(rx.Component):
    library = "react-icons/gi"
    tag = "GiFullMetalBucket"


class GiFullMotorcycleHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiFullMotorcycleHelmet"


class GiFullPizza(rx.Component):
    library = "react-icons/gi"
    tag = "GiFullPizza"


class GiFullWoodBucketHandle(rx.Component):
    library = "react-icons/gi"
    tag = "GiFullWoodBucketHandle"


class GiFullWoodBucket(rx.Component):
    library = "react-icons/gi"
    tag = "GiFullWoodBucket"


class GiFunnel(rx.Component):
    library = "react-icons/gi"
    tag = "GiFunnel"


class GiFurBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiFurBoot"


class GiFurShirt(rx.Component):
    library = "react-icons/gi"
    tag = "GiFurShirt"


class GiFurnace(rx.Component):
    library = "react-icons/gi"
    tag = "GiFurnace"


class GiGClef(rx.Component):
    library = "react-icons/gi"
    tag = "GiGClef"


class GiGalaxy(rx.Component):
    library = "react-icons/gi"
    tag = "GiGalaxy"


class GiGalea(rx.Component):
    library = "react-icons/gi"
    tag = "GiGalea"


class GiGalleon(rx.Component):
    library = "react-icons/gi"
    tag = "GiGalleon"


class GiGalley(rx.Component):
    library = "react-icons/gi"
    tag = "GiGalley"


class GiGameConsole(rx.Component):
    library = "react-icons/gi"
    tag = "GiGameConsole"


class GiGamepadCross(rx.Component):
    library = "react-icons/gi"
    tag = "GiGamepadCross"


class GiGamepad(rx.Component):
    library = "react-icons/gi"
    tag = "GiGamepad"


class GiGardeningShears(rx.Component):
    library = "react-icons/gi"
    tag = "GiGardeningShears"


class GiGargoyle(rx.Component):
    library = "react-icons/gi"
    tag = "GiGargoyle"


class GiGarlic(rx.Component):
    library = "react-icons/gi"
    tag = "GiGarlic"


class GiGasMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiGasMask"


class GiGasPump(rx.Component):
    library = "react-icons/gi"
    tag = "GiGasPump"


class GiGasStove(rx.Component):
    library = "react-icons/gi"
    tag = "GiGasStove"


class GiGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiGate"


class GiGaulsHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiGaulsHelm"


class GiGauntlet(rx.Component):
    library = "react-icons/gi"
    tag = "GiGauntlet"


class GiGavel(rx.Component):
    library = "react-icons/gi"
    tag = "GiGavel"


class GiGaze(rx.Component):
    library = "react-icons/gi"
    tag = "GiGaze"


class GiGearHammer(rx.Component):
    library = "react-icons/gi"
    tag = "GiGearHammer"


class GiGearStickPattern(rx.Component):
    library = "react-icons/gi"
    tag = "GiGearStickPattern"


class GiGearStick(rx.Component):
    library = "react-icons/gi"
    tag = "GiGearStick"


class GiGears(rx.Component):
    library = "react-icons/gi"
    tag = "GiGears"


class GiGecko(rx.Component):
    library = "react-icons/gi"
    tag = "GiGecko"


class GiGemChain(rx.Component):
    library = "react-icons/gi"
    tag = "GiGemChain"


class GiGemNecklace(rx.Component):
    library = "react-icons/gi"
    tag = "GiGemNecklace"


class GiGemPendant(rx.Component):
    library = "react-icons/gi"
    tag = "GiGemPendant"


class GiGemini(rx.Component):
    library = "react-icons/gi"
    tag = "GiGemini"


class GiGems(rx.Component):
    library = "react-icons/gi"
    tag = "GiGems"


class GiGhostAlly(rx.Component):
    library = "react-icons/gi"
    tag = "GiGhostAlly"


class GiGhost(rx.Component):
    library = "react-icons/gi"
    tag = "GiGhost"


class GiGiantSquid(rx.Component):
    library = "react-icons/gi"
    tag = "GiGiantSquid"


class GiGiant(rx.Component):
    library = "react-icons/gi"
    tag = "GiGiant"


class GiGibbet(rx.Component):
    library = "react-icons/gi"
    tag = "GiGibbet"


class GiGiftOfKnowledge(rx.Component):
    library = "react-icons/gi"
    tag = "GiGiftOfKnowledge"


class GiGiftTrap(rx.Component):
    library = "react-icons/gi"
    tag = "GiGiftTrap"


class GiGingerbreadMan(rx.Component):
    library = "react-icons/gi"
    tag = "GiGingerbreadMan"


class GiGinkgoLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiGinkgoLeaf"


class GiGladius(rx.Component):
    library = "react-icons/gi"
    tag = "GiGladius"


class GiGlaive(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlaive"


class GiGlassBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlassBall"


class GiGlassCelebration(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlassCelebration"


class GiGlassHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlassHeart"


class GiGlassShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlassShot"


class GiGlider(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlider"


class GiGlobeRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlobeRing"


class GiGlobe(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlobe"


class GiGlock(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlock"


class GiGloop(rx.Component):
    library = "react-icons/gi"
    tag = "GiGloop"


class GiGloves(rx.Component):
    library = "react-icons/gi"
    tag = "GiGloves"


class GiGlowingArtifact(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlowingArtifact"


class GiGlowingHands(rx.Component):
    library = "react-icons/gi"
    tag = "GiGlowingHands"


class GiGluttonousSmile(rx.Component):
    library = "react-icons/gi"
    tag = "GiGluttonousSmile"


class GiGluttony(rx.Component):
    library = "react-icons/gi"
    tag = "GiGluttony"


class GiGoalKeeper(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoalKeeper"


class GiGoat(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoat"


class GiGoblinCamp(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoblinCamp"


class GiGoblinHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoblinHead"


class GiGoldBar(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoldBar"


class GiGoldMine(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoldMine"


class GiGoldNuggets(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoldNuggets"


class GiGoldScarab(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoldScarab"


class GiGoldShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoldShell"


class GiGoldStack(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoldStack"


class GiGolemHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiGolemHead"


class GiGolfFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiGolfFlag"


class GiGolfTee(rx.Component):
    library = "react-icons/gi"
    tag = "GiGolfTee"


class GiGong(rx.Component):
    library = "react-icons/gi"
    tag = "GiGong"


class GiGooExplosion(rx.Component):
    library = "react-icons/gi"
    tag = "GiGooExplosion"


class GiGooSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiGooSkull"


class GiGooSpurt(rx.Component):
    library = "react-icons/gi"
    tag = "GiGooSpurt"


class GiGooeyDaemon(rx.Component):
    library = "react-icons/gi"
    tag = "GiGooeyDaemon"


class GiGooeyEyedSun(rx.Component):
    library = "react-icons/gi"
    tag = "GiGooeyEyedSun"


class GiGooeyImpact(rx.Component):
    library = "react-icons/gi"
    tag = "GiGooeyImpact"


class GiGooeyMolecule(rx.Component):
    library = "react-icons/gi"
    tag = "GiGooeyMolecule"


class GiGooeySword(rx.Component):
    library = "react-icons/gi"
    tag = "GiGooeySword"


class GiGoose(rx.Component):
    library = "react-icons/gi"
    tag = "GiGoose"


class GiGorilla(rx.Component):
    library = "react-icons/gi"
    tag = "GiGorilla"


class GiGothicCross(rx.Component):
    library = "react-icons/gi"
    tag = "GiGothicCross"


class GiGps(rx.Component):
    library = "react-icons/gi"
    tag = "GiGps"


class GiGrab(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrab"


class GiGraduateCap(rx.Component):
    library = "react-icons/gi"
    tag = "GiGraduateCap"


class GiGrainBundle(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrainBundle"


class GiGrain(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrain"


class GiGranary(rx.Component):
    library = "react-icons/gi"
    tag = "GiGranary"


class GiGrandPiano(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrandPiano"


class GiGrapes(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrapes"


class GiGrapple(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrapple"


class GiGraspingClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiGraspingClaws"


class GiGraspingSlug(rx.Component):
    library = "react-icons/gi"
    tag = "GiGraspingSlug"


class GiGrassMushroom(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrassMushroom"


class GiGrass(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrass"


class GiGraveFlowers(rx.Component):
    library = "react-icons/gi"
    tag = "GiGraveFlowers"


class GiGraveyard(rx.Component):
    library = "react-icons/gi"
    tag = "GiGraveyard"


class GiGreaseTrap(rx.Component):
    library = "react-icons/gi"
    tag = "GiGreaseTrap"


class GiGreatPyramid(rx.Component):
    library = "react-icons/gi"
    tag = "GiGreatPyramid"


class GiGreatWarTank(rx.Component):
    library = "react-icons/gi"
    tag = "GiGreatWarTank"


class GiGreaves(rx.Component):
    library = "react-icons/gi"
    tag = "GiGreaves"


class GiGreekSphinx(rx.Component):
    library = "react-icons/gi"
    tag = "GiGreekSphinx"


class GiGreekTemple(rx.Component):
    library = "react-icons/gi"
    tag = "GiGreekTemple"


class GiGreenPower(rx.Component):
    library = "react-icons/gi"
    tag = "GiGreenPower"


class GiGreenhouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiGreenhouse"


class GiGrenade(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrenade"


class GiGriffinShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiGriffinShield"


class GiGriffinSymbol(rx.Component):
    library = "react-icons/gi"
    tag = "GiGriffinSymbol"


class GiGrimReaper(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrimReaper"


class GiGroundSprout(rx.Component):
    library = "react-icons/gi"
    tag = "GiGroundSprout"


class GiGroundbreaker(rx.Component):
    library = "react-icons/gi"
    tag = "GiGroundbreaker"


class GiGroupedDrops(rx.Component):
    library = "react-icons/gi"
    tag = "GiGroupedDrops"


class GiGrowth(rx.Component):
    library = "react-icons/gi"
    tag = "GiGrowth"


class GiGuardedTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiGuardedTower"


class GiGuards(rx.Component):
    library = "react-icons/gi"
    tag = "GiGuards"


class GiGuatemala(rx.Component):
    library = "react-icons/gi"
    tag = "GiGuatemala"


class GiGuillotine(rx.Component):
    library = "react-icons/gi"
    tag = "GiGuillotine"


class GiGuitarBassHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiGuitarBassHead"


class GiGuitarHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiGuitarHead"


class GiGuitar(rx.Component):
    library = "react-icons/gi"
    tag = "GiGuitar"


class GiGunRose(rx.Component):
    library = "react-icons/gi"
    tag = "GiGunRose"


class GiGunStock(rx.Component):
    library = "react-icons/gi"
    tag = "GiGunStock"


class GiGunshot(rx.Component):
    library = "react-icons/gi"
    tag = "GiGunshot"


class GiGymBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiGymBag"


class GiH2O(rx.Component):
    library = "react-icons/gi"
    tag = "GiH2O"


class GiHabitatDome(rx.Component):
    library = "react-icons/gi"
    tag = "GiHabitatDome"


class GiHadesSymbol(rx.Component):
    library = "react-icons/gi"
    tag = "GiHadesSymbol"


class GiHairStrands(rx.Component):
    library = "react-icons/gi"
    tag = "GiHairStrands"


class GiHalberdShuriken(rx.Component):
    library = "react-icons/gi"
    tag = "GiHalberdShuriken"


class GiHalberd(rx.Component):
    library = "react-icons/gi"
    tag = "GiHalberd"


class GiHalfBodyCrawling(rx.Component):
    library = "react-icons/gi"
    tag = "GiHalfBodyCrawling"


class GiHalfDead(rx.Component):
    library = "react-icons/gi"
    tag = "GiHalfDead"


class GiHalfHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiHalfHeart"


class GiHalfLog(rx.Component):
    library = "react-icons/gi"
    tag = "GiHalfLog"


class GiHalfTornado(rx.Component):
    library = "react-icons/gi"
    tag = "GiHalfTornado"


class GiHalt(rx.Component):
    library = "react-icons/gi"
    tag = "GiHalt"


class GiHamShank(rx.Component):
    library = "react-icons/gi"
    tag = "GiHamShank"


class GiHamburgerMenu(rx.Component):
    library = "react-icons/gi"
    tag = "GiHamburgerMenu"


class GiHamburger(rx.Component):
    library = "react-icons/gi"
    tag = "GiHamburger"


class GiHammerBreak(rx.Component):
    library = "react-icons/gi"
    tag = "GiHammerBreak"


class GiHammerDrop(rx.Component):
    library = "react-icons/gi"
    tag = "GiHammerDrop"


class GiHammerNails(rx.Component):
    library = "react-icons/gi"
    tag = "GiHammerNails"


class GiHammerSickle(rx.Component):
    library = "react-icons/gi"
    tag = "GiHammerSickle"


class GiHandBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandBag"


class GiHandBandage(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandBandage"


class GiHandGrip(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandGrip"


class GiHandOfGod(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandOfGod"


class GiHandOk(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandOk"


class GiHandSaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandSaw"


class GiHandTruck(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandTruck"


class GiHandWing(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandWing"


class GiHand(rx.Component):
    library = "react-icons/gi"
    tag = "GiHand"


class GiHandcuffed(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandcuffed"


class GiHandcuffs(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandcuffs"


class GiHandheldFan(rx.Component):
    library = "react-icons/gi"
    tag = "GiHandheldFan"


class GiHangGlider(rx.Component):
    library = "react-icons/gi"
    tag = "GiHangGlider"


class GiHanger(rx.Component):
    library = "react-icons/gi"
    tag = "GiHanger"


class GiHangingSign(rx.Component):
    library = "react-icons/gi"
    tag = "GiHangingSign"


class GiHangingSpider(rx.Component):
    library = "react-icons/gi"
    tag = "GiHangingSpider"


class GiHappySkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiHappySkull"


class GiHarborDock(rx.Component):
    library = "react-icons/gi"
    tag = "GiHarborDock"


class GiHarp(rx.Component):
    library = "react-icons/gi"
    tag = "GiHarp"


class GiHarpoonChain(rx.Component):
    library = "react-icons/gi"
    tag = "GiHarpoonChain"


class GiHarpoonTrident(rx.Component):
    library = "react-icons/gi"
    tag = "GiHarpoonTrident"


class GiHarpy(rx.Component):
    library = "react-icons/gi"
    tag = "GiHarpy"


class GiHarryPotterSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiHarryPotterSkull"


class GiHastyGrave(rx.Component):
    library = "react-icons/gi"
    tag = "GiHastyGrave"


class GiHatchet(rx.Component):
    library = "react-icons/gi"
    tag = "GiHatchet"


class GiHatchets(rx.Component):
    library = "react-icons/gi"
    tag = "GiHatchets"


class GiHaunting(rx.Component):
    library = "react-icons/gi"
    tag = "GiHaunting"


class GiHawkEmblem(rx.Component):
    library = "react-icons/gi"
    tag = "GiHawkEmblem"


class GiHazardSign(rx.Component):
    library = "react-icons/gi"
    tag = "GiHazardSign"


class GiHazmatSuit(rx.Component):
    library = "react-icons/gi"
    tag = "GiHazmatSuit"


class GiHeadShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeadShot"


class GiHeadbandKnot(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeadbandKnot"


class GiHeadphones(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeadphones"


class GiHeadshot(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeadshot"


class GiHealingShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiHealingShield"


class GiHealing(rx.Component):
    library = "react-icons/gi"
    tag = "GiHealing"


class GiHealthCapsule(rx.Component):
    library = "react-icons/gi"
    tag = "GiHealthCapsule"


class GiHealthDecrease(rx.Component):
    library = "react-icons/gi"
    tag = "GiHealthDecrease"


class GiHealthIncrease(rx.Component):
    library = "react-icons/gi"
    tag = "GiHealthIncrease"


class GiHealthNormal(rx.Component):
    library = "react-icons/gi"
    tag = "GiHealthNormal"


class GiHealthPotion(rx.Component):
    library = "react-icons/gi"
    tag = "GiHealthPotion"


class GiHearingDisabled(rx.Component):
    library = "react-icons/gi"
    tag = "GiHearingDisabled"


class GiHeartArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartArmor"


class GiHeartBattery(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartBattery"


class GiHeartBeats(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartBeats"


class GiHeartBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartBottle"


class GiHeartDrop(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartDrop"


class GiHeartEarrings(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartEarrings"


class GiHeartInside(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartInside"


class GiHeartKey(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartKey"


class GiHeartMinus(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartMinus"


class GiHeartNecklace(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartNecklace"


class GiHeartOrgan(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartOrgan"


class GiHeartPlus(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartPlus"


class GiHeartShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartShield"


class GiHeartStake(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartStake"


class GiHeartTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartTower"


class GiHeartWings(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartWings"


class GiHeartburn(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeartburn"


class GiHearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiHearts"


class GiHeatHaze(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeatHaze"


class GiHeavenGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavenGate"


class GiHeavyArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyArrow"


class GiHeavyBullets(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyBullets"


class GiHeavyCollar(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyCollar"


class GiHeavyFall(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyFall"


class GiHeavyFighter(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyFighter"


class GiHeavyHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyHelm"


class GiHeavyLightning(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyLightning"


class GiHeavyRain(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyRain"


class GiHeavyThornyTriskelion(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyThornyTriskelion"


class GiHeavyTimer(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeavyTimer"


class GiHedgehog(rx.Component):
    library = "react-icons/gi"
    tag = "GiHedgehog"


class GiHedjetWhiteCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiHedjetWhiteCrown"


class GiHelicoprion(rx.Component):
    library = "react-icons/gi"
    tag = "GiHelicoprion"


class GiHelicopterTail(rx.Component):
    library = "react-icons/gi"
    tag = "GiHelicopterTail"


class GiHelicopter(rx.Component):
    library = "react-icons/gi"
    tag = "GiHelicopter"


class GiHellCrosses(rx.Component):
    library = "react-icons/gi"
    tag = "GiHellCrosses"


class GiHelmetHeadShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiHelmetHeadShot"


class GiHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiHelmet"


class GiHelp(rx.Component):
    library = "react-icons/gi"
    tag = "GiHelp"


class GiHemp(rx.Component):
    library = "react-icons/gi"
    tag = "GiHemp"


class GiHeptagram(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeptagram"


class GiHeraldicSun(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeraldicSun"


class GiHerbsBundle(rx.Component):
    library = "react-icons/gi"
    tag = "GiHerbsBundle"


class GiHeron(rx.Component):
    library = "react-icons/gi"
    tag = "GiHeron"


class GiHexagonalNut(rx.Component):
    library = "react-icons/gi"
    tag = "GiHexagonalNut"


class GiHexes(rx.Component):
    library = "react-icons/gi"
    tag = "GiHexes"


class GiHidden(rx.Component):
    library = "react-icons/gi"
    tag = "GiHidden"


class GiHieroglyphLegs(rx.Component):
    library = "react-icons/gi"
    tag = "GiHieroglyphLegs"


class GiHieroglyphY(rx.Component):
    library = "react-icons/gi"
    tag = "GiHieroglyphY"


class GiHighFive(rx.Component):
    library = "react-icons/gi"
    tag = "GiHighFive"


class GiHighGrass(rx.Component):
    library = "react-icons/gi"
    tag = "GiHighGrass"


class GiHighHeel(rx.Component):
    library = "react-icons/gi"
    tag = "GiHighHeel"


class GiHighKick(rx.Component):
    library = "react-icons/gi"
    tag = "GiHighKick"


class GiHighPunch(rx.Component):
    library = "react-icons/gi"
    tag = "GiHighPunch"


class GiHighShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiHighShot"


class GiHighTide(rx.Component):
    library = "react-icons/gi"
    tag = "GiHighTide"


class GiHighlighter(rx.Component):
    library = "react-icons/gi"
    tag = "GiHighlighter"


class GiHiking(rx.Component):
    library = "react-icons/gi"
    tag = "GiHiking"


class GiHillConquest(rx.Component):
    library = "react-icons/gi"
    tag = "GiHillConquest"


class GiHillFort(rx.Component):
    library = "react-icons/gi"
    tag = "GiHillFort"


class GiHills(rx.Component):
    library = "react-icons/gi"
    tag = "GiHills"


class GiHistogram(rx.Component):
    library = "react-icons/gi"
    tag = "GiHistogram"


class GiHiveMind(rx.Component):
    library = "react-icons/gi"
    tag = "GiHiveMind"


class GiHive(rx.Component):
    library = "react-icons/gi"
    tag = "GiHive"


class GiHobbitDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiHobbitDoor"


class GiHobbitDwelling(rx.Component):
    library = "react-icons/gi"
    tag = "GiHobbitDwelling"


class GiHockey(rx.Component):
    library = "react-icons/gi"
    tag = "GiHockey"


class GiHoleLadder(rx.Component):
    library = "react-icons/gi"
    tag = "GiHoleLadder"


class GiHole(rx.Component):
    library = "react-icons/gi"
    tag = "GiHole"


class GiHollowCat(rx.Component):
    library = "react-icons/gi"
    tag = "GiHollowCat"


class GiHolosphere(rx.Component):
    library = "react-icons/gi"
    tag = "GiHolosphere"


class GiHolyGrail(rx.Component):
    library = "react-icons/gi"
    tag = "GiHolyGrail"


class GiHolyHandGrenade(rx.Component):
    library = "react-icons/gi"
    tag = "GiHolyHandGrenade"


class GiHolyOak(rx.Component):
    library = "react-icons/gi"
    tag = "GiHolyOak"


class GiHolySymbol(rx.Component):
    library = "react-icons/gi"
    tag = "GiHolySymbol"


class GiHolyWater(rx.Component):
    library = "react-icons/gi"
    tag = "GiHolyWater"


class GiHomeGarage(rx.Component):
    library = "react-icons/gi"
    tag = "GiHomeGarage"


class GiHoneyJar(rx.Component):
    library = "react-icons/gi"
    tag = "GiHoneyJar"


class GiHoneycomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiHoneycomb"


class GiHoneypot(rx.Component):
    library = "react-icons/gi"
    tag = "GiHoneypot"


class GiHood(rx.Component):
    library = "react-icons/gi"
    tag = "GiHood"


class GiHoodedAssassin(rx.Component):
    library = "react-icons/gi"
    tag = "GiHoodedAssassin"


class GiHoodedFigure(rx.Component):
    library = "react-icons/gi"
    tag = "GiHoodedFigure"


class GiHoodie(rx.Component):
    library = "react-icons/gi"
    tag = "GiHoodie"


class GiHoof(rx.Component):
    library = "react-icons/gi"
    tag = "GiHoof"


class GiHook(rx.Component):
    library = "react-icons/gi"
    tag = "GiHook"


class GiHops(rx.Component):
    library = "react-icons/gi"
    tag = "GiHops"


class GiHorizonRoad(rx.Component):
    library = "react-icons/gi"
    tag = "GiHorizonRoad"


class GiHorizontalFlip(rx.Component):
    library = "react-icons/gi"
    tag = "GiHorizontalFlip"


class GiHornInternal(rx.Component):
    library = "react-icons/gi"
    tag = "GiHornInternal"


class GiHornedHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiHornedHelm"


class GiHornedReptile(rx.Component):
    library = "react-icons/gi"
    tag = "GiHornedReptile"


class GiHornedSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiHornedSkull"


class GiHorseHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiHorseHead"


class GiHorseshoe(rx.Component):
    library = "react-icons/gi"
    tag = "GiHorseshoe"


class GiHorus(rx.Component):
    library = "react-icons/gi"
    tag = "GiHorus"


class GiHospitalCross(rx.Component):
    library = "react-icons/gi"
    tag = "GiHospitalCross"


class GiHospital(rx.Component):
    library = "react-icons/gi"
    tag = "GiHospital"


class GiHotDog(rx.Component):
    library = "react-icons/gi"
    tag = "GiHotDog"


class GiHotMeal(rx.Component):
    library = "react-icons/gi"
    tag = "GiHotMeal"


class GiHotSpices(rx.Component):
    library = "react-icons/gi"
    tag = "GiHotSpices"


class GiHotSurface(rx.Component):
    library = "react-icons/gi"
    tag = "GiHotSurface"


class GiHound(rx.Component):
    library = "react-icons/gi"
    tag = "GiHound"


class GiHourglass(rx.Component):
    library = "react-icons/gi"
    tag = "GiHourglass"


class GiHouseKeys(rx.Component):
    library = "react-icons/gi"
    tag = "GiHouseKeys"


class GiHouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiHouse"


class GiHumanCannonball(rx.Component):
    library = "react-icons/gi"
    tag = "GiHumanCannonball"


class GiHumanEar(rx.Component):
    library = "react-icons/gi"
    tag = "GiHumanEar"


class GiHumanPyramid(rx.Component):
    library = "react-icons/gi"
    tag = "GiHumanPyramid"


class GiHumanTarget(rx.Component):
    library = "react-icons/gi"
    tag = "GiHumanTarget"


class GiHummingbird(rx.Component):
    library = "react-icons/gi"
    tag = "GiHummingbird"


class GiHungary(rx.Component):
    library = "react-icons/gi"
    tag = "GiHungary"


class GiHunterEyes(rx.Component):
    library = "react-icons/gi"
    tag = "GiHunterEyes"


class GiHuntingBolas(rx.Component):
    library = "react-icons/gi"
    tag = "GiHuntingBolas"


class GiHuntingHorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiHuntingHorn"


class GiHut(rx.Component):
    library = "react-icons/gi"
    tag = "GiHut"


class GiHutsVillage(rx.Component):
    library = "react-icons/gi"
    tag = "GiHutsVillage"


class GiHydraShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiHydraShot"


class GiHydra(rx.Component):
    library = "react-icons/gi"
    tag = "GiHydra"


class GiHyenaHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiHyenaHead"


class GiHypersonicBolt(rx.Component):
    library = "react-icons/gi"
    tag = "GiHypersonicBolt"


class GiHypersonicMelon(rx.Component):
    library = "react-icons/gi"
    tag = "GiHypersonicMelon"


class GiHypodermicTest(rx.Component):
    library = "react-icons/gi"
    tag = "GiHypodermicTest"


class GiIBeam(rx.Component):
    library = "react-icons/gi"
    tag = "GiIBeam"


class GiIBrick(rx.Component):
    library = "react-icons/gi"
    tag = "GiIBrick"


class GiIbis(rx.Component):
    library = "react-icons/gi"
    tag = "GiIbis"


class GiIcarus(rx.Component):
    library = "react-icons/gi"
    tag = "GiIcarus"


class GiIceBolt(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceBolt"


class GiIceBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceBomb"


class GiIceCreamCone(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceCreamCone"


class GiIceCreamScoop(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceCreamScoop"


class GiIceCube(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceCube"


class GiIceCubes(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceCubes"


class GiIceGolem(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceGolem"


class GiIceIris(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceIris"


class GiIcePop(rx.Component):
    library = "react-icons/gi"
    tag = "GiIcePop"


class GiIceShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceShield"


class GiIceSkate(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceSkate"


class GiIceSpear(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceSpear"


class GiIceSpellCast(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceSpellCast"


class GiIceberg(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceberg"


class GiIcebergs(rx.Component):
    library = "react-icons/gi"
    tag = "GiIcebergs"


class GiIceland(rx.Component):
    library = "react-icons/gi"
    tag = "GiIceland"


class GiIciclesAura(rx.Component):
    library = "react-icons/gi"
    tag = "GiIciclesAura"


class GiIciclesFence(rx.Component):
    library = "react-icons/gi"
    tag = "GiIciclesFence"


class GiIdCard(rx.Component):
    library = "react-icons/gi"
    tag = "GiIdCard"


class GiIdea(rx.Component):
    library = "react-icons/gi"
    tag = "GiIdea"


class GiIfrit(rx.Component):
    library = "react-icons/gi"
    tag = "GiIfrit"


class GiIgloo(rx.Component):
    library = "react-icons/gi"
    tag = "GiIgloo"


class GiImbricatedArrows(rx.Component):
    library = "react-icons/gi"
    tag = "GiImbricatedArrows"


class GiImpLaugh(rx.Component):
    library = "react-icons/gi"
    tag = "GiImpLaugh"


class GiImp(rx.Component):
    library = "react-icons/gi"
    tag = "GiImp"


class GiImpactPoint(rx.Component):
    library = "react-icons/gi"
    tag = "GiImpactPoint"


class GiImperialCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiImperialCrown"


class GiImplosion(rx.Component):
    library = "react-icons/gi"
    tag = "GiImplosion"


class GiImprisoned(rx.Component):
    library = "react-icons/gi"
    tag = "GiImprisoned"


class GiInauguration(rx.Component):
    library = "react-icons/gi"
    tag = "GiInauguration"


class GiIncense(rx.Component):
    library = "react-icons/gi"
    tag = "GiIncense"


class GiIncisors(rx.Component):
    library = "react-icons/gi"
    tag = "GiIncisors"


class GiIncomingRocket(rx.Component):
    library = "react-icons/gi"
    tag = "GiIncomingRocket"


class GiIncubator(rx.Component):
    library = "react-icons/gi"
    tag = "GiIncubator"


class GiIndiaGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiIndiaGate"


class GiIndianPalace(rx.Component):
    library = "react-icons/gi"
    tag = "GiIndianPalace"


class GiInfernoBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiInfernoBomb"


class GiInfestedMass(rx.Component):
    library = "react-icons/gi"
    tag = "GiInfestedMass"


class GiInfinity(rx.Component):
    library = "react-icons/gi"
    tag = "GiInfinity"


class GiInfo(rx.Component):
    library = "react-icons/gi"
    tag = "GiInfo"


class GiInjustice(rx.Component):
    library = "react-icons/gi"
    tag = "GiInjustice"


class GiInkSwirl(rx.Component):
    library = "react-icons/gi"
    tag = "GiInkSwirl"


class GiInnerSelf(rx.Component):
    library = "react-icons/gi"
    tag = "GiInnerSelf"


class GiInsectJaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiInsectJaws"


class GiInspiration(rx.Component):
    library = "react-icons/gi"
    tag = "GiInspiration"


class GiInterceptorShip(rx.Component):
    library = "react-icons/gi"
    tag = "GiInterceptorShip"


class GiInterdiction(rx.Component):
    library = "react-icons/gi"
    tag = "GiInterdiction"


class GiInterlacedTentacles(rx.Component):
    library = "react-icons/gi"
    tag = "GiInterlacedTentacles"


class GiInterleavedArrows(rx.Component):
    library = "react-icons/gi"
    tag = "GiInterleavedArrows"


class GiInterleavedClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiInterleavedClaws"


class GiInternalInjury(rx.Component):
    library = "react-icons/gi"
    tag = "GiInternalInjury"


class GiInternalOrgan(rx.Component):
    library = "react-icons/gi"
    tag = "GiInternalOrgan"


class GiInterstellarPath(rx.Component):
    library = "react-icons/gi"
    tag = "GiInterstellarPath"


class GiIntricateNecklace(rx.Component):
    library = "react-icons/gi"
    tag = "GiIntricateNecklace"


class GiInvertedDice1(rx.Component):
    library = "react-icons/gi"
    tag = "GiInvertedDice1"


class GiInvertedDice2(rx.Component):
    library = "react-icons/gi"
    tag = "GiInvertedDice2"


class GiInvertedDice3(rx.Component):
    library = "react-icons/gi"
    tag = "GiInvertedDice3"


class GiInvertedDice4(rx.Component):
    library = "react-icons/gi"
    tag = "GiInvertedDice4"


class GiInvertedDice5(rx.Component):
    library = "react-icons/gi"
    tag = "GiInvertedDice5"


class GiInvertedDice6(rx.Component):
    library = "react-icons/gi"
    tag = "GiInvertedDice6"


class GiInvisibleFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiInvisibleFace"


class GiInvisible(rx.Component):
    library = "react-icons/gi"
    tag = "GiInvisible"


class GiIonCannonBlast(rx.Component):
    library = "react-icons/gi"
    tag = "GiIonCannonBlast"


class GiIonicColumn(rx.Component):
    library = "react-icons/gi"
    tag = "GiIonicColumn"


class GiIraq(rx.Component):
    library = "react-icons/gi"
    tag = "GiIraq"


class GiIronCross(rx.Component):
    library = "react-icons/gi"
    tag = "GiIronCross"


class GiIronHulledWarship(rx.Component):
    library = "react-icons/gi"
    tag = "GiIronHulledWarship"


class GiIronMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiIronMask"


class GiIsland(rx.Component):
    library = "react-icons/gi"
    tag = "GiIsland"


class GiItalia(rx.Component):
    library = "react-icons/gi"
    tag = "GiItalia"


class GiIvoryTusks(rx.Component):
    library = "react-icons/gi"
    tag = "GiIvoryTusks"


class GiJBrick(rx.Component):
    library = "react-icons/gi"
    tag = "GiJBrick"


class GiJackPlug(rx.Component):
    library = "react-icons/gi"
    tag = "GiJackPlug"


class GiJamesBondAperture(rx.Component):
    library = "react-icons/gi"
    tag = "GiJamesBondAperture"


class GiJapan(rx.Component):
    library = "react-icons/gi"
    tag = "GiJapan"


class GiJapaneseBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiJapaneseBridge"


class GiJasmine(rx.Component):
    library = "react-icons/gi"
    tag = "GiJasmine"


class GiJasonMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiJasonMask"


class GiJawbone(rx.Component):
    library = "react-icons/gi"
    tag = "GiJawbone"


class GiJawlessCyclop(rx.Component):
    library = "react-icons/gi"
    tag = "GiJawlessCyclop"


class GiJeep(rx.Component):
    library = "react-icons/gi"
    tag = "GiJeep"


class GiJellyBeans(rx.Component):
    library = "react-icons/gi"
    tag = "GiJellyBeans"


class GiJelly(rx.Component):
    library = "react-icons/gi"
    tag = "GiJelly"


class GiJellyfish(rx.Component):
    library = "react-icons/gi"
    tag = "GiJellyfish"


class GiJerrycan(rx.Component):
    library = "react-icons/gi"
    tag = "GiJerrycan"


class GiJerusalemCross(rx.Component):
    library = "react-icons/gi"
    tag = "GiJerusalemCross"


class GiJesterHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiJesterHat"


class GiJetFighter(rx.Component):
    library = "react-icons/gi"
    tag = "GiJetFighter"


class GiJetPack(rx.Component):
    library = "react-icons/gi"
    tag = "GiJetPack"


class GiJetpack(rx.Component):
    library = "react-icons/gi"
    tag = "GiJetpack"


class GiJewelCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiJewelCrown"


class GiJeweledChalice(rx.Component):
    library = "react-icons/gi"
    tag = "GiJeweledChalice"


class GiJigsawBox(rx.Component):
    library = "react-icons/gi"
    tag = "GiJigsawBox"


class GiJigsawPiece(rx.Component):
    library = "react-icons/gi"
    tag = "GiJigsawPiece"


class GiJoin(rx.Component):
    library = "react-icons/gi"
    tag = "GiJoin"


class GiJoint(rx.Component):
    library = "react-icons/gi"
    tag = "GiJoint"


class GiJourney(rx.Component):
    library = "react-icons/gi"
    tag = "GiJourney"


class GiJoystick(rx.Component):
    library = "react-icons/gi"
    tag = "GiJoystick"


class GiJug(rx.Component):
    library = "react-icons/gi"
    tag = "GiJug"


class GiJuggler(rx.Component):
    library = "react-icons/gi"
    tag = "GiJuggler"


class GiJugglingClubs(rx.Component):
    library = "react-icons/gi"
    tag = "GiJugglingClubs"


class GiJugglingSeal(rx.Component):
    library = "react-icons/gi"
    tag = "GiJugglingSeal"


class GiJumpAcross(rx.Component):
    library = "react-icons/gi"
    tag = "GiJumpAcross"


class GiJumpingDog(rx.Component):
    library = "react-icons/gi"
    tag = "GiJumpingDog"


class GiJumpingRope(rx.Component):
    library = "react-icons/gi"
    tag = "GiJumpingRope"


class GiJungle(rx.Component):
    library = "react-icons/gi"
    tag = "GiJungle"


class GiJupiter(rx.Component):
    library = "react-icons/gi"
    tag = "GiJupiter"


class GiJusticeStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiJusticeStar"


class GiKaleidoscopePearls(rx.Component):
    library = "react-icons/gi"
    tag = "GiKaleidoscopePearls"


class GiKangaroo(rx.Component):
    library = "react-icons/gi"
    tag = "GiKangaroo"


class GiKatana(rx.Component):
    library = "react-icons/gi"
    tag = "GiKatana"


class GiKebabSpit(rx.Component):
    library = "react-icons/gi"
    tag = "GiKebabSpit"


class GiKenkuHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiKenkuHead"


class GiKenya(rx.Component):
    library = "react-icons/gi"
    tag = "GiKenya"


class GiKetchup(rx.Component):
    library = "react-icons/gi"
    tag = "GiKetchup"


class GiKevlarVest(rx.Component):
    library = "react-icons/gi"
    tag = "GiKevlarVest"


class GiKevlar(rx.Component):
    library = "react-icons/gi"
    tag = "GiKevlar"


class GiKeyCard(rx.Component):
    library = "react-icons/gi"
    tag = "GiKeyCard"


class GiKeyLock(rx.Component):
    library = "react-icons/gi"
    tag = "GiKeyLock"


class GiKey(rx.Component):
    library = "react-icons/gi"
    tag = "GiKey"


class GiKeyboard(rx.Component):
    library = "react-icons/gi"
    tag = "GiKeyboard"


class GiKeyring(rx.Component):
    library = "react-icons/gi"
    tag = "GiKeyring"


class GiKickScooter(rx.Component):
    library = "react-icons/gi"
    tag = "GiKickScooter"


class GiKidSlide(rx.Component):
    library = "react-icons/gi"
    tag = "GiKidSlide"


class GiKidneys(rx.Component):
    library = "react-icons/gi"
    tag = "GiKidneys"


class GiKimono(rx.Component):
    library = "react-icons/gi"
    tag = "GiKimono"


class GiKindle(rx.Component):
    library = "react-icons/gi"
    tag = "GiKindle"


class GiKingJuMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiKingJuMask"


class GiKing(rx.Component):
    library = "react-icons/gi"
    tag = "GiKing"


class GiKitchenKnives(rx.Component):
    library = "react-icons/gi"
    tag = "GiKitchenKnives"


class GiKitchenScale(rx.Component):
    library = "react-icons/gi"
    tag = "GiKitchenScale"


class GiKitchenTap(rx.Component):
    library = "react-icons/gi"
    tag = "GiKitchenTap"


class GiKite(rx.Component):
    library = "react-icons/gi"
    tag = "GiKite"


class GiKiwiBird(rx.Component):
    library = "react-icons/gi"
    tag = "GiKiwiBird"


class GiKiwiFruit(rx.Component):
    library = "react-icons/gi"
    tag = "GiKiwiFruit"


class GiKlingon(rx.Component):
    library = "react-icons/gi"
    tag = "GiKlingon"


class GiKnapsack(rx.Component):
    library = "react-icons/gi"
    tag = "GiKnapsack"


class GiKneeBandage(rx.Component):
    library = "react-icons/gi"
    tag = "GiKneeBandage"


class GiKneeCap(rx.Component):
    library = "react-icons/gi"
    tag = "GiKneeCap"


class GiKneePad(rx.Component):
    library = "react-icons/gi"
    tag = "GiKneePad"


class GiKneeling(rx.Component):
    library = "react-icons/gi"
    tag = "GiKneeling"


class GiKnifeFork(rx.Component):
    library = "react-icons/gi"
    tag = "GiKnifeFork"


class GiKnifeThrust(rx.Component):
    library = "react-icons/gi"
    tag = "GiKnifeThrust"


class GiKnightBanner(rx.Component):
    library = "react-icons/gi"
    tag = "GiKnightBanner"


class GiKnockedOutStars(rx.Component):
    library = "react-icons/gi"
    tag = "GiKnockedOutStars"


class GiKnockout(rx.Component):
    library = "react-icons/gi"
    tag = "GiKnockout"


class GiKnot(rx.Component):
    library = "react-icons/gi"
    tag = "GiKnot"


class GiKoala(rx.Component):
    library = "react-icons/gi"
    tag = "GiKoala"


class GiKoholintEgg(rx.Component):
    library = "react-icons/gi"
    tag = "GiKoholintEgg"


class GiKrakenTentacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiKrakenTentacle"


class GiKusarigama(rx.Component):
    library = "react-icons/gi"
    tag = "GiKusarigama"


class GiLBrick(rx.Component):
    library = "react-icons/gi"
    tag = "GiLBrick"


class GiLabCoat(rx.Component):
    library = "react-icons/gi"
    tag = "GiLabCoat"


class GiLabradorHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiLabradorHead"


class GiLadder(rx.Component):
    library = "react-icons/gi"
    tag = "GiLadder"


class GiLaddersPlatform(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaddersPlatform"


class GiLadle(rx.Component):
    library = "react-icons/gi"
    tag = "GiLadle"


class GiLadybug(rx.Component):
    library = "react-icons/gi"
    tag = "GiLadybug"


class GiLamellar(rx.Component):
    library = "react-icons/gi"
    tag = "GiLamellar"


class GiLampreyMouth(rx.Component):
    library = "react-icons/gi"
    tag = "GiLampreyMouth"


class GiLandMine(rx.Component):
    library = "react-icons/gi"
    tag = "GiLandMine"


class GiLanternFlame(rx.Component):
    library = "react-icons/gi"
    tag = "GiLanternFlame"


class GiLantern(rx.Component):
    library = "react-icons/gi"
    tag = "GiLantern"


class GiLaptop(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaptop"


class GiLargeDress(rx.Component):
    library = "react-icons/gi"
    tag = "GiLargeDress"


class GiLargePaintBrush(rx.Component):
    library = "react-icons/gi"
    tag = "GiLargePaintBrush"


class GiLargeWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiLargeWound"


class GiLaserBlast(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaserBlast"


class GiLaserBurst(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaserBurst"


class GiLaserGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaserGun"


class GiLaserPrecision(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaserPrecision"


class GiLaserSparks(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaserSparks"


class GiLaserTurret(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaserTurret"


class GiLaserWarning(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaserWarning"


class GiLaserburn(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaserburn"


class GiLasso(rx.Component):
    library = "react-icons/gi"
    tag = "GiLasso"


class GiLatvia(rx.Component):
    library = "react-icons/gi"
    tag = "GiLatvia"


class GiLaurelCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaurelCrown"


class GiLaurelsTrophy(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaurelsTrophy"


class GiLaurels(rx.Component):
    library = "react-icons/gi"
    tag = "GiLaurels"


class GiLava(rx.Component):
    library = "react-icons/gi"
    tag = "GiLava"


class GiLawStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiLawStar"


class GiLayeredArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiLayeredArmor"


class GiLeadPipe(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeadPipe"


class GiLeafSkeleton(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeafSkeleton"


class GiLeafSwirl(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeafSwirl"


class GiLeak(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeak"


class GiLeakySkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeakySkull"


class GiLeapfrog(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeapfrog"


class GiLeatherArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeatherArmor"


class GiLeatherBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeatherBoot"


class GiLeatherVest(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeatherVest"


class GiLed(rx.Component):
    library = "react-icons/gi"
    tag = "GiLed"


class GiLeeEnfield(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeeEnfield"


class GiLeechingWorm(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeechingWorm"


class GiLeek(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeek"


class GiLegArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiLegArmor"


class GiLeg(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeg"


class GiLemon(rx.Component):
    library = "react-icons/gi"
    tag = "GiLemon"


class GiLeo(rx.Component):
    library = "react-icons/gi"
    tag = "GiLeo"


class GiLetterBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiLetterBomb"


class GiLevelCrossing(rx.Component):
    library = "react-icons/gi"
    tag = "GiLevelCrossing"


class GiLevelEndFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiLevelEndFlag"


class GiLevelFourAdvanced(rx.Component):
    library = "react-icons/gi"
    tag = "GiLevelFourAdvanced"


class GiLevelFour(rx.Component):
    library = "react-icons/gi"
    tag = "GiLevelFour"


class GiLevelThreeAdvanced(rx.Component):
    library = "react-icons/gi"
    tag = "GiLevelThreeAdvanced"


class GiLevelThree(rx.Component):
    library = "react-icons/gi"
    tag = "GiLevelThree"


class GiLevelTwoAdvanced(rx.Component):
    library = "react-icons/gi"
    tag = "GiLevelTwoAdvanced"


class GiLevelTwo(rx.Component):
    library = "react-icons/gi"
    tag = "GiLevelTwo"


class GiLever(rx.Component):
    library = "react-icons/gi"
    tag = "GiLever"


class GiLiar(rx.Component):
    library = "react-icons/gi"
    tag = "GiLiar"


class GiLibertyWing(rx.Component):
    library = "react-icons/gi"
    tag = "GiLibertyWing"


class GiLibra(rx.Component):
    library = "react-icons/gi"
    tag = "GiLibra"


class GiLibya(rx.Component):
    library = "react-icons/gi"
    tag = "GiLibya"


class GiLifeBar(rx.Component):
    library = "react-icons/gi"
    tag = "GiLifeBar"


class GiLifeBuoy(rx.Component):
    library = "react-icons/gi"
    tag = "GiLifeBuoy"


class GiLifeInTheBalance(rx.Component):
    library = "react-icons/gi"
    tag = "GiLifeInTheBalance"


class GiLifeJacket(rx.Component):
    library = "react-icons/gi"
    tag = "GiLifeJacket"


class GiLifeSupport(rx.Component):
    library = "react-icons/gi"
    tag = "GiLifeSupport"


class GiLifeTap(rx.Component):
    library = "react-icons/gi"
    tag = "GiLifeTap"


class GiLift(rx.Component):
    library = "react-icons/gi"
    tag = "GiLift"


class GiLightBackpack(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightBackpack"


class GiLightBulb(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightBulb"


class GiLightFighter(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightFighter"


class GiLightHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightHelm"


class GiLightProjector(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightProjector"


class GiLightSabers(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightSabers"


class GiLightThornyTriskelion(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightThornyTriskelion"


class GiLighter(rx.Component):
    library = "react-icons/gi"
    tag = "GiLighter"


class GiLighthouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiLighthouse"


class GiLightningArc(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningArc"


class GiLightningBow(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningBow"


class GiLightningBranches(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningBranches"


class GiLightningDissipation(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningDissipation"


class GiLightningDome(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningDome"


class GiLightningElectron(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningElectron"


class GiLightningFlame(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningFlame"


class GiLightningFrequency(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningFrequency"


class GiLightningHelix(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningHelix"


class GiLightningMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningMask"


class GiLightningSaber(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningSaber"


class GiLightningShadow(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningShadow"


class GiLightningShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningShield"


class GiLightningShout(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningShout"


class GiLightningSlashes(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningSlashes"


class GiLightningSpanner(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningSpanner"


class GiLightningStorm(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningStorm"


class GiLightningTear(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningTear"


class GiLightningTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningTree"


class GiLightningTrio(rx.Component):
    library = "react-icons/gi"
    tag = "GiLightningTrio"


class GiLilyPads(rx.Component):
    library = "react-icons/gi"
    tag = "GiLilyPads"


class GiLindenLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiLindenLeaf"


class GiLinkedRings(rx.Component):
    library = "react-icons/gi"
    tag = "GiLinkedRings"


class GiLion(rx.Component):
    library = "react-icons/gi"
    tag = "GiLion"


class GiLips(rx.Component):
    library = "react-icons/gi"
    tag = "GiLips"


class GiLipstick(rx.Component):
    library = "react-icons/gi"
    tag = "GiLipstick"


class GiLiquidSoap(rx.Component):
    library = "react-icons/gi"
    tag = "GiLiquidSoap"


class GiLitCandelabra(rx.Component):
    library = "react-icons/gi"
    tag = "GiLitCandelabra"


class GiLiver(rx.Component):
    library = "react-icons/gi"
    tag = "GiLiver"


class GiLizardTongue(rx.Component):
    library = "react-icons/gi"
    tag = "GiLizardTongue"


class GiLizardman(rx.Component):
    library = "react-icons/gi"
    tag = "GiLizardman"


class GiLoad(rx.Component):
    library = "react-icons/gi"
    tag = "GiLoad"


class GiLobArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiLobArrow"


class GiLockPicking(rx.Component):
    library = "react-icons/gi"
    tag = "GiLockPicking"


class GiLockSpy(rx.Component):
    library = "react-icons/gi"
    tag = "GiLockSpy"


class GiLockedBox(rx.Component):
    library = "react-icons/gi"
    tag = "GiLockedBox"


class GiLockedChest(rx.Component):
    library = "react-icons/gi"
    tag = "GiLockedChest"


class GiLockedDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiLockedDoor"


class GiLockedFortress(rx.Component):
    library = "react-icons/gi"
    tag = "GiLockedFortress"


class GiLockedHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiLockedHeart"


class GiLockers(rx.Component):
    library = "react-icons/gi"
    tag = "GiLockers"


class GiLockpicks(rx.Component):
    library = "react-icons/gi"
    tag = "GiLockpicks"


class GiLog(rx.Component):
    library = "react-icons/gi"
    tag = "GiLog"


class GiLogging(rx.Component):
    library = "react-icons/gi"
    tag = "GiLogging"


class GiLogicGateAnd(rx.Component):
    library = "react-icons/gi"
    tag = "GiLogicGateAnd"


class GiLogicGateNand(rx.Component):
    library = "react-icons/gi"
    tag = "GiLogicGateNand"


class GiLogicGateNor(rx.Component):
    library = "react-icons/gi"
    tag = "GiLogicGateNor"


class GiLogicGateNot(rx.Component):
    library = "react-icons/gi"
    tag = "GiLogicGateNot"


class GiLogicGateNxor(rx.Component):
    library = "react-icons/gi"
    tag = "GiLogicGateNxor"


class GiLogicGateOr(rx.Component):
    library = "react-icons/gi"
    tag = "GiLogicGateOr"


class GiLogicGateXor(rx.Component):
    library = "react-icons/gi"
    tag = "GiLogicGateXor"


class GiLoincloth(rx.Component):
    library = "react-icons/gi"
    tag = "GiLoincloth"


class GiLongAntennaeBug(rx.Component):
    library = "react-icons/gi"
    tag = "GiLongAntennaeBug"


class GiLongLeggedSpider(rx.Component):
    library = "react-icons/gi"
    tag = "GiLongLeggedSpider"


class GiLookAt(rx.Component):
    library = "react-icons/gi"
    tag = "GiLookAt"


class GiLorgnette(rx.Component):
    library = "react-icons/gi"
    tag = "GiLorgnette"


class GiLostLimb(rx.Component):
    library = "react-icons/gi"
    tag = "GiLostLimb"


class GiLotusFlower(rx.Component):
    library = "react-icons/gi"
    tag = "GiLotusFlower"


class GiLotus(rx.Component):
    library = "react-icons/gi"
    tag = "GiLotus"


class GiLouvrePyramid(rx.Component):
    library = "react-icons/gi"
    tag = "GiLouvrePyramid"


class GiLoveHowl(rx.Component):
    library = "react-icons/gi"
    tag = "GiLoveHowl"


class GiLoveInjection(rx.Component):
    library = "react-icons/gi"
    tag = "GiLoveInjection"


class GiLoveLetter(rx.Component):
    library = "react-icons/gi"
    tag = "GiLoveLetter"


class GiLoveMystery(rx.Component):
    library = "react-icons/gi"
    tag = "GiLoveMystery"


class GiLoveSong(rx.Component):
    library = "react-icons/gi"
    tag = "GiLoveSong"


class GiLovers(rx.Component):
    library = "react-icons/gi"
    tag = "GiLovers"


class GiLowTide(rx.Component):
    library = "react-icons/gi"
    tag = "GiLowTide"


class GiLuchador(rx.Component):
    library = "react-icons/gi"
    tag = "GiLuchador"


class GiLuciferCannon(rx.Component):
    library = "react-icons/gi"
    tag = "GiLuciferCannon"


class GiLuckyFisherman(rx.Component):
    library = "react-icons/gi"
    tag = "GiLuckyFisherman"


class GiLuger(rx.Component):
    library = "react-icons/gi"
    tag = "GiLuger"


class GiLunarModule(rx.Component):
    library = "react-icons/gi"
    tag = "GiLunarModule"


class GiLunarWand(rx.Component):
    library = "react-icons/gi"
    tag = "GiLunarWand"


class GiLungs(rx.Component):
    library = "react-icons/gi"
    tag = "GiLungs"


class GiLynxHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiLynxHead"


class GiLyre(rx.Component):
    library = "react-icons/gi"
    tag = "GiLyre"


class GiM3GreaseGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiM3GreaseGun"


class GiMac10(rx.Component):
    library = "react-icons/gi"
    tag = "GiMac10"


class GiMaceHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiMaceHead"


class GiMachete(rx.Component):
    library = "react-icons/gi"
    tag = "GiMachete"


class GiMachineGunMagazine(rx.Component):
    library = "react-icons/gi"
    tag = "GiMachineGunMagazine"


class GiMachineGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiMachineGun"


class GiMadScientist(rx.Component):
    library = "react-icons/gi"
    tag = "GiMadScientist"


class GiMaggot(rx.Component):
    library = "react-icons/gi"
    tag = "GiMaggot"


class GiMagicAxe(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicAxe"


class GiMagicBroom(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicBroom"


class GiMagicGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicGate"


class GiMagicHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicHat"


class GiMagicLamp(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicLamp"


class GiMagicPalm(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicPalm"


class GiMagicPortal(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicPortal"


class GiMagicPotion(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicPotion"


class GiMagicShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicShield"


class GiMagicSwirl(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicSwirl"


class GiMagicTrident(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagicTrident"


class GiMagickTrick(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagickTrick"


class GiMagnetBlast(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagnetBlast"


class GiMagnetMan(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagnetMan"


class GiMagnet(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagnet"


class GiMagnifyingGlass(rx.Component):
    library = "react-icons/gi"
    tag = "GiMagnifyingGlass"


class GiMailShirt(rx.Component):
    library = "react-icons/gi"
    tag = "GiMailShirt"


class GiMailbox(rx.Component):
    library = "react-icons/gi"
    tag = "GiMailbox"


class GiMailedFist(rx.Component):
    library = "react-icons/gi"
    tag = "GiMailedFist"


class GiMale(rx.Component):
    library = "react-icons/gi"
    tag = "GiMale"


class GiMammoth(rx.Component):
    library = "react-icons/gi"
    tag = "GiMammoth"


class GiManacles(rx.Component):
    library = "react-icons/gi"
    tag = "GiManacles"


class GiMandrillHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiMandrillHead"


class GiMantaRay(rx.Component):
    library = "react-icons/gi"
    tag = "GiMantaRay"


class GiMantrap(rx.Component):
    library = "react-icons/gi"
    tag = "GiMantrap"


class GiManualJuicer(rx.Component):
    library = "react-icons/gi"
    tag = "GiManualJuicer"


class GiManualMeatGrinder(rx.Component):
    library = "react-icons/gi"
    tag = "GiManualMeatGrinder"


class GiMapleLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiMapleLeaf"


class GiMaracas(rx.Component):
    library = "react-icons/gi"
    tag = "GiMaracas"


class GiMarbleTap(rx.Component):
    library = "react-icons/gi"
    tag = "GiMarbleTap"


class GiMarbles(rx.Component):
    library = "react-icons/gi"
    tag = "GiMarbles"


class GiMarrowDrain(rx.Component):
    library = "react-icons/gi"
    tag = "GiMarrowDrain"


class GiMarsCuriosity(rx.Component):
    library = "react-icons/gi"
    tag = "GiMarsCuriosity"


class GiMarsPathfinder(rx.Component):
    library = "react-icons/gi"
    tag = "GiMarsPathfinder"


class GiMarshmallows(rx.Component):
    library = "react-icons/gi"
    tag = "GiMarshmallows"


class GiMartini(rx.Component):
    library = "react-icons/gi"
    tag = "GiMartini"


class GiMartyrMemorial(rx.Component):
    library = "react-icons/gi"
    tag = "GiMartyrMemorial"


class GiMaskedSpider(rx.Component):
    library = "react-icons/gi"
    tag = "GiMaskedSpider"


class GiMasonJar(rx.Component):
    library = "react-icons/gi"
    tag = "GiMasonJar"


class GiMassDriver(rx.Component):
    library = "react-icons/gi"
    tag = "GiMassDriver"


class GiMasterOfArms(rx.Component):
    library = "react-icons/gi"
    tag = "GiMasterOfArms"


class GiMatchHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiMatchHead"


class GiMatchTip(rx.Component):
    library = "react-icons/gi"
    tag = "GiMatchTip"


class GiMatchbox(rx.Component):
    library = "react-icons/gi"
    tag = "GiMatchbox"


class GiMaterialsScience(rx.Component):
    library = "react-icons/gi"
    tag = "GiMaterialsScience"


class GiMatryoshkaDolls(rx.Component):
    library = "react-icons/gi"
    tag = "GiMatryoshkaDolls"


class GiMatterStates(rx.Component):
    library = "react-icons/gi"
    tag = "GiMatterStates"


class GiMayanPyramid(rx.Component):
    library = "react-icons/gi"
    tag = "GiMayanPyramid"


class GiMazeCornea(rx.Component):
    library = "react-icons/gi"
    tag = "GiMazeCornea"


class GiMazeSaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiMazeSaw"


class GiMaze(rx.Component):
    library = "react-icons/gi"
    tag = "GiMaze"


class GiMeal(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeal"


class GiMeatCleaver(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeatCleaver"


class GiMeatHook(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeatHook"


class GiMeat(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeat"


class GiMechaHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiMechaHead"


class GiMechaMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiMechaMask"


class GiMechanicGarage(rx.Component):
    library = "react-icons/gi"
    tag = "GiMechanicGarage"


class GiMechanicalArm(rx.Component):
    library = "react-icons/gi"
    tag = "GiMechanicalArm"


class GiMedalSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedalSkull"


class GiMedal(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedal"


class GiMedallist(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedallist"


class GiMedicalDrip(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedicalDrip"


class GiMedicalPackAlt(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedicalPackAlt"


class GiMedicalPack(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedicalPack"


class GiMedicalThermometer(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedicalThermometer"


class GiMedicinePills(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedicinePills"


class GiMedicines(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedicines"


class GiMedievalBarracks(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedievalBarracks"


class GiMedievalGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedievalGate"


class GiMedievalPavilion(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedievalPavilion"


class GiMeditation(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeditation"


class GiMedusaHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiMedusaHead"


class GiMeepleArmy(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeepleArmy"


class GiMeepleCircle(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeepleCircle"


class GiMeepleGroup(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeepleGroup"


class GiMeepleKing(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeepleKing"


class GiMeeple(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeeple"


class GiMegabot(rx.Component):
    library = "react-icons/gi"
    tag = "GiMegabot"


class GiMegaphone(rx.Component):
    library = "react-icons/gi"
    tag = "GiMegaphone"


class GiMeltingIceCube(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeltingIceCube"


class GiMeltingMetal(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeltingMetal"


class GiMenhir(rx.Component):
    library = "react-icons/gi"
    tag = "GiMenhir"


class GiMermaid(rx.Component):
    library = "react-icons/gi"
    tag = "GiMermaid"


class GiMeshBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeshBall"


class GiMeshNetwork(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeshNetwork"


class GiMetalBar(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetalBar"


class GiMetalBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetalBoot"


class GiMetalDisc(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetalDisc"


class GiMetalGolemHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetalGolemHead"


class GiMetalHand(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetalHand"


class GiMetalPlate(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetalPlate"


class GiMetalScales(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetalScales"


class GiMetalSkirt(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetalSkirt"


class GiMeteorImpact(rx.Component):
    library = "react-icons/gi"
    tag = "GiMeteorImpact"


class GiMetroid(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetroid"


class GiMetronome(rx.Component):
    library = "react-icons/gi"
    tag = "GiMetronome"


class GiMexico(rx.Component):
    library = "react-icons/gi"
    tag = "GiMexico"


class GiMicrochip(rx.Component):
    library = "react-icons/gi"
    tag = "GiMicrochip"


class GiMicrophone(rx.Component):
    library = "react-icons/gi"
    tag = "GiMicrophone"


class GiMicroscopeLens(rx.Component):
    library = "react-icons/gi"
    tag = "GiMicroscopeLens"


class GiMicroscope(rx.Component):
    library = "react-icons/gi"
    tag = "GiMicroscope"


class GiMiddleArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiMiddleArrow"


class GiMidnightClaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiMidnightClaw"


class GiMightyBoosh(rx.Component):
    library = "react-icons/gi"
    tag = "GiMightyBoosh"


class GiMightyForce(rx.Component):
    library = "react-icons/gi"
    tag = "GiMightyForce"


class GiMightyHorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiMightyHorn"


class GiMightySpanner(rx.Component):
    library = "react-icons/gi"
    tag = "GiMightySpanner"


class GiMilitaryAmbulance(rx.Component):
    library = "react-icons/gi"
    tag = "GiMilitaryAmbulance"


class GiMilitaryFort(rx.Component):
    library = "react-icons/gi"
    tag = "GiMilitaryFort"


class GiMilkCarton(rx.Component):
    library = "react-icons/gi"
    tag = "GiMilkCarton"


class GiMilleniumKey(rx.Component):
    library = "react-icons/gi"
    tag = "GiMilleniumKey"


class GiMimicChest(rx.Component):
    library = "react-icons/gi"
    tag = "GiMimicChest"


class GiMineExplosion(rx.Component):
    library = "react-icons/gi"
    tag = "GiMineExplosion"


class GiMineTruck(rx.Component):
    library = "react-icons/gi"
    tag = "GiMineTruck"


class GiMineWagon(rx.Component):
    library = "react-icons/gi"
    tag = "GiMineWagon"


class GiMinefield(rx.Component):
    library = "react-icons/gi"
    tag = "GiMinefield"


class GiMiner(rx.Component):
    library = "react-icons/gi"
    tag = "GiMiner"


class GiMineralHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiMineralHeart"


class GiMineralPearls(rx.Component):
    library = "react-icons/gi"
    tag = "GiMineralPearls"


class GiMinerals(rx.Component):
    library = "react-icons/gi"
    tag = "GiMinerals"


class GiMiniSubmarine(rx.Component):
    library = "react-icons/gi"
    tag = "GiMiniSubmarine"


class GiMinigun(rx.Component):
    library = "react-icons/gi"
    tag = "GiMinigun"


class GiMiningHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiMiningHelmet"


class GiMining(rx.Component):
    library = "react-icons/gi"
    tag = "GiMining"


class GiMinions(rx.Component):
    library = "react-icons/gi"
    tag = "GiMinions"


class GiMinotaur(rx.Component):
    library = "react-icons/gi"
    tag = "GiMinotaur"


class GiMiracleMedecine(rx.Component):
    library = "react-icons/gi"
    tag = "GiMiracleMedecine"


class GiMirrorMirror(rx.Component):
    library = "react-icons/gi"
    tag = "GiMirrorMirror"


class GiMisdirection(rx.Component):
    library = "react-icons/gi"
    tag = "GiMisdirection"


class GiMissileLauncher(rx.Component):
    library = "react-icons/gi"
    tag = "GiMissileLauncher"


class GiMissileMech(rx.Component):
    library = "react-icons/gi"
    tag = "GiMissileMech"


class GiMissilePod(rx.Component):
    library = "react-icons/gi"
    tag = "GiMissilePod"


class GiMissileSwarm(rx.Component):
    library = "react-icons/gi"
    tag = "GiMissileSwarm"


class GiMiteAlt(rx.Component):
    library = "react-icons/gi"
    tag = "GiMiteAlt"


class GiMite(rx.Component):
    library = "react-icons/gi"
    tag = "GiMite"


class GiMoai(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoai"


class GiModernCity(rx.Component):
    library = "react-icons/gi"
    tag = "GiModernCity"


class GiMoebiusStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoebiusStar"


class GiMoebiusTrefoil(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoebiusTrefoil"


class GiMoebiusTriangle(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoebiusTriangle"


class GiMokaPot(rx.Component):
    library = "react-icons/gi"
    tag = "GiMokaPot"


class GiMoldova(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoldova"


class GiMolecule(rx.Component):
    library = "react-icons/gi"
    tag = "GiMolecule"


class GiMolotov(rx.Component):
    library = "react-icons/gi"
    tag = "GiMolotov"


class GiMonaLisa(rx.Component):
    library = "react-icons/gi"
    tag = "GiMonaLisa"


class GiMonclerJacket(rx.Component):
    library = "react-icons/gi"
    tag = "GiMonclerJacket"


class GiMoneyStack(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoneyStack"


class GiMongolia(rx.Component):
    library = "react-icons/gi"
    tag = "GiMongolia"


class GiMonkFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiMonkFace"


class GiMonkeyWrench(rx.Component):
    library = "react-icons/gi"
    tag = "GiMonkeyWrench"


class GiMonkey(rx.Component):
    library = "react-icons/gi"
    tag = "GiMonkey"


class GiMonoWheelRobot(rx.Component):
    library = "react-icons/gi"
    tag = "GiMonoWheelRobot"


class GiMonsterGrasp(rx.Component):
    library = "react-icons/gi"
    tag = "GiMonsterGrasp"


class GiMonsteraLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiMonsteraLeaf"


class GiMonumentValley(rx.Component):
    library = "react-icons/gi"
    tag = "GiMonumentValley"


class GiMoonBats(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoonBats"


class GiMoonClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoonClaws"


class GiMoonOrbit(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoonOrbit"


class GiMoon(rx.Component):
    library = "react-icons/gi"
    tag = "GiMoon"


class GiMooringBollard(rx.Component):
    library = "react-icons/gi"
    tag = "GiMooringBollard"


class GiMorbidHumour(rx.Component):
    library = "react-icons/gi"
    tag = "GiMorbidHumour"


class GiMorgueFeet(rx.Component):
    library = "react-icons/gi"
    tag = "GiMorgueFeet"


class GiMorphBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiMorphBall"


class GiMortar(rx.Component):
    library = "react-icons/gi"
    tag = "GiMortar"


class GiMountainCave(rx.Component):
    library = "react-icons/gi"
    tag = "GiMountainCave"


class GiMountainClimbing(rx.Component):
    library = "react-icons/gi"
    tag = "GiMountainClimbing"


class GiMountainRoad(rx.Component):
    library = "react-icons/gi"
    tag = "GiMountainRoad"


class GiMountains(rx.Component):
    library = "react-icons/gi"
    tag = "GiMountains"


class GiMountaintop(rx.Component):
    library = "react-icons/gi"
    tag = "GiMountaintop"


class GiMountedKnight(rx.Component):
    library = "react-icons/gi"
    tag = "GiMountedKnight"


class GiMouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiMouse"


class GiMouthWatering(rx.Component):
    library = "react-icons/gi"
    tag = "GiMouthWatering"


class GiMove(rx.Component):
    library = "react-icons/gi"
    tag = "GiMove"


class GiMovementSensor(rx.Component):
    library = "react-icons/gi"
    tag = "GiMovementSensor"


class GiMp40(rx.Component):
    library = "react-icons/gi"
    tag = "GiMp40"


class GiMp5(rx.Component):
    library = "react-icons/gi"
    tag = "GiMp5"


class GiMp5K(rx.Component):
    library = "react-icons/gi"
    tag = "GiMp5K"


class GiMucousPillar(rx.Component):
    library = "react-icons/gi"
    tag = "GiMucousPillar"


class GiMugShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiMugShot"


class GiMultiDirections(rx.Component):
    library = "react-icons/gi"
    tag = "GiMultiDirections"


class GiMultipleTargets(rx.Component):
    library = "react-icons/gi"
    tag = "GiMultipleTargets"


class GiMummyHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiMummyHead"


class GiMuscleFat(rx.Component):
    library = "react-icons/gi"
    tag = "GiMuscleFat"


class GiMuscleUp(rx.Component):
    library = "react-icons/gi"
    tag = "GiMuscleUp"


class GiMuscularTorso(rx.Component):
    library = "react-icons/gi"
    tag = "GiMuscularTorso"


class GiMushroomCloud(rx.Component):
    library = "react-icons/gi"
    tag = "GiMushroomCloud"


class GiMushroomGills(rx.Component):
    library = "react-icons/gi"
    tag = "GiMushroomGills"


class GiMushroomHouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiMushroomHouse"


class GiMushroom(rx.Component):
    library = "react-icons/gi"
    tag = "GiMushroom"


class GiMushroomsCluster(rx.Component):
    library = "react-icons/gi"
    tag = "GiMushroomsCluster"


class GiMushrooms(rx.Component):
    library = "react-icons/gi"
    tag = "GiMushrooms"


class GiMusicSpell(rx.Component):
    library = "react-icons/gi"
    tag = "GiMusicSpell"


class GiMusicalKeyboard(rx.Component):
    library = "react-icons/gi"
    tag = "GiMusicalKeyboard"


class GiMusicalNotes(rx.Component):
    library = "react-icons/gi"
    tag = "GiMusicalNotes"


class GiMusicalScore(rx.Component):
    library = "react-icons/gi"
    tag = "GiMusicalScore"


class GiMusket(rx.Component):
    library = "react-icons/gi"
    tag = "GiMusket"


class GiMussel(rx.Component):
    library = "react-icons/gi"
    tag = "GiMussel"


class GiMustache(rx.Component):
    library = "react-icons/gi"
    tag = "GiMustache"


class GiMute(rx.Component):
    library = "react-icons/gi"
    tag = "GiMute"


class GiNachos(rx.Component):
    library = "react-icons/gi"
    tag = "GiNachos"


class GiNailedFoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiNailedFoot"


class GiNailedHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiNailedHead"


class GiNails(rx.Component):
    library = "react-icons/gi"
    tag = "GiNails"


class GiNanoBot(rx.Component):
    library = "react-icons/gi"
    tag = "GiNanoBot"


class GiNautilusShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiNautilusShell"


class GiNeckBite(rx.Component):
    library = "react-icons/gi"
    tag = "GiNeckBite"


class GiNecklaceDisplay(rx.Component):
    library = "react-icons/gi"
    tag = "GiNecklaceDisplay"


class GiNecklace(rx.Component):
    library = "react-icons/gi"
    tag = "GiNecklace"


class GiNeedleDrill(rx.Component):
    library = "react-icons/gi"
    tag = "GiNeedleDrill"


class GiNeedleJaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiNeedleJaws"


class GiNefertiti(rx.Component):
    library = "react-icons/gi"
    tag = "GiNefertiti"


class GiNestBirds(rx.Component):
    library = "react-icons/gi"
    tag = "GiNestBirds"


class GiNestEggs(rx.Component):
    library = "react-icons/gi"
    tag = "GiNestEggs"


class GiNestedEclipses(rx.Component):
    library = "react-icons/gi"
    tag = "GiNestedEclipses"


class GiNestedHearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiNestedHearts"


class GiNestedHexagons(rx.Component):
    library = "react-icons/gi"
    tag = "GiNestedHexagons"


class GiNetworkBars(rx.Component):
    library = "react-icons/gi"
    tag = "GiNetworkBars"


class GiNewBorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiNewBorn"


class GiNewShoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiNewShoot"


class GiNewspaper(rx.Component):
    library = "react-icons/gi"
    tag = "GiNewspaper"


class GiNextButton(rx.Component):
    library = "react-icons/gi"
    tag = "GiNextButton"


class GiNigeria(rx.Component):
    library = "react-icons/gi"
    tag = "GiNigeria"


class GiNightSky(rx.Component):
    library = "react-icons/gi"
    tag = "GiNightSky"


class GiNightSleep(rx.Component):
    library = "react-icons/gi"
    tag = "GiNightSleep"


class GiNightVision(rx.Component):
    library = "react-icons/gi"
    tag = "GiNightVision"


class GiNinjaArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiNinjaArmor"


class GiNinjaHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiNinjaHead"


class GiNinjaHeroicStance(rx.Component):
    library = "react-icons/gi"
    tag = "GiNinjaHeroicStance"


class GiNinjaMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiNinjaMask"


class GiNinjaStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiNinjaStar"


class GiNinjaVelociraptor(rx.Component):
    library = "react-icons/gi"
    tag = "GiNinjaVelociraptor"


class GiNodular(rx.Component):
    library = "react-icons/gi"
    tag = "GiNodular"


class GiNoodleBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiNoodleBall"


class GiNoodles(rx.Component):
    library = "react-icons/gi"
    tag = "GiNoodles"


class GiNorthStarShuriken(rx.Component):
    library = "react-icons/gi"
    tag = "GiNorthStarShuriken"


class GiNoseFront(rx.Component):
    library = "react-icons/gi"
    tag = "GiNoseFront"


class GiNoseSide(rx.Component):
    library = "react-icons/gi"
    tag = "GiNoseSide"


class GiNotebook(rx.Component):
    library = "react-icons/gi"
    tag = "GiNotebook"


class GiNothingToSay(rx.Component):
    library = "react-icons/gi"
    tag = "GiNothingToSay"


class GiNuclearBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiNuclearBomb"


class GiNuclearPlant(rx.Component):
    library = "react-icons/gi"
    tag = "GiNuclearPlant"


class GiNuclearWaste(rx.Component):
    library = "react-icons/gi"
    tag = "GiNuclearWaste"


class GiNuclear(rx.Component):
    library = "react-icons/gi"
    tag = "GiNuclear"


class GiNunFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiNunFace"


class GiNunchaku(rx.Component):
    library = "react-icons/gi"
    tag = "GiNunchaku"


class GiNurseFemale(rx.Component):
    library = "react-icons/gi"
    tag = "GiNurseFemale"


class GiNurseMale(rx.Component):
    library = "react-icons/gi"
    tag = "GiNurseMale"


class GiOBrick(rx.Component):
    library = "react-icons/gi"
    tag = "GiOBrick"


class GiOakLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiOakLeaf"


class GiOak(rx.Component):
    library = "react-icons/gi"
    tag = "GiOak"


class GiOasis(rx.Component):
    library = "react-icons/gi"
    tag = "GiOasis"


class GiOat(rx.Component):
    library = "react-icons/gi"
    tag = "GiOat"


class GiObelisk(rx.Component):
    library = "react-icons/gi"
    tag = "GiObelisk"


class GiObservatory(rx.Component):
    library = "react-icons/gi"
    tag = "GiObservatory"


class GiOcarina(rx.Component):
    library = "react-icons/gi"
    tag = "GiOcarina"


class GiOccupy(rx.Component):
    library = "react-icons/gi"
    tag = "GiOccupy"


class GiOctogonalEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiOctogonalEye"


class GiOctoman(rx.Component):
    library = "react-icons/gi"
    tag = "GiOctoman"


class GiOctopus(rx.Component):
    library = "react-icons/gi"
    tag = "GiOctopus"


class GiOden(rx.Component):
    library = "react-icons/gi"
    tag = "GiOden"


class GiOfficeChair(rx.Component):
    library = "react-icons/gi"
    tag = "GiOfficeChair"


class GiOffshorePlatform(rx.Component):
    library = "react-icons/gi"
    tag = "GiOffshorePlatform"


class GiOgre(rx.Component):
    library = "react-icons/gi"
    tag = "GiOgre"


class GiOilDrum(rx.Component):
    library = "react-icons/gi"
    tag = "GiOilDrum"


class GiOilPump(rx.Component):
    library = "react-icons/gi"
    tag = "GiOilPump"


class GiOilRig(rx.Component):
    library = "react-icons/gi"
    tag = "GiOilRig"


class GiOilySpiral(rx.Component):
    library = "react-icons/gi"
    tag = "GiOilySpiral"


class GiOldKing(rx.Component):
    library = "react-icons/gi"
    tag = "GiOldKing"


class GiOldLantern(rx.Component):
    library = "react-icons/gi"
    tag = "GiOldLantern"


class GiOldMicrophone(rx.Component):
    library = "react-icons/gi"
    tag = "GiOldMicrophone"


class GiOldWagon(rx.Component):
    library = "react-icons/gi"
    tag = "GiOldWagon"


class GiOlive(rx.Component):
    library = "react-icons/gi"
    tag = "GiOlive"


class GiOmega(rx.Component):
    library = "react-icons/gi"
    tag = "GiOmega"


class GiOnSight(rx.Component):
    library = "react-icons/gi"
    tag = "GiOnSight"


class GiOnTarget(rx.Component):
    library = "react-icons/gi"
    tag = "GiOnTarget"


class GiOneEyed(rx.Component):
    library = "react-icons/gi"
    tag = "GiOneEyed"


class GiOni(rx.Component):
    library = "react-icons/gi"
    tag = "GiOni"


class GiOnigori(rx.Component):
    library = "react-icons/gi"
    tag = "GiOnigori"


class GiOpenBook(rx.Component):
    library = "react-icons/gi"
    tag = "GiOpenBook"


class GiOpenChest(rx.Component):
    library = "react-icons/gi"
    tag = "GiOpenChest"


class GiOpenFolder(rx.Component):
    library = "react-icons/gi"
    tag = "GiOpenFolder"


class GiOpenGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiOpenGate"


class GiOpenPalm(rx.Component):
    library = "react-icons/gi"
    tag = "GiOpenPalm"


class GiOpenTreasureChest(rx.Component):
    library = "react-icons/gi"
    tag = "GiOpenTreasureChest"


class GiOpenWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiOpenWound"


class GiOpenedFoodCan(rx.Component):
    library = "react-icons/gi"
    tag = "GiOpenedFoodCan"


class GiOpeningShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiOpeningShell"


class GiOphiuchus(rx.Component):
    library = "react-icons/gi"
    tag = "GiOphiuchus"


class GiOppidum(rx.Component):
    library = "react-icons/gi"
    tag = "GiOppidum"


class GiOppositeHearts(rx.Component):
    library = "react-icons/gi"
    tag = "GiOppositeHearts"


class GiOppression(rx.Component):
    library = "react-icons/gi"
    tag = "GiOppression"


class GiOrangeSlice(rx.Component):
    library = "react-icons/gi"
    tag = "GiOrangeSlice"


class GiOrange(rx.Component):
    library = "react-icons/gi"
    tag = "GiOrange"


class GiOrbDirection(rx.Component):
    library = "react-icons/gi"
    tag = "GiOrbDirection"


class GiOrbWand(rx.Component):
    library = "react-icons/gi"
    tag = "GiOrbWand"


class GiOrbit(rx.Component):
    library = "react-icons/gi"
    tag = "GiOrbit"


class GiOrbitalRays(rx.Component):
    library = "react-icons/gi"
    tag = "GiOrbitalRays"


class GiOrbital(rx.Component):
    library = "react-icons/gi"
    tag = "GiOrbital"


class GiOrcHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiOrcHead"


class GiOre(rx.Component):
    library = "react-icons/gi"
    tag = "GiOre"


class GiOrganigram(rx.Component):
    library = "react-icons/gi"
    tag = "GiOrganigram"


class GiOstrich(rx.Component):
    library = "react-icons/gi"
    tag = "GiOstrich"


class GiOuroboros(rx.Component):
    library = "react-icons/gi"
    tag = "GiOuroboros"


class GiOutbackHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiOutbackHat"


class GiOverInfinity(rx.Component):
    library = "react-icons/gi"
    tag = "GiOverInfinity"


class GiOverdose(rx.Component):
    library = "react-icons/gi"
    tag = "GiOverdose"


class GiOverdrive(rx.Component):
    library = "react-icons/gi"
    tag = "GiOverdrive"


class GiOverhead(rx.Component):
    library = "react-icons/gi"
    tag = "GiOverhead"


class GiOverkill(rx.Component):
    library = "react-icons/gi"
    tag = "GiOverkill"


class GiOverlordHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiOverlordHelm"


class GiOvermind(rx.Component):
    library = "react-icons/gi"
    tag = "GiOvermind"


class GiOwl(rx.Component):
    library = "react-icons/gi"
    tag = "GiOwl"


class GiOysterPearl(rx.Component):
    library = "react-icons/gi"
    tag = "GiOysterPearl"


class GiOyster(rx.Component):
    library = "react-icons/gi"
    tag = "GiOyster"


class GiP90(rx.Component):
    library = "react-icons/gi"
    tag = "GiP90"


class GiPackedPlanks(rx.Component):
    library = "react-icons/gi"
    tag = "GiPackedPlanks"


class GiPaddleSteamer(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaddleSteamer"


class GiPaddles(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaddles"


class GiPadlockOpen(rx.Component):
    library = "react-icons/gi"
    tag = "GiPadlockOpen"


class GiPadlock(rx.Component):
    library = "react-icons/gi"
    tag = "GiPadlock"


class GiPagoda(rx.Component):
    library = "react-icons/gi"
    tag = "GiPagoda"


class GiPaintBrush(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaintBrush"


class GiPaintBucket(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaintBucket"


class GiPaintRoller(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaintRoller"


class GiPaintedPottery(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaintedPottery"


class GiPalette(rx.Component):
    library = "react-icons/gi"
    tag = "GiPalette"


class GiPalisade(rx.Component):
    library = "react-icons/gi"
    tag = "GiPalisade"


class GiPalmTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiPalmTree"


class GiPalm(rx.Component):
    library = "react-icons/gi"
    tag = "GiPalm"


class GiPanFlute(rx.Component):
    library = "react-icons/gi"
    tag = "GiPanFlute"


class GiPanda(rx.Component):
    library = "react-icons/gi"
    tag = "GiPanda"


class GiPangolin(rx.Component):
    library = "react-icons/gi"
    tag = "GiPangolin"


class GiPanzerfaust(rx.Component):
    library = "react-icons/gi"
    tag = "GiPanzerfaust"


class GiPaperArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperArrow"


class GiPaperBagCrumpled(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperBagCrumpled"


class GiPaperBagFolded(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperBagFolded"


class GiPaperBagOpen(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperBagOpen"


class GiPaperBoat(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperBoat"


class GiPaperBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperBomb"


class GiPaperClip(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperClip"


class GiPaperCrane(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperCrane"


class GiPaperFrog(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperFrog"


class GiPaperLantern(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperLantern"


class GiPaperPlane(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperPlane"


class GiPaperTray(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperTray"


class GiPaperWindmill(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaperWindmill"


class GiPaper(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaper"


class GiPapers(rx.Component):
    library = "react-icons/gi"
    tag = "GiPapers"


class GiPapyrus(rx.Component):
    library = "react-icons/gi"
    tag = "GiPapyrus"


class GiParachute(rx.Component):
    library = "react-icons/gi"
    tag = "GiParachute"


class GiParaguay(rx.Component):
    library = "react-icons/gi"
    tag = "GiParaguay"


class GiParanoia(rx.Component):
    library = "react-icons/gi"
    tag = "GiParanoia"


class GiParasaurolophus(rx.Component):
    library = "react-icons/gi"
    tag = "GiParasaurolophus"


class GiParkBench(rx.Component):
    library = "react-icons/gi"
    tag = "GiParkBench"


class GiParmecia(rx.Component):
    library = "react-icons/gi"
    tag = "GiParmecia"


class GiParrotHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiParrotHead"


class GiPartyFlags(rx.Component):
    library = "react-icons/gi"
    tag = "GiPartyFlags"


class GiPartyHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiPartyHat"


class GiPartyPopper(rx.Component):
    library = "react-icons/gi"
    tag = "GiPartyPopper"


class GiPassport(rx.Component):
    library = "react-icons/gi"
    tag = "GiPassport"


class GiPathDistance(rx.Component):
    library = "react-icons/gi"
    tag = "GiPathDistance"


class GiPathTile(rx.Component):
    library = "react-icons/gi"
    tag = "GiPathTile"


class GiPauldrons(rx.Component):
    library = "react-icons/gi"
    tag = "GiPauldrons"


class GiPauseButton(rx.Component):
    library = "react-icons/gi"
    tag = "GiPauseButton"


class GiPawFront(rx.Component):
    library = "react-icons/gi"
    tag = "GiPawFront"


class GiPawHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiPawHeart"


class GiPawPrint(rx.Component):
    library = "react-icons/gi"
    tag = "GiPawPrint"


class GiPaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiPaw"


class GiPawn(rx.Component):
    library = "react-icons/gi"
    tag = "GiPawn"


class GiPayMoney(rx.Component):
    library = "react-icons/gi"
    tag = "GiPayMoney"


class GiPc(rx.Component):
    library = "react-icons/gi"
    tag = "GiPc"


class GiPeaceDove(rx.Component):
    library = "react-icons/gi"
    tag = "GiPeaceDove"


class GiPeach(rx.Component):
    library = "react-icons/gi"
    tag = "GiPeach"


class GiPeaks(rx.Component):
    library = "react-icons/gi"
    tag = "GiPeaks"


class GiPeanut(rx.Component):
    library = "react-icons/gi"
    tag = "GiPeanut"


class GiPear(rx.Component):
    library = "react-icons/gi"
    tag = "GiPear"


class GiPearlEarring(rx.Component):
    library = "react-icons/gi"
    tag = "GiPearlEarring"


class GiPearlNecklace(rx.Component):
    library = "react-icons/gi"
    tag = "GiPearlNecklace"


class GiPeas(rx.Component):
    library = "react-icons/gi"
    tag = "GiPeas"


class GiPegasus(rx.Component):
    library = "react-icons/gi"
    tag = "GiPegasus"


class GiPelvisBone(rx.Component):
    library = "react-icons/gi"
    tag = "GiPelvisBone"


class GiPencilBrush(rx.Component):
    library = "react-icons/gi"
    tag = "GiPencilBrush"


class GiPencilRuler(rx.Component):
    library = "react-icons/gi"
    tag = "GiPencilRuler"


class GiPencil(rx.Component):
    library = "react-icons/gi"
    tag = "GiPencil"


class GiPendantKey(rx.Component):
    library = "react-icons/gi"
    tag = "GiPendantKey"


class GiPendulumSwing(rx.Component):
    library = "react-icons/gi"
    tag = "GiPendulumSwing"


class GiPenguin(rx.Component):
    library = "react-icons/gi"
    tag = "GiPenguin"


class GiPentacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiPentacle"


class GiPentagramRose(rx.Component):
    library = "react-icons/gi"
    tag = "GiPentagramRose"


class GiPentarrowsTornado(rx.Component):
    library = "react-icons/gi"
    tag = "GiPentarrowsTornado"


class GiPerfumeBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerfumeBottle"


class GiPeriscope(rx.Component):
    library = "react-icons/gi"
    tag = "GiPeriscope"


class GiPerpendicularRings(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerpendicularRings"


class GiPersonInBed(rx.Component):
    library = "react-icons/gi"
    tag = "GiPersonInBed"


class GiPerson(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerson"


class GiPerspectiveDiceFive(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceFive"


class GiPerspectiveDiceFour(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceFour"


class GiPerspectiveDiceOne(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceOne"


class GiPerspectiveDiceSixFacesFive(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceSixFacesFive"


class GiPerspectiveDiceSixFacesFour(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceSixFacesFour"


class GiPerspectiveDiceSixFacesOne(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceSixFacesOne"


class GiPerspectiveDiceSixFacesRandom(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceSixFacesRandom"


class GiPerspectiveDiceSixFacesSix(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceSixFacesSix"


class GiPerspectiveDiceSixFacesThree(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceSixFacesThree"


class GiPerspectiveDiceSixFacesTwo(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceSixFacesTwo"


class GiPerspectiveDiceSix(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceSix"


class GiPerspectiveDiceThree(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceThree"


class GiPerspectiveDiceTwo(rx.Component):
    library = "react-icons/gi"
    tag = "GiPerspectiveDiceTwo"


class GiPeru(rx.Component):
    library = "react-icons/gi"
    tag = "GiPeru"


class GiPestleMortar(rx.Component):
    library = "react-icons/gi"
    tag = "GiPestleMortar"


class GiPharoah(rx.Component):
    library = "react-icons/gi"
    tag = "GiPharoah"


class GiPhone(rx.Component):
    library = "react-icons/gi"
    tag = "GiPhone"


class GiPhotoCamera(rx.Component):
    library = "react-icons/gi"
    tag = "GiPhotoCamera"


class GiPhrygianCap(rx.Component):
    library = "react-icons/gi"
    tag = "GiPhrygianCap"


class GiPianist(rx.Component):
    library = "react-icons/gi"
    tag = "GiPianist"


class GiPianoKeys(rx.Component):
    library = "react-icons/gi"
    tag = "GiPianoKeys"


class GiPickOfDestiny(rx.Component):
    library = "react-icons/gi"
    tag = "GiPickOfDestiny"


class GiPickelhaube(rx.Component):
    library = "react-icons/gi"
    tag = "GiPickelhaube"


class GiPickle(rx.Component):
    library = "react-icons/gi"
    tag = "GiPickle"


class GiPieChart(rx.Component):
    library = "react-icons/gi"
    tag = "GiPieChart"


class GiPieSlice(rx.Component):
    library = "react-icons/gi"
    tag = "GiPieSlice"


class GiPieceSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiPieceSkull"


class GiPiercedBody(rx.Component):
    library = "react-icons/gi"
    tag = "GiPiercedBody"


class GiPiercedHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiPiercedHeart"


class GiPiercingSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiPiercingSword"


class GiPigFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiPigFace"


class GiPig(rx.Component):
    library = "react-icons/gi"
    tag = "GiPig"


class GiPiggyBank(rx.Component):
    library = "react-icons/gi"
    tag = "GiPiggyBank"


class GiPikeman(rx.Component):
    library = "react-icons/gi"
    tag = "GiPikeman"


class GiPilgrimHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiPilgrimHat"


class GiPillDrop(rx.Component):
    library = "react-icons/gi"
    tag = "GiPillDrop"


class GiPill(rx.Component):
    library = "react-icons/gi"
    tag = "GiPill"


class GiPillow(rx.Component):
    library = "react-icons/gi"
    tag = "GiPillow"


class GiPimiento(rx.Component):
    library = "react-icons/gi"
    tag = "GiPimiento"


class GiPin(rx.Component):
    library = "react-icons/gi"
    tag = "GiPin"


class GiPinata(rx.Component):
    library = "react-icons/gi"
    tag = "GiPinata"


class GiPinballFlipper(rx.Component):
    library = "react-icons/gi"
    tag = "GiPinballFlipper"


class GiPincers(rx.Component):
    library = "react-icons/gi"
    tag = "GiPincers"


class GiPineTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiPineTree"


class GiPineapple(rx.Component):
    library = "react-icons/gi"
    tag = "GiPineapple"


class GiPingPongBat(rx.Component):
    library = "react-icons/gi"
    tag = "GiPingPongBat"


class GiPipeOrgan(rx.Component):
    library = "react-icons/gi"
    tag = "GiPipeOrgan"


class GiPipes(rx.Component):
    library = "react-icons/gi"
    tag = "GiPipes"


class GiPiranha(rx.Component):
    library = "react-icons/gi"
    tag = "GiPiranha"


class GiPirateCannon(rx.Component):
    library = "react-icons/gi"
    tag = "GiPirateCannon"


class GiPirateCaptain(rx.Component):
    library = "react-icons/gi"
    tag = "GiPirateCaptain"


class GiPirateCoat(rx.Component):
    library = "react-icons/gi"
    tag = "GiPirateCoat"


class GiPirateFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiPirateFlag"


class GiPirateGrave(rx.Component):
    library = "react-icons/gi"
    tag = "GiPirateGrave"


class GiPirateHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiPirateHat"


class GiPirateHook(rx.Component):
    library = "react-icons/gi"
    tag = "GiPirateHook"


class GiPirateSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiPirateSkull"


class GiPisaTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiPisaTower"


class GiPisces(rx.Component):
    library = "react-icons/gi"
    tag = "GiPisces"


class GiPistolGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiPistolGun"


class GiPitchfork(rx.Component):
    library = "react-icons/gi"
    tag = "GiPitchfork"


class GiPizzaCutter(rx.Component):
    library = "react-icons/gi"
    tag = "GiPizzaCutter"


class GiPizzaSlice(rx.Component):
    library = "react-icons/gi"
    tag = "GiPizzaSlice"


class GiPlagueDoctorProfile(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlagueDoctorProfile"


class GiPlainArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlainArrow"


class GiPlainCircle(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlainCircle"


class GiPlainDagger(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlainDagger"


class GiPlainSquare(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlainSquare"


class GiPlanePilot(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlanePilot"


class GiPlaneWing(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlaneWing"


class GiPlanetConquest(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlanetConquest"


class GiPlanetCore(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlanetCore"


class GiPlanks(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlanks"


class GiPlantRoots(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlantRoots"


class GiPlantSeed(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlantSeed"


class GiPlantWatering(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlantWatering"


class GiPlantsAndAnimals(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlantsAndAnimals"


class GiPlasmaBolt(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlasmaBolt"


class GiPlasticDuck(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlasticDuck"


class GiPlastron(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlastron"


class GiPlateClaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlateClaw"


class GiPlatform(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlatform"


class GiPlayButton(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlayButton"


class GiPlayerBase(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlayerBase"


class GiPlayerNext(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlayerNext"


class GiPlayerPrevious(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlayerPrevious"


class GiPlayerTime(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlayerTime"


class GiPlesiosaurus(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlesiosaurus"


class GiPlow(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlow"


class GiPlug(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlug"


class GiPlunger(rx.Component):
    library = "react-icons/gi"
    tag = "GiPlunger"


class GiPocketBow(rx.Component):
    library = "react-icons/gi"
    tag = "GiPocketBow"


class GiPocketRadio(rx.Component):
    library = "react-icons/gi"
    tag = "GiPocketRadio"


class GiPocketWatch(rx.Component):
    library = "react-icons/gi"
    tag = "GiPocketWatch"


class GiPodiumSecond(rx.Component):
    library = "react-icons/gi"
    tag = "GiPodiumSecond"


class GiPodiumThird(rx.Component):
    library = "react-icons/gi"
    tag = "GiPodiumThird"


class GiPodiumWinner(rx.Component):
    library = "react-icons/gi"
    tag = "GiPodiumWinner"


class GiPodium(rx.Component):
    library = "react-icons/gi"
    tag = "GiPodium"


class GiPointing(rx.Component):
    library = "react-icons/gi"
    tag = "GiPointing"


class GiPointyHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiPointyHat"


class GiPointySword(rx.Component):
    library = "react-icons/gi"
    tag = "GiPointySword"


class GiPoisonBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoisonBottle"


class GiPoisonCloud(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoisonCloud"


class GiPoisonGas(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoisonGas"


class GiPoison(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoison"


class GiPokecog(rx.Component):
    library = "react-icons/gi"
    tag = "GiPokecog"


class GiPokerHand(rx.Component):
    library = "react-icons/gi"
    tag = "GiPokerHand"


class GiPoland(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoland"


class GiPolarBear(rx.Component):
    library = "react-icons/gi"
    tag = "GiPolarBear"


class GiPolarStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiPolarStar"


class GiPoliceBadge(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoliceBadge"


class GiPoliceCar(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoliceCar"


class GiPoliceOfficerHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoliceOfficerHead"


class GiPoliceTarget(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoliceTarget"


class GiPollenDust(rx.Component):
    library = "react-icons/gi"
    tag = "GiPollenDust"


class GiPoloShirt(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoloShirt"


class GiPoncho(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoncho"


class GiPoolDive(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoolDive"


class GiPoolTableCorner(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoolTableCorner"


class GiPoolTriangle(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoolTriangle"


class GiPopcorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiPopcorn"


class GiPopeCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiPopeCrown"


class GiPoppy(rx.Component):
    library = "react-icons/gi"
    tag = "GiPoppy"


class GiPorcelainVase(rx.Component):
    library = "react-icons/gi"
    tag = "GiPorcelainVase"


class GiPorcupine(rx.Component):
    library = "react-icons/gi"
    tag = "GiPorcupine"


class GiPorcupinefish(rx.Component):
    library = "react-icons/gi"
    tag = "GiPorcupinefish"


class GiPortal(rx.Component):
    library = "react-icons/gi"
    tag = "GiPortal"


class GiPortculis(rx.Component):
    library = "react-icons/gi"
    tag = "GiPortculis"


class GiPortrait(rx.Component):
    library = "react-icons/gi"
    tag = "GiPortrait"


class GiPortugal(rx.Component):
    library = "react-icons/gi"
    tag = "GiPortugal"


class GiPositionMarker(rx.Component):
    library = "react-icons/gi"
    tag = "GiPositionMarker"


class GiPostOffice(rx.Component):
    library = "react-icons/gi"
    tag = "GiPostOffice"


class GiPostStamp(rx.Component):
    library = "react-icons/gi"
    tag = "GiPostStamp"


class GiPotato(rx.Component):
    library = "react-icons/gi"
    tag = "GiPotato"


class GiPotionBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiPotionBall"


class GiPotionOfMadness(rx.Component):
    library = "react-icons/gi"
    tag = "GiPotionOfMadness"


class GiPounce(rx.Component):
    library = "react-icons/gi"
    tag = "GiPounce"


class GiPouringChalice(rx.Component):
    library = "react-icons/gi"
    tag = "GiPouringChalice"


class GiPouringPot(rx.Component):
    library = "react-icons/gi"
    tag = "GiPouringPot"


class GiPowderBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiPowderBag"


class GiPowder(rx.Component):
    library = "react-icons/gi"
    tag = "GiPowder"


class GiPowerButton(rx.Component):
    library = "react-icons/gi"
    tag = "GiPowerButton"


class GiPowerGenerator(rx.Component):
    library = "react-icons/gi"
    tag = "GiPowerGenerator"


class GiPowerLightning(rx.Component):
    library = "react-icons/gi"
    tag = "GiPowerLightning"


class GiPowerRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiPowerRing"


class GiPrayerBeads(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrayerBeads"


class GiPrayer(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrayer"


class GiPrayingMantis(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrayingMantis"


class GiPresent(rx.Component):
    library = "react-icons/gi"
    tag = "GiPresent"


class GiPressureCooker(rx.Component):
    library = "react-icons/gi"
    tag = "GiPressureCooker"


class GiPrettyFangs(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrettyFangs"


class GiPretzel(rx.Component):
    library = "react-icons/gi"
    tag = "GiPretzel"


class GiPreviousButton(rx.Component):
    library = "react-icons/gi"
    tag = "GiPreviousButton"


class GiPriceTag(rx.Component):
    library = "react-icons/gi"
    tag = "GiPriceTag"


class GiPrimitiveNecklace(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrimitiveNecklace"


class GiPrimitiveTorch(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrimitiveTorch"


class GiPrism(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrism"


class GiPrisoner(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrisoner"


class GiPrivateFirstClass(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrivateFirstClass"


class GiPrivate(rx.Component):
    library = "react-icons/gi"
    tag = "GiPrivate"


class GiProcessor(rx.Component):
    library = "react-icons/gi"
    tag = "GiProcessor"


class GiProfit(rx.Component):
    library = "react-icons/gi"
    tag = "GiProfit"


class GiProgression(rx.Component):
    library = "react-icons/gi"
    tag = "GiProgression"


class GiPropellerBeanie(rx.Component):
    library = "react-icons/gi"
    tag = "GiPropellerBeanie"


class GiProtectionGlasses(rx.Component):
    library = "react-icons/gi"
    tag = "GiProtectionGlasses"


class GiPschentDoubleCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiPschentDoubleCrown"


class GiPsychicWaves(rx.Component):
    library = "react-icons/gi"
    tag = "GiPsychicWaves"


class GiPterodactylus(rx.Component):
    library = "react-icons/gi"
    tag = "GiPterodactylus"


class GiPteruges(rx.Component):
    library = "react-icons/gi"
    tag = "GiPteruges"


class GiPublicSpeaker(rx.Component):
    library = "react-icons/gi"
    tag = "GiPublicSpeaker"


class GiPull(rx.Component):
    library = "react-icons/gi"
    tag = "GiPull"


class GiPulleyHook(rx.Component):
    library = "react-icons/gi"
    tag = "GiPulleyHook"


class GiPulse(rx.Component):
    library = "react-icons/gi"
    tag = "GiPulse"


class GiPummeled(rx.Component):
    library = "react-icons/gi"
    tag = "GiPummeled"


class GiPumpkinLantern(rx.Component):
    library = "react-icons/gi"
    tag = "GiPumpkinLantern"


class GiPumpkinMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiPumpkinMask"


class GiPumpkin(rx.Component):
    library = "react-icons/gi"
    tag = "GiPumpkin"


class GiPunchBlast(rx.Component):
    library = "react-icons/gi"
    tag = "GiPunchBlast"


class GiPunch(rx.Component):
    library = "react-icons/gi"
    tag = "GiPunch"


class GiPunchingBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiPunchingBag"


class GiPuppet(rx.Component):
    library = "react-icons/gi"
    tag = "GiPuppet"


class GiPurpleTentacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiPurpleTentacle"


class GiPush(rx.Component):
    library = "react-icons/gi"
    tag = "GiPush"


class GiPuzzle(rx.Component):
    library = "react-icons/gi"
    tag = "GiPuzzle"


class GiPylon(rx.Component):
    library = "react-icons/gi"
    tag = "GiPylon"


class GiPyre(rx.Component):
    library = "react-icons/gi"
    tag = "GiPyre"


class GiPyromaniac(rx.Component):
    library = "react-icons/gi"
    tag = "GiPyromaniac"


class GiQaitbayCitadel(rx.Component):
    library = "react-icons/gi"
    tag = "GiQaitbayCitadel"


class GiQuakeStomp(rx.Component):
    library = "react-icons/gi"
    tag = "GiQuakeStomp"


class GiQueenCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiQueenCrown"


class GiQuickMan(rx.Component):
    library = "react-icons/gi"
    tag = "GiQuickMan"


class GiQuickSlash(rx.Component):
    library = "react-icons/gi"
    tag = "GiQuickSlash"


class GiQuicksand(rx.Component):
    library = "react-icons/gi"
    tag = "GiQuicksand"


class GiQuillInk(rx.Component):
    library = "react-icons/gi"
    tag = "GiQuillInk"


class GiQuill(rx.Component):
    library = "react-icons/gi"
    tag = "GiQuill"


class GiQuiver(rx.Component):
    library = "react-icons/gi"
    tag = "GiQuiver"


class GiRabbitHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiRabbitHead"


class GiRabbit(rx.Component):
    library = "react-icons/gi"
    tag = "GiRabbit"


class GiRaccoonHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaccoonHead"


class GiRaceCar(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaceCar"


class GiRadarCrossSection(rx.Component):
    library = "react-icons/gi"
    tag = "GiRadarCrossSection"


class GiRadarDish(rx.Component):
    library = "react-icons/gi"
    tag = "GiRadarDish"


class GiRadarSweep(rx.Component):
    library = "react-icons/gi"
    tag = "GiRadarSweep"


class GiRaddish(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaddish"


class GiRadialBalance(rx.Component):
    library = "react-icons/gi"
    tag = "GiRadialBalance"


class GiRadiations(rx.Component):
    library = "react-icons/gi"
    tag = "GiRadiations"


class GiRadioTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiRadioTower"


class GiRadioactive(rx.Component):
    library = "react-icons/gi"
    tag = "GiRadioactive"


class GiRaft(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaft"


class GiRaggedWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaggedWound"


class GiRailRoad(rx.Component):
    library = "react-icons/gi"
    tag = "GiRailRoad"


class GiRailway(rx.Component):
    library = "react-icons/gi"
    tag = "GiRailway"


class GiRainbowStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiRainbowStar"


class GiRaining(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaining"


class GiRaiseSkeleton(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaiseSkeleton"


class GiRaiseZombie(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaiseZombie"


class GiRake(rx.Component):
    library = "react-icons/gi"
    tag = "GiRake"


class GiRallyTheTroops(rx.Component):
    library = "react-icons/gi"
    tag = "GiRallyTheTroops"


class GiRamProfile(rx.Component):
    library = "react-icons/gi"
    tag = "GiRamProfile"


class GiRam(rx.Component):
    library = "react-icons/gi"
    tag = "GiRam"


class GiRanchGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiRanchGate"


class GiRank1(rx.Component):
    library = "react-icons/gi"
    tag = "GiRank1"


class GiRank2(rx.Component):
    library = "react-icons/gi"
    tag = "GiRank2"


class GiRank3(rx.Component):
    library = "react-icons/gi"
    tag = "GiRank3"


class GiRapidshareArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiRapidshareArrow"


class GiRaspberry(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaspberry"


class GiRat(rx.Component):
    library = "react-icons/gi"
    tag = "GiRat"


class GiRattlesnake(rx.Component):
    library = "react-icons/gi"
    tag = "GiRattlesnake"


class GiRaven(rx.Component):
    library = "react-icons/gi"
    tag = "GiRaven"


class GiRawEgg(rx.Component):
    library = "react-icons/gi"
    tag = "GiRawEgg"


class GiRayGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiRayGun"


class GiRazorBlade(rx.Component):
    library = "react-icons/gi"
    tag = "GiRazorBlade"


class GiRazor(rx.Component):
    library = "react-icons/gi"
    tag = "GiRazor"


class GiReactor(rx.Component):
    library = "react-icons/gi"
    tag = "GiReactor"


class GiRead(rx.Component):
    library = "react-icons/gi"
    tag = "GiRead"


class GiReaperScythe(rx.Component):
    library = "react-icons/gi"
    tag = "GiReaperScythe"


class GiRearAura(rx.Component):
    library = "react-icons/gi"
    tag = "GiRearAura"


class GiReceiveMoney(rx.Component):
    library = "react-icons/gi"
    tag = "GiReceiveMoney"


class GiRecycle(rx.Component):
    library = "react-icons/gi"
    tag = "GiRecycle"


class GiRedCarpet(rx.Component):
    library = "react-icons/gi"
    tag = "GiRedCarpet"


class GiReed(rx.Component):
    library = "react-icons/gi"
    tag = "GiReed"


class GiRefinery(rx.Component):
    library = "react-icons/gi"
    tag = "GiRefinery"


class GiRegeneration(rx.Component):
    library = "react-icons/gi"
    tag = "GiRegeneration"


class GiRelationshipBounds(rx.Component):
    library = "react-icons/gi"
    tag = "GiRelationshipBounds"


class GiRelicBlade(rx.Component):
    library = "react-icons/gi"
    tag = "GiRelicBlade"


class GiReloadGunBarrel(rx.Component):
    library = "react-icons/gi"
    tag = "GiReloadGunBarrel"


class GiRemedy(rx.Component):
    library = "react-icons/gi"
    tag = "GiRemedy"


class GiRempart(rx.Component):
    library = "react-icons/gi"
    tag = "GiRempart"


class GiReptileTail(rx.Component):
    library = "react-icons/gi"
    tag = "GiReptileTail"


class GiResize(rx.Component):
    library = "react-icons/gi"
    tag = "GiResize"


class GiResonance(rx.Component):
    library = "react-icons/gi"
    tag = "GiResonance"


class GiRestingVampire(rx.Component):
    library = "react-icons/gi"
    tag = "GiRestingVampire"


class GiReticule(rx.Component):
    library = "react-icons/gi"
    tag = "GiReticule"


class GiRetroController(rx.Component):
    library = "react-icons/gi"
    tag = "GiRetroController"


class GiReturnArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiReturnArrow"


class GiRevolt(rx.Component):
    library = "react-icons/gi"
    tag = "GiRevolt"


class GiRevolver(rx.Component):
    library = "react-icons/gi"
    tag = "GiRevolver"


class GiRhinocerosHorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiRhinocerosHorn"


class GiRialtoBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiRialtoBridge"


class GiRibbonMedal(rx.Component):
    library = "react-icons/gi"
    tag = "GiRibbonMedal"


class GiRibbonShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiRibbonShield"


class GiRibbon(rx.Component):
    library = "react-icons/gi"
    tag = "GiRibbon"


class GiRibcage(rx.Component):
    library = "react-icons/gi"
    tag = "GiRibcage"


class GiRiceCooker(rx.Component):
    library = "react-icons/gi"
    tag = "GiRiceCooker"


class GiRifle(rx.Component):
    library = "react-icons/gi"
    tag = "GiRifle"


class GiRingBox(rx.Component):
    library = "react-icons/gi"
    tag = "GiRingBox"


class GiRingMould(rx.Component):
    library = "react-icons/gi"
    tag = "GiRingMould"


class GiRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiRing"


class GiRingedBeam(rx.Component):
    library = "react-icons/gi"
    tag = "GiRingedBeam"


class GiRingedPlanet(rx.Component):
    library = "react-icons/gi"
    tag = "GiRingedPlanet"


class GiRingingAlarm(rx.Component):
    library = "react-icons/gi"
    tag = "GiRingingAlarm"


class GiRingingBell(rx.Component):
    library = "react-icons/gi"
    tag = "GiRingingBell"


class GiRingmaster(rx.Component):
    library = "react-icons/gi"
    tag = "GiRingmaster"


class GiRiotShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiRiotShield"


class GiRiver(rx.Component):
    library = "react-icons/gi"
    tag = "GiRiver"


class GiRoad(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoad"


class GiRoastChicken(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoastChicken"


class GiRobberHand(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobberHand"


class GiRobberMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobberMask"


class GiRobber(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobber"


class GiRobe(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobe"


class GiRobinHoodHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobinHoodHat"


class GiRobotAntennas(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobotAntennas"


class GiRobotGolem(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobotGolem"


class GiRobotGrab(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobotGrab"


class GiRobotHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobotHelmet"


class GiRobotLeg(rx.Component):
    library = "react-icons/gi"
    tag = "GiRobotLeg"


class GiRockGolem(rx.Component):
    library = "react-icons/gi"
    tag = "GiRockGolem"


class GiRock(rx.Component):
    library = "react-icons/gi"
    tag = "GiRock"


class GiRocketFlight(rx.Component):
    library = "react-icons/gi"
    tag = "GiRocketFlight"


class GiRocketThruster(rx.Component):
    library = "react-icons/gi"
    tag = "GiRocketThruster"


class GiRocket(rx.Component):
    library = "react-icons/gi"
    tag = "GiRocket"


class GiRockingChair(rx.Component):
    library = "react-icons/gi"
    tag = "GiRockingChair"


class GiRodOfAsclepius(rx.Component):
    library = "react-icons/gi"
    tag = "GiRodOfAsclepius"


class GiRogue(rx.Component):
    library = "react-icons/gi"
    tag = "GiRogue"


class GiRolledCloth(rx.Component):
    library = "react-icons/gi"
    tag = "GiRolledCloth"


class GiRollerSkate(rx.Component):
    library = "react-icons/gi"
    tag = "GiRollerSkate"


class GiRollingBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiRollingBomb"


class GiRollingDiceCup(rx.Component):
    library = "react-icons/gi"
    tag = "GiRollingDiceCup"


class GiRollingDices(rx.Component):
    library = "react-icons/gi"
    tag = "GiRollingDices"


class GiRollingEnergy(rx.Component):
    library = "react-icons/gi"
    tag = "GiRollingEnergy"


class GiRollingSuitcase(rx.Component):
    library = "react-icons/gi"
    tag = "GiRollingSuitcase"


class GiRomanShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiRomanShield"


class GiRomanToga(rx.Component):
    library = "react-icons/gi"
    tag = "GiRomanToga"


class GiRooster(rx.Component):
    library = "react-icons/gi"
    tag = "GiRooster"


class GiRootTip(rx.Component):
    library = "react-icons/gi"
    tag = "GiRootTip"


class GiRopeBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiRopeBridge"


class GiRopeCoil(rx.Component):
    library = "react-icons/gi"
    tag = "GiRopeCoil"


class GiRopeDart(rx.Component):
    library = "react-icons/gi"
    tag = "GiRopeDart"


class GiRopeway(rx.Component):
    library = "react-icons/gi"
    tag = "GiRopeway"


class GiRosaShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiRosaShield"


class GiRose(rx.Component):
    library = "react-icons/gi"
    tag = "GiRose"


class GiRotaryPhone(rx.Component):
    library = "react-icons/gi"
    tag = "GiRotaryPhone"


class GiRoughWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoughWound"


class GiRoundBottomFlask(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoundBottomFlask"


class GiRoundKnob(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoundKnob"


class GiRoundShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoundShield"


class GiRoundSilo(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoundSilo"


class GiRoundStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoundStar"


class GiRoundStrawBale(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoundStrawBale"


class GiRoundStruck(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoundStruck"


class GiRoundTable(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoundTable"


class GiRoyalLove(rx.Component):
    library = "react-icons/gi"
    tag = "GiRoyalLove"


class GiRss(rx.Component):
    library = "react-icons/gi"
    tag = "GiRss"


class GiRubElHizb(rx.Component):
    library = "react-icons/gi"
    tag = "GiRubElHizb"


class GiRubberBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiRubberBoot"


class GiRugbyConversion(rx.Component):
    library = "react-icons/gi"
    tag = "GiRugbyConversion"


class GiRuleBook(rx.Component):
    library = "react-icons/gi"
    tag = "GiRuleBook"


class GiRun(rx.Component):
    library = "react-icons/gi"
    tag = "GiRun"


class GiRuneStone(rx.Component):
    library = "react-icons/gi"
    tag = "GiRuneStone"


class GiRuneSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiRuneSword"


class GiRunningNinja(rx.Component):
    library = "react-icons/gi"
    tag = "GiRunningNinja"


class GiRunningShoe(rx.Component):
    library = "react-icons/gi"
    tag = "GiRunningShoe"


class GiRupee(rx.Component):
    library = "react-icons/gi"
    tag = "GiRupee"


class GiRustySword(rx.Component):
    library = "react-icons/gi"
    tag = "GiRustySword"


class GiSBrick(rx.Component):
    library = "react-icons/gi"
    tag = "GiSBrick"


class GiSaberAndPistol(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaberAndPistol"


class GiSaberSlash(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaberSlash"


class GiSaberTooth(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaberTooth"


class GiSaberToothedCatHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaberToothedCatHead"


class GiSabersChoc(rx.Component):
    library = "react-icons/gi"
    tag = "GiSabersChoc"


class GiSacrificialDagger(rx.Component):
    library = "react-icons/gi"
    tag = "GiSacrificialDagger"


class GiSadCrab(rx.Component):
    library = "react-icons/gi"
    tag = "GiSadCrab"


class GiSaddle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaddle"


class GiSafetyPin(rx.Component):
    library = "react-icons/gi"
    tag = "GiSafetyPin"


class GiSagittarius(rx.Component):
    library = "react-icons/gi"
    tag = "GiSagittarius"


class GiSai(rx.Component):
    library = "react-icons/gi"
    tag = "GiSai"


class GiSail(rx.Component):
    library = "react-icons/gi"
    tag = "GiSail"


class GiSailboat(rx.Component):
    library = "react-icons/gi"
    tag = "GiSailboat"


class GiSaintBasilCathedral(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaintBasilCathedral"


class GiSaiyanSuit(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaiyanSuit"


class GiSalamander(rx.Component):
    library = "react-icons/gi"
    tag = "GiSalamander"


class GiSalmon(rx.Component):
    library = "react-icons/gi"
    tag = "GiSalmon"


class GiSaloonDoors(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaloonDoors"


class GiSaloon(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaloon"


class GiSaltShaker(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaltShaker"


class GiSamaraMosque(rx.Component):
    library = "react-icons/gi"
    tag = "GiSamaraMosque"


class GiSamuraiHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiSamuraiHelmet"


class GiSamusHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiSamusHelmet"


class GiSandCastle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSandCastle"


class GiSandSnake(rx.Component):
    library = "react-icons/gi"
    tag = "GiSandSnake"


class GiSandal(rx.Component):
    library = "react-icons/gi"
    tag = "GiSandal"


class GiSandsOfTime(rx.Component):
    library = "react-icons/gi"
    tag = "GiSandsOfTime"


class GiSandstorm(rx.Component):
    library = "react-icons/gi"
    tag = "GiSandstorm"


class GiSandwich(rx.Component):
    library = "react-icons/gi"
    tag = "GiSandwich"


class GiSaphir(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaphir"


class GiSarcophagus(rx.Component):
    library = "react-icons/gi"
    tag = "GiSarcophagus"


class GiSasquatch(rx.Component):
    library = "react-icons/gi"
    tag = "GiSasquatch"


class GiSatelliteCommunication(rx.Component):
    library = "react-icons/gi"
    tag = "GiSatelliteCommunication"


class GiSattelite(rx.Component):
    library = "react-icons/gi"
    tag = "GiSattelite"


class GiSaucepan(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaucepan"


class GiSauropodHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiSauropodHead"


class GiSauropodSkeleton(rx.Component):
    library = "react-icons/gi"
    tag = "GiSauropodSkeleton"


class GiSausage(rx.Component):
    library = "react-icons/gi"
    tag = "GiSausage"


class GiSausagesRibbon(rx.Component):
    library = "react-icons/gi"
    tag = "GiSausagesRibbon"


class GiSaveArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaveArrow"


class GiSave(rx.Component):
    library = "react-icons/gi"
    tag = "GiSave"


class GiSawClaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiSawClaw"


class GiSawedOffShotgun(rx.Component):
    library = "react-icons/gi"
    tag = "GiSawedOffShotgun"


class GiSaxophone(rx.Component):
    library = "react-icons/gi"
    tag = "GiSaxophone"


class GiScabbard(rx.Component):
    library = "react-icons/gi"
    tag = "GiScabbard"


class GiScaleMail(rx.Component):
    library = "react-icons/gi"
    tag = "GiScaleMail"


class GiScales(rx.Component):
    library = "react-icons/gi"
    tag = "GiScales"


class GiScallop(rx.Component):
    library = "react-icons/gi"
    tag = "GiScallop"


class GiScalpelStrike(rx.Component):
    library = "react-icons/gi"
    tag = "GiScalpelStrike"


class GiScalpel(rx.Component):
    library = "react-icons/gi"
    tag = "GiScalpel"


class GiScarWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiScarWound"


class GiScarabBeetle(rx.Component):
    library = "react-icons/gi"
    tag = "GiScarabBeetle"


class GiScarecrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiScarecrow"


class GiSchoolBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiSchoolBag"


class GiSchoolOfFish(rx.Component):
    library = "react-icons/gi"
    tag = "GiSchoolOfFish"


class GiScissors(rx.Component):
    library = "react-icons/gi"
    tag = "GiScissors"


class GiScooter(rx.Component):
    library = "react-icons/gi"
    tag = "GiScooter"


class GiScorpio(rx.Component):
    library = "react-icons/gi"
    tag = "GiScorpio"


class GiScorpionTail(rx.Component):
    library = "react-icons/gi"
    tag = "GiScorpionTail"


class GiScorpion(rx.Component):
    library = "react-icons/gi"
    tag = "GiScorpion"


class GiScoutShip(rx.Component):
    library = "react-icons/gi"
    tag = "GiScoutShip"


class GiScreaming(rx.Component):
    library = "react-icons/gi"
    tag = "GiScreaming"


class GiScreenImpact(rx.Component):
    library = "react-icons/gi"
    tag = "GiScreenImpact"


class GiScrew(rx.Component):
    library = "react-icons/gi"
    tag = "GiScrew"


class GiScrewdriver(rx.Component):
    library = "react-icons/gi"
    tag = "GiScrewdriver"


class GiScrollQuill(rx.Component):
    library = "react-icons/gi"
    tag = "GiScrollQuill"


class GiScrollUnfurled(rx.Component):
    library = "react-icons/gi"
    tag = "GiScrollUnfurled"


class GiScubaMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiScubaMask"


class GiScubaTanks(rx.Component):
    library = "react-icons/gi"
    tag = "GiScubaTanks"


class GiScythe(rx.Component):
    library = "react-icons/gi"
    tag = "GiScythe"


class GiSeaCliff(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeaCliff"


class GiSeaCreature(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeaCreature"


class GiSeaDragon(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeaDragon"


class GiSeaSerpent(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeaSerpent"


class GiSeaStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeaStar"


class GiSeaTurtle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeaTurtle"


class GiSeagull(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeagull"


class GiSeahorse(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeahorse"


class GiSeatedMouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeatedMouse"


class GiSecretBook(rx.Component):
    library = "react-icons/gi"
    tag = "GiSecretBook"


class GiSecretDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiSecretDoor"


class GiSecurityGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiSecurityGate"


class GiSeedling(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeedling"


class GiSelect(rx.Component):
    library = "react-icons/gi"
    tag = "GiSelect"


class GiSelfLove(rx.Component):
    library = "react-icons/gi"
    tag = "GiSelfLove"


class GiSellCard(rx.Component):
    library = "react-icons/gi"
    tag = "GiSellCard"


class GiSemiClosedEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiSemiClosedEye"


class GiSensuousness(rx.Component):
    library = "react-icons/gi"
    tag = "GiSensuousness"


class GiSentryGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiSentryGun"


class GiSergeant(rx.Component):
    library = "react-icons/gi"
    tag = "GiSergeant"


class GiSerratedSlash(rx.Component):
    library = "react-icons/gi"
    tag = "GiSerratedSlash"


class GiServerRack(rx.Component):
    library = "react-icons/gi"
    tag = "GiServerRack"


class GiSesame(rx.Component):
    library = "react-icons/gi"
    tag = "GiSesame"


class GiSettingsKnobs(rx.Component):
    library = "react-icons/gi"
    tag = "GiSettingsKnobs"


class GiSevenPointedStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiSevenPointedStar"


class GiSeveredHand(rx.Component):
    library = "react-icons/gi"
    tag = "GiSeveredHand"


class GiSewedShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiSewedShell"


class GiSewingMachine(rx.Component):
    library = "react-icons/gi"
    tag = "GiSewingMachine"


class GiSewingNeedle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSewingNeedle"


class GiSewingString(rx.Component):
    library = "react-icons/gi"
    tag = "GiSewingString"


class GiSextant(rx.Component):
    library = "react-icons/gi"
    tag = "GiSextant"


class GiShadowFollower(rx.Component):
    library = "react-icons/gi"
    tag = "GiShadowFollower"


class GiShadowGrasp(rx.Component):
    library = "react-icons/gi"
    tag = "GiShadowGrasp"


class GiShakingHands(rx.Component):
    library = "react-icons/gi"
    tag = "GiShakingHands"


class GiShamblingMound(rx.Component):
    library = "react-icons/gi"
    tag = "GiShamblingMound"


class GiShamblingZombie(rx.Component):
    library = "react-icons/gi"
    tag = "GiShamblingZombie"


class GiShamrock(rx.Component):
    library = "react-icons/gi"
    tag = "GiShamrock"


class GiShardSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiShardSword"


class GiShare(rx.Component):
    library = "react-icons/gi"
    tag = "GiShare"


class GiSharkBite(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharkBite"


class GiSharkFin(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharkFin"


class GiSharkJaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharkJaws"


class GiSharpAxe(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharpAxe"


class GiSharpCrown(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharpCrown"


class GiSharpHalberd(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharpHalberd"


class GiSharpLips(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharpLips"


class GiSharpShuriken(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharpShuriken"


class GiSharpSmile(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharpSmile"


class GiSharpedTeethSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiSharpedTeethSkull"


class GiShatter(rx.Component):
    library = "react-icons/gi"
    tag = "GiShatter"


class GiShatteredGlass(rx.Component):
    library = "react-icons/gi"
    tag = "GiShatteredGlass"


class GiShatteredHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiShatteredHeart"


class GiShatteredSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiShatteredSword"


class GiShears(rx.Component):
    library = "react-icons/gi"
    tag = "GiShears"


class GiSheep(rx.Component):
    library = "react-icons/gi"
    tag = "GiSheep"


class GiSheikahEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiSheikahEye"


class GiShepherdsCrook(rx.Component):
    library = "react-icons/gi"
    tag = "GiShepherdsCrook"


class GiSherlockHolmes(rx.Component):
    library = "react-icons/gi"
    tag = "GiSherlockHolmes"


class GiShieldBash(rx.Component):
    library = "react-icons/gi"
    tag = "GiShieldBash"


class GiShieldBounces(rx.Component):
    library = "react-icons/gi"
    tag = "GiShieldBounces"


class GiShieldDisabled(rx.Component):
    library = "react-icons/gi"
    tag = "GiShieldDisabled"


class GiShieldEchoes(rx.Component):
    library = "react-icons/gi"
    tag = "GiShieldEchoes"


class GiShieldImpact(rx.Component):
    library = "react-icons/gi"
    tag = "GiShieldImpact"


class GiShieldOpposition(rx.Component):
    library = "react-icons/gi"
    tag = "GiShieldOpposition"


class GiShieldReflect(rx.Component):
    library = "react-icons/gi"
    tag = "GiShieldReflect"


class GiShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiShield"


class GiShieldcomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiShieldcomb"


class GiShiningClaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiShiningClaw"


class GiShiningHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiShiningHeart"


class GiShiningSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiShiningSword"


class GiShintoShrineMirror(rx.Component):
    library = "react-icons/gi"
    tag = "GiShintoShrineMirror"


class GiShintoShrine(rx.Component):
    library = "react-icons/gi"
    tag = "GiShintoShrine"


class GiShinyApple(rx.Component):
    library = "react-icons/gi"
    tag = "GiShinyApple"


class GiShinyEntrance(rx.Component):
    library = "react-icons/gi"
    tag = "GiShinyEntrance"


class GiShinyIris(rx.Component):
    library = "react-icons/gi"
    tag = "GiShinyIris"


class GiShinyOmega(rx.Component):
    library = "react-icons/gi"
    tag = "GiShinyOmega"


class GiShinyPurse(rx.Component):
    library = "react-icons/gi"
    tag = "GiShinyPurse"


class GiShipBow(rx.Component):
    library = "react-icons/gi"
    tag = "GiShipBow"


class GiShipWheel(rx.Component):
    library = "react-icons/gi"
    tag = "GiShipWheel"


class GiShipWreck(rx.Component):
    library = "react-icons/gi"
    tag = "GiShipWreck"


class GiShirtButton(rx.Component):
    library = "react-icons/gi"
    tag = "GiShirtButton"


class GiShirt(rx.Component):
    library = "react-icons/gi"
    tag = "GiShirt"


class GiShoebillStork(rx.Component):
    library = "react-icons/gi"
    tag = "GiShoebillStork"


class GiShoonerSailboat(rx.Component):
    library = "react-icons/gi"
    tag = "GiShoonerSailboat"


class GiShop(rx.Component):
    library = "react-icons/gi"
    tag = "GiShop"


class GiShoppingBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiShoppingBag"


class GiShoppingCart(rx.Component):
    library = "react-icons/gi"
    tag = "GiShoppingCart"


class GiShorts(rx.Component):
    library = "react-icons/gi"
    tag = "GiShorts"


class GiShotgunRounds(rx.Component):
    library = "react-icons/gi"
    tag = "GiShotgunRounds"


class GiShotgun(rx.Component):
    library = "react-icons/gi"
    tag = "GiShotgun"


class GiShoulderArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiShoulderArmor"


class GiShoulderBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiShoulderBag"


class GiShoulderScales(rx.Component):
    library = "react-icons/gi"
    tag = "GiShoulderScales"


class GiShouting(rx.Component):
    library = "react-icons/gi"
    tag = "GiShouting"


class GiShower(rx.Component):
    library = "react-icons/gi"
    tag = "GiShower"


class GiShrimp(rx.Component):
    library = "react-icons/gi"
    tag = "GiShrimp"


class GiShrug(rx.Component):
    library = "react-icons/gi"
    tag = "GiShrug"


class GiShurikenAperture(rx.Component):
    library = "react-icons/gi"
    tag = "GiShurikenAperture"


class GiShuriken(rx.Component):
    library = "react-icons/gi"
    tag = "GiShuriken"


class GiShutRose(rx.Component):
    library = "react-icons/gi"
    tag = "GiShutRose"


class GiShuttlecock(rx.Component):
    library = "react-icons/gi"
    tag = "GiShuttlecock"


class GiSickle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSickle"


class GiSideswipe(rx.Component):
    library = "react-icons/gi"
    tag = "GiSideswipe"


class GiSiegeRam(rx.Component):
    library = "react-icons/gi"
    tag = "GiSiegeRam"


class GiSiegeTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiSiegeTower"


class GiSightDisabled(rx.Component):
    library = "react-icons/gi"
    tag = "GiSightDisabled"


class GiSilence(rx.Component):
    library = "react-icons/gi"
    tag = "GiSilence"


class GiSilenced(rx.Component):
    library = "react-icons/gi"
    tag = "GiSilenced"


class GiSilex(rx.Component):
    library = "react-icons/gi"
    tag = "GiSilex"


class GiSilverBullet(rx.Component):
    library = "react-icons/gi"
    tag = "GiSilverBullet"


class GiSinagot(rx.Component):
    library = "react-icons/gi"
    tag = "GiSinagot"


class GiSing(rx.Component):
    library = "react-icons/gi"
    tag = "GiSing"


class GiSinkingShip(rx.Component):
    library = "react-icons/gi"
    tag = "GiSinkingShip"


class GiSinkingTrap(rx.Component):
    library = "react-icons/gi"
    tag = "GiSinkingTrap"


class GiSinusoidalBeam(rx.Component):
    library = "react-icons/gi"
    tag = "GiSinusoidalBeam"


class GiSiren(rx.Component):
    library = "react-icons/gi"
    tag = "GiSiren"


class GiSittingDog(rx.Component):
    library = "react-icons/gi"
    tag = "GiSittingDog"


class GiSixEyes(rx.Component):
    library = "react-icons/gi"
    tag = "GiSixEyes"


class GiSkateboard(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkateboard"


class GiSkeletalHand(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkeletalHand"


class GiSkeletonInside(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkeletonInside"


class GiSkeletonKey(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkeletonKey"


class GiSkeleton(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkeleton"


class GiSkiBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkiBoot"


class GiSkidMark(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkidMark"


class GiSkier(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkier"


class GiSkills(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkills"


class GiSkippingRope(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkippingRope"


class GiSkirt(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkirt"


class GiSkis(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkis"


class GiSkullBolt(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullBolt"


class GiSkullCrack(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullCrack"


class GiSkullCrossedBones(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullCrossedBones"


class GiSkullInJar(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullInJar"


class GiSkullMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullMask"


class GiSkullRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullRing"


class GiSkullSabertooth(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullSabertooth"


class GiSkullShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullShield"


class GiSkullSignet(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullSignet"


class GiSkullSlices(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullSlices"


class GiSkullStaff(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullStaff"


class GiSkullWithSyringe(rx.Component):
    library = "react-icons/gi"
    tag = "GiSkullWithSyringe"


class GiSlalom(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlalom"


class GiSlap(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlap"


class GiSlashedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlashedShield"


class GiSlaveryWhip(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlaveryWhip"


class GiSleepingBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiSleepingBag"


class GiSleepy(rx.Component):
    library = "react-icons/gi"
    tag = "GiSleepy"


class GiSleevelessJacket(rx.Component):
    library = "react-icons/gi"
    tag = "GiSleevelessJacket"


class GiSleevelessTop(rx.Component):
    library = "react-icons/gi"
    tag = "GiSleevelessTop"


class GiSlicedBread(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlicedBread"


class GiSlicedMushroom(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlicedMushroom"


class GiSlicedSausage(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlicedSausage"


class GiSlicingArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlicingArrow"


class GiSlime(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlime"


class GiSling(rx.Component):
    library = "react-icons/gi"
    tag = "GiSling"


class GiSlingshot(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlingshot"


class GiSlipknot(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlipknot"


class GiSlippers(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlippers"


class GiSloth(rx.Component):
    library = "react-icons/gi"
    tag = "GiSloth"


class GiSlowBlob(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlowBlob"


class GiSlumberingSanctuary(rx.Component):
    library = "react-icons/gi"
    tag = "GiSlumberingSanctuary"


class GiSly(rx.Component):
    library = "react-icons/gi"
    tag = "GiSly"


class GiSmallFire(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmallFire"


class GiSmallFishingSailboat(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmallFishingSailboat"


class GiSmart(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmart"


class GiSmartphone(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmartphone"


class GiSmashArrows(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmashArrows"


class GiSmitten(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmitten"


class GiSmokeBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmokeBomb"


class GiSmokingFinger(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmokingFinger"


class GiSmokingOrb(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmokingOrb"


class GiSmokingPipe(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmokingPipe"


class GiSmokingVolcano(rx.Component):
    library = "react-icons/gi"
    tag = "GiSmokingVolcano"


class GiSnailEyes(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnailEyes"


class GiSnail(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnail"


class GiSnakeBite(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnakeBite"


class GiSnakeEgg(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnakeEgg"


class GiSnakeJar(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnakeJar"


class GiSnakeSpiral(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnakeSpiral"


class GiSnakeTongue(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnakeTongue"


class GiSnakeTotem(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnakeTotem"


class GiSnake(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnake"


class GiSnatch(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnatch"


class GiSniffingDog(rx.Component):
    library = "react-icons/gi"
    tag = "GiSniffingDog"


class GiSnitchQuidditchBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnitchQuidditchBall"


class GiSnorkel(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnorkel"


class GiSnout(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnout"


class GiSnowBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnowBottle"


class GiSnowboard(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnowboard"


class GiSnowflake1(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnowflake1"


class GiSnowflake2(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnowflake2"


class GiSnowing(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnowing"


class GiSnowman(rx.Component):
    library = "react-icons/gi"
    tag = "GiSnowman"


class GiSoapExperiment(rx.Component):
    library = "react-icons/gi"
    tag = "GiSoapExperiment"


class GiSoap(rx.Component):
    library = "react-icons/gi"
    tag = "GiSoap"


class GiSoccerBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiSoccerBall"


class GiSoccerField(rx.Component):
    library = "react-icons/gi"
    tag = "GiSoccerField"


class GiSoccerKick(rx.Component):
    library = "react-icons/gi"
    tag = "GiSoccerKick"


class GiSocks(rx.Component):
    library = "react-icons/gi"
    tag = "GiSocks"


class GiSodaCan(rx.Component):
    library = "react-icons/gi"
    tag = "GiSodaCan"


class GiSofa(rx.Component):
    library = "react-icons/gi"
    tag = "GiSofa"


class GiSolarPower(rx.Component):
    library = "react-icons/gi"
    tag = "GiSolarPower"


class GiSolarSystem(rx.Component):
    library = "react-icons/gi"
    tag = "GiSolarSystem"


class GiSolarTime(rx.Component):
    library = "react-icons/gi"
    tag = "GiSolarTime"


class GiSolderingIron(rx.Component):
    library = "react-icons/gi"
    tag = "GiSolderingIron"


class GiSolidLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiSolidLeaf"


class GiSombrero(rx.Component):
    library = "react-icons/gi"
    tag = "GiSombrero"


class GiSonicBoom(rx.Component):
    library = "react-icons/gi"
    tag = "GiSonicBoom"


class GiSonicLightning(rx.Component):
    library = "react-icons/gi"
    tag = "GiSonicLightning"


class GiSonicScreech(rx.Component):
    library = "react-icons/gi"
    tag = "GiSonicScreech"


class GiSonicShoes(rx.Component):
    library = "react-icons/gi"
    tag = "GiSonicShoes"


class GiSonicShout(rx.Component):
    library = "react-icons/gi"
    tag = "GiSonicShout"


class GiSoulVessel(rx.Component):
    library = "react-icons/gi"
    tag = "GiSoulVessel"


class GiSoundOff(rx.Component):
    library = "react-icons/gi"
    tag = "GiSoundOff"


class GiSoundOn(rx.Component):
    library = "react-icons/gi"
    tag = "GiSoundOn"


class GiSoundWaves(rx.Component):
    library = "react-icons/gi"
    tag = "GiSoundWaves"


class GiSouthAfricaFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiSouthAfricaFlag"


class GiSouthAfrica(rx.Component):
    library = "react-icons/gi"
    tag = "GiSouthAfrica"


class GiSouthAmerica(rx.Component):
    library = "react-icons/gi"
    tag = "GiSouthAmerica"


class GiSouthKorea(rx.Component):
    library = "react-icons/gi"
    tag = "GiSouthKorea"


class GiSpaceNeedle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpaceNeedle"


class GiSpaceShuttle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpaceShuttle"


class GiSpaceSuit(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpaceSuit"


class GiSpaceship(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpaceship"


class GiSpadeSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpadeSkull"


class GiSpade(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpade"


class GiSpades(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpades"


class GiSpain(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpain"


class GiSpanner(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpanner"


class GiSparkPlug(rx.Component):
    library = "react-icons/gi"
    tag = "GiSparkPlug"


class GiSparkSpirit(rx.Component):
    library = "react-icons/gi"
    tag = "GiSparkSpirit"


class GiSparkles(rx.Component):
    library = "react-icons/gi"
    tag = "GiSparkles"


class GiSparklingSabre(rx.Component):
    library = "react-icons/gi"
    tag = "GiSparklingSabre"


class GiSparkyBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiSparkyBomb"


class GiSparrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiSparrow"


class GiSpartanHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpartanHelmet"


class GiSpartan(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpartan"


class GiSpatter(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpatter"


class GiSpawnNode(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpawnNode"


class GiSpeakerOff(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpeakerOff"


class GiSpeaker(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpeaker"


class GiSpearFeather(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpearFeather"


class GiSpearHook(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpearHook"


class GiSpearfishing(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpearfishing"


class GiSpears(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpears"


class GiSpectacleLenses(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpectacleLenses"


class GiSpectacles(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpectacles"


class GiSpectreM4(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpectreM4"


class GiSpectre(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpectre"


class GiSpeedBoat(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpeedBoat"


class GiSpeedometer(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpeedometer"


class GiSpellBook(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpellBook"


class GiSpermWhale(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpermWhale"


class GiSpiderAlt(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiderAlt"


class GiSpiderBot(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiderBot"


class GiSpiderEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiderEye"


class GiSpiderFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiderFace"


class GiSpiderMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiderMask"


class GiSpiderWeb(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiderWeb"


class GiSpikeball(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikeball"


class GiSpikedArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedArmor"


class GiSpikedBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedBall"


class GiSpikedBat(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedBat"


class GiSpikedCollar(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedCollar"


class GiSpikedDragonHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedDragonHead"


class GiSpikedFence(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedFence"


class GiSpikedHalo(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedHalo"


class GiSpikedMace(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedMace"


class GiSpikedShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedShell"


class GiSpikedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedShield"


class GiSpikedShoulderArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedShoulderArmor"


class GiSpikedSnail(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedSnail"


class GiSpikedTail(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedTail"


class GiSpikedTentacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedTentacle"


class GiSpikedTrunk(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedTrunk"


class GiSpikedWall(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikedWall"


class GiSpikesFull(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikesFull"


class GiSpikesHalf(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikesHalf"


class GiSpikesInit(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikesInit"


class GiSpikes(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikes"


class GiSpikyEclipse(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikyEclipse"


class GiSpikyExplosion(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikyExplosion"


class GiSpikyField(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikyField"


class GiSpikyPit(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikyPit"


class GiSpikyWing(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpikyWing"


class GiSpill(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpill"


class GiSpinalCoil(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpinalCoil"


class GiSpineArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpineArrow"


class GiSpinningBlades(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpinningBlades"


class GiSpinningRibbons(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpinningRibbons"


class GiSpinningSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpinningSword"


class GiSpinningTop(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpinningTop"


class GiSpinningWheel(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpinningWheel"


class GiSpiralArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiralArrow"


class GiSpiralBloom(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiralBloom"


class GiSpiralBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiralBottle"


class GiSpiralHilt(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiralHilt"


class GiSpiralLollipop(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiralLollipop"


class GiSpiralShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiralShell"


class GiSpiralTentacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiralTentacle"


class GiSpiralThrust(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpiralThrust"


class GiSplash(rx.Component):
    library = "react-icons/gi"
    tag = "GiSplash"


class GiSplashyStream(rx.Component):
    library = "react-icons/gi"
    tag = "GiSplashyStream"


class GiSplitArrows(rx.Component):
    library = "react-icons/gi"
    tag = "GiSplitArrows"


class GiSplitBody(rx.Component):
    library = "react-icons/gi"
    tag = "GiSplitBody"


class GiSplitCross(rx.Component):
    library = "react-icons/gi"
    tag = "GiSplitCross"


class GiSplurt(rx.Component):
    library = "react-icons/gi"
    tag = "GiSplurt"


class GiSpockHand(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpockHand"


class GiSpookyHouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpookyHouse"


class GiSpoon(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpoon"


class GiSportMedal(rx.Component):
    library = "react-icons/gi"
    tag = "GiSportMedal"


class GiSpotedFlower(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpotedFlower"


class GiSpottedArrowhead(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpottedArrowhead"


class GiSpottedBug(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpottedBug"


class GiSpottedMushroom(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpottedMushroom"


class GiSpottedWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpottedWound"


class GiSpoutnik(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpoutnik"


class GiSpray(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpray"


class GiSpring(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpring"


class GiSprint(rx.Component):
    library = "react-icons/gi"
    tag = "GiSprint"


class GiSproutDisc(rx.Component):
    library = "react-icons/gi"
    tag = "GiSproutDisc"


class GiSprout(rx.Component):
    library = "react-icons/gi"
    tag = "GiSprout"


class GiSpy(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpy"


class GiSpyglass(rx.Component):
    library = "react-icons/gi"
    tag = "GiSpyglass"


class GiSquareBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSquareBottle"


class GiSquare(rx.Component):
    library = "react-icons/gi"
    tag = "GiSquare"


class GiSquib(rx.Component):
    library = "react-icons/gi"
    tag = "GiSquib"


class GiSquidHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiSquidHead"


class GiSquid(rx.Component):
    library = "react-icons/gi"
    tag = "GiSquid"


class GiSquirrel(rx.Component):
    library = "react-icons/gi"
    tag = "GiSquirrel"


class GiSriLanka(rx.Component):
    library = "react-icons/gi"
    tag = "GiSriLanka"


class GiStabbedNote(rx.Component):
    library = "react-icons/gi"
    tag = "GiStabbedNote"


class GiStable(rx.Component):
    library = "react-icons/gi"
    tag = "GiStable"


class GiStack(rx.Component):
    library = "react-icons/gi"
    tag = "GiStack"


class GiStagHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiStagHead"


class GiStahlhelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiStahlhelm"


class GiStairsCake(rx.Component):
    library = "react-icons/gi"
    tag = "GiStairsCake"


class GiStairsGoal(rx.Component):
    library = "react-icons/gi"
    tag = "GiStairsGoal"


class GiStairs(rx.Component):
    library = "react-icons/gi"
    tag = "GiStairs"


class GiStakeHammer(rx.Component):
    library = "react-icons/gi"
    tag = "GiStakeHammer"


class GiStakesFence(rx.Component):
    library = "react-icons/gi"
    tag = "GiStakesFence"


class GiStalactites(rx.Component):
    library = "react-icons/gi"
    tag = "GiStalactites"


class GiStalagtite(rx.Component):
    library = "react-icons/gi"
    tag = "GiStalagtite"


class GiStamper(rx.Component):
    library = "react-icons/gi"
    tag = "GiStamper"


class GiStandingPotion(rx.Component):
    library = "react-icons/gi"
    tag = "GiStandingPotion"


class GiStaplerHeavyDuty(rx.Component):
    library = "react-icons/gi"
    tag = "GiStaplerHeavyDuty"


class GiStaplerPneumatic(rx.Component):
    library = "react-icons/gi"
    tag = "GiStaplerPneumatic"


class GiStapler(rx.Component):
    library = "react-icons/gi"
    tag = "GiStapler"


class GiStarAltar(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarAltar"


class GiStarCycle(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarCycle"


class GiStarFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarFlag"


class GiStarFormation(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarFormation"


class GiStarGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarGate"


class GiStarKey(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarKey"


class GiStarMedal(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarMedal"


class GiStarProminences(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarProminences"


class GiStarPupil(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarPupil"


class GiStarSattelites(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarSattelites"


class GiStarShuriken(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarShuriken"


class GiStarSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarSkull"


class GiStarStruck(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarStruck"


class GiStarSwirl(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarSwirl"


class GiStarfighter(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarfighter"


class GiStarsStack(rx.Component):
    library = "react-icons/gi"
    tag = "GiStarsStack"


class GiStaryu(rx.Component):
    library = "react-icons/gi"
    tag = "GiStaryu"


class GiStaticGuard(rx.Component):
    library = "react-icons/gi"
    tag = "GiStaticGuard"


class GiStaticWaves(rx.Component):
    library = "react-icons/gi"
    tag = "GiStaticWaves"


class GiStatic(rx.Component):
    library = "react-icons/gi"
    tag = "GiStatic"


class GiSteak(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteak"


class GiStealthBomber(rx.Component):
    library = "react-icons/gi"
    tag = "GiStealthBomber"


class GiSteamBlast(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteamBlast"


class GiSteamLocomotive(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteamLocomotive"


class GiSteam(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteam"


class GiSteampunkGoggles(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteampunkGoggles"


class GiSteelClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteelClaws"


class GiSteelDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteelDoor"


class GiSteeltoeBoots(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteeltoeBoots"


class GiSteelwingEmblem(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteelwingEmblem"


class GiSteeringWheel(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteeringWheel"


class GiStegosaurusScales(rx.Component):
    library = "react-icons/gi"
    tag = "GiStegosaurusScales"


class GiStethoscope(rx.Component):
    library = "react-icons/gi"
    tag = "GiStethoscope"


class GiSteyrAug(rx.Component):
    library = "react-icons/gi"
    tag = "GiSteyrAug"


class GiStickFrame(rx.Component):
    library = "react-icons/gi"
    tag = "GiStickFrame"


class GiStickGrenade(rx.Component):
    library = "react-icons/gi"
    tag = "GiStickGrenade"


class GiStickSplitting(rx.Component):
    library = "react-icons/gi"
    tag = "GiStickSplitting"


class GiStickingPlaster(rx.Component):
    library = "react-icons/gi"
    tag = "GiStickingPlaster"


class GiStickyBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiStickyBoot"


class GiStigmata(rx.Component):
    library = "react-icons/gi"
    tag = "GiStigmata"


class GiStiletto(rx.Component):
    library = "react-icons/gi"
    tag = "GiStiletto"


class GiStitchedWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiStitchedWound"


class GiStockpiles(rx.Component):
    library = "react-icons/gi"
    tag = "GiStockpiles"


class GiStomach(rx.Component):
    library = "react-icons/gi"
    tag = "GiStomach"


class GiStompTornado(rx.Component):
    library = "react-icons/gi"
    tag = "GiStompTornado"


class GiStomp(rx.Component):
    library = "react-icons/gi"
    tag = "GiStomp"


class GiStoneAxe(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneAxe"


class GiStoneBlock(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneBlock"


class GiStoneBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneBridge"


class GiStoneBust(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneBust"


class GiStoneCrafting(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneCrafting"


class GiStonePath(rx.Component):
    library = "react-icons/gi"
    tag = "GiStonePath"


class GiStonePile(rx.Component):
    library = "react-icons/gi"
    tag = "GiStonePile"


class GiStoneSpear(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneSpear"


class GiStoneSphere(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneSphere"


class GiStoneStack(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneStack"


class GiStoneTablet(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneTablet"


class GiStoneThrone(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneThrone"


class GiStoneTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneTower"


class GiStoneWall(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneWall"


class GiStoneWheel(rx.Component):
    library = "react-icons/gi"
    tag = "GiStoneWheel"


class GiStonedSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiStonedSkull"


class GiStopSign(rx.Component):
    library = "react-icons/gi"
    tag = "GiStopSign"


class GiStopwatch(rx.Component):
    library = "react-icons/gi"
    tag = "GiStopwatch"


class GiStorkDelivery(rx.Component):
    library = "react-icons/gi"
    tag = "GiStorkDelivery"


class GiStrafe(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrafe"


class GiStraightPipe(rx.Component):
    library = "react-icons/gi"
    tag = "GiStraightPipe"


class GiStrawberry(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrawberry"


class GiStreetLight(rx.Component):
    library = "react-icons/gi"
    tag = "GiStreetLight"


class GiStrikingArrows(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrikingArrows"


class GiStrikingBalls(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrikingBalls"


class GiStrikingClamps(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrikingClamps"


class GiStrikingDiamonds(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrikingDiamonds"


class GiStrikingSplinter(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrikingSplinter"


class GiStripedSun(rx.Component):
    library = "react-icons/gi"
    tag = "GiStripedSun"


class GiStripedSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiStripedSword"


class GiStrongMan(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrongMan"


class GiStrong(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrong"


class GiStrongbox(rx.Component):
    library = "react-icons/gi"
    tag = "GiStrongbox"


class GiStumpRegrowth(rx.Component):
    library = "react-icons/gi"
    tag = "GiStumpRegrowth"


class GiStunGrenade(rx.Component):
    library = "react-icons/gi"
    tag = "GiStunGrenade"


class GiSubmarineMissile(rx.Component):
    library = "react-icons/gi"
    tag = "GiSubmarineMissile"


class GiSubmarine(rx.Component):
    library = "react-icons/gi"
    tag = "GiSubmarine"


class GiSubway(rx.Component):
    library = "react-icons/gi"
    tag = "GiSubway"


class GiSuckeredTentacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiSuckeredTentacle"


class GiSugarCane(rx.Component):
    library = "react-icons/gi"
    tag = "GiSugarCane"


class GiSuicide(rx.Component):
    library = "react-icons/gi"
    tag = "GiSuicide"


class GiSuitcase(rx.Component):
    library = "react-icons/gi"
    tag = "GiSuitcase"


class GiSuits(rx.Component):
    library = "react-icons/gi"
    tag = "GiSuits"


class GiSummits(rx.Component):
    library = "react-icons/gi"
    tag = "GiSummits"


class GiSunCloud(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunCloud"


class GiSunPriest(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunPriest"


class GiSunRadiations(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunRadiations"


class GiSunSpear(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunSpear"


class GiSun(rx.Component):
    library = "react-icons/gi"
    tag = "GiSun"


class GiSunbeams(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunbeams"


class GiSundial(rx.Component):
    library = "react-icons/gi"
    tag = "GiSundial"


class GiSunflower(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunflower"


class GiSunglasses(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunglasses"


class GiSunkenEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunkenEye"


class GiSunrise(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunrise"


class GiSunset(rx.Component):
    library = "react-icons/gi"
    tag = "GiSunset"


class GiSuperMushroom(rx.Component):
    library = "react-icons/gi"
    tag = "GiSuperMushroom"


class GiSupersonicArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiSupersonicArrow"


class GiSupersonicBullet(rx.Component):
    library = "react-icons/gi"
    tag = "GiSupersonicBullet"


class GiSurfBoard(rx.Component):
    library = "react-icons/gi"
    tag = "GiSurfBoard"


class GiSurferVan(rx.Component):
    library = "react-icons/gi"
    tag = "GiSurferVan"


class GiSurprisedSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiSurprisedSkull"


class GiSurprised(rx.Component):
    library = "react-icons/gi"
    tag = "GiSurprised"


class GiSurroundedEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiSurroundedEye"


class GiSurroundedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiSurroundedShield"


class GiSushis(rx.Component):
    library = "react-icons/gi"
    tag = "GiSushis"


class GiSuspensionBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiSuspensionBridge"


class GiSuspicious(rx.Component):
    library = "react-icons/gi"
    tag = "GiSuspicious"


class GiSverdIFjell(rx.Component):
    library = "react-icons/gi"
    tag = "GiSverdIFjell"


class GiSwallow(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwallow"


class GiSwallower(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwallower"


class GiSwampBat(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwampBat"


class GiSwamp(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwamp"


class GiSwanBreeze(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwanBreeze"


class GiSwan(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwan"


class GiSwapBag(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwapBag"


class GiSwimfins(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwimfins"


class GiSwipeCard(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwipeCard"


class GiSwirlRing(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwirlRing"


class GiSwirlString(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwirlString"


class GiSwirledShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwirledShell"


class GiSwissArmyKnife(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwissArmyKnife"


class GiSwitchWeapon(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwitchWeapon"


class GiSwitchblade(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwitchblade"


class GiSwitzerland(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwitzerland"


class GiSwordAltar(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordAltar"


class GiSwordArray(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordArray"


class GiSwordBrandish(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordBrandish"


class GiSwordBreak(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordBreak"


class GiSwordClash(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordClash"


class GiSwordHilt(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordHilt"


class GiSwordInStone(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordInStone"


class GiSwordMold(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordMold"


class GiSwordSlice(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordSlice"


class GiSwordSmithing(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordSmithing"


class GiSwordSpade(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordSpade"


class GiSwordSpin(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordSpin"


class GiSwordTie(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordTie"


class GiSwordWound(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordWound"


class GiSwordman(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordman"


class GiSwordsEmblem(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordsEmblem"


class GiSwordsPower(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordsPower"


class GiSwordwoman(rx.Component):
    library = "react-icons/gi"
    tag = "GiSwordwoman"


class GiSydneyOperaHouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiSydneyOperaHouse"


class GiSyringe(rx.Component):
    library = "react-icons/gi"
    tag = "GiSyringe"


class GiTBrick(rx.Component):
    library = "react-icons/gi"
    tag = "GiTBrick"


class GiTRexSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiTRexSkull"


class GiTShirt(rx.Component):
    library = "react-icons/gi"
    tag = "GiTShirt"


class GiTabiBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiTabiBoot"


class GiTable(rx.Component):
    library = "react-icons/gi"
    tag = "GiTable"


class GiTablet(rx.Component):
    library = "react-icons/gi"
    tag = "GiTablet"


class GiTabletopPlayers(rx.Component):
    library = "react-icons/gi"
    tag = "GiTabletopPlayers"


class GiTacos(rx.Component):
    library = "react-icons/gi"
    tag = "GiTacos"


class GiTadpole(rx.Component):
    library = "react-icons/gi"
    tag = "GiTadpole"


class GiTakeMyMoney(rx.Component):
    library = "react-icons/gi"
    tag = "GiTakeMyMoney"


class GiTalk(rx.Component):
    library = "react-icons/gi"
    tag = "GiTalk"


class GiTallBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiTallBridge"


class GiTambourine(rx.Component):
    library = "react-icons/gi"
    tag = "GiTambourine"


class GiTangerine(rx.Component):
    library = "react-icons/gi"
    tag = "GiTangerine"


class GiTankTop(rx.Component):
    library = "react-icons/gi"
    tag = "GiTankTop"


class GiTankTread(rx.Component):
    library = "react-icons/gi"
    tag = "GiTankTread"


class GiTank(rx.Component):
    library = "react-icons/gi"
    tag = "GiTank"


class GiTanzania(rx.Component):
    library = "react-icons/gi"
    tag = "GiTanzania"


class GiTap(rx.Component):
    library = "react-icons/gi"
    tag = "GiTap"


class GiTapir(rx.Component):
    library = "react-icons/gi"
    tag = "GiTapir"


class GiTargetArrows(rx.Component):
    library = "react-icons/gi"
    tag = "GiTargetArrows"


class GiTargetDummy(rx.Component):
    library = "react-icons/gi"
    tag = "GiTargetDummy"


class GiTargetLaser(rx.Component):
    library = "react-icons/gi"
    tag = "GiTargetLaser"


class GiTargetPoster(rx.Component):
    library = "react-icons/gi"
    tag = "GiTargetPoster"


class GiTargetPrize(rx.Component):
    library = "react-icons/gi"
    tag = "GiTargetPrize"


class GiTargetShot(rx.Component):
    library = "react-icons/gi"
    tag = "GiTargetShot"


class GiTargeted(rx.Component):
    library = "react-icons/gi"
    tag = "GiTargeted"


class GiTargeting(rx.Component):
    library = "react-icons/gi"
    tag = "GiTargeting"


class GiTatteredBanner(rx.Component):
    library = "react-icons/gi"
    tag = "GiTatteredBanner"


class GiTaurus(rx.Component):
    library = "react-icons/gi"
    tag = "GiTaurus"


class GiTavernSign(rx.Component):
    library = "react-icons/gi"
    tag = "GiTavernSign"


class GiTeacher(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeacher"


class GiTeamDowngrade(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeamDowngrade"


class GiTeamIdea(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeamIdea"


class GiTeamUpgrade(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeamUpgrade"


class GiTeapotLeaves(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeapotLeaves"


class GiTeapot(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeapot"


class GiTearTracks(rx.Component):
    library = "react-icons/gi"
    tag = "GiTearTracks"


class GiTearing(rx.Component):
    library = "react-icons/gi"
    tag = "GiTearing"


class GiTec9(rx.Component):
    library = "react-icons/gi"
    tag = "GiTec9"


class GiTechnoHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiTechnoHeart"


class GiTeePipe(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeePipe"


class GiTelefrag(rx.Component):
    library = "react-icons/gi"
    tag = "GiTelefrag"


class GiTelepathy(rx.Component):
    library = "react-icons/gi"
    tag = "GiTelepathy"


class GiTeleport(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeleport"


class GiTelescopicBaton(rx.Component):
    library = "react-icons/gi"
    tag = "GiTelescopicBaton"


class GiTellerMine(rx.Component):
    library = "react-icons/gi"
    tag = "GiTellerMine"


class GiTemplarEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiTemplarEye"


class GiTemplarHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiTemplarHeart"


class GiTemplarShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiTemplarShield"


class GiTempleDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiTempleDoor"


class GiTempleGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiTempleGate"


class GiTemporaryShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiTemporaryShield"


class GiTemptation(rx.Component):
    library = "react-icons/gi"
    tag = "GiTemptation"


class GiTennisBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiTennisBall"


class GiTennisCourt(rx.Component):
    library = "react-icons/gi"
    tag = "GiTennisCourt"


class GiTennisRacket(rx.Component):
    library = "react-icons/gi"
    tag = "GiTennisRacket"


class GiTensionSnowflake(rx.Component):
    library = "react-icons/gi"
    tag = "GiTensionSnowflake"


class GiTentacleHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiTentacleHeart"


class GiTentacleStrike(rx.Component):
    library = "react-icons/gi"
    tag = "GiTentacleStrike"


class GiTentaclesBarrier(rx.Component):
    library = "react-icons/gi"
    tag = "GiTentaclesBarrier"


class GiTentaclesSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiTentaclesSkull"


class GiTentacurl(rx.Component):
    library = "react-icons/gi"
    tag = "GiTentacurl"


class GiTerror(rx.Component):
    library = "react-icons/gi"
    tag = "GiTerror"


class GiTeslaCoil(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeslaCoil"


class GiTeslaTurret(rx.Component):
    library = "react-icons/gi"
    tag = "GiTeslaTurret"


class GiTesla(rx.Component):
    library = "react-icons/gi"
    tag = "GiTesla"


class GiTestTubes(rx.Component):
    library = "react-icons/gi"
    tag = "GiTestTubes"


class GiTexas(rx.Component):
    library = "react-icons/gi"
    tag = "GiTexas"


class GiTheaterCurtains(rx.Component):
    library = "react-icons/gi"
    tag = "GiTheaterCurtains"


class GiTheater(rx.Component):
    library = "react-icons/gi"
    tag = "GiTheater"


class GiThermometerCold(rx.Component):
    library = "react-icons/gi"
    tag = "GiThermometerCold"


class GiThermometerHot(rx.Component):
    library = "react-icons/gi"
    tag = "GiThermometerHot"


class GiThermometerScale(rx.Component):
    library = "react-icons/gi"
    tag = "GiThermometerScale"


class GiThink(rx.Component):
    library = "react-icons/gi"
    tag = "GiThink"


class GiThirdEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiThirdEye"


class GiThompsonM1(rx.Component):
    library = "react-icons/gi"
    tag = "GiThompsonM1"


class GiThompsonM1928(rx.Component):
    library = "react-icons/gi"
    tag = "GiThompsonM1928"


class GiThorFist(rx.Component):
    library = "react-icons/gi"
    tag = "GiThorFist"


class GiThorHammer(rx.Component):
    library = "react-icons/gi"
    tag = "GiThorHammer"


class GiThornHelix(rx.Component):
    library = "react-icons/gi"
    tag = "GiThornHelix"


class GiThornedArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiThornedArrow"


class GiThornyTentacle(rx.Component):
    library = "react-icons/gi"
    tag = "GiThornyTentacle"


class GiThornyVine(rx.Component):
    library = "react-icons/gi"
    tag = "GiThornyVine"


class GiThreeBurningBalls(rx.Component):
    library = "react-icons/gi"
    tag = "GiThreeBurningBalls"


class GiThreeFriends(rx.Component):
    library = "react-icons/gi"
    tag = "GiThreeFriends"


class GiThreeKeys(rx.Component):
    library = "react-icons/gi"
    tag = "GiThreeKeys"


class GiThreeLeaves(rx.Component):
    library = "react-icons/gi"
    tag = "GiThreeLeaves"


class GiThreePointedShuriken(rx.Component):
    library = "react-icons/gi"
    tag = "GiThreePointedShuriken"


class GiThroneKing(rx.Component):
    library = "react-icons/gi"
    tag = "GiThroneKing"


class GiThrowingBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiThrowingBall"


class GiThrownCharcoal(rx.Component):
    library = "react-icons/gi"
    tag = "GiThrownCharcoal"


class GiThrownDaggers(rx.Component):
    library = "react-icons/gi"
    tag = "GiThrownDaggers"


class GiThrownKnife(rx.Component):
    library = "react-icons/gi"
    tag = "GiThrownKnife"


class GiThrownSpear(rx.Component):
    library = "react-icons/gi"
    tag = "GiThrownSpear"


class GiThrustBend(rx.Component):
    library = "react-icons/gi"
    tag = "GiThrustBend"


class GiThrust(rx.Component):
    library = "react-icons/gi"
    tag = "GiThrust"


class GiThumbDown(rx.Component):
    library = "react-icons/gi"
    tag = "GiThumbDown"


class GiThumbUp(rx.Component):
    library = "react-icons/gi"
    tag = "GiThumbUp"


class GiThunderBlade(rx.Component):
    library = "react-icons/gi"
    tag = "GiThunderBlade"


class GiThunderSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiThunderSkull"


class GiThunderStruck(rx.Component):
    library = "react-icons/gi"
    tag = "GiThunderStruck"


class GiThunderball(rx.Component):
    library = "react-icons/gi"
    tag = "GiThunderball"


class GiThwomp(rx.Component):
    library = "react-icons/gi"
    tag = "GiThwomp"


class GiTiara(rx.Component):
    library = "react-icons/gi"
    tag = "GiTiara"


class GiTicTacToe(rx.Component):
    library = "react-icons/gi"
    tag = "GiTicTacToe"


class GiTick(rx.Component):
    library = "react-icons/gi"
    tag = "GiTick"


class GiTicket(rx.Component):
    library = "react-icons/gi"
    tag = "GiTicket"


class GiTie(rx.Component):
    library = "react-icons/gi"
    tag = "GiTie"


class GiTiedScroll(rx.Component):
    library = "react-icons/gi"
    tag = "GiTiedScroll"


class GiTigerHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiTigerHead"


class GiTiger(rx.Component):
    library = "react-icons/gi"
    tag = "GiTiger"


class GiTightrope(rx.Component):
    library = "react-icons/gi"
    tag = "GiTightrope"


class GiTimeBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiTimeBomb"


class GiTimeDynamite(rx.Component):
    library = "react-icons/gi"
    tag = "GiTimeDynamite"


class GiTimeSynchronization(rx.Component):
    library = "react-icons/gi"
    tag = "GiTimeSynchronization"


class GiTimeTrap(rx.Component):
    library = "react-icons/gi"
    tag = "GiTimeTrap"


class GiTinker(rx.Component):
    library = "react-icons/gi"
    tag = "GiTinker"


class GiTipi(rx.Component):
    library = "react-icons/gi"
    tag = "GiTipi"


class GiTireIronCross(rx.Component):
    library = "react-icons/gi"
    tag = "GiTireIronCross"


class GiTireIron(rx.Component):
    library = "react-icons/gi"
    tag = "GiTireIron"


class GiTireTracks(rx.Component):
    library = "react-icons/gi"
    tag = "GiTireTracks"


class GiTiredEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiTiredEye"


class GiToadTeeth(rx.Component):
    library = "react-icons/gi"
    tag = "GiToadTeeth"


class GiToaster(rx.Component):
    library = "react-icons/gi"
    tag = "GiToaster"


class GiToggles(rx.Component):
    library = "react-icons/gi"
    tag = "GiToggles"


class GiToken(rx.Component):
    library = "react-icons/gi"
    tag = "GiToken"


class GiTomahawk(rx.Component):
    library = "react-icons/gi"
    tag = "GiTomahawk"


class GiTomato(rx.Component):
    library = "react-icons/gi"
    tag = "GiTomato"


class GiTombstone(rx.Component):
    library = "react-icons/gi"
    tag = "GiTombstone"


class GiTongue(rx.Component):
    library = "react-icons/gi"
    tag = "GiTongue"


class GiToolbox(rx.Component):
    library = "react-icons/gi"
    tag = "GiToolbox"


class GiTooth(rx.Component):
    library = "react-icons/gi"
    tag = "GiTooth"


class GiToothbrush(rx.Component):
    library = "react-icons/gi"
    tag = "GiToothbrush"


class GiTopHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiTopHat"


class GiTopPaw(rx.Component):
    library = "react-icons/gi"
    tag = "GiTopPaw"


class GiTopaz(rx.Component):
    library = "react-icons/gi"
    tag = "GiTopaz"


class GiTorc(rx.Component):
    library = "react-icons/gi"
    tag = "GiTorc"


class GiTorch(rx.Component):
    library = "react-icons/gi"
    tag = "GiTorch"


class GiTornadoDiscs(rx.Component):
    library = "react-icons/gi"
    tag = "GiTornadoDiscs"


class GiTornado(rx.Component):
    library = "react-icons/gi"
    tag = "GiTornado"


class GiTorpedo(rx.Component):
    library = "react-icons/gi"
    tag = "GiTorpedo"


class GiTortoise(rx.Component):
    library = "react-icons/gi"
    tag = "GiTortoise"


class GiTotemHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiTotemHead"


class GiTotemMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiTotemMask"


class GiTotem(rx.Component):
    library = "react-icons/gi"
    tag = "GiTotem"


class GiToucan(rx.Component):
    library = "react-icons/gi"
    tag = "GiToucan"


class GiTowTruck(rx.Component):
    library = "react-icons/gi"
    tag = "GiTowTruck"


class GiTowel(rx.Component):
    library = "react-icons/gi"
    tag = "GiTowel"


class GiTowerBridge(rx.Component):
    library = "react-icons/gi"
    tag = "GiTowerBridge"


class GiTowerFall(rx.Component):
    library = "react-icons/gi"
    tag = "GiTowerFall"


class GiTowerFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiTowerFlag"


class GiToyMallet(rx.Component):
    library = "react-icons/gi"
    tag = "GiToyMallet"


class GiTrackedRobot(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrackedRobot"


class GiTrade(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrade"


class GiTrafficCone(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrafficCone"


class GiTrafficLightsGreen(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrafficLightsGreen"


class GiTrafficLightsOrange(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrafficLightsOrange"


class GiTrafficLightsReadyToGo(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrafficLightsReadyToGo"


class GiTrafficLightsRed(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrafficLightsRed"


class GiTrail(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrail"


class GiTrample(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrample"


class GiTransform(rx.Component):
    library = "react-icons/gi"
    tag = "GiTransform"


class GiTransfuse(rx.Component):
    library = "react-icons/gi"
    tag = "GiTransfuse"


class GiTransparentSlime(rx.Component):
    library = "react-icons/gi"
    tag = "GiTransparentSlime"


class GiTransparentTubes(rx.Component):
    library = "react-icons/gi"
    tag = "GiTransparentTubes"


class GiTransportationRings(rx.Component):
    library = "react-icons/gi"
    tag = "GiTransportationRings"


class GiTrapMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrapMask"


class GiTrashCan(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrashCan"


class GiTravelDress(rx.Component):
    library = "react-icons/gi"
    tag = "GiTravelDress"


class GiTread(rx.Component):
    library = "react-icons/gi"
    tag = "GiTread"


class GiTreasureMap(rx.Component):
    library = "react-icons/gi"
    tag = "GiTreasureMap"


class GiTrebuchet(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrebuchet"


class GiTreeBeehive(rx.Component):
    library = "react-icons/gi"
    tag = "GiTreeBeehive"


class GiTreeBranch(rx.Component):
    library = "react-icons/gi"
    tag = "GiTreeBranch"


class GiTreeDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiTreeDoor"


class GiTreeFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiTreeFace"


class GiTreeGrowth(rx.Component):
    library = "react-icons/gi"
    tag = "GiTreeGrowth"


class GiTreeRoots(rx.Component):
    library = "react-icons/gi"
    tag = "GiTreeRoots"


class GiTreeSwing(rx.Component):
    library = "react-icons/gi"
    tag = "GiTreeSwing"


class GiTreehouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiTreehouse"


class GiTrefoilLily(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrefoilLily"


class GiTrefoilShuriken(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrefoilShuriken"


class GiTrenchAssault(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrenchAssault"


class GiTrenchBodyArmor(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrenchBodyArmor"


class GiTrenchKnife(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrenchKnife"


class GiTrenchSpade(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrenchSpade"


class GiTriangleTarget(rx.Component):
    library = "react-icons/gi"
    tag = "GiTriangleTarget"


class GiTribalGear(rx.Component):
    library = "react-icons/gi"
    tag = "GiTribalGear"


class GiTribalMask(rx.Component):
    library = "react-icons/gi"
    tag = "GiTribalMask"


class GiTribalPendant(rx.Component):
    library = "react-icons/gi"
    tag = "GiTribalPendant"


class GiTribalShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiTribalShield"


class GiTribunalJury(rx.Component):
    library = "react-icons/gi"
    tag = "GiTribunalJury"


class GiTriceratopsHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiTriceratopsHead"


class GiTridentShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiTridentShield"


class GiTrident(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrident"


class GiTriforce(rx.Component):
    library = "react-icons/gi"
    tag = "GiTriforce"


class GiTriggerHurt(rx.Component):
    library = "react-icons/gi"
    tag = "GiTriggerHurt"


class GiTrilobite(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrilobite"


class GiTrinacria(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrinacria"


class GiTriorb(rx.Component):
    library = "react-icons/gi"
    tag = "GiTriorb"


class GiTripleBeak(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleBeak"


class GiTripleClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleClaws"


class GiTripleCorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleCorn"


class GiTripleGate(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleGate"


class GiTripleLock(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleLock"


class GiTripleNeedle(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleNeedle"


class GiTriplePlier(rx.Component):
    library = "react-icons/gi"
    tag = "GiTriplePlier"


class GiTripleScratches(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleScratches"


class GiTripleShells(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleShells"


class GiTripleSkulls(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleSkulls"


class GiTripleYin(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripleYin"


class GiTripwire(rx.Component):
    library = "react-icons/gi"
    tag = "GiTripwire"


class GiTriquetra(rx.Component):
    library = "react-icons/gi"
    tag = "GiTriquetra"


class GiTrireme(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrireme"


class GiTritonHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiTritonHead"


class GiTroglodyte(rx.Component):
    library = "react-icons/gi"
    tag = "GiTroglodyte"


class GiTrojanHorse(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrojanHorse"


class GiTroll(rx.Component):
    library = "react-icons/gi"
    tag = "GiTroll"


class GiTrombone(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrombone"


class GiTronArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiTronArrow"


class GiTrophiesShelf(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrophiesShelf"


class GiTrophyCup(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrophyCup"


class GiTrophy(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrophy"


class GiTropicalFish(rx.Component):
    library = "react-icons/gi"
    tag = "GiTropicalFish"


class GiTrousers(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrousers"


class GiTrowel(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrowel"


class GiTruce(rx.Component):
    library = "react-icons/gi"
    tag = "GiTruce"


class GiTruck(rx.Component):
    library = "react-icons/gi"
    tag = "GiTruck"


class GiTrumpetFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrumpetFlag"


class GiTrumpet(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrumpet"


class GiTrunkMushroom(rx.Component):
    library = "react-icons/gi"
    tag = "GiTrunkMushroom"


class GiTuba(rx.Component):
    library = "react-icons/gi"
    tag = "GiTuba"


class GiTumbleweed(rx.Component):
    library = "react-icons/gi"
    tag = "GiTumbleweed"


class GiTumor(rx.Component):
    library = "react-icons/gi"
    tag = "GiTumor"


class GiTumulus(rx.Component):
    library = "react-icons/gi"
    tag = "GiTumulus"


class GiTunePitch(rx.Component):
    library = "react-icons/gi"
    tag = "GiTunePitch"


class GiTunisia(rx.Component):
    library = "react-icons/gi"
    tag = "GiTunisia"


class GiTurban(rx.Component):
    library = "react-icons/gi"
    tag = "GiTurban"


class GiTurbine(rx.Component):
    library = "react-icons/gi"
    tag = "GiTurbine"


class GiTurd(rx.Component):
    library = "react-icons/gi"
    tag = "GiTurd"


class GiTurnstile(rx.Component):
    library = "react-icons/gi"
    tag = "GiTurnstile"


class GiTurret(rx.Component):
    library = "react-icons/gi"
    tag = "GiTurret"


class GiTurtleShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiTurtleShell"


class GiTurtle(rx.Component):
    library = "react-icons/gi"
    tag = "GiTurtle"


class GiTusksFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiTusksFlag"


class GiTvRemote(rx.Component):
    library = "react-icons/gi"
    tag = "GiTvRemote"


class GiTvTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiTvTower"


class GiTv(rx.Component):
    library = "react-icons/gi"
    tag = "GiTv"


class GiTwinShell(rx.Component):
    library = "react-icons/gi"
    tag = "GiTwinShell"


class GiTwirlCenter(rx.Component):
    library = "react-icons/gi"
    tag = "GiTwirlCenter"


class GiTwirlyFlower(rx.Component):
    library = "react-icons/gi"
    tag = "GiTwirlyFlower"


class GiTwister(rx.Component):
    library = "react-icons/gi"
    tag = "GiTwister"


class GiTwoCoins(rx.Component):
    library = "react-icons/gi"
    tag = "GiTwoCoins"


class GiTwoFeathers(rx.Component):
    library = "react-icons/gi"
    tag = "GiTwoFeathers"


class GiTwoHandedSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiTwoHandedSword"


class GiTwoShadows(rx.Component):
    library = "react-icons/gi"
    tag = "GiTwoShadows"


class GiTyre(rx.Component):
    library = "react-icons/gi"
    tag = "GiTyre"


class GiUbisoftSun(rx.Component):
    library = "react-icons/gi"
    tag = "GiUbisoftSun"


class GiUdder(rx.Component):
    library = "react-icons/gi"
    tag = "GiUdder"


class GiUfo(rx.Component):
    library = "react-icons/gi"
    tag = "GiUfo"


class GiUltrasound(rx.Component):
    library = "react-icons/gi"
    tag = "GiUltrasound"


class GiUluru(rx.Component):
    library = "react-icons/gi"
    tag = "GiUluru"


class GiUmbrellaBayonet(rx.Component):
    library = "react-icons/gi"
    tag = "GiUmbrellaBayonet"


class GiUmbrella(rx.Component):
    library = "react-icons/gi"
    tag = "GiUmbrella"


class GiUnbalanced(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnbalanced"


class GiUncertainty(rx.Component):
    library = "react-icons/gi"
    tag = "GiUncertainty"


class GiUndergroundCave(rx.Component):
    library = "react-icons/gi"
    tag = "GiUndergroundCave"


class GiUnderhand(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnderhand"


class GiUnderwearShorts(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnderwearShorts"


class GiUnderwear(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnderwear"


class GiUnfriendlyFire(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnfriendlyFire"


class GiUnicorn(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnicorn"


class GiUnicycle(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnicycle"


class GiUnionJack(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnionJack"


class GiUnlitBomb(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnlitBomb"


class GiUnlitCandelabra(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnlitCandelabra"


class GiUnlocking(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnlocking"


class GiUnplugged(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnplugged"


class GiUnstableOrb(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnstableOrb"


class GiUnstableProjectile(rx.Component):
    library = "react-icons/gi"
    tag = "GiUnstableProjectile"


class GiUpCard(rx.Component):
    library = "react-icons/gi"
    tag = "GiUpCard"


class GiUpgrade(rx.Component):
    library = "react-icons/gi"
    tag = "GiUpgrade"


class GiUprising(rx.Component):
    library = "react-icons/gi"
    tag = "GiUprising"


class GiUrsaMajor(rx.Component):
    library = "react-icons/gi"
    tag = "GiUrsaMajor"


class GiUruguay(rx.Component):
    library = "react-icons/gi"
    tag = "GiUruguay"


class GiUsaFlag(rx.Component):
    library = "react-icons/gi"
    tag = "GiUsaFlag"


class GiUsable(rx.Component):
    library = "react-icons/gi"
    tag = "GiUsable"


class GiUsbKey(rx.Component):
    library = "react-icons/gi"
    tag = "GiUsbKey"


class GiUshanka(rx.Component):
    library = "react-icons/gi"
    tag = "GiUshanka"


class GiUzi(rx.Component):
    library = "react-icons/gi"
    tag = "GiUzi"


class GiVacuumCleaner(rx.Component):
    library = "react-icons/gi"
    tag = "GiVacuumCleaner"


class GiValley(rx.Component):
    library = "react-icons/gi"
    tag = "GiValley"


class GiValve(rx.Component):
    library = "react-icons/gi"
    tag = "GiValve"


class GiVampireCape(rx.Component):
    library = "react-icons/gi"
    tag = "GiVampireCape"


class GiVampireDracula(rx.Component):
    library = "react-icons/gi"
    tag = "GiVampireDracula"


class GiVanDammeSplit(rx.Component):
    library = "react-icons/gi"
    tag = "GiVanDammeSplit"


class GiVanillaFlower(rx.Component):
    library = "react-icons/gi"
    tag = "GiVanillaFlower"


class GiVelocipede(rx.Component):
    library = "react-icons/gi"
    tag = "GiVelocipede"


class GiVelociraptorTracks(rx.Component):
    library = "react-icons/gi"
    tag = "GiVelociraptorTracks"


class GiVelociraptor(rx.Component):
    library = "react-icons/gi"
    tag = "GiVelociraptor"


class GiVendingMachine(rx.Component):
    library = "react-icons/gi"
    tag = "GiVendingMachine"


class GiVenezuela(rx.Component):
    library = "react-icons/gi"
    tag = "GiVenezuela"


class GiVenusFlytrap(rx.Component):
    library = "react-icons/gi"
    tag = "GiVenusFlytrap"


class GiVenusOfWillendorf(rx.Component):
    library = "react-icons/gi"
    tag = "GiVenusOfWillendorf"


class GiVerticalBanner(rx.Component):
    library = "react-icons/gi"
    tag = "GiVerticalBanner"


class GiVerticalFlip(rx.Component):
    library = "react-icons/gi"
    tag = "GiVerticalFlip"


class GiVhs(rx.Component):
    library = "react-icons/gi"
    tag = "GiVhs"


class GiVial(rx.Component):
    library = "react-icons/gi"
    tag = "GiVial"


class GiVibratingBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiVibratingBall"


class GiVibratingShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiVibratingShield"


class GiVibratingSmartphone(rx.Component):
    library = "react-icons/gi"
    tag = "GiVibratingSmartphone"


class GiVideoCamera(rx.Component):
    library = "react-icons/gi"
    tag = "GiVideoCamera"


class GiVideoConference(rx.Component):
    library = "react-icons/gi"
    tag = "GiVideoConference"


class GiVikingChurch(rx.Component):
    library = "react-icons/gi"
    tag = "GiVikingChurch"


class GiVikingHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiVikingHead"


class GiVikingHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiVikingHelmet"


class GiVikingLonghouse(rx.Component):
    library = "react-icons/gi"
    tag = "GiVikingLonghouse"


class GiVikingShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiVikingShield"


class GiVileFluid(rx.Component):
    library = "react-icons/gi"
    tag = "GiVileFluid"


class GiVillage(rx.Component):
    library = "react-icons/gi"
    tag = "GiVillage"


class GiVineFlower(rx.Component):
    library = "react-icons/gi"
    tag = "GiVineFlower"


class GiVineLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiVineLeaf"


class GiVineWhip(rx.Component):
    library = "react-icons/gi"
    tag = "GiVineWhip"


class GiVines(rx.Component):
    library = "react-icons/gi"
    tag = "GiVines"


class GiVintageRobot(rx.Component):
    library = "react-icons/gi"
    tag = "GiVintageRobot"


class GiViola(rx.Component):
    library = "react-icons/gi"
    tag = "GiViola"


class GiViolin(rx.Component):
    library = "react-icons/gi"
    tag = "GiViolin"


class GiVirgo(rx.Component):
    library = "react-icons/gi"
    tag = "GiVirgo"


class GiVirtualMarker(rx.Component):
    library = "react-icons/gi"
    tag = "GiVirtualMarker"


class GiVirus(rx.Component):
    library = "react-icons/gi"
    tag = "GiVirus"


class GiVisoredHelm(rx.Component):
    library = "react-icons/gi"
    tag = "GiVisoredHelm"


class GiVitruvianMan(rx.Component):
    library = "react-icons/gi"
    tag = "GiVitruvianMan"


class GiVolcano(rx.Component):
    library = "react-icons/gi"
    tag = "GiVolcano"


class GiVolleyballBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiVolleyballBall"


class GiVomiting(rx.Component):
    library = "react-icons/gi"
    tag = "GiVomiting"


class GiVoodooDoll(rx.Component):
    library = "react-icons/gi"
    tag = "GiVoodooDoll"


class GiVortex(rx.Component):
    library = "react-icons/gi"
    tag = "GiVortex"


class GiVote(rx.Component):
    library = "react-icons/gi"
    tag = "GiVote"


class GiVrHeadset(rx.Component):
    library = "react-icons/gi"
    tag = "GiVrHeadset"


class GiVulture(rx.Component):
    library = "react-icons/gi"
    tag = "GiVulture"


class GiVuvuzelas(rx.Component):
    library = "react-icons/gi"
    tag = "GiVuvuzelas"


class GiWalk(rx.Component):
    library = "react-icons/gi"
    tag = "GiWalk"


class GiWalkieTalkie(rx.Component):
    library = "react-icons/gi"
    tag = "GiWalkieTalkie"


class GiWalkingBoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiWalkingBoot"


class GiWalkingScout(rx.Component):
    library = "react-icons/gi"
    tag = "GiWalkingScout"


class GiWalkingTurret(rx.Component):
    library = "react-icons/gi"
    tag = "GiWalkingTurret"


class GiWallLight(rx.Component):
    library = "react-icons/gi"
    tag = "GiWallLight"


class GiWallet(rx.Component):
    library = "react-icons/gi"
    tag = "GiWallet"


class GiWalrusHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiWalrusHead"


class GiWaltherPpk(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaltherPpk"


class GiWantedReward(rx.Component):
    library = "react-icons/gi"
    tag = "GiWantedReward"


class GiWarAxe(rx.Component):
    library = "react-icons/gi"
    tag = "GiWarAxe"


class GiWarBonnet(rx.Component):
    library = "react-icons/gi"
    tag = "GiWarBonnet"


class GiWarPick(rx.Component):
    library = "react-icons/gi"
    tag = "GiWarPick"


class GiWarhammer(rx.Component):
    library = "react-icons/gi"
    tag = "GiWarhammer"


class GiWarlockEye(rx.Component):
    library = "react-icons/gi"
    tag = "GiWarlockEye"


class GiWarlockHood(rx.Component):
    library = "react-icons/gi"
    tag = "GiWarlockHood"


class GiWarpPipe(rx.Component):
    library = "react-icons/gi"
    tag = "GiWarpPipe"


class GiWashingMachine(rx.Component):
    library = "react-icons/gi"
    tag = "GiWashingMachine"


class GiWaspSting(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaspSting"


class GiWatch(rx.Component):
    library = "react-icons/gi"
    tag = "GiWatch"


class GiWatchtower(rx.Component):
    library = "react-icons/gi"
    tag = "GiWatchtower"


class GiWaterBolt(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterBolt"


class GiWaterBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterBottle"


class GiWaterDivinerStick(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterDivinerStick"


class GiWaterDrop(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterDrop"


class GiWaterFlask(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterFlask"


class GiWaterFountain(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterFountain"


class GiWaterGallon(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterGallon"


class GiWaterGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterGun"


class GiWaterMill(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterMill"


class GiWaterPolo(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterPolo"


class GiWaterRecycling(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterRecycling"


class GiWaterSplash(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterSplash"


class GiWaterTank(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterTank"


class GiWaterTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterTower"


class GiWaterfall(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaterfall"


class GiWateringCan(rx.Component):
    library = "react-icons/gi"
    tag = "GiWateringCan"


class GiWatermelon(rx.Component):
    library = "react-icons/gi"
    tag = "GiWatermelon"


class GiWaveCrest(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaveCrest"


class GiWaveStrike(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaveStrike"


class GiWaveSurfer(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaveSurfer"


class GiWaves(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaves"


class GiWavyChains(rx.Component):
    library = "react-icons/gi"
    tag = "GiWavyChains"


class GiWavyItinerary(rx.Component):
    library = "react-icons/gi"
    tag = "GiWavyItinerary"


class GiWaxSeal(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaxSeal"


class GiWaxTablet(rx.Component):
    library = "react-icons/gi"
    tag = "GiWaxTablet"


class GiWebSpit(rx.Component):
    library = "react-icons/gi"
    tag = "GiWebSpit"


class GiWeightCrush(rx.Component):
    library = "react-icons/gi"
    tag = "GiWeightCrush"


class GiWeightLiftingDown(rx.Component):
    library = "react-icons/gi"
    tag = "GiWeightLiftingDown"


class GiWeightLiftingUp(rx.Component):
    library = "react-icons/gi"
    tag = "GiWeightLiftingUp"


class GiWeightScale(rx.Component):
    library = "react-icons/gi"
    tag = "GiWeightScale"


class GiWeight(rx.Component):
    library = "react-icons/gi"
    tag = "GiWeight"


class GiWell(rx.Component):
    library = "react-icons/gi"
    tag = "GiWell"


class GiWerewolf(rx.Component):
    library = "react-icons/gi"
    tag = "GiWerewolf"


class GiWesternHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiWesternHat"


class GiWhaleTail(rx.Component):
    library = "react-icons/gi"
    tag = "GiWhaleTail"


class GiWheat(rx.Component):
    library = "react-icons/gi"
    tag = "GiWheat"


class GiWheelbarrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiWheelbarrow"


class GiWhip(rx.Component):
    library = "react-icons/gi"
    tag = "GiWhip"


class GiWhiplash(rx.Component):
    library = "react-icons/gi"
    tag = "GiWhiplash"


class GiWhirlpoolShuriken(rx.Component):
    library = "react-icons/gi"
    tag = "GiWhirlpoolShuriken"


class GiWhirlwind(rx.Component):
    library = "react-icons/gi"
    tag = "GiWhirlwind"


class GiWhisk(rx.Component):
    library = "react-icons/gi"
    tag = "GiWhisk"


class GiWhistle(rx.Component):
    library = "react-icons/gi"
    tag = "GiWhistle"


class GiWhiteBook(rx.Component):
    library = "react-icons/gi"
    tag = "GiWhiteBook"


class GiWhiteTower(rx.Component):
    library = "react-icons/gi"
    tag = "GiWhiteTower"


class GiWideArrowDunk(rx.Component):
    library = "react-icons/gi"
    tag = "GiWideArrowDunk"


class GiWifiRouter(rx.Component):
    library = "react-icons/gi"
    tag = "GiWifiRouter"


class GiWildfires(rx.Component):
    library = "react-icons/gi"
    tag = "GiWildfires"


class GiWilliamTellSkull(rx.Component):
    library = "react-icons/gi"
    tag = "GiWilliamTellSkull"


class GiWilliamTell(rx.Component):
    library = "react-icons/gi"
    tag = "GiWilliamTell"


class GiWillowTree(rx.Component):
    library = "react-icons/gi"
    tag = "GiWillowTree"


class GiWinchesterRifle(rx.Component):
    library = "react-icons/gi"
    tag = "GiWinchesterRifle"


class GiWindHole(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindHole"


class GiWindSlap(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindSlap"


class GiWindTurbine(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindTurbine"


class GiWindchimes(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindchimes"


class GiWindmill(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindmill"


class GiWindowBars(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindowBars"


class GiWindow(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindow"


class GiWindpump(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindpump"


class GiWindsock(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindsock"


class GiWindyStripes(rx.Component):
    library = "react-icons/gi"
    tag = "GiWindyStripes"


class GiWineBottle(rx.Component):
    library = "react-icons/gi"
    tag = "GiWineBottle"


class GiWineGlass(rx.Component):
    library = "react-icons/gi"
    tag = "GiWineGlass"


class GiWingCloak(rx.Component):
    library = "react-icons/gi"
    tag = "GiWingCloak"


class GiWingedArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiWingedArrow"


class GiWingedEmblem(rx.Component):
    library = "react-icons/gi"
    tag = "GiWingedEmblem"


class GiWingedLeg(rx.Component):
    library = "react-icons/gi"
    tag = "GiWingedLeg"


class GiWingedScepter(rx.Component):
    library = "react-icons/gi"
    tag = "GiWingedScepter"


class GiWingedShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiWingedShield"


class GiWingedSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiWingedSword"


class GiWingfoot(rx.Component):
    library = "react-icons/gi"
    tag = "GiWingfoot"


class GiWinterGloves(rx.Component):
    library = "react-icons/gi"
    tag = "GiWinterGloves"


class GiWinterHat(rx.Component):
    library = "react-icons/gi"
    tag = "GiWinterHat"


class GiWireCoil(rx.Component):
    library = "react-icons/gi"
    tag = "GiWireCoil"


class GiWireframeGlobe(rx.Component):
    library = "react-icons/gi"
    tag = "GiWireframeGlobe"


class GiWisdom(rx.Component):
    library = "react-icons/gi"
    tag = "GiWisdom"


class GiWitchFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiWitchFace"


class GiWitchFlight(rx.Component):
    library = "react-icons/gi"
    tag = "GiWitchFlight"


class GiWizardFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiWizardFace"


class GiWizardStaff(rx.Component):
    library = "react-icons/gi"
    tag = "GiWizardStaff"


class GiWok(rx.Component):
    library = "react-icons/gi"
    tag = "GiWok"


class GiWolfHead(rx.Component):
    library = "react-icons/gi"
    tag = "GiWolfHead"


class GiWolfHowl(rx.Component):
    library = "react-icons/gi"
    tag = "GiWolfHowl"


class GiWolfTrap(rx.Component):
    library = "react-icons/gi"
    tag = "GiWolfTrap"


class GiWolverineClaws(rx.Component):
    library = "react-icons/gi"
    tag = "GiWolverineClaws"


class GiWomanElfFace(rx.Component):
    library = "react-icons/gi"
    tag = "GiWomanElfFace"


class GiWoodAxe(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodAxe"


class GiWoodBeam(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodBeam"


class GiWoodCabin(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodCabin"


class GiWoodCanoe(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodCanoe"


class GiWoodClub(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodClub"


class GiWoodFrame(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodFrame"


class GiWoodPile(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodPile"


class GiWoodStick(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodStick"


class GiWoodenChair(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodenChair"


class GiWoodenClogs(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodenClogs"


class GiWoodenCrate(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodenCrate"


class GiWoodenDoor(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodenDoor"


class GiWoodenFence(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodenFence"


class GiWoodenHelmet(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodenHelmet"


class GiWoodenPegleg(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodenPegleg"


class GiWoodenPier(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodenPier"


class GiWoodenSign(rx.Component):
    library = "react-icons/gi"
    tag = "GiWoodenSign"


class GiWool(rx.Component):
    library = "react-icons/gi"
    tag = "GiWool"


class GiWorld(rx.Component):
    library = "react-icons/gi"
    tag = "GiWorld"


class GiWormMouth(rx.Component):
    library = "react-icons/gi"
    tag = "GiWormMouth"


class GiWorms(rx.Component):
    library = "react-icons/gi"
    tag = "GiWorms"


class GiWorriedEyes(rx.Component):
    library = "react-icons/gi"
    tag = "GiWorriedEyes"


class GiWrappedHeart(rx.Component):
    library = "react-icons/gi"
    tag = "GiWrappedHeart"


class GiWrappedSweet(rx.Component):
    library = "react-icons/gi"
    tag = "GiWrappedSweet"


class GiWrappingStar(rx.Component):
    library = "react-icons/gi"
    tag = "GiWrappingStar"


class GiWreckingBall(rx.Component):
    library = "react-icons/gi"
    tag = "GiWreckingBall"


class GiWrench(rx.Component):
    library = "react-icons/gi"
    tag = "GiWrench"


class GiWyvern(rx.Component):
    library = "react-icons/gi"
    tag = "GiWyvern"


class GiXylophone(rx.Component):
    library = "react-icons/gi"
    tag = "GiXylophone"


class GiYarn(rx.Component):
    library = "react-icons/gi"
    tag = "GiYarn"


class GiYinYang(rx.Component):
    library = "react-icons/gi"
    tag = "GiYinYang"


class GiYunluo(rx.Component):
    library = "react-icons/gi"
    tag = "GiYunluo"


class GiZBrick(rx.Component):
    library = "react-icons/gi"
    tag = "GiZBrick"


class GiZatGun(rx.Component):
    library = "react-icons/gi"
    tag = "GiZatGun"


class GiZebraShield(rx.Component):
    library = "react-icons/gi"
    tag = "GiZebraShield"


class GiZeppelin(rx.Component):
    library = "react-icons/gi"
    tag = "GiZeppelin"


class GiZeusSword(rx.Component):
    library = "react-icons/gi"
    tag = "GiZeusSword"


class GiZigArrow(rx.Component):
    library = "react-icons/gi"
    tag = "GiZigArrow"


class GiZigzagCage(rx.Component):
    library = "react-icons/gi"
    tag = "GiZigzagCage"


class GiZigzagHieroglyph(rx.Component):
    library = "react-icons/gi"
    tag = "GiZigzagHieroglyph"


class GiZigzagLeaf(rx.Component):
    library = "react-icons/gi"
    tag = "GiZigzagLeaf"


class GiZigzagTune(rx.Component):
    library = "react-icons/gi"
    tag = "GiZigzagTune"


class GiZipper(rx.Component):
    library = "react-icons/gi"
    tag = "GiZipper"


