import reflex as rx

class Tb123(rx.Component):
    library = "react-icons/tb"
    tag = "Tb123"


class Tb24Hours(rx.Component):
    library = "react-icons/tb"
    tag = "Tb24Hours"


class Tb2Fa(rx.Component):
    library = "react-icons/tb"
    tag = "Tb2Fa"


class Tb360View(rx.Component):
    library = "react-icons/tb"
    tag = "Tb360View"


class Tb360(rx.Component):
    library = "react-icons/tb"
    tag = "Tb360"


class Tb3DCubeSphereOff(rx.Component):
    library = "react-icons/tb"
    tag = "Tb3DCubeSphereOff"


class Tb3DCubeSphere(rx.Component):
    library = "react-icons/tb"
    tag = "Tb3DCubeSphere"


class Tb3DRotate(rx.Component):
    library = "react-icons/tb"
    tag = "Tb3DRotate"


class TbAB2(rx.Component):
    library = "react-icons/tb"
    tag = "TbAB2"


class TbABOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbABOff"


class TbAB(rx.Component):
    library = "react-icons/tb"
    tag = "TbAB"


class TbAbacusOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAbacusOff"


class TbAbacus(rx.Component):
    library = "react-icons/tb"
    tag = "TbAbacus"


class TbAbc(rx.Component):
    library = "react-icons/tb"
    tag = "TbAbc"


class TbAccessPointOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAccessPointOff"


class TbAccessPoint(rx.Component):
    library = "react-icons/tb"
    tag = "TbAccessPoint"


class TbAccessibleOffFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAccessibleOffFilled"


class TbAccessibleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAccessibleOff"


class TbAccessible(rx.Component):
    library = "react-icons/tb"
    tag = "TbAccessible"


class TbActivityHeartbeat(rx.Component):
    library = "react-icons/tb"
    tag = "TbActivityHeartbeat"


class TbActivity(rx.Component):
    library = "react-icons/tb"
    tag = "TbActivity"


class TbAd2(rx.Component):
    library = "react-icons/tb"
    tag = "TbAd2"


class TbAdCircleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdCircleFilled"


class TbAdCircleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdCircleOff"


class TbAdCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdCircle"


class TbAdFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdFilled"


class TbAdOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdOff"


class TbAd(rx.Component):
    library = "react-icons/tb"
    tag = "TbAd"


class TbAddressBookOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAddressBookOff"


class TbAddressBook(rx.Component):
    library = "react-icons/tb"
    tag = "TbAddressBook"


class TbAdjustmentsAlt(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsAlt"


class TbAdjustmentsBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsBolt"


class TbAdjustmentsCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsCancel"


class TbAdjustmentsCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsCheck"


class TbAdjustmentsCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsCode"


class TbAdjustmentsCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsCog"


class TbAdjustmentsDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsDollar"


class TbAdjustmentsDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsDown"


class TbAdjustmentsExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsExclamation"


class TbAdjustmentsFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsFilled"


class TbAdjustmentsHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsHeart"


class TbAdjustmentsHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsHorizontal"


class TbAdjustmentsMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsMinus"


class TbAdjustmentsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsOff"


class TbAdjustmentsPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsPause"


class TbAdjustmentsPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsPin"


class TbAdjustmentsPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsPlus"


class TbAdjustmentsQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsQuestion"


class TbAdjustmentsSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsSearch"


class TbAdjustmentsShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsShare"


class TbAdjustmentsStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsStar"


class TbAdjustmentsUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsUp"


class TbAdjustmentsX(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustmentsX"


class TbAdjustments(rx.Component):
    library = "react-icons/tb"
    tag = "TbAdjustments"


class TbAerialLift(rx.Component):
    library = "react-icons/tb"
    tag = "TbAerialLift"


class TbAffiliateFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAffiliateFilled"


class TbAffiliate(rx.Component):
    library = "react-icons/tb"
    tag = "TbAffiliate"


class TbAirBalloon(rx.Component):
    library = "react-icons/tb"
    tag = "TbAirBalloon"


class TbAirConditioningDisabled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAirConditioningDisabled"


class TbAirConditioning(rx.Component):
    library = "react-icons/tb"
    tag = "TbAirConditioning"


class TbAlarmFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlarmFilled"


class TbAlarmMinusFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlarmMinusFilled"


class TbAlarmMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlarmMinus"


class TbAlarmOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlarmOff"


class TbAlarmPlusFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlarmPlusFilled"


class TbAlarmPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlarmPlus"


class TbAlarmSnoozeFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlarmSnoozeFilled"


class TbAlarmSnooze(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlarmSnooze"


class TbAlarm(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlarm"


class TbAlbumOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlbumOff"


class TbAlbum(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlbum"


class TbAlertCircleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertCircleFilled"


class TbAlertCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertCircle"


class TbAlertHexagonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertHexagonFilled"


class TbAlertHexagon(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertHexagon"


class TbAlertOctagonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertOctagonFilled"


class TbAlertOctagon(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertOctagon"


class TbAlertSmall(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertSmall"


class TbAlertSquareFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertSquareFilled"


class TbAlertSquareRoundedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertSquareRoundedFilled"


class TbAlertSquareRounded(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertSquareRounded"


class TbAlertSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertSquare"


class TbAlertTriangleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertTriangleFilled"


class TbAlertTriangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlertTriangle"


class TbAlienFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlienFilled"


class TbAlien(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlien"


class TbAlignBoxBottomCenterFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxBottomCenterFilled"


class TbAlignBoxBottomCenter(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxBottomCenter"


class TbAlignBoxBottomLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxBottomLeftFilled"


class TbAlignBoxBottomLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxBottomLeft"


class TbAlignBoxBottomRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxBottomRightFilled"


class TbAlignBoxBottomRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxBottomRight"


class TbAlignBoxCenterMiddleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxCenterMiddleFilled"


class TbAlignBoxCenterMiddle(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxCenterMiddle"


class TbAlignBoxLeftBottomFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxLeftBottomFilled"


class TbAlignBoxLeftBottom(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxLeftBottom"


class TbAlignBoxLeftMiddleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxLeftMiddleFilled"


class TbAlignBoxLeftMiddle(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxLeftMiddle"


class TbAlignBoxLeftTopFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxLeftTopFilled"


class TbAlignBoxLeftTop(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxLeftTop"


class TbAlignBoxRightBottomFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxRightBottomFilled"


class TbAlignBoxRightBottom(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxRightBottom"


class TbAlignBoxRightMiddleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxRightMiddleFilled"


class TbAlignBoxRightMiddle(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxRightMiddle"


class TbAlignBoxRightTopFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxRightTopFilled"


class TbAlignBoxRightTop(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxRightTop"


class TbAlignBoxTopCenterFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxTopCenterFilled"


class TbAlignBoxTopCenter(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxTopCenter"


class TbAlignBoxTopLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxTopLeftFilled"


class TbAlignBoxTopLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxTopLeft"


class TbAlignBoxTopRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxTopRightFilled"


class TbAlignBoxTopRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignBoxTopRight"


class TbAlignCenter(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignCenter"


class TbAlignJustified(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignJustified"


class TbAlignLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignLeft"


class TbAlignRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlignRight"


class TbAlpha(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlpha"


class TbAlphabetCyrillic(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlphabetCyrillic"


class TbAlphabetGreek(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlphabetGreek"


class TbAlphabetLatin(rx.Component):
    library = "react-icons/tb"
    tag = "TbAlphabetLatin"


class TbAmbulance(rx.Component):
    library = "react-icons/tb"
    tag = "TbAmbulance"


class TbAmpersand(rx.Component):
    library = "react-icons/tb"
    tag = "TbAmpersand"


class TbAnalyzeFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAnalyzeFilled"


class TbAnalyzeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAnalyzeOff"


class TbAnalyze(rx.Component):
    library = "react-icons/tb"
    tag = "TbAnalyze"


class TbAnchorOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAnchorOff"


class TbAnchor(rx.Component):
    library = "react-icons/tb"
    tag = "TbAnchor"


class TbAngle(rx.Component):
    library = "react-icons/tb"
    tag = "TbAngle"


class TbAnkh(rx.Component):
    library = "react-icons/tb"
    tag = "TbAnkh"


class TbAntennaBars1(rx.Component):
    library = "react-icons/tb"
    tag = "TbAntennaBars1"


class TbAntennaBars2(rx.Component):
    library = "react-icons/tb"
    tag = "TbAntennaBars2"


class TbAntennaBars3(rx.Component):
    library = "react-icons/tb"
    tag = "TbAntennaBars3"


class TbAntennaBars4(rx.Component):
    library = "react-icons/tb"
    tag = "TbAntennaBars4"


class TbAntennaBars5(rx.Component):
    library = "react-icons/tb"
    tag = "TbAntennaBars5"


class TbAntennaBarsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAntennaBarsOff"


class TbAntennaOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAntennaOff"


class TbAntenna(rx.Component):
    library = "react-icons/tb"
    tag = "TbAntenna"


class TbApertureOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbApertureOff"


class TbAperture(rx.Component):
    library = "react-icons/tb"
    tag = "TbAperture"


class TbApiAppOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbApiAppOff"


class TbApiApp(rx.Component):
    library = "react-icons/tb"
    tag = "TbApiApp"


class TbApiOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbApiOff"


class TbApi(rx.Component):
    library = "react-icons/tb"
    tag = "TbApi"


class TbAppWindowFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAppWindowFilled"


class TbAppWindow(rx.Component):
    library = "react-icons/tb"
    tag = "TbAppWindow"


class TbApple(rx.Component):
    library = "react-icons/tb"
    tag = "TbApple"


class TbAppsFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAppsFilled"


class TbAppsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAppsOff"


class TbApps(rx.Component):
    library = "react-icons/tb"
    tag = "TbApps"


class TbArchiveFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArchiveFilled"


class TbArchiveOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbArchiveOff"


class TbArchive(rx.Component):
    library = "react-icons/tb"
    tag = "TbArchive"


class TbArmchair2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbArmchair2Off"


class TbArmchair2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArmchair2"


class TbArmchairOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbArmchairOff"


class TbArmchair(rx.Component):
    library = "react-icons/tb"
    tag = "TbArmchair"


class TbArrowAutofitContentFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowAutofitContentFilled"


class TbArrowAutofitContent(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowAutofitContent"


class TbArrowAutofitDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowAutofitDown"


class TbArrowAutofitHeight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowAutofitHeight"


class TbArrowAutofitLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowAutofitLeft"


class TbArrowAutofitRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowAutofitRight"


class TbArrowAutofitUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowAutofitUp"


class TbArrowAutofitWidth(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowAutofitWidth"


class TbArrowBackUpDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBackUpDouble"


class TbArrowBackUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBackUp"


class TbArrowBack(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBack"


class TbArrowBadgeDownFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBadgeDownFilled"


class TbArrowBadgeDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBadgeDown"


class TbArrowBadgeLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBadgeLeftFilled"


class TbArrowBadgeLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBadgeLeft"


class TbArrowBadgeRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBadgeRightFilled"


class TbArrowBadgeRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBadgeRight"


class TbArrowBadgeUpFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBadgeUpFilled"


class TbArrowBadgeUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBadgeUp"


class TbArrowBarDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBarDown"


class TbArrowBarLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBarLeft"


class TbArrowBarRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBarRight"


class TbArrowBarToDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBarToDown"


class TbArrowBarToLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBarToLeft"


class TbArrowBarToRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBarToRight"


class TbArrowBarToUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBarToUp"


class TbArrowBarUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBarUp"


class TbArrowBearLeft2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBearLeft2"


class TbArrowBearLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBearLeft"


class TbArrowBearRight2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBearRight2"


class TbArrowBearRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBearRight"


class TbArrowBigDownFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigDownFilled"


class TbArrowBigDownLineFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigDownLineFilled"


class TbArrowBigDownLine(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigDownLine"


class TbArrowBigDownLinesFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigDownLinesFilled"


class TbArrowBigDownLines(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigDownLines"


class TbArrowBigDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigDown"


class TbArrowBigLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigLeftFilled"


class TbArrowBigLeftLineFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigLeftLineFilled"


class TbArrowBigLeftLine(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigLeftLine"


class TbArrowBigLeftLinesFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigLeftLinesFilled"


class TbArrowBigLeftLines(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigLeftLines"


class TbArrowBigLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigLeft"


class TbArrowBigRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigRightFilled"


class TbArrowBigRightLineFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigRightLineFilled"


class TbArrowBigRightLine(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigRightLine"


class TbArrowBigRightLinesFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigRightLinesFilled"


class TbArrowBigRightLines(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigRightLines"


class TbArrowBigRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigRight"


class TbArrowBigUpFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigUpFilled"


class TbArrowBigUpLineFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigUpLineFilled"


class TbArrowBigUpLine(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigUpLine"


class TbArrowBigUpLinesFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigUpLinesFilled"


class TbArrowBigUpLines(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigUpLines"


class TbArrowBigUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBigUp"


class TbArrowBounce(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowBounce"


class TbArrowCurveLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowCurveLeft"


class TbArrowCurveRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowCurveRight"


class TbArrowDownBar(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDownBar"


class TbArrowDownCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDownCircle"


class TbArrowDownLeftCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDownLeftCircle"


class TbArrowDownLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDownLeft"


class TbArrowDownRhombus(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDownRhombus"


class TbArrowDownRightCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDownRightCircle"


class TbArrowDownRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDownRight"


class TbArrowDownSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDownSquare"


class TbArrowDownTail(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDownTail"


class TbArrowDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowDown"


class TbArrowElbowLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowElbowLeft"


class TbArrowElbowRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowElbowRight"


class TbArrowFork(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowFork"


class TbArrowForwardUpDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowForwardUpDouble"


class TbArrowForwardUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowForwardUp"


class TbArrowForward(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowForward"


class TbArrowGuide(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowGuide"


class TbArrowIteration(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowIteration"


class TbArrowLeftBar(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLeftBar"


class TbArrowLeftCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLeftCircle"


class TbArrowLeftRhombus(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLeftRhombus"


class TbArrowLeftRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLeftRight"


class TbArrowLeftSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLeftSquare"


class TbArrowLeftTail(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLeftTail"


class TbArrowLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLeft"


class TbArrowLoopLeft2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLoopLeft2"


class TbArrowLoopLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLoopLeft"


class TbArrowLoopRight2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLoopRight2"


class TbArrowLoopRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowLoopRight"


class TbArrowMergeBoth(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowMergeBoth"


class TbArrowMergeLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowMergeLeft"


class TbArrowMergeRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowMergeRight"


class TbArrowMerge(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowMerge"


class TbArrowMoveDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowMoveDown"


class TbArrowMoveLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowMoveLeft"


class TbArrowMoveRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowMoveRight"


class TbArrowMoveUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowMoveUp"


class TbArrowNarrowDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowNarrowDown"


class TbArrowNarrowLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowNarrowLeft"


class TbArrowNarrowRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowNarrowRight"


class TbArrowNarrowUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowNarrowUp"


class TbArrowRampLeft2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRampLeft2"


class TbArrowRampLeft3(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRampLeft3"


class TbArrowRampLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRampLeft"


class TbArrowRampRight2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRampRight2"


class TbArrowRampRight3(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRampRight3"


class TbArrowRampRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRampRight"


class TbArrowRightBar(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRightBar"


class TbArrowRightCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRightCircle"


class TbArrowRightRhombus(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRightRhombus"


class TbArrowRightSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRightSquare"


class TbArrowRightTail(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRightTail"


class TbArrowRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRight"


class TbArrowRotaryFirstLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRotaryFirstLeft"


class TbArrowRotaryFirstRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRotaryFirstRight"


class TbArrowRotaryLastLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRotaryLastLeft"


class TbArrowRotaryLastRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRotaryLastRight"


class TbArrowRotaryLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRotaryLeft"


class TbArrowRotaryRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRotaryRight"


class TbArrowRotaryStraight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRotaryStraight"


class TbArrowRoundaboutLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRoundaboutLeft"


class TbArrowRoundaboutRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowRoundaboutRight"


class TbArrowSharpTurnLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowSharpTurnLeft"


class TbArrowSharpTurnRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowSharpTurnRight"


class TbArrowUpBar(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUpBar"


class TbArrowUpCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUpCircle"


class TbArrowUpLeftCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUpLeftCircle"


class TbArrowUpLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUpLeft"


class TbArrowUpRhombus(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUpRhombus"


class TbArrowUpRightCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUpRightCircle"


class TbArrowUpRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUpRight"


class TbArrowUpSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUpSquare"


class TbArrowUpTail(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUpTail"


class TbArrowUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowUp"


class TbArrowWaveLeftDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowWaveLeftDown"


class TbArrowWaveLeftUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowWaveLeftUp"


class TbArrowWaveRightDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowWaveRightDown"


class TbArrowWaveRightUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowWaveRightUp"


class TbArrowZigZag(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowZigZag"


class TbArrowsCross(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsCross"


class TbArrowsDiagonal2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDiagonal2"


class TbArrowsDiagonalMinimize2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDiagonalMinimize2"


class TbArrowsDiagonalMinimize(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDiagonalMinimize"


class TbArrowsDiagonal(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDiagonal"


class TbArrowsDiff(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDiff"


class TbArrowsDoubleNeSw(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDoubleNeSw"


class TbArrowsDoubleNwSe(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDoubleNwSe"


class TbArrowsDoubleSeNw(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDoubleSeNw"


class TbArrowsDoubleSwNe(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDoubleSwNe"


class TbArrowsDownUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDownUp"


class TbArrowsDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsDown"


class TbArrowsExchange2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsExchange2"


class TbArrowsExchange(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsExchange"


class TbArrowsHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsHorizontal"


class TbArrowsJoin2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsJoin2"


class TbArrowsJoin(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsJoin"


class TbArrowsLeftDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsLeftDown"


class TbArrowsLeftRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsLeftRight"


class TbArrowsLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsLeft"


class TbArrowsMaximize(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsMaximize"


class TbArrowsMinimize(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsMinimize"


class TbArrowsMoveHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsMoveHorizontal"


class TbArrowsMoveVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsMoveVertical"


class TbArrowsMove(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsMove"


class TbArrowsRandom(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsRandom"


class TbArrowsRightDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsRightDown"


class TbArrowsRightLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsRightLeft"


class TbArrowsRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsRight"


class TbArrowsShuffle2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsShuffle2"


class TbArrowsShuffle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsShuffle"


class TbArrowsSort(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsSort"


class TbArrowsSplit2(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsSplit2"


class TbArrowsSplit(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsSplit"


class TbArrowsTransferDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsTransferDown"


class TbArrowsTransferUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsTransferUp"


class TbArrowsUpDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsUpDown"


class TbArrowsUpLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsUpLeft"


class TbArrowsUpRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsUpRight"


class TbArrowsUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsUp"


class TbArrowsVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbArrowsVertical"


class TbArtboardFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArtboardFilled"


class TbArtboardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbArtboardOff"


class TbArtboard(rx.Component):
    library = "react-icons/tb"
    tag = "TbArtboard"


class TbArticleFilledFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbArticleFilledFilled"


class TbArticleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbArticleOff"


class TbArticle(rx.Component):
    library = "react-icons/tb"
    tag = "TbArticle"


class TbAspectRatioFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAspectRatioFilled"


class TbAspectRatioOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAspectRatioOff"


class TbAspectRatio(rx.Component):
    library = "react-icons/tb"
    tag = "TbAspectRatio"


class TbAssemblyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAssemblyOff"


class TbAssembly(rx.Component):
    library = "react-icons/tb"
    tag = "TbAssembly"


class TbAsset(rx.Component):
    library = "react-icons/tb"
    tag = "TbAsset"


class TbAsteriskSimple(rx.Component):
    library = "react-icons/tb"
    tag = "TbAsteriskSimple"


class TbAsterisk(rx.Component):
    library = "react-icons/tb"
    tag = "TbAsterisk"


class TbAtOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAtOff"


class TbAt(rx.Component):
    library = "react-icons/tb"
    tag = "TbAt"


class TbAtom2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAtom2Filled"


class TbAtom2(rx.Component):
    library = "react-icons/tb"
    tag = "TbAtom2"


class TbAtomOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAtomOff"


class TbAtom(rx.Component):
    library = "react-icons/tb"
    tag = "TbAtom"


class TbAugmentedReality2(rx.Component):
    library = "react-icons/tb"
    tag = "TbAugmentedReality2"


class TbAugmentedRealityOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAugmentedRealityOff"


class TbAugmentedReality(rx.Component):
    library = "react-icons/tb"
    tag = "TbAugmentedReality"


class TbAwardFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbAwardFilled"


class TbAwardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbAwardOff"


class TbAward(rx.Component):
    library = "react-icons/tb"
    tag = "TbAward"


class TbAxe(rx.Component):
    library = "react-icons/tb"
    tag = "TbAxe"


class TbAxisX(rx.Component):
    library = "react-icons/tb"
    tag = "TbAxisX"


class TbAxisY(rx.Component):
    library = "react-icons/tb"
    tag = "TbAxisY"


class TbBabyBottle(rx.Component):
    library = "react-icons/tb"
    tag = "TbBabyBottle"


class TbBabyCarriage(rx.Component):
    library = "react-icons/tb"
    tag = "TbBabyCarriage"


class TbBackhoe(rx.Component):
    library = "react-icons/tb"
    tag = "TbBackhoe"


class TbBackpackOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBackpackOff"


class TbBackpack(rx.Component):
    library = "react-icons/tb"
    tag = "TbBackpack"


class TbBackslash(rx.Component):
    library = "react-icons/tb"
    tag = "TbBackslash"


class TbBackspaceFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBackspaceFilled"


class TbBackspace(rx.Component):
    library = "react-icons/tb"
    tag = "TbBackspace"


class TbBadge3D(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadge3D"


class TbBadge4K(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadge4K"


class TbBadge8K(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadge8K"


class TbBadgeAd(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeAd"


class TbBadgeAr(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeAr"


class TbBadgeCc(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeCc"


class TbBadgeFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeFilled"


class TbBadgeHd(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeHd"


class TbBadgeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeOff"


class TbBadgeSd(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeSd"


class TbBadgeTm(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeTm"


class TbBadgeVo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeVo"


class TbBadgeVr(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeVr"


class TbBadgeWc(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgeWc"


class TbBadge(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadge"


class TbBadgesFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgesFilled"


class TbBadgesOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadgesOff"


class TbBadges(rx.Component):
    library = "react-icons/tb"
    tag = "TbBadges"


class TbBaguette(rx.Component):
    library = "react-icons/tb"
    tag = "TbBaguette"


class TbBallAmericanFootballOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallAmericanFootballOff"


class TbBallAmericanFootball(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallAmericanFootball"


class TbBallBaseball(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallBaseball"


class TbBallBasketball(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallBasketball"


class TbBallBowling(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallBowling"


class TbBallFootballOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallFootballOff"


class TbBallFootball(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallFootball"


class TbBallTennis(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallTennis"


class TbBallVolleyball(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallVolleyball"


class TbBalloonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBalloonFilled"


class TbBalloonOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBalloonOff"


class TbBalloon(rx.Component):
    library = "react-icons/tb"
    tag = "TbBalloon"


class TbBallpenFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallpenFilled"


class TbBallpenOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallpenOff"


class TbBallpen(rx.Component):
    library = "react-icons/tb"
    tag = "TbBallpen"


class TbBan(rx.Component):
    library = "react-icons/tb"
    tag = "TbBan"


class TbBandageFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBandageFilled"


class TbBandageOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBandageOff"


class TbBandage(rx.Component):
    library = "react-icons/tb"
    tag = "TbBandage"


class TbBarbellOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBarbellOff"


class TbBarbell(rx.Component):
    library = "react-icons/tb"
    tag = "TbBarbell"


class TbBarcodeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBarcodeOff"


class TbBarcode(rx.Component):
    library = "react-icons/tb"
    tag = "TbBarcode"


class TbBarrelOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBarrelOff"


class TbBarrel(rx.Component):
    library = "react-icons/tb"
    tag = "TbBarrel"


class TbBarrierBlockOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBarrierBlockOff"


class TbBarrierBlock(rx.Component):
    library = "react-icons/tb"
    tag = "TbBarrierBlock"


class TbBaselineDensityLarge(rx.Component):
    library = "react-icons/tb"
    tag = "TbBaselineDensityLarge"


class TbBaselineDensityMedium(rx.Component):
    library = "react-icons/tb"
    tag = "TbBaselineDensityMedium"


class TbBaselineDensitySmall(rx.Component):
    library = "react-icons/tb"
    tag = "TbBaselineDensitySmall"


class TbBaseline(rx.Component):
    library = "react-icons/tb"
    tag = "TbBaseline"


class TbBasketFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBasketFilled"


class TbBasketOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBasketOff"


class TbBasket(rx.Component):
    library = "react-icons/tb"
    tag = "TbBasket"


class TbBat(rx.Component):
    library = "react-icons/tb"
    tag = "TbBat"


class TbBathFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBathFilled"


class TbBathOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBathOff"


class TbBath(rx.Component):
    library = "react-icons/tb"
    tag = "TbBath"


class TbBattery1Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBattery1Filled"


class TbBattery1(rx.Component):
    library = "react-icons/tb"
    tag = "TbBattery1"


class TbBattery2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBattery2Filled"


class TbBattery2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBattery2"


class TbBattery3Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBattery3Filled"


class TbBattery3(rx.Component):
    library = "react-icons/tb"
    tag = "TbBattery3"


class TbBattery4Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBattery4Filled"


class TbBattery4(rx.Component):
    library = "react-icons/tb"
    tag = "TbBattery4"


class TbBatteryAutomotive(rx.Component):
    library = "react-icons/tb"
    tag = "TbBatteryAutomotive"


class TbBatteryCharging2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBatteryCharging2"


class TbBatteryCharging(rx.Component):
    library = "react-icons/tb"
    tag = "TbBatteryCharging"


class TbBatteryEco(rx.Component):
    library = "react-icons/tb"
    tag = "TbBatteryEco"


class TbBatteryFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBatteryFilled"


class TbBatteryOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBatteryOff"


class TbBattery(rx.Component):
    library = "react-icons/tb"
    tag = "TbBattery"


class TbBeachOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBeachOff"


class TbBeach(rx.Component):
    library = "react-icons/tb"
    tag = "TbBeach"


class TbBedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBedFilled"


class TbBedOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBedOff"


class TbBed(rx.Component):
    library = "react-icons/tb"
    tag = "TbBed"


class TbBeerFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBeerFilled"


class TbBeerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBeerOff"


class TbBeer(rx.Component):
    library = "react-icons/tb"
    tag = "TbBeer"


class TbBellBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellBolt"


class TbBellCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellCancel"


class TbBellCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellCheck"


class TbBellCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellCode"


class TbBellCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellCog"


class TbBellDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellDollar"


class TbBellDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellDown"


class TbBellExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellExclamation"


class TbBellFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellFilled"


class TbBellHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellHeart"


class TbBellMinusFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellMinusFilled"


class TbBellMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellMinus"


class TbBellOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellOff"


class TbBellPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellPause"


class TbBellPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellPin"


class TbBellPlusFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellPlusFilled"


class TbBellPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellPlus"


class TbBellQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellQuestion"


class TbBellRinging2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellRinging2Filled"


class TbBellRinging2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellRinging2"


class TbBellRingingFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellRingingFilled"


class TbBellRinging(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellRinging"


class TbBellSchool(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellSchool"


class TbBellSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellSearch"


class TbBellShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellShare"


class TbBellStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellStar"


class TbBellUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellUp"


class TbBellXFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellXFilled"


class TbBellX(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellX"


class TbBellZFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellZFilled"


class TbBellZ(rx.Component):
    library = "react-icons/tb"
    tag = "TbBellZ"


class TbBell(rx.Component):
    library = "react-icons/tb"
    tag = "TbBell"


class TbBeta(rx.Component):
    library = "react-icons/tb"
    tag = "TbBeta"


class TbBible(rx.Component):
    library = "react-icons/tb"
    tag = "TbBible"


class TbBikeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBikeOff"


class TbBike(rx.Component):
    library = "react-icons/tb"
    tag = "TbBike"


class TbBinaryOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBinaryOff"


class TbBinaryTree2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBinaryTree2"


class TbBinaryTree(rx.Component):
    library = "react-icons/tb"
    tag = "TbBinaryTree"


class TbBinary(rx.Component):
    library = "react-icons/tb"
    tag = "TbBinary"


class TbBiohazardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBiohazardOff"


class TbBiohazard(rx.Component):
    library = "react-icons/tb"
    tag = "TbBiohazard"


class TbBladeFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBladeFilled"


class TbBlade(rx.Component):
    library = "react-icons/tb"
    tag = "TbBlade"


class TbBleachChlorine(rx.Component):
    library = "react-icons/tb"
    tag = "TbBleachChlorine"


class TbBleachNoChlorine(rx.Component):
    library = "react-icons/tb"
    tag = "TbBleachNoChlorine"


class TbBleachOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBleachOff"


class TbBleach(rx.Component):
    library = "react-icons/tb"
    tag = "TbBleach"


class TbBlockquote(rx.Component):
    library = "react-icons/tb"
    tag = "TbBlockquote"


class TbBluetoothConnected(rx.Component):
    library = "react-icons/tb"
    tag = "TbBluetoothConnected"


class TbBluetoothOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBluetoothOff"


class TbBluetoothX(rx.Component):
    library = "react-icons/tb"
    tag = "TbBluetoothX"


class TbBluetooth(rx.Component):
    library = "react-icons/tb"
    tag = "TbBluetooth"


class TbBlurOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBlurOff"


class TbBlur(rx.Component):
    library = "react-icons/tb"
    tag = "TbBlur"


class TbBmp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBmp"


class TbBoldOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoldOff"


class TbBold(rx.Component):
    library = "react-icons/tb"
    tag = "TbBold"


class TbBoltOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoltOff"


class TbBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbBolt"


class TbBombFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBombFilled"


class TbBomb(rx.Component):
    library = "react-icons/tb"
    tag = "TbBomb"


class TbBoneOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoneOff"


class TbBone(rx.Component):
    library = "react-icons/tb"
    tag = "TbBone"


class TbBongOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBongOff"


class TbBong(rx.Component):
    library = "react-icons/tb"
    tag = "TbBong"


class TbBook2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBook2"


class TbBookDownload(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookDownload"


class TbBookFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookFilled"


class TbBookOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookOff"


class TbBookUpload(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookUpload"


class TbBook(rx.Component):
    library = "react-icons/tb"
    tag = "TbBook"


class TbBookmarkEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookmarkEdit"


class TbBookmarkFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookmarkFilled"


class TbBookmarkMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookmarkMinus"


class TbBookmarkOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookmarkOff"


class TbBookmarkPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookmarkPlus"


class TbBookmarkQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookmarkQuestion"


class TbBookmark(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookmark"


class TbBookmarksOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookmarksOff"


class TbBookmarks(rx.Component):
    library = "react-icons/tb"
    tag = "TbBookmarks"


class TbBooksOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBooksOff"


class TbBooks(rx.Component):
    library = "react-icons/tb"
    tag = "TbBooks"


class TbBorderAll(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderAll"


class TbBorderBottom(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderBottom"


class TbBorderCorners(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderCorners"


class TbBorderHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderHorizontal"


class TbBorderInner(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderInner"


class TbBorderLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderLeft"


class TbBorderNone(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderNone"


class TbBorderOuter(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderOuter"


class TbBorderRadius(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderRadius"


class TbBorderRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderRight"


class TbBorderSides(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderSides"


class TbBorderStyle2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderStyle2"


class TbBorderStyle(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderStyle"


class TbBorderTop(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderTop"


class TbBorderVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbBorderVertical"


class TbBottleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBottleFilled"


class TbBottleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBottleOff"


class TbBottle(rx.Component):
    library = "react-icons/tb"
    tag = "TbBottle"


class TbBounceLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbBounceLeft"


class TbBounceRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbBounceRight"


class TbBow(rx.Component):
    library = "react-icons/tb"
    tag = "TbBow"


class TbBowl(rx.Component):
    library = "react-icons/tb"
    tag = "TbBowl"


class TbBoxAlignBottomFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignBottomFilled"


class TbBoxAlignBottomLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignBottomLeftFilled"


class TbBoxAlignBottomLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignBottomLeft"


class TbBoxAlignBottomRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignBottomRightFilled"


class TbBoxAlignBottomRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignBottomRight"


class TbBoxAlignBottom(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignBottom"


class TbBoxAlignLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignLeftFilled"


class TbBoxAlignLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignLeft"


class TbBoxAlignRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignRightFilled"


class TbBoxAlignRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignRight"


class TbBoxAlignTopFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignTopFilled"


class TbBoxAlignTopLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignTopLeftFilled"


class TbBoxAlignTopLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignTopLeft"


class TbBoxAlignTopRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignTopRightFilled"


class TbBoxAlignTopRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignTopRight"


class TbBoxAlignTop(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxAlignTop"


class TbBoxMargin(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMargin"


class TbBoxModel2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxModel2Off"


class TbBoxModel2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxModel2"


class TbBoxModelOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxModelOff"


class TbBoxModel(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxModel"


class TbBoxMultiple0(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple0"


class TbBoxMultiple1(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple1"


class TbBoxMultiple2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple2"


class TbBoxMultiple3(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple3"


class TbBoxMultiple4(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple4"


class TbBoxMultiple5(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple5"


class TbBoxMultiple6(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple6"


class TbBoxMultiple7(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple7"


class TbBoxMultiple8(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple8"


class TbBoxMultiple9(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple9"


class TbBoxMultiple(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxMultiple"


class TbBoxOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxOff"


class TbBoxPadding(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxPadding"


class TbBoxSeam(rx.Component):
    library = "react-icons/tb"
    tag = "TbBoxSeam"


class TbBox(rx.Component):
    library = "react-icons/tb"
    tag = "TbBox"


class TbBracesOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBracesOff"


class TbBraces(rx.Component):
    library = "react-icons/tb"
    tag = "TbBraces"


class TbBracketsContainEnd(rx.Component):
    library = "react-icons/tb"
    tag = "TbBracketsContainEnd"


class TbBracketsContainStart(rx.Component):
    library = "react-icons/tb"
    tag = "TbBracketsContainStart"


class TbBracketsContain(rx.Component):
    library = "react-icons/tb"
    tag = "TbBracketsContain"


class TbBracketsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBracketsOff"


class TbBrackets(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrackets"


class TbBraille(rx.Component):
    library = "react-icons/tb"
    tag = "TbBraille"


class TbBrain(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrain"


class TbBrand4Chan(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrand4Chan"


class TbBrandAbstract(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAbstract"


class TbBrandAdobe(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAdobe"


class TbBrandAdonisJs(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAdonisJs"


class TbBrandAirbnb(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAirbnb"


class TbBrandAirtable(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAirtable"


class TbBrandAlgolia(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAlgolia"


class TbBrandAlipay(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAlipay"


class TbBrandAlpineJs(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAlpineJs"


class TbBrandAmazon(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAmazon"


class TbBrandAmd(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAmd"


class TbBrandAmigo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAmigo"


class TbBrandAmongUs(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAmongUs"


class TbBrandAndroid(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAndroid"


class TbBrandAngular(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAngular"


class TbBrandAnsible(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAnsible"


class TbBrandAo3(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAo3"


class TbBrandAppgallery(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAppgallery"


class TbBrandAppleArcade(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAppleArcade"


class TbBrandApplePodcast(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandApplePodcast"


class TbBrandApple(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandApple"


class TbBrandAppstore(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAppstore"


class TbBrandAsana(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAsana"


class TbBrandAws(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAws"


class TbBrandAzure(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandAzure"


class TbBrandBackbone(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBackbone"


class TbBrandBadoo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBadoo"


class TbBrandBaidu(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBaidu"


class TbBrandBandcamp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBandcamp"


class TbBrandBandlab(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBandlab"


class TbBrandBeats(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBeats"


class TbBrandBehance(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBehance"


class TbBrandBilibili(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBilibili"


class TbBrandBinance(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBinance"


class TbBrandBing(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBing"


class TbBrandBitbucket(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBitbucket"


class TbBrandBlackberry(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBlackberry"


class TbBrandBlender(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBlender"


class TbBrandBlogger(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBlogger"


class TbBrandBooking(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBooking"


class TbBrandBootstrap(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBootstrap"


class TbBrandBulma(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBulma"


class TbBrandBumble(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBumble"


class TbBrandBunpo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandBunpo"


class TbBrandCSharp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCSharp"


class TbBrandCake(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCake"


class TbBrandCakephp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCakephp"


class TbBrandCampaignmonitor(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCampaignmonitor"


class TbBrandCarbon(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCarbon"


class TbBrandCashapp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCashapp"


class TbBrandChrome(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandChrome"


class TbBrandCinema4D(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCinema4D"


class TbBrandCitymapper(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCitymapper"


class TbBrandCloudflare(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCloudflare"


class TbBrandCodecov(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCodecov"


class TbBrandCodepen(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCodepen"


class TbBrandCodesandbox(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCodesandbox"


class TbBrandCohost(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCohost"


class TbBrandCoinbase(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCoinbase"


class TbBrandComedyCentral(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandComedyCentral"


class TbBrandCoreos(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCoreos"


class TbBrandCouchdb(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCouchdb"


class TbBrandCouchsurfing(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCouchsurfing"


class TbBrandCpp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCpp"


class TbBrandCraft(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCraft"


class TbBrandCrunchbase(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCrunchbase"


class TbBrandCss3(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCss3"


class TbBrandCtemplar(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCtemplar"


class TbBrandCucumber(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCucumber"


class TbBrandCupra(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCupra"


class TbBrandCypress(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandCypress"


class TbBrandD3(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandD3"


class TbBrandDaysCounter(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDaysCounter"


class TbBrandDcos(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDcos"


class TbBrandDebian(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDebian"


class TbBrandDeezer(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDeezer"


class TbBrandDeliveroo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDeliveroo"


class TbBrandDeno(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDeno"


class TbBrandDenodo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDenodo"


class TbBrandDeviantart(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDeviantart"


class TbBrandDigg(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDigg"


class TbBrandDingtalk(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDingtalk"


class TbBrandDiscordFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDiscordFilled"


class TbBrandDiscord(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDiscord"


class TbBrandDisney(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDisney"


class TbBrandDisqus(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDisqus"


class TbBrandDjango(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDjango"


class TbBrandDocker(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDocker"


class TbBrandDoctrine(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDoctrine"


class TbBrandDolbyDigital(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDolbyDigital"


class TbBrandDouban(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDouban"


class TbBrandDribbbleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDribbbleFilled"


class TbBrandDribbble(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDribbble"


class TbBrandDrops(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDrops"


class TbBrandDrupal(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandDrupal"


class TbBrandEdge(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandEdge"


class TbBrandElastic(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandElastic"


class TbBrandElectronicArts(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandElectronicArts"


class TbBrandEmber(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandEmber"


class TbBrandEnvato(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandEnvato"


class TbBrandEtsy(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandEtsy"


class TbBrandEvernote(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandEvernote"


class TbBrandFacebookFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFacebookFilled"


class TbBrandFacebook(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFacebook"


class TbBrandFeedly(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFeedly"


class TbBrandFigma(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFigma"


class TbBrandFilezilla(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFilezilla"


class TbBrandFinder(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFinder"


class TbBrandFirebase(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFirebase"


class TbBrandFirefox(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFirefox"


class TbBrandFiverr(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFiverr"


class TbBrandFlickr(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFlickr"


class TbBrandFlightradar24(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFlightradar24"


class TbBrandFlipboard(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFlipboard"


class TbBrandFlutter(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFlutter"


class TbBrandFortnite(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFortnite"


class TbBrandFoursquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFoursquare"


class TbBrandFramerMotion(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFramerMotion"


class TbBrandFramer(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFramer"


class TbBrandFunimation(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandFunimation"


class TbBrandGatsby(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGatsby"


class TbBrandGit(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGit"


class TbBrandGithubCopilot(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGithubCopilot"


class TbBrandGithubFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGithubFilled"


class TbBrandGithub(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGithub"


class TbBrandGitlab(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGitlab"


class TbBrandGmail(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGmail"


class TbBrandGolang(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGolang"


class TbBrandGoogleAnalytics(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGoogleAnalytics"


class TbBrandGoogleBigQuery(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGoogleBigQuery"


class TbBrandGoogleDrive(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGoogleDrive"


class TbBrandGoogleFit(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGoogleFit"


class TbBrandGoogleHome(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGoogleHome"


class TbBrandGoogleMaps(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGoogleMaps"


class TbBrandGoogleOne(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGoogleOne"


class TbBrandGooglePhotos(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGooglePhotos"


class TbBrandGooglePlay(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGooglePlay"


class TbBrandGooglePodcasts(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGooglePodcasts"


class TbBrandGoogle(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGoogle"


class TbBrandGrammarly(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGrammarly"


class TbBrandGraphql(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGraphql"


class TbBrandGravatar(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGravatar"


class TbBrandGrindr(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGrindr"


class TbBrandGuardian(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGuardian"


class TbBrandGumroad(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandGumroad"


class TbBrandHbo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandHbo"


class TbBrandHeadlessui(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandHeadlessui"


class TbBrandHexo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandHexo"


class TbBrandHipchat(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandHipchat"


class TbBrandHtml5(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandHtml5"


class TbBrandInertia(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandInertia"


class TbBrandInstagram(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandInstagram"


class TbBrandIntercom(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandIntercom"


class TbBrandItch(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandItch"


class TbBrandJavascript(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandJavascript"


class TbBrandJuejin(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandJuejin"


class TbBrandKick(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandKick"


class TbBrandKickstarter(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandKickstarter"


class TbBrandKotlin(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandKotlin"


class TbBrandLaravel(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandLaravel"


class TbBrandLastfm(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandLastfm"


class TbBrandLeetcode(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandLeetcode"


class TbBrandLetterboxd(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandLetterboxd"


class TbBrandLine(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandLine"


class TbBrandLinkedin(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandLinkedin"


class TbBrandLinktree(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandLinktree"


class TbBrandLinqpad(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandLinqpad"


class TbBrandLoom(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandLoom"


class TbBrandMailgun(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMailgun"


class TbBrandMantine(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMantine"


class TbBrandMastercard(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMastercard"


class TbBrandMastodon(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMastodon"


class TbBrandMatrix(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMatrix"


class TbBrandMcdonalds(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMcdonalds"


class TbBrandMedium(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMedium"


class TbBrandMercedes(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMercedes"


class TbBrandMessenger(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMessenger"


class TbBrandMeta(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMeta"


class TbBrandMiniprogram(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMiniprogram"


class TbBrandMixpanel(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMixpanel"


class TbBrandMonday(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMonday"


class TbBrandMongodb(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMongodb"


class TbBrandMyOppo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMyOppo"


class TbBrandMysql(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandMysql"


class TbBrandNationalGeographic(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNationalGeographic"


class TbBrandNem(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNem"


class TbBrandNetbeans(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNetbeans"


class TbBrandNeteaseMusic(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNeteaseMusic"


class TbBrandNetflix(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNetflix"


class TbBrandNexo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNexo"


class TbBrandNextcloud(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNextcloud"


class TbBrandNextjs(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNextjs"


class TbBrandNordVpn(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNordVpn"


class TbBrandNotion(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNotion"


class TbBrandNpm(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNpm"


class TbBrandNuxt(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNuxt"


class TbBrandNytimes(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandNytimes"


class TbBrandOauth(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandOauth"


class TbBrandOffice(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandOffice"


class TbBrandOkRu(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandOkRu"


class TbBrandOnedrive(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandOnedrive"


class TbBrandOnlyfans(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandOnlyfans"


class TbBrandOpenSource(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandOpenSource"


class TbBrandOpenai(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandOpenai"


class TbBrandOpenvpn(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandOpenvpn"


class TbBrandOpera(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandOpera"


class TbBrandPagekit(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPagekit"


class TbBrandPatreon(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPatreon"


class TbBrandPaypalFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPaypalFilled"


class TbBrandPaypal(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPaypal"


class TbBrandPaypay(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPaypay"


class TbBrandPeanut(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPeanut"


class TbBrandPepsi(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPepsi"


class TbBrandPhp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPhp"


class TbBrandPicsart(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPicsart"


class TbBrandPinterest(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPinterest"


class TbBrandPlanetscale(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPlanetscale"


class TbBrandPocket(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPocket"


class TbBrandPolymer(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPolymer"


class TbBrandPowershell(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPowershell"


class TbBrandPrisma(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPrisma"


class TbBrandProducthunt(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandProducthunt"


class TbBrandPushbullet(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPushbullet"


class TbBrandPushover(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPushover"


class TbBrandPython(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandPython"


class TbBrandQq(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandQq"


class TbBrandRadixUi(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandRadixUi"


class TbBrandReactNative(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandReactNative"


class TbBrandReact(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandReact"


class TbBrandReason(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandReason"


class TbBrandReddit(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandReddit"


class TbBrandRedhat(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandRedhat"


class TbBrandRedux(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandRedux"


class TbBrandRevolut(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandRevolut"


class TbBrandRust(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandRust"


class TbBrandSafari(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSafari"


class TbBrandSamsungpass(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSamsungpass"


class TbBrandSass(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSass"


class TbBrandSentry(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSentry"


class TbBrandSharik(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSharik"


class TbBrandShazam(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandShazam"


class TbBrandShopee(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandShopee"


class TbBrandSketch(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSketch"


class TbBrandSkype(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSkype"


class TbBrandSlack(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSlack"


class TbBrandSnapchat(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSnapchat"


class TbBrandSnapseed(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSnapseed"


class TbBrandSnowflake(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSnowflake"


class TbBrandSocketIo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSocketIo"


class TbBrandSolidjs(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSolidjs"


class TbBrandSoundcloud(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSoundcloud"


class TbBrandSpacehey(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSpacehey"


class TbBrandSpeedtest(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSpeedtest"


class TbBrandSpotify(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSpotify"


class TbBrandStackoverflow(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandStackoverflow"


class TbBrandStackshare(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandStackshare"


class TbBrandSteam(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSteam"


class TbBrandStorj(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandStorj"


class TbBrandStorybook(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandStorybook"


class TbBrandStorytel(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandStorytel"


class TbBrandStrava(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandStrava"


class TbBrandStripe(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandStripe"


class TbBrandSublimeText(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSublimeText"


class TbBrandSugarizer(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSugarizer"


class TbBrandSupabase(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSupabase"


class TbBrandSuperhuman(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSuperhuman"


class TbBrandSupernova(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSupernova"


class TbBrandSurfshark(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSurfshark"


class TbBrandSvelte(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSvelte"


class TbBrandSwift(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSwift"


class TbBrandSymfony(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandSymfony"


class TbBrandTabler(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTabler"


class TbBrandTailwind(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTailwind"


class TbBrandTaobao(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTaobao"


class TbBrandTed(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTed"


class TbBrandTelegram(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTelegram"


class TbBrandTerraform(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTerraform"


class TbBrandTether(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTether"


class TbBrandThreejs(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandThreejs"


class TbBrandTidal(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTidal"


class TbBrandTiktoFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTiktoFilled"


class TbBrandTiktok(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTiktok"


class TbBrandTinder(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTinder"


class TbBrandTopbuzz(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTopbuzz"


class TbBrandTorchain(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTorchain"


class TbBrandToyota(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandToyota"


class TbBrandTrello(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTrello"


class TbBrandTripadvisor(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTripadvisor"


class TbBrandTumblr(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTumblr"


class TbBrandTwilio(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTwilio"


class TbBrandTwitch(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTwitch"


class TbBrandTwitterFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTwitterFilled"


class TbBrandTwitter(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTwitter"


class TbBrandTypescript(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandTypescript"


class TbBrandUber(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandUber"


class TbBrandUbuntu(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandUbuntu"


class TbBrandUnity(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandUnity"


class TbBrandUnsplash(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandUnsplash"


class TbBrandUpwork(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandUpwork"


class TbBrandValorant(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandValorant"


class TbBrandVercel(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVercel"


class TbBrandVimeo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVimeo"


class TbBrandVinted(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVinted"


class TbBrandVisa(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVisa"


class TbBrandVisualStudio(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVisualStudio"


class TbBrandVite(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVite"


class TbBrandVivaldi(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVivaldi"


class TbBrandVk(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVk"


class TbBrandVlc(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVlc"


class TbBrandVolkswagen(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVolkswagen"


class TbBrandVsco(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVsco"


class TbBrandVscode(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVscode"


class TbBrandVue(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandVue"


class TbBrandWalmart(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWalmart"


class TbBrandWaze(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWaze"


class TbBrandWebflow(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWebflow"


class TbBrandWechat(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWechat"


class TbBrandWeibo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWeibo"


class TbBrandWhatsapp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWhatsapp"


class TbBrandWikipedia(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWikipedia"


class TbBrandWindows(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWindows"


class TbBrandWindy(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWindy"


class TbBrandWish(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWish"


class TbBrandWix(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWix"


class TbBrandWordpress(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandWordpress"


class TbBrandXamarin(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandXamarin"


class TbBrandXbox(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandXbox"


class TbBrandXing(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandXing"


class TbBrandYahoo(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandYahoo"


class TbBrandYatse(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandYatse"


class TbBrandYcombinator(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandYcombinator"


class TbBrandYoutubeKids(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandYoutubeKids"


class TbBrandYoutube(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandYoutube"


class TbBrandZalando(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandZalando"


class TbBrandZapier(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandZapier"


class TbBrandZeit(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandZeit"


class TbBrandZhihu(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandZhihu"


class TbBrandZoom(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandZoom"


class TbBrandZulip(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandZulip"


class TbBrandZwift(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrandZwift"


class TbBreadOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBreadOff"


class TbBread(rx.Component):
    library = "react-icons/tb"
    tag = "TbBread"


class TbBriefcaseOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBriefcaseOff"


class TbBriefcase(rx.Component):
    library = "react-icons/tb"
    tag = "TbBriefcase"


class TbBrightness2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrightness2"


class TbBrightnessDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrightnessDown"


class TbBrightnessHalf(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrightnessHalf"


class TbBrightnessOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrightnessOff"


class TbBrightnessUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrightnessUp"


class TbBrightness(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrightness"


class TbBroadcastOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBroadcastOff"


class TbBroadcast(rx.Component):
    library = "react-icons/tb"
    tag = "TbBroadcast"


class TbBrowserCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrowserCheck"


class TbBrowserOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrowserOff"


class TbBrowserPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrowserPlus"


class TbBrowserX(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrowserX"


class TbBrowser(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrowser"


class TbBrushOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrushOff"


class TbBrush(rx.Component):
    library = "react-icons/tb"
    tag = "TbBrush"


class TbBucketDroplet(rx.Component):
    library = "react-icons/tb"
    tag = "TbBucketDroplet"


class TbBucketOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBucketOff"


class TbBucket(rx.Component):
    library = "react-icons/tb"
    tag = "TbBucket"


class TbBugOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBugOff"


class TbBug(rx.Component):
    library = "react-icons/tb"
    tag = "TbBug"


class TbBuildingArch(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingArch"


class TbBuildingBank(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingBank"


class TbBuildingBridge2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingBridge2"


class TbBuildingBridge(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingBridge"


class TbBuildingBroadcastTower(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingBroadcastTower"


class TbBuildingCarousel(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingCarousel"


class TbBuildingCastle(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingCastle"


class TbBuildingChurch(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingChurch"


class TbBuildingCircus(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingCircus"


class TbBuildingCommunity(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingCommunity"


class TbBuildingCottage(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingCottage"


class TbBuildingEstate(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingEstate"


class TbBuildingFactory2(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingFactory2"


class TbBuildingFactory(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingFactory"


class TbBuildingFortress(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingFortress"


class TbBuildingHospital(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingHospital"


class TbBuildingLighthouse(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingLighthouse"


class TbBuildingMonument(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingMonument"


class TbBuildingMosque(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingMosque"


class TbBuildingPavilion(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingPavilion"


class TbBuildingSkyscraper(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingSkyscraper"


class TbBuildingStadium(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingStadium"


class TbBuildingStore(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingStore"


class TbBuildingTunnel(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingTunnel"


class TbBuildingWarehouse(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingWarehouse"


class TbBuildingWindTurbine(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuildingWindTurbine"


class TbBuilding(rx.Component):
    library = "react-icons/tb"
    tag = "TbBuilding"


class TbBulbFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbBulbFilled"


class TbBulbOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBulbOff"


class TbBulb(rx.Component):
    library = "react-icons/tb"
    tag = "TbBulb"


class TbBulldozer(rx.Component):
    library = "react-icons/tb"
    tag = "TbBulldozer"


class TbBusOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbBusOff"


class TbBusStop(rx.Component):
    library = "react-icons/tb"
    tag = "TbBusStop"


class TbBus(rx.Component):
    library = "react-icons/tb"
    tag = "TbBus"


class TbBusinessplan(rx.Component):
    library = "react-icons/tb"
    tag = "TbBusinessplan"


class TbButterfly(rx.Component):
    library = "react-icons/tb"
    tag = "TbButterfly"


class TbCactusOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCactusOff"


class TbCactus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCactus"


class TbCakeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCakeOff"


class TbCake(rx.Component):
    library = "react-icons/tb"
    tag = "TbCake"


class TbCalculatorOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalculatorOff"


class TbCalculator(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalculator"


class TbCalendarBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarBolt"


class TbCalendarCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarCancel"


class TbCalendarCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarCheck"


class TbCalendarCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarCode"


class TbCalendarCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarCog"


class TbCalendarDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarDollar"


class TbCalendarDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarDown"


class TbCalendarDue(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarDue"


class TbCalendarEvent(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarEvent"


class TbCalendarExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarExclamation"


class TbCalendarHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarHeart"


class TbCalendarMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarMinus"


class TbCalendarOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarOff"


class TbCalendarPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarPause"


class TbCalendarPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarPin"


class TbCalendarPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarPlus"


class TbCalendarQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarQuestion"


class TbCalendarSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarSearch"


class TbCalendarShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarShare"


class TbCalendarStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarStar"


class TbCalendarStats(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarStats"


class TbCalendarTime(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarTime"


class TbCalendarUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarUp"


class TbCalendarX(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendarX"


class TbCalendar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCalendar"


class TbCameraBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraBolt"


class TbCameraCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraCancel"


class TbCameraCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraCheck"


class TbCameraCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraCode"


class TbCameraCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraCog"


class TbCameraDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraDollar"


class TbCameraDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraDown"


class TbCameraExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraExclamation"


class TbCameraFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraFilled"


class TbCameraHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraHeart"


class TbCameraMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraMinus"


class TbCameraOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraOff"


class TbCameraPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraPause"


class TbCameraPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraPin"


class TbCameraPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraPlus"


class TbCameraQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraQuestion"


class TbCameraRotate(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraRotate"


class TbCameraSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraSearch"


class TbCameraSelfie(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraSelfie"


class TbCameraShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraShare"


class TbCameraStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraStar"


class TbCameraUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraUp"


class TbCameraX(rx.Component):
    library = "react-icons/tb"
    tag = "TbCameraX"


class TbCamera(rx.Component):
    library = "react-icons/tb"
    tag = "TbCamera"


class TbCamper(rx.Component):
    library = "react-icons/tb"
    tag = "TbCamper"


class TbCampfire(rx.Component):
    library = "react-icons/tb"
    tag = "TbCampfire"


class TbCandle(rx.Component):
    library = "react-icons/tb"
    tag = "TbCandle"


class TbCandyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCandyOff"


class TbCandy(rx.Component):
    library = "react-icons/tb"
    tag = "TbCandy"


class TbCane(rx.Component):
    library = "react-icons/tb"
    tag = "TbCane"


class TbCannabis(rx.Component):
    library = "react-icons/tb"
    tag = "TbCannabis"


class TbCaptureOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCaptureOff"


class TbCapture(rx.Component):
    library = "react-icons/tb"
    tag = "TbCapture"


class TbCarCrane(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarCrane"


class TbCarCrash(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarCrash"


class TbCarOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarOff"


class TbCarTurbine(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarTurbine"


class TbCar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCar"


class TbCaravan(rx.Component):
    library = "react-icons/tb"
    tag = "TbCaravan"


class TbCardboardsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCardboardsOff"


class TbCardboards(rx.Component):
    library = "react-icons/tb"
    tag = "TbCardboards"


class TbCards(rx.Component):
    library = "react-icons/tb"
    tag = "TbCards"


class TbCaretDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCaretDown"


class TbCaretLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCaretLeft"


class TbCaretRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbCaretRight"


class TbCaretUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCaretUp"


class TbCarouselHorizontalFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarouselHorizontalFilled"


class TbCarouselHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarouselHorizontal"


class TbCarouselVerticalFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarouselVerticalFilled"


class TbCarouselVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarouselVertical"


class TbCarrotOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarrotOff"


class TbCarrot(rx.Component):
    library = "react-icons/tb"
    tag = "TbCarrot"


class TbCashBanknoteOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCashBanknoteOff"


class TbCashBanknote(rx.Component):
    library = "react-icons/tb"
    tag = "TbCashBanknote"


class TbCashOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCashOff"


class TbCash(rx.Component):
    library = "react-icons/tb"
    tag = "TbCash"


class TbCastOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCastOff"


class TbCast(rx.Component):
    library = "react-icons/tb"
    tag = "TbCast"


class TbCat(rx.Component):
    library = "react-icons/tb"
    tag = "TbCat"


class TbCategory2(rx.Component):
    library = "react-icons/tb"
    tag = "TbCategory2"


class TbCategory(rx.Component):
    library = "react-icons/tb"
    tag = "TbCategory"


class TbCeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCeOff"


class TbCe(rx.Component):
    library = "react-icons/tb"
    tag = "TbCe"


class TbCellSignal1(rx.Component):
    library = "react-icons/tb"
    tag = "TbCellSignal1"


class TbCellSignal2(rx.Component):
    library = "react-icons/tb"
    tag = "TbCellSignal2"


class TbCellSignal3(rx.Component):
    library = "react-icons/tb"
    tag = "TbCellSignal3"


class TbCellSignal4(rx.Component):
    library = "react-icons/tb"
    tag = "TbCellSignal4"


class TbCellSignal5(rx.Component):
    library = "react-icons/tb"
    tag = "TbCellSignal5"


class TbCellSignalOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCellSignalOff"


class TbCell(rx.Component):
    library = "react-icons/tb"
    tag = "TbCell"


class TbCertificate2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbCertificate2Off"


class TbCertificate2(rx.Component):
    library = "react-icons/tb"
    tag = "TbCertificate2"


class TbCertificateOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCertificateOff"


class TbCertificate(rx.Component):
    library = "react-icons/tb"
    tag = "TbCertificate"


class TbChairDirector(rx.Component):
    library = "react-icons/tb"
    tag = "TbChairDirector"


class TbChalkboardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbChalkboardOff"


class TbChalkboard(rx.Component):
    library = "react-icons/tb"
    tag = "TbChalkboard"


class TbChargingPile(rx.Component):
    library = "react-icons/tb"
    tag = "TbChargingPile"


class TbChartArcs3(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartArcs3"


class TbChartArcs(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartArcs"


class TbChartAreaFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartAreaFilled"


class TbChartAreaLineFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartAreaLineFilled"


class TbChartAreaLine(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartAreaLine"


class TbChartArea(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartArea"


class TbChartArrowsVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartArrowsVertical"


class TbChartArrows(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartArrows"


class TbChartBarOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartBarOff"


class TbChartBar(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartBar"


class TbChartBubbleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartBubbleFilled"


class TbChartBubble(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartBubble"


class TbChartCandleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartCandleFilled"


class TbChartCandle(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartCandle"


class TbChartCircles(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartCircles"


class TbChartDonut2(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartDonut2"


class TbChartDonut3(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartDonut3"


class TbChartDonut4(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartDonut4"


class TbChartDonutFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartDonutFilled"


class TbChartDonut(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartDonut"


class TbChartDots2(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartDots2"


class TbChartDots3(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartDots3"


class TbChartDots(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartDots"


class TbChartGridDots(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartGridDots"


class TbChartHistogram(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartHistogram"


class TbChartInfographic(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartInfographic"


class TbChartLine(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartLine"


class TbChartPie2(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartPie2"


class TbChartPie3(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartPie3"


class TbChartPie4(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartPie4"


class TbChartPieFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartPieFilled"


class TbChartPieOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartPieOff"


class TbChartPie(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartPie"


class TbChartPpf(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartPpf"


class TbChartRadar(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartRadar"


class TbChartSankey(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartSankey"


class TbChartTreemap(rx.Component):
    library = "react-icons/tb"
    tag = "TbChartTreemap"


class TbCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbCheck"


class TbCheckbox(rx.Component):
    library = "react-icons/tb"
    tag = "TbCheckbox"


class TbChecklist(rx.Component):
    library = "react-icons/tb"
    tag = "TbChecklist"


class TbChecks(rx.Component):
    library = "react-icons/tb"
    tag = "TbChecks"


class TbCheckupList(rx.Component):
    library = "react-icons/tb"
    tag = "TbCheckupList"


class TbCheese(rx.Component):
    library = "react-icons/tb"
    tag = "TbCheese"


class TbChefHatOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbChefHatOff"


class TbChefHat(rx.Component):
    library = "react-icons/tb"
    tag = "TbChefHat"


class TbCherryFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCherryFilled"


class TbCherry(rx.Component):
    library = "react-icons/tb"
    tag = "TbCherry"


class TbChessBishopFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessBishopFilled"


class TbChessBishop(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessBishop"


class TbChessFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessFilled"


class TbChessKingFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessKingFilled"


class TbChessKing(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessKing"


class TbChessKnightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessKnightFilled"


class TbChessKnight(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessKnight"


class TbChessQueenFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessQueenFilled"


class TbChessQueen(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessQueen"


class TbChessRookFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessRookFilled"


class TbChessRook(rx.Component):
    library = "react-icons/tb"
    tag = "TbChessRook"


class TbChess(rx.Component):
    library = "react-icons/tb"
    tag = "TbChess"


class TbChevronDownLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronDownLeft"


class TbChevronDownRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronDownRight"


class TbChevronDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronDown"


class TbChevronLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronLeft"


class TbChevronRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronRight"


class TbChevronUpLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronUpLeft"


class TbChevronUpRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronUpRight"


class TbChevronUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronUp"


class TbChevronsDownLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronsDownLeft"


class TbChevronsDownRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronsDownRight"


class TbChevronsDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronsDown"


class TbChevronsLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronsLeft"


class TbChevronsRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronsRight"


class TbChevronsUpLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronsUpLeft"


class TbChevronsUpRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronsUpRight"


class TbChevronsUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbChevronsUp"


class TbChisel(rx.Component):
    library = "react-icons/tb"
    tag = "TbChisel"


class TbChristmasTreeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbChristmasTreeOff"


class TbChristmasTree(rx.Component):
    library = "react-icons/tb"
    tag = "TbChristmasTree"


class TbCircle0Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle0Filled"


class TbCircle1Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle1Filled"


class TbCircle2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle2Filled"


class TbCircle3Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle3Filled"


class TbCircle4Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle4Filled"


class TbCircle5Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle5Filled"


class TbCircle6Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle6Filled"


class TbCircle7Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle7Filled"


class TbCircle8Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle8Filled"


class TbCircle9Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle9Filled"


class TbCircleArrowDownFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowDownFilled"


class TbCircleArrowDownLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowDownLeftFilled"


class TbCircleArrowDownLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowDownLeft"


class TbCircleArrowDownRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowDownRightFilled"


class TbCircleArrowDownRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowDownRight"


class TbCircleArrowDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowDown"


class TbCircleArrowLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowLeftFilled"


class TbCircleArrowLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowLeft"


class TbCircleArrowRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowRightFilled"


class TbCircleArrowRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowRight"


class TbCircleArrowUpFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowUpFilled"


class TbCircleArrowUpLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowUpLeftFilled"


class TbCircleArrowUpLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowUpLeft"


class TbCircleArrowUpRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowUpRightFilled"


class TbCircleArrowUpRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowUpRight"


class TbCircleArrowUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleArrowUp"


class TbCircleCaretDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleCaretDown"


class TbCircleCaretLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleCaretLeft"


class TbCircleCaretRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleCaretRight"


class TbCircleCaretUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleCaretUp"


class TbCircleCheckFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleCheckFilled"


class TbCircleCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleCheck"


class TbCircleChevronDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleChevronDown"


class TbCircleChevronLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleChevronLeft"


class TbCircleChevronRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleChevronRight"


class TbCircleChevronUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleChevronUp"


class TbCircleChevronsDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleChevronsDown"


class TbCircleChevronsLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleChevronsLeft"


class TbCircleChevronsRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleChevronsRight"


class TbCircleChevronsUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleChevronsUp"


class TbCircleDashed(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleDashed"


class TbCircleDotFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleDotFilled"


class TbCircleDot(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleDot"


class TbCircleDotted(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleDotted"


class TbCircleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleFilled"


class TbCircleHalf2(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleHalf2"


class TbCircleHalfVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleHalfVertical"


class TbCircleHalf(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleHalf"


class TbCircleKeyFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleKeyFilled"


class TbCircleKey(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleKey"


class TbCircleLetterA(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterA"


class TbCircleLetterB(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterB"


class TbCircleLetterC(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterC"


class TbCircleLetterD(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterD"


class TbCircleLetterE(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterE"


class TbCircleLetterF(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterF"


class TbCircleLetterG(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterG"


class TbCircleLetterH(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterH"


class TbCircleLetterI(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterI"


class TbCircleLetterJ(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterJ"


class TbCircleLetterK(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterK"


class TbCircleLetterL(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterL"


class TbCircleLetterM(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterM"


class TbCircleLetterN(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterN"


class TbCircleLetterO(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterO"


class TbCircleLetterP(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterP"


class TbCircleLetterQ(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterQ"


class TbCircleLetterR(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterR"


class TbCircleLetterS(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterS"


class TbCircleLetterT(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterT"


class TbCircleLetterU(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterU"


class TbCircleLetterV(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterV"


class TbCircleLetterW(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterW"


class TbCircleLetterX(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterX"


class TbCircleLetterY(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterY"


class TbCircleLetterZ(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleLetterZ"


class TbCircleMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleMinus"


class TbCircleNumber0(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber0"


class TbCircleNumber1(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber1"


class TbCircleNumber2(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber2"


class TbCircleNumber3(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber3"


class TbCircleNumber4(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber4"


class TbCircleNumber5(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber5"


class TbCircleNumber6(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber6"


class TbCircleNumber7(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber7"


class TbCircleNumber8(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber8"


class TbCircleNumber9(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleNumber9"


class TbCircleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleOff"


class TbCirclePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCirclePlus"


class TbCircleRectangleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleRectangleOff"


class TbCircleRectangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleRectangle"


class TbCircleSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleSquare"


class TbCircleTriangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleTriangle"


class TbCircleXFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleXFilled"


class TbCircleX(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircleX"


class TbCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircle"


class TbCirclesFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCirclesFilled"


class TbCirclesRelation(rx.Component):
    library = "react-icons/tb"
    tag = "TbCirclesRelation"


class TbCircles(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircles"


class TbCircuitAmmeter(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitAmmeter"


class TbCircuitBattery(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitBattery"


class TbCircuitBulb(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitBulb"


class TbCircuitCapacitorPolarized(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitCapacitorPolarized"


class TbCircuitCapacitor(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitCapacitor"


class TbCircuitCellPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitCellPlus"


class TbCircuitCell(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitCell"


class TbCircuitChangeover(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitChangeover"


class TbCircuitDiodeZener(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitDiodeZener"


class TbCircuitDiode(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitDiode"


class TbCircuitGroundDigital(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitGroundDigital"


class TbCircuitGround(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitGround"


class TbCircuitInductor(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitInductor"


class TbCircuitMotor(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitMotor"


class TbCircuitPushbutton(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitPushbutton"


class TbCircuitResistor(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitResistor"


class TbCircuitSwitchClosed(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitSwitchClosed"


class TbCircuitSwitchOpen(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitSwitchOpen"


class TbCircuitVoltmeter(rx.Component):
    library = "react-icons/tb"
    tag = "TbCircuitVoltmeter"


class TbClearAll(rx.Component):
    library = "react-icons/tb"
    tag = "TbClearAll"


class TbClearFormatting(rx.Component):
    library = "react-icons/tb"
    tag = "TbClearFormatting"


class TbClick(rx.Component):
    library = "react-icons/tb"
    tag = "TbClick"


class TbClipboardCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardCheck"


class TbClipboardCopy(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardCopy"


class TbClipboardData(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardData"


class TbClipboardHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardHeart"


class TbClipboardList(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardList"


class TbClipboardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardOff"


class TbClipboardPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardPlus"


class TbClipboardText(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardText"


class TbClipboardTypography(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardTypography"


class TbClipboardX(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboardX"


class TbClipboard(rx.Component):
    library = "react-icons/tb"
    tag = "TbClipboard"


class TbClock2(rx.Component):
    library = "react-icons/tb"
    tag = "TbClock2"


class TbClockBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockBolt"


class TbClockCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockCancel"


class TbClockCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockCheck"


class TbClockCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockCode"


class TbClockCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockCog"


class TbClockDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockDollar"


class TbClockDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockDown"


class TbClockEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockEdit"


class TbClockExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockExclamation"


class TbClockFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockFilled"


class TbClockHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHeart"


class TbClockHour1(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour1"


class TbClockHour10(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour10"


class TbClockHour11(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour11"


class TbClockHour12(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour12"


class TbClockHour2(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour2"


class TbClockHour3(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour3"


class TbClockHour4(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour4"


class TbClockHour5(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour5"


class TbClockHour6(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour6"


class TbClockHour7(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour7"


class TbClockHour8(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour8"


class TbClockHour9(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockHour9"


class TbClockMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockMinus"


class TbClockOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockOff"


class TbClockPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockPause"


class TbClockPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockPin"


class TbClockPlay(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockPlay"


class TbClockPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockPlus"


class TbClockQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockQuestion"


class TbClockRecord(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockRecord"


class TbClockSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockSearch"


class TbClockShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockShare"


class TbClockShield(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockShield"


class TbClockStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockStar"


class TbClockStop(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockStop"


class TbClockUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockUp"


class TbClockX(rx.Component):
    library = "react-icons/tb"
    tag = "TbClockX"


class TbClock(rx.Component):
    library = "react-icons/tb"
    tag = "TbClock"


class TbClothesRackOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbClothesRackOff"


class TbClothesRack(rx.Component):
    library = "react-icons/tb"
    tag = "TbClothesRack"


class TbCloudBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudBolt"


class TbCloudCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudCancel"


class TbCloudCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudCheck"


class TbCloudCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudCode"


class TbCloudCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudCog"


class TbCloudComputing(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudComputing"


class TbCloudDataConnection(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudDataConnection"


class TbCloudDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudDollar"


class TbCloudDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudDown"


class TbCloudDownload(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudDownload"


class TbCloudExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudExclamation"


class TbCloudFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudFilled"


class TbCloudFog(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudFog"


class TbCloudHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudHeart"


class TbCloudLockOpen(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudLockOpen"


class TbCloudLock(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudLock"


class TbCloudMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudMinus"


class TbCloudOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudOff"


class TbCloudPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudPause"


class TbCloudPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudPin"


class TbCloudPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudPlus"


class TbCloudQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudQuestion"


class TbCloudRain(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudRain"


class TbCloudSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudSearch"


class TbCloudShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudShare"


class TbCloudSnow(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudSnow"


class TbCloudStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudStar"


class TbCloudStorm(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudStorm"


class TbCloudUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudUp"


class TbCloudUpload(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudUpload"


class TbCloudX(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloudX"


class TbCloud(rx.Component):
    library = "react-icons/tb"
    tag = "TbCloud"


class TbClover2(rx.Component):
    library = "react-icons/tb"
    tag = "TbClover2"


class TbClover(rx.Component):
    library = "react-icons/tb"
    tag = "TbClover"


class TbClubsFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbClubsFilled"


class TbClubs(rx.Component):
    library = "react-icons/tb"
    tag = "TbClubs"


class TbCodeAsterix(rx.Component):
    library = "react-icons/tb"
    tag = "TbCodeAsterix"


class TbCodeCircle2(rx.Component):
    library = "react-icons/tb"
    tag = "TbCodeCircle2"


class TbCodeCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbCodeCircle"


class TbCodeDots(rx.Component):
    library = "react-icons/tb"
    tag = "TbCodeDots"


class TbCodeMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCodeMinus"


class TbCodeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCodeOff"


class TbCodePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCodePlus"


class TbCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbCode"


class TbCoffeeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoffeeOff"


class TbCoffee(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoffee"


class TbCoffin(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoffin"


class TbCoinBitcoin(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoinBitcoin"


class TbCoinEuro(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoinEuro"


class TbCoinMonero(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoinMonero"


class TbCoinOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoinOff"


class TbCoinPound(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoinPound"


class TbCoinRupee(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoinRupee"


class TbCoinYen(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoinYen"


class TbCoinYuan(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoinYuan"


class TbCoin(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoin"


class TbCoins(rx.Component):
    library = "react-icons/tb"
    tag = "TbCoins"


class TbColorFilter(rx.Component):
    library = "react-icons/tb"
    tag = "TbColorFilter"


class TbColorPickerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbColorPickerOff"


class TbColorPicker(rx.Component):
    library = "react-icons/tb"
    tag = "TbColorPicker"


class TbColorSwatchOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbColorSwatchOff"


class TbColorSwatch(rx.Component):
    library = "react-icons/tb"
    tag = "TbColorSwatch"


class TbColumnInsertLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbColumnInsertLeft"


class TbColumnInsertRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbColumnInsertRight"


class TbColumns1(rx.Component):
    library = "react-icons/tb"
    tag = "TbColumns1"


class TbColumns2(rx.Component):
    library = "react-icons/tb"
    tag = "TbColumns2"


class TbColumns3(rx.Component):
    library = "react-icons/tb"
    tag = "TbColumns3"


class TbColumnsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbColumnsOff"


class TbColumns(rx.Component):
    library = "react-icons/tb"
    tag = "TbColumns"


class TbComet(rx.Component):
    library = "react-icons/tb"
    tag = "TbComet"


class TbCommandOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCommandOff"


class TbCommand(rx.Component):
    library = "react-icons/tb"
    tag = "TbCommand"


class TbCompassOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCompassOff"


class TbCompass(rx.Component):
    library = "react-icons/tb"
    tag = "TbCompass"


class TbComponentsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbComponentsOff"


class TbComponents(rx.Component):
    library = "react-icons/tb"
    tag = "TbComponents"


class TbCone2(rx.Component):
    library = "react-icons/tb"
    tag = "TbCone2"


class TbConeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbConeOff"


class TbConePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbConePlus"


class TbCone(rx.Component):
    library = "react-icons/tb"
    tag = "TbCone"


class TbConfettiOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbConfettiOff"


class TbConfetti(rx.Component):
    library = "react-icons/tb"
    tag = "TbConfetti"


class TbConfucius(rx.Component):
    library = "react-icons/tb"
    tag = "TbConfucius"


class TbContainerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbContainerOff"


class TbContainer(rx.Component):
    library = "react-icons/tb"
    tag = "TbContainer"


class TbContrast2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbContrast2Off"


class TbContrast2(rx.Component):
    library = "react-icons/tb"
    tag = "TbContrast2"


class TbContrastOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbContrastOff"


class TbContrast(rx.Component):
    library = "react-icons/tb"
    tag = "TbContrast"


class TbCooker(rx.Component):
    library = "react-icons/tb"
    tag = "TbCooker"


class TbCookieMan(rx.Component):
    library = "react-icons/tb"
    tag = "TbCookieMan"


class TbCookieOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCookieOff"


class TbCookie(rx.Component):
    library = "react-icons/tb"
    tag = "TbCookie"


class TbCopyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCopyOff"


class TbCopy(rx.Component):
    library = "react-icons/tb"
    tag = "TbCopy"


class TbCopyleftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCopyleftFilled"


class TbCopyleftOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCopyleftOff"


class TbCopyleft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCopyleft"


class TbCopyrightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCopyrightFilled"


class TbCopyrightOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCopyrightOff"


class TbCopyright(rx.Component):
    library = "react-icons/tb"
    tag = "TbCopyright"


class TbCornerDownLeftDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerDownLeftDouble"


class TbCornerDownLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerDownLeft"


class TbCornerDownRightDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerDownRightDouble"


class TbCornerDownRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerDownRight"


class TbCornerLeftDownDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerLeftDownDouble"


class TbCornerLeftDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerLeftDown"


class TbCornerLeftUpDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerLeftUpDouble"


class TbCornerLeftUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerLeftUp"


class TbCornerRightDownDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerRightDownDouble"


class TbCornerRightDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerRightDown"


class TbCornerRightUpDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerRightUpDouble"


class TbCornerRightUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerRightUp"


class TbCornerUpLeftDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerUpLeftDouble"


class TbCornerUpLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerUpLeft"


class TbCornerUpRightDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerUpRightDouble"


class TbCornerUpRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbCornerUpRight"


class TbCpu2(rx.Component):
    library = "react-icons/tb"
    tag = "TbCpu2"


class TbCpuOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCpuOff"


class TbCpu(rx.Component):
    library = "react-icons/tb"
    tag = "TbCpu"


class TbCraneOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCraneOff"


class TbCrane(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrane"


class TbCreativeCommonsBy(rx.Component):
    library = "react-icons/tb"
    tag = "TbCreativeCommonsBy"


class TbCreativeCommonsNc(rx.Component):
    library = "react-icons/tb"
    tag = "TbCreativeCommonsNc"


class TbCreativeCommonsNd(rx.Component):
    library = "react-icons/tb"
    tag = "TbCreativeCommonsNd"


class TbCreativeCommonsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCreativeCommonsOff"


class TbCreativeCommonsSa(rx.Component):
    library = "react-icons/tb"
    tag = "TbCreativeCommonsSa"


class TbCreativeCommonsZero(rx.Component):
    library = "react-icons/tb"
    tag = "TbCreativeCommonsZero"


class TbCreativeCommons(rx.Component):
    library = "react-icons/tb"
    tag = "TbCreativeCommons"


class TbCreditCardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCreditCardOff"


class TbCreditCard(rx.Component):
    library = "react-icons/tb"
    tag = "TbCreditCard"


class TbCricket(rx.Component):
    library = "react-icons/tb"
    tag = "TbCricket"


class TbCrop(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrop"


class TbCrossFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrossFilled"


class TbCrossOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrossOff"


class TbCross(rx.Component):
    library = "react-icons/tb"
    tag = "TbCross"


class TbCrosshair(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrosshair"


class TbCrownOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrownOff"


class TbCrown(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrown"


class TbCrutchesOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrutchesOff"


class TbCrutches(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrutches"


class TbCrystalBall(rx.Component):
    library = "react-icons/tb"
    tag = "TbCrystalBall"


class TbCsv(rx.Component):
    library = "react-icons/tb"
    tag = "TbCsv"


class TbCubeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCubeOff"


class TbCubePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCubePlus"


class TbCubeSend(rx.Component):
    library = "react-icons/tb"
    tag = "TbCubeSend"


class TbCubeUnfolded(rx.Component):
    library = "react-icons/tb"
    tag = "TbCubeUnfolded"


class TbCube(rx.Component):
    library = "react-icons/tb"
    tag = "TbCube"


class TbCupOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCupOff"


class TbCup(rx.Component):
    library = "react-icons/tb"
    tag = "TbCup"


class TbCurling(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurling"


class TbCurlyLoop(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurlyLoop"


class TbCurrencyAfghani(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyAfghani"


class TbCurrencyBahraini(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyBahraini"


class TbCurrencyBaht(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyBaht"


class TbCurrencyBitcoin(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyBitcoin"


class TbCurrencyCent(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyCent"


class TbCurrencyDinar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDinar"


class TbCurrencyDirham(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDirham"


class TbCurrencyDogecoin(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDogecoin"


class TbCurrencyDollarAustralian(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDollarAustralian"


class TbCurrencyDollarBrunei(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDollarBrunei"


class TbCurrencyDollarCanadian(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDollarCanadian"


class TbCurrencyDollarGuyanese(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDollarGuyanese"


class TbCurrencyDollarOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDollarOff"


class TbCurrencyDollarSingapore(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDollarSingapore"


class TbCurrencyDollarZimbabwean(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDollarZimbabwean"


class TbCurrencyDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDollar"


class TbCurrencyDong(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDong"


class TbCurrencyDram(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyDram"


class TbCurrencyEthereum(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyEthereum"


class TbCurrencyEuroOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyEuroOff"


class TbCurrencyEuro(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyEuro"


class TbCurrencyForint(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyForint"


class TbCurrencyFrank(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyFrank"


class TbCurrencyGuarani(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyGuarani"


class TbCurrencyHryvnia(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyHryvnia"


class TbCurrencyIranianRial(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyIranianRial"


class TbCurrencyKip(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyKip"


class TbCurrencyKroneCzech(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyKroneCzech"


class TbCurrencyKroneDanish(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyKroneDanish"


class TbCurrencyKroneSwedish(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyKroneSwedish"


class TbCurrencyLari(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyLari"


class TbCurrencyLeu(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyLeu"


class TbCurrencyLira(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyLira"


class TbCurrencyLitecoin(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyLitecoin"


class TbCurrencyLyd(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyLyd"


class TbCurrencyManat(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyManat"


class TbCurrencyMonero(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyMonero"


class TbCurrencyNaira(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyNaira"


class TbCurrencyNano(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyNano"


class TbCurrencyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyOff"


class TbCurrencyPaanga(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyPaanga"


class TbCurrencyPeso(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyPeso"


class TbCurrencyPoundOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyPoundOff"


class TbCurrencyPound(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyPound"


class TbCurrencyQuetzal(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyQuetzal"


class TbCurrencyReal(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyReal"


class TbCurrencyRenminbi(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyRenminbi"


class TbCurrencyRipple(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyRipple"


class TbCurrencyRiyal(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyRiyal"


class TbCurrencyRubel(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyRubel"


class TbCurrencyRufiyaa(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyRufiyaa"


class TbCurrencyRupeeNepalese(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyRupeeNepalese"


class TbCurrencyRupee(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyRupee"


class TbCurrencyShekel(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyShekel"


class TbCurrencySolana(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencySolana"


class TbCurrencySom(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencySom"


class TbCurrencyTaka(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyTaka"


class TbCurrencyTenge(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyTenge"


class TbCurrencyTugrik(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyTugrik"


class TbCurrencyWon(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyWon"


class TbCurrencyYenOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyYenOff"


class TbCurrencyYen(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyYen"


class TbCurrencyYuan(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyYuan"


class TbCurrencyZloty(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrencyZloty"


class TbCurrency(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrency"


class TbCurrentLocationOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrentLocationOff"


class TbCurrentLocation(rx.Component):
    library = "react-icons/tb"
    tag = "TbCurrentLocation"


class TbCursorOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCursorOff"


class TbCursorText(rx.Component):
    library = "react-icons/tb"
    tag = "TbCursorText"


class TbCut(rx.Component):
    library = "react-icons/tb"
    tag = "TbCut"


class TbCylinderOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbCylinderOff"


class TbCylinderPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbCylinderPlus"


class TbCylinder(rx.Component):
    library = "react-icons/tb"
    tag = "TbCylinder"


class TbDashboardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDashboardOff"


class TbDashboard(rx.Component):
    library = "react-icons/tb"
    tag = "TbDashboard"


class TbDatabaseCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseCog"


class TbDatabaseDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseDollar"


class TbDatabaseEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseEdit"


class TbDatabaseExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseExclamation"


class TbDatabaseExport(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseExport"


class TbDatabaseHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseHeart"


class TbDatabaseImport(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseImport"


class TbDatabaseLeak(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseLeak"


class TbDatabaseMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseMinus"


class TbDatabaseOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseOff"


class TbDatabasePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabasePlus"


class TbDatabaseSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseSearch"


class TbDatabaseShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseShare"


class TbDatabaseStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseStar"


class TbDatabaseX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabaseX"


class TbDatabase(rx.Component):
    library = "react-icons/tb"
    tag = "TbDatabase"


class TbDecimal(rx.Component):
    library = "react-icons/tb"
    tag = "TbDecimal"


class TbDeer(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeer"


class TbDelta(rx.Component):
    library = "react-icons/tb"
    tag = "TbDelta"


class TbDentalBroken(rx.Component):
    library = "react-icons/tb"
    tag = "TbDentalBroken"


class TbDentalOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDentalOff"


class TbDental(rx.Component):
    library = "react-icons/tb"
    tag = "TbDental"


class TbDeselect(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeselect"


class TbDetailsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDetailsOff"


class TbDetails(rx.Component):
    library = "react-icons/tb"
    tag = "TbDetails"


class TbDeviceAirpodsCase(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceAirpodsCase"


class TbDeviceAirpods(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceAirpods"


class TbDeviceAnalytics(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceAnalytics"


class TbDeviceAudioTape(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceAudioTape"


class TbDeviceCameraPhone(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceCameraPhone"


class TbDeviceCctvOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceCctvOff"


class TbDeviceCctv(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceCctv"


class TbDeviceComputerCameraOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceComputerCameraOff"


class TbDeviceComputerCamera(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceComputerCamera"


class TbDeviceDesktopAnalytics(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopAnalytics"


class TbDeviceDesktopBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopBolt"


class TbDeviceDesktopCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopCancel"


class TbDeviceDesktopCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopCheck"


class TbDeviceDesktopCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopCode"


class TbDeviceDesktopCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopCog"


class TbDeviceDesktopDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopDollar"


class TbDeviceDesktopDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopDown"


class TbDeviceDesktopExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopExclamation"


class TbDeviceDesktopHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopHeart"


class TbDeviceDesktopMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopMinus"


class TbDeviceDesktopOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopOff"


class TbDeviceDesktopPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopPause"


class TbDeviceDesktopPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopPin"


class TbDeviceDesktopPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopPlus"


class TbDeviceDesktopQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopQuestion"


class TbDeviceDesktopSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopSearch"


class TbDeviceDesktopShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopShare"


class TbDeviceDesktopStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopStar"


class TbDeviceDesktopUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopUp"


class TbDeviceDesktopX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktopX"


class TbDeviceDesktop(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceDesktop"


class TbDeviceFloppy(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceFloppy"


class TbDeviceGamepad2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceGamepad2"


class TbDeviceGamepad(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceGamepad"


class TbDeviceHeartMonitorFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceHeartMonitorFilled"


class TbDeviceHeartMonitor(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceHeartMonitor"


class TbDeviceImacBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacBolt"


class TbDeviceImacCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacCancel"


class TbDeviceImacCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacCheck"


class TbDeviceImacCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacCode"


class TbDeviceImacCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacCog"


class TbDeviceImacDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacDollar"


class TbDeviceImacDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacDown"


class TbDeviceImacExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacExclamation"


class TbDeviceImacHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacHeart"


class TbDeviceImacMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacMinus"


class TbDeviceImacOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacOff"


class TbDeviceImacPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacPause"


class TbDeviceImacPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacPin"


class TbDeviceImacPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacPlus"


class TbDeviceImacQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacQuestion"


class TbDeviceImacSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacSearch"


class TbDeviceImacShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacShare"


class TbDeviceImacStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacStar"


class TbDeviceImacUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacUp"


class TbDeviceImacX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImacX"


class TbDeviceImac(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceImac"


class TbDeviceIpadBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadBolt"


class TbDeviceIpadCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadCancel"


class TbDeviceIpadCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadCheck"


class TbDeviceIpadCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadCode"


class TbDeviceIpadCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadCog"


class TbDeviceIpadDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadDollar"


class TbDeviceIpadDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadDown"


class TbDeviceIpadExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadExclamation"


class TbDeviceIpadHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHeart"


class TbDeviceIpadHorizontalBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalBolt"


class TbDeviceIpadHorizontalCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalCancel"


class TbDeviceIpadHorizontalCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalCheck"


class TbDeviceIpadHorizontalCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalCode"


class TbDeviceIpadHorizontalCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalCog"


class TbDeviceIpadHorizontalDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalDollar"


class TbDeviceIpadHorizontalDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalDown"


class TbDeviceIpadHorizontalExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalExclamation"


class TbDeviceIpadHorizontalHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalHeart"


class TbDeviceIpadHorizontalMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalMinus"


class TbDeviceIpadHorizontalOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalOff"


class TbDeviceIpadHorizontalPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalPause"


class TbDeviceIpadHorizontalPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalPin"


class TbDeviceIpadHorizontalPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalPlus"


class TbDeviceIpadHorizontalQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalQuestion"


class TbDeviceIpadHorizontalSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalSearch"


class TbDeviceIpadHorizontalShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalShare"


class TbDeviceIpadHorizontalStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalStar"


class TbDeviceIpadHorizontalUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalUp"


class TbDeviceIpadHorizontalX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontalX"


class TbDeviceIpadHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadHorizontal"


class TbDeviceIpadMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadMinus"


class TbDeviceIpadOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadOff"


class TbDeviceIpadPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadPause"


class TbDeviceIpadPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadPin"


class TbDeviceIpadPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadPlus"


class TbDeviceIpadQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadQuestion"


class TbDeviceIpadSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadSearch"


class TbDeviceIpadShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadShare"


class TbDeviceIpadStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadStar"


class TbDeviceIpadUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadUp"


class TbDeviceIpadX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpadX"


class TbDeviceIpad(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceIpad"


class TbDeviceLandlinePhone(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceLandlinePhone"


class TbDeviceLaptopOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceLaptopOff"


class TbDeviceLaptop(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceLaptop"


class TbDeviceMobileBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileBolt"


class TbDeviceMobileCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileCancel"


class TbDeviceMobileCharging(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileCharging"


class TbDeviceMobileCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileCheck"


class TbDeviceMobileCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileCode"


class TbDeviceMobileCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileCog"


class TbDeviceMobileDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileDollar"


class TbDeviceMobileDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileDown"


class TbDeviceMobileExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileExclamation"


class TbDeviceMobileFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileFilled"


class TbDeviceMobileHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileHeart"


class TbDeviceMobileMessage(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileMessage"


class TbDeviceMobileMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileMinus"


class TbDeviceMobileOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileOff"


class TbDeviceMobilePause(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobilePause"


class TbDeviceMobilePin(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobilePin"


class TbDeviceMobilePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobilePlus"


class TbDeviceMobileQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileQuestion"


class TbDeviceMobileRotated(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileRotated"


class TbDeviceMobileSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileSearch"


class TbDeviceMobileShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileShare"


class TbDeviceMobileStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileStar"


class TbDeviceMobileUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileUp"


class TbDeviceMobileVibration(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileVibration"


class TbDeviceMobileX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobileX"


class TbDeviceMobile(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceMobile"


class TbDeviceNintendoOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceNintendoOff"


class TbDeviceNintendo(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceNintendo"


class TbDeviceRemote(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceRemote"


class TbDeviceSdCard(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceSdCard"


class TbDeviceSim1(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceSim1"


class TbDeviceSim2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceSim2"


class TbDeviceSim3(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceSim3"


class TbDeviceSim(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceSim"


class TbDeviceSpeakerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceSpeakerOff"


class TbDeviceSpeaker(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceSpeaker"


class TbDeviceTabletBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletBolt"


class TbDeviceTabletCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletCancel"


class TbDeviceTabletCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletCheck"


class TbDeviceTabletCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletCode"


class TbDeviceTabletCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletCog"


class TbDeviceTabletDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletDollar"


class TbDeviceTabletDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletDown"


class TbDeviceTabletExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletExclamation"


class TbDeviceTabletFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletFilled"


class TbDeviceTabletHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletHeart"


class TbDeviceTabletMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletMinus"


class TbDeviceTabletOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletOff"


class TbDeviceTabletPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletPause"


class TbDeviceTabletPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletPin"


class TbDeviceTabletPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletPlus"


class TbDeviceTabletQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletQuestion"


class TbDeviceTabletSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletSearch"


class TbDeviceTabletShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletShare"


class TbDeviceTabletStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletStar"


class TbDeviceTabletUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletUp"


class TbDeviceTabletX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTabletX"


class TbDeviceTablet(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTablet"


class TbDeviceTvOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTvOff"


class TbDeviceTvOld(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTvOld"


class TbDeviceTv(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceTv"


class TbDeviceWatchBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchBolt"


class TbDeviceWatchCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchCancel"


class TbDeviceWatchCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchCheck"


class TbDeviceWatchCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchCode"


class TbDeviceWatchCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchCog"


class TbDeviceWatchDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchDollar"


class TbDeviceWatchDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchDown"


class TbDeviceWatchExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchExclamation"


class TbDeviceWatchHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchHeart"


class TbDeviceWatchMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchMinus"


class TbDeviceWatchOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchOff"


class TbDeviceWatchPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchPause"


class TbDeviceWatchPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchPin"


class TbDeviceWatchPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchPlus"


class TbDeviceWatchQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchQuestion"


class TbDeviceWatchSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchSearch"


class TbDeviceWatchShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchShare"


class TbDeviceWatchStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchStar"


class TbDeviceWatchStats2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchStats2"


class TbDeviceWatchStats(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchStats"


class TbDeviceWatchUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchUp"


class TbDeviceWatchX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatchX"


class TbDeviceWatch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDeviceWatch"


class TbDevices2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevices2"


class TbDevicesBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesBolt"


class TbDevicesCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesCancel"


class TbDevicesCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesCheck"


class TbDevicesCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesCode"


class TbDevicesCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesCog"


class TbDevicesDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesDollar"


class TbDevicesDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesDown"


class TbDevicesExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesExclamation"


class TbDevicesHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesHeart"


class TbDevicesMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesMinus"


class TbDevicesOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesOff"


class TbDevicesPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesPause"


class TbDevicesPcOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesPcOff"


class TbDevicesPc(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesPc"


class TbDevicesPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesPin"


class TbDevicesPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesPlus"


class TbDevicesQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesQuestion"


class TbDevicesSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesSearch"


class TbDevicesShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesShare"


class TbDevicesStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesStar"


class TbDevicesUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesUp"


class TbDevicesX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevicesX"


class TbDevices(rx.Component):
    library = "react-icons/tb"
    tag = "TbDevices"


class TbDiaboloOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiaboloOff"


class TbDiaboloPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiaboloPlus"


class TbDiabolo(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiabolo"


class TbDialpadFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDialpadFilled"


class TbDialpadOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDialpadOff"


class TbDialpad(rx.Component):
    library = "react-icons/tb"
    tag = "TbDialpad"


class TbDiamondFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiamondFilled"


class TbDiamondOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiamondOff"


class TbDiamond(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiamond"


class TbDiamondsFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiamondsFilled"


class TbDiamonds(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiamonds"


class TbDice1Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice1Filled"


class TbDice1(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice1"


class TbDice2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice2Filled"


class TbDice2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice2"


class TbDice3Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice3Filled"


class TbDice3(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice3"


class TbDice4Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice4Filled"


class TbDice4(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice4"


class TbDice5Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice5Filled"


class TbDice5(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice5"


class TbDice6Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice6Filled"


class TbDice6(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice6"


class TbDiceFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiceFilled"


class TbDice(rx.Component):
    library = "react-icons/tb"
    tag = "TbDice"


class TbDimensions(rx.Component):
    library = "react-icons/tb"
    tag = "TbDimensions"


class TbDirectionHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbDirectionHorizontal"


class TbDirectionSignFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDirectionSignFilled"


class TbDirectionSignOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDirectionSignOff"


class TbDirectionSign(rx.Component):
    library = "react-icons/tb"
    tag = "TbDirectionSign"


class TbDirection(rx.Component):
    library = "react-icons/tb"
    tag = "TbDirection"


class TbDirectionsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDirectionsOff"


class TbDirections(rx.Component):
    library = "react-icons/tb"
    tag = "TbDirections"


class TbDisabled2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDisabled2"


class TbDisabledOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDisabledOff"


class TbDisabled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDisabled"


class TbDiscGolf(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiscGolf"


class TbDiscOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiscOff"


class TbDisc(rx.Component):
    library = "react-icons/tb"
    tag = "TbDisc"


class TbDiscount2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiscount2Off"


class TbDiscount2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiscount2"


class TbDiscountCheckFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiscountCheckFilled"


class TbDiscountCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiscountCheck"


class TbDiscountOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiscountOff"


class TbDiscount(rx.Component):
    library = "react-icons/tb"
    tag = "TbDiscount"


class TbDivide(rx.Component):
    library = "react-icons/tb"
    tag = "TbDivide"


class TbDna2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbDna2Off"


class TbDna2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDna2"


class TbDnaOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDnaOff"


class TbDna(rx.Component):
    library = "react-icons/tb"
    tag = "TbDna"


class TbDogBowl(rx.Component):
    library = "react-icons/tb"
    tag = "TbDogBowl"


class TbDog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDog"


class TbDoorEnter(rx.Component):
    library = "react-icons/tb"
    tag = "TbDoorEnter"


class TbDoorExit(rx.Component):
    library = "react-icons/tb"
    tag = "TbDoorExit"


class TbDoorOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDoorOff"


class TbDoor(rx.Component):
    library = "react-icons/tb"
    tag = "TbDoor"


class TbDotsCircleHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbDotsCircleHorizontal"


class TbDotsDiagonal2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDotsDiagonal2"


class TbDotsDiagonal(rx.Component):
    library = "react-icons/tb"
    tag = "TbDotsDiagonal"


class TbDotsVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbDotsVertical"


class TbDots(rx.Component):
    library = "react-icons/tb"
    tag = "TbDots"


class TbDownloadOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDownloadOff"


class TbDownload(rx.Component):
    library = "react-icons/tb"
    tag = "TbDownload"


class TbDragDrop2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDragDrop2"


class TbDragDrop(rx.Component):
    library = "react-icons/tb"
    tag = "TbDragDrop"


class TbDroneOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDroneOff"


class TbDrone(rx.Component):
    library = "react-icons/tb"
    tag = "TbDrone"


class TbDropCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropCircle"


class TbDropletBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletBolt"


class TbDropletCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletCancel"


class TbDropletCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletCheck"


class TbDropletCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletCode"


class TbDropletCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletCog"


class TbDropletDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletDollar"


class TbDropletDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletDown"


class TbDropletExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletExclamation"


class TbDropletFilled2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletFilled2"


class TbDropletFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletFilled"


class TbDropletHalf2(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletHalf2"


class TbDropletHalfFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletHalfFilled"


class TbDropletHalf(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletHalf"


class TbDropletHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletHeart"


class TbDropletMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletMinus"


class TbDropletOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletOff"


class TbDropletPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletPause"


class TbDropletPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletPin"


class TbDropletPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletPlus"


class TbDropletQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletQuestion"


class TbDropletSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletSearch"


class TbDropletShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletShare"


class TbDropletStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletStar"


class TbDropletUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletUp"


class TbDropletX(rx.Component):
    library = "react-icons/tb"
    tag = "TbDropletX"


class TbDroplet(rx.Component):
    library = "react-icons/tb"
    tag = "TbDroplet"


class TbDualScreen(rx.Component):
    library = "react-icons/tb"
    tag = "TbDualScreen"


class TbEPassport(rx.Component):
    library = "react-icons/tb"
    tag = "TbEPassport"


class TbEarOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbEarOff"


class TbEar(rx.Component):
    library = "react-icons/tb"
    tag = "TbEar"


class TbEaseInControlPoint(rx.Component):
    library = "react-icons/tb"
    tag = "TbEaseInControlPoint"


class TbEaseInOutControlPoints(rx.Component):
    library = "react-icons/tb"
    tag = "TbEaseInOutControlPoints"


class TbEaseInOut(rx.Component):
    library = "react-icons/tb"
    tag = "TbEaseInOut"


class TbEaseIn(rx.Component):
    library = "react-icons/tb"
    tag = "TbEaseIn"


class TbEaseOutControlPoint(rx.Component):
    library = "react-icons/tb"
    tag = "TbEaseOutControlPoint"


class TbEaseOut(rx.Component):
    library = "react-icons/tb"
    tag = "TbEaseOut"


class TbEditCircleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbEditCircleOff"


class TbEditCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbEditCircle"


class TbEditOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbEditOff"


class TbEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbEdit"


class TbEggCracked(rx.Component):
    library = "react-icons/tb"
    tag = "TbEggCracked"


class TbEggFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbEggFilled"


class TbEggFried(rx.Component):
    library = "react-icons/tb"
    tag = "TbEggFried"


class TbEggOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbEggOff"


class TbEgg(rx.Component):
    library = "react-icons/tb"
    tag = "TbEgg"


class TbEggs(rx.Component):
    library = "react-icons/tb"
    tag = "TbEggs"


class TbElevatorOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbElevatorOff"


class TbElevator(rx.Component):
    library = "react-icons/tb"
    tag = "TbElevator"


class TbEmergencyBed(rx.Component):
    library = "react-icons/tb"
    tag = "TbEmergencyBed"


class TbEmpathizeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbEmpathizeOff"


class TbEmpathize(rx.Component):
    library = "react-icons/tb"
    tag = "TbEmpathize"


class TbEmphasis(rx.Component):
    library = "react-icons/tb"
    tag = "TbEmphasis"


class TbEngineOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbEngineOff"


class TbEngine(rx.Component):
    library = "react-icons/tb"
    tag = "TbEngine"


class TbEqualDouble(rx.Component):
    library = "react-icons/tb"
    tag = "TbEqualDouble"


class TbEqualNot(rx.Component):
    library = "react-icons/tb"
    tag = "TbEqualNot"


class TbEqual(rx.Component):
    library = "react-icons/tb"
    tag = "TbEqual"


class TbEraserOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbEraserOff"


class TbEraser(rx.Component):
    library = "react-icons/tb"
    tag = "TbEraser"


class TbError404Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbError404Off"


class TbError404(rx.Component):
    library = "react-icons/tb"
    tag = "TbError404"


class TbExchangeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbExchangeOff"


class TbExchange(rx.Component):
    library = "react-icons/tb"
    tag = "TbExchange"


class TbExclamationCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbExclamationCircle"


class TbExclamationMarkOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbExclamationMarkOff"


class TbExclamationMark(rx.Component):
    library = "react-icons/tb"
    tag = "TbExclamationMark"


class TbExplicitOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbExplicitOff"


class TbExplicit(rx.Component):
    library = "react-icons/tb"
    tag = "TbExplicit"


class TbExposure0(rx.Component):
    library = "react-icons/tb"
    tag = "TbExposure0"


class TbExposureMinus1(rx.Component):
    library = "react-icons/tb"
    tag = "TbExposureMinus1"


class TbExposureMinus2(rx.Component):
    library = "react-icons/tb"
    tag = "TbExposureMinus2"


class TbExposureOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbExposureOff"


class TbExposurePlus1(rx.Component):
    library = "react-icons/tb"
    tag = "TbExposurePlus1"


class TbExposurePlus2(rx.Component):
    library = "react-icons/tb"
    tag = "TbExposurePlus2"


class TbExposure(rx.Component):
    library = "react-icons/tb"
    tag = "TbExposure"


class TbExternalLinkOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbExternalLinkOff"


class TbExternalLink(rx.Component):
    library = "react-icons/tb"
    tag = "TbExternalLink"


class TbEyeCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeCheck"


class TbEyeClosed(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeClosed"


class TbEyeCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeCog"


class TbEyeEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeEdit"


class TbEyeExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeExclamation"


class TbEyeFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeFilled"


class TbEyeHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeHeart"


class TbEyeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeOff"


class TbEyeTable(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeTable"


class TbEyeX(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeX"


class TbEye(rx.Component):
    library = "react-icons/tb"
    tag = "TbEye"


class TbEyeglass2(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeglass2"


class TbEyeglassOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeglassOff"


class TbEyeglass(rx.Component):
    library = "react-icons/tb"
    tag = "TbEyeglass"


class TbFaceIdError(rx.Component):
    library = "react-icons/tb"
    tag = "TbFaceIdError"


class TbFaceId(rx.Component):
    library = "react-icons/tb"
    tag = "TbFaceId"


class TbFaceMaskOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFaceMaskOff"


class TbFaceMask(rx.Component):
    library = "react-icons/tb"
    tag = "TbFaceMask"


class TbFall(rx.Component):
    library = "react-icons/tb"
    tag = "TbFall"


class TbFeatherOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFeatherOff"


class TbFeather(rx.Component):
    library = "react-icons/tb"
    tag = "TbFeather"


class TbFenceOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFenceOff"


class TbFence(rx.Component):
    library = "react-icons/tb"
    tag = "TbFence"


class TbFidgetSpinner(rx.Component):
    library = "react-icons/tb"
    tag = "TbFidgetSpinner"


class TbFile3D(rx.Component):
    library = "react-icons/tb"
    tag = "TbFile3D"


class TbFileAlert(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileAlert"


class TbFileAnalytics(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileAnalytics"


class TbFileArrowLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileArrowLeft"


class TbFileArrowRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileArrowRight"


class TbFileBarcode(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileBarcode"


class TbFileBroken(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileBroken"


class TbFileCertificate(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileCertificate"


class TbFileChart(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileChart"


class TbFileCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileCheck"


class TbFileCode2(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileCode2"


class TbFileCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileCode"


class TbFileCv(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileCv"


class TbFileDatabase(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileDatabase"


class TbFileDelta(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileDelta"


class TbFileDescription(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileDescription"


class TbFileDiff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileDiff"


class TbFileDigit(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileDigit"


class TbFileDislike(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileDislike"


class TbFileDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileDollar"


class TbFileDots(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileDots"


class TbFileDownload(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileDownload"


class TbFileEuro(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileEuro"


class TbFileExport(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileExport"


class TbFileFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileFilled"


class TbFileFunction(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileFunction"


class TbFileHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileHorizontal"


class TbFileImport(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileImport"


class TbFileInfinity(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileInfinity"


class TbFileInfo(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileInfo"


class TbFileInvoice(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileInvoice"


class TbFileLambda(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileLambda"


class TbFileLike(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileLike"


class TbFileMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileMinus"


class TbFileMusic(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileMusic"


class TbFileOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileOff"


class TbFileOrientation(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileOrientation"


class TbFilePencil(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilePencil"


class TbFilePercent(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilePercent"


class TbFilePhone(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilePhone"


class TbFilePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilePlus"


class TbFilePower(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilePower"


class TbFileReport(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileReport"


class TbFileRss(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileRss"


class TbFileScissors(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileScissors"


class TbFileSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileSearch"


class TbFileSettings(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileSettings"


class TbFileShredder(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileShredder"


class TbFileSignal(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileSignal"


class TbFileSpreadsheet(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileSpreadsheet"


class TbFileStack(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileStack"


class TbFileStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileStar"


class TbFileSymlink(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileSymlink"


class TbFileTextAi(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileTextAi"


class TbFileText(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileText"


class TbFileTime(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileTime"


class TbFileTypography(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileTypography"


class TbFileUnknown(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileUnknown"


class TbFileUpload(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileUpload"


class TbFileVector(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileVector"


class TbFileXFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileXFilled"


class TbFileX(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileX"


class TbFileZip(rx.Component):
    library = "react-icons/tb"
    tag = "TbFileZip"


class TbFile(rx.Component):
    library = "react-icons/tb"
    tag = "TbFile"


class TbFilesOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilesOff"


class TbFiles(rx.Component):
    library = "react-icons/tb"
    tag = "TbFiles"


class TbFilterCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilterCog"


class TbFilterDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilterDollar"


class TbFilterEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilterEdit"


class TbFilterMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilterMinus"


class TbFilterOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilterOff"


class TbFilterPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilterPlus"


class TbFilterStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilterStar"


class TbFilterX(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilterX"


class TbFilter(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilter"


class TbFilters(rx.Component):
    library = "react-icons/tb"
    tag = "TbFilters"


class TbFingerprintOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFingerprintOff"


class TbFingerprint(rx.Component):
    library = "react-icons/tb"
    tag = "TbFingerprint"


class TbFireHydrantOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFireHydrantOff"


class TbFireHydrant(rx.Component):
    library = "react-icons/tb"
    tag = "TbFireHydrant"


class TbFiretruck(rx.Component):
    library = "react-icons/tb"
    tag = "TbFiretruck"


class TbFirstAidKitOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFirstAidKitOff"


class TbFirstAidKit(rx.Component):
    library = "react-icons/tb"
    tag = "TbFirstAidKit"


class TbFishBone(rx.Component):
    library = "react-icons/tb"
    tag = "TbFishBone"


class TbFishChristianity(rx.Component):
    library = "react-icons/tb"
    tag = "TbFishChristianity"


class TbFishHookOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFishHookOff"


class TbFishHook(rx.Component):
    library = "react-icons/tb"
    tag = "TbFishHook"


class TbFishOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFishOff"


class TbFish(rx.Component):
    library = "react-icons/tb"
    tag = "TbFish"


class TbFlag2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlag2Filled"


class TbFlag2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlag2Off"


class TbFlag2(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlag2"


class TbFlag3Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlag3Filled"


class TbFlag3(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlag3"


class TbFlagFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlagFilled"


class TbFlagOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlagOff"


class TbFlag(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlag"


class TbFlameOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlameOff"


class TbFlame(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlame"


class TbFlare(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlare"


class TbFlask2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlask2Off"


class TbFlask2(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlask2"


class TbFlaskOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlaskOff"


class TbFlask(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlask"


class TbFlipFlops(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlipFlops"


class TbFlipHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlipHorizontal"


class TbFlipVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlipVertical"


class TbFloatCenter(rx.Component):
    library = "react-icons/tb"
    tag = "TbFloatCenter"


class TbFloatLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbFloatLeft"


class TbFloatNone(rx.Component):
    library = "react-icons/tb"
    tag = "TbFloatNone"


class TbFloatRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbFloatRight"


class TbFlowerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlowerOff"


class TbFlower(rx.Component):
    library = "react-icons/tb"
    tag = "TbFlower"


class TbFocus2(rx.Component):
    library = "react-icons/tb"
    tag = "TbFocus2"


class TbFocusAuto(rx.Component):
    library = "react-icons/tb"
    tag = "TbFocusAuto"


class TbFocusCentered(rx.Component):
    library = "react-icons/tb"
    tag = "TbFocusCentered"


class TbFocus(rx.Component):
    library = "react-icons/tb"
    tag = "TbFocus"


class TbFoldDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbFoldDown"


class TbFoldUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbFoldUp"


class TbFold(rx.Component):
    library = "react-icons/tb"
    tag = "TbFold"


class TbFolderBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderBolt"


class TbFolderCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderCancel"


class TbFolderCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderCheck"


class TbFolderCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderCode"


class TbFolderCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderCog"


class TbFolderDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderDollar"


class TbFolderDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderDown"


class TbFolderExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderExclamation"


class TbFolderFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderFilled"


class TbFolderHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderHeart"


class TbFolderMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderMinus"


class TbFolderOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderOff"


class TbFolderPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderPause"


class TbFolderPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderPin"


class TbFolderPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderPlus"


class TbFolderQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderQuestion"


class TbFolderSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderSearch"


class TbFolderShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderShare"


class TbFolderStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderStar"


class TbFolderSymlink(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderSymlink"


class TbFolderUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderUp"


class TbFolderX(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolderX"


class TbFolder(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolder"


class TbFoldersOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFoldersOff"


class TbFolders(rx.Component):
    library = "react-icons/tb"
    tag = "TbFolders"


class TbForbid2(rx.Component):
    library = "react-icons/tb"
    tag = "TbForbid2"


class TbForbid(rx.Component):
    library = "react-icons/tb"
    tag = "TbForbid"


class TbForklift(rx.Component):
    library = "react-icons/tb"
    tag = "TbForklift"


class TbForms(rx.Component):
    library = "react-icons/tb"
    tag = "TbForms"


class TbFountainOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFountainOff"


class TbFountain(rx.Component):
    library = "react-icons/tb"
    tag = "TbFountain"


class TbFrameOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFrameOff"


class TbFrame(rx.Component):
    library = "react-icons/tb"
    tag = "TbFrame"


class TbFreeRights(rx.Component):
    library = "react-icons/tb"
    tag = "TbFreeRights"


class TbFreezeColumn(rx.Component):
    library = "react-icons/tb"
    tag = "TbFreezeColumn"


class TbFreezeRowColumn(rx.Component):
    library = "react-icons/tb"
    tag = "TbFreezeRowColumn"


class TbFreezeRow(rx.Component):
    library = "react-icons/tb"
    tag = "TbFreezeRow"


class TbFridgeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFridgeOff"


class TbFridge(rx.Component):
    library = "react-icons/tb"
    tag = "TbFridge"


class TbFriendsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFriendsOff"


class TbFriends(rx.Component):
    library = "react-icons/tb"
    tag = "TbFriends"


class TbFrustumOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFrustumOff"


class TbFrustumPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbFrustumPlus"


class TbFrustum(rx.Component):
    library = "react-icons/tb"
    tag = "TbFrustum"


class TbFunctionOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbFunctionOff"


class TbFunction(rx.Component):
    library = "react-icons/tb"
    tag = "TbFunction"


class TbGardenCartOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGardenCartOff"


class TbGardenCart(rx.Component):
    library = "react-icons/tb"
    tag = "TbGardenCart"


class TbGasStationOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGasStationOff"


class TbGasStation(rx.Component):
    library = "react-icons/tb"
    tag = "TbGasStation"


class TbGaugeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGaugeOff"


class TbGauge(rx.Component):
    library = "react-icons/tb"
    tag = "TbGauge"


class TbGavel(rx.Component):
    library = "react-icons/tb"
    tag = "TbGavel"


class TbGenderAgender(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderAgender"


class TbGenderAndrogyne(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderAndrogyne"


class TbGenderBigender(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderBigender"


class TbGenderDemiboy(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderDemiboy"


class TbGenderDemigirl(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderDemigirl"


class TbGenderEpicene(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderEpicene"


class TbGenderFemale(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderFemale"


class TbGenderFemme(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderFemme"


class TbGenderGenderfluid(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderGenderfluid"


class TbGenderGenderless(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderGenderless"


class TbGenderGenderqueer(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderGenderqueer"


class TbGenderHermaphrodite(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderHermaphrodite"


class TbGenderIntergender(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderIntergender"


class TbGenderMale(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderMale"


class TbGenderNeutrois(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderNeutrois"


class TbGenderThird(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderThird"


class TbGenderTransgender(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderTransgender"


class TbGenderTrasvesti(rx.Component):
    library = "react-icons/tb"
    tag = "TbGenderTrasvesti"


class TbGeometry(rx.Component):
    library = "react-icons/tb"
    tag = "TbGeometry"


class TbGhost2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbGhost2Filled"


class TbGhost2(rx.Component):
    library = "react-icons/tb"
    tag = "TbGhost2"


class TbGhostFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbGhostFilled"


class TbGhostOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGhostOff"


class TbGhost(rx.Component):
    library = "react-icons/tb"
    tag = "TbGhost"


class TbGif(rx.Component):
    library = "react-icons/tb"
    tag = "TbGif"


class TbGiftCard(rx.Component):
    library = "react-icons/tb"
    tag = "TbGiftCard"


class TbGiftOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGiftOff"


class TbGift(rx.Component):
    library = "react-icons/tb"
    tag = "TbGift"


class TbGitBranchDeleted(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitBranchDeleted"


class TbGitBranch(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitBranch"


class TbGitCherryPick(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitCherryPick"


class TbGitCommit(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitCommit"


class TbGitCompare(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitCompare"


class TbGitFork(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitFork"


class TbGitMerge(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitMerge"


class TbGitPullRequestClosed(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitPullRequestClosed"


class TbGitPullRequestDraft(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitPullRequestDraft"


class TbGitPullRequest(rx.Component):
    library = "react-icons/tb"
    tag = "TbGitPullRequest"


class TbGizmo(rx.Component):
    library = "react-icons/tb"
    tag = "TbGizmo"


class TbGlassFull(rx.Component):
    library = "react-icons/tb"
    tag = "TbGlassFull"


class TbGlassOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGlassOff"


class TbGlass(rx.Component):
    library = "react-icons/tb"
    tag = "TbGlass"


class TbGlobeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGlobeOff"


class TbGlobe(rx.Component):
    library = "react-icons/tb"
    tag = "TbGlobe"


class TbGoGame(rx.Component):
    library = "react-icons/tb"
    tag = "TbGoGame"


class TbGolfOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGolfOff"


class TbGolf(rx.Component):
    library = "react-icons/tb"
    tag = "TbGolf"


class TbGps(rx.Component):
    library = "react-icons/tb"
    tag = "TbGps"


class TbGradienter(rx.Component):
    library = "react-icons/tb"
    tag = "TbGradienter"


class TbGrain(rx.Component):
    library = "react-icons/tb"
    tag = "TbGrain"


class TbGraphOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGraphOff"


class TbGraph(rx.Component):
    library = "react-icons/tb"
    tag = "TbGraph"


class TbGrave2(rx.Component):
    library = "react-icons/tb"
    tag = "TbGrave2"


class TbGrave(rx.Component):
    library = "react-icons/tb"
    tag = "TbGrave"


class TbGridDots(rx.Component):
    library = "react-icons/tb"
    tag = "TbGridDots"


class TbGridPattern(rx.Component):
    library = "react-icons/tb"
    tag = "TbGridPattern"


class TbGrillFork(rx.Component):
    library = "react-icons/tb"
    tag = "TbGrillFork"


class TbGrillOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbGrillOff"


class TbGrillSpatula(rx.Component):
    library = "react-icons/tb"
    tag = "TbGrillSpatula"


class TbGrill(rx.Component):
    library = "react-icons/tb"
    tag = "TbGrill"


class TbGripHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbGripHorizontal"


class TbGripVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbGripVertical"


class TbGrowth(rx.Component):
    library = "react-icons/tb"
    tag = "TbGrowth"


class TbGuitarPickFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbGuitarPickFilled"


class TbGuitarPick(rx.Component):
    library = "react-icons/tb"
    tag = "TbGuitarPick"


class TbH1(rx.Component):
    library = "react-icons/tb"
    tag = "TbH1"


class TbH2(rx.Component):
    library = "react-icons/tb"
    tag = "TbH2"


class TbH3(rx.Component):
    library = "react-icons/tb"
    tag = "TbH3"


class TbH4(rx.Component):
    library = "react-icons/tb"
    tag = "TbH4"


class TbH5(rx.Component):
    library = "react-icons/tb"
    tag = "TbH5"


class TbH6(rx.Component):
    library = "react-icons/tb"
    tag = "TbH6"


class TbHammerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHammerOff"


class TbHammer(rx.Component):
    library = "react-icons/tb"
    tag = "TbHammer"


class TbHandClick(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandClick"


class TbHandFingerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandFingerOff"


class TbHandFinger(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandFinger"


class TbHandGrab(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandGrab"


class TbHandLittleFinger(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandLittleFinger"


class TbHandMiddleFinger(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandMiddleFinger"


class TbHandMove(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandMove"


class TbHandOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandOff"


class TbHandRingFinger(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandRingFinger"


class TbHandRock(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandRock"


class TbHandSanitizer(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandSanitizer"


class TbHandStop(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandStop"


class TbHandThreeFingers(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandThreeFingers"


class TbHandTwoFingers(rx.Component):
    library = "react-icons/tb"
    tag = "TbHandTwoFingers"


class TbHanger2(rx.Component):
    library = "react-icons/tb"
    tag = "TbHanger2"


class TbHangerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHangerOff"


class TbHanger(rx.Component):
    library = "react-icons/tb"
    tag = "TbHanger"


class TbHash(rx.Component):
    library = "react-icons/tb"
    tag = "TbHash"


class TbHaze(rx.Component):
    library = "react-icons/tb"
    tag = "TbHaze"


class TbHdr(rx.Component):
    library = "react-icons/tb"
    tag = "TbHdr"


class TbHeadingOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeadingOff"


class TbHeading(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeading"


class TbHeadphonesFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeadphonesFilled"


class TbHeadphonesOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeadphonesOff"


class TbHeadphones(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeadphones"


class TbHeadsetOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeadsetOff"


class TbHeadset(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeadset"


class TbHealthRecognition(rx.Component):
    library = "react-icons/tb"
    tag = "TbHealthRecognition"


class TbHeartBroken(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeartBroken"


class TbHeartFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeartFilled"


class TbHeartHandshake(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeartHandshake"


class TbHeartMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeartMinus"


class TbHeartOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeartOff"


class TbHeartPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeartPlus"


class TbHeartRateMonitor(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeartRateMonitor"


class TbHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeart"


class TbHeartbeat(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeartbeat"


class TbHeartsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHeartsOff"


class TbHearts(rx.Component):
    library = "react-icons/tb"
    tag = "TbHearts"


class TbHelicopterLanding(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelicopterLanding"


class TbHelicopter(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelicopter"


class TbHelmetOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelmetOff"


class TbHelmet(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelmet"


class TbHelpCircleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpCircleFilled"


class TbHelpCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpCircle"


class TbHelpHexagonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpHexagonFilled"


class TbHelpHexagon(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpHexagon"


class TbHelpOctagonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpOctagonFilled"


class TbHelpOctagon(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpOctagon"


class TbHelpOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpOff"


class TbHelpSmall(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpSmall"


class TbHelpSquareFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpSquareFilled"


class TbHelpSquareRoundedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpSquareRoundedFilled"


class TbHelpSquareRounded(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpSquareRounded"


class TbHelpSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpSquare"


class TbHelpTriangleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpTriangleFilled"


class TbHelpTriangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelpTriangle"


class TbHelp(rx.Component):
    library = "react-icons/tb"
    tag = "TbHelp"


class TbHemisphereOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHemisphereOff"


class TbHemispherePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbHemispherePlus"


class TbHemisphere(rx.Component):
    library = "react-icons/tb"
    tag = "TbHemisphere"


class TbHexagon0Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon0Filled"


class TbHexagon1Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon1Filled"


class TbHexagon2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon2Filled"


class TbHexagon3Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon3Filled"


class TbHexagon3D(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon3D"


class TbHexagon4Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon4Filled"


class TbHexagon5Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon5Filled"


class TbHexagon6Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon6Filled"


class TbHexagon7Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon7Filled"


class TbHexagon8Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon8Filled"


class TbHexagon9Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon9Filled"


class TbHexagonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonFilled"


class TbHexagonLetterA(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterA"


class TbHexagonLetterB(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterB"


class TbHexagonLetterC(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterC"


class TbHexagonLetterD(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterD"


class TbHexagonLetterE(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterE"


class TbHexagonLetterF(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterF"


class TbHexagonLetterG(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterG"


class TbHexagonLetterH(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterH"


class TbHexagonLetterI(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterI"


class TbHexagonLetterJ(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterJ"


class TbHexagonLetterK(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterK"


class TbHexagonLetterL(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterL"


class TbHexagonLetterM(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterM"


class TbHexagonLetterN(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterN"


class TbHexagonLetterO(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterO"


class TbHexagonLetterP(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterP"


class TbHexagonLetterQ(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterQ"


class TbHexagonLetterR(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterR"


class TbHexagonLetterS(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterS"


class TbHexagonLetterT(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterT"


class TbHexagonLetterU(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterU"


class TbHexagonLetterV(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterV"


class TbHexagonLetterW(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterW"


class TbHexagonLetterX(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterX"


class TbHexagonLetterY(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterY"


class TbHexagonLetterZ(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonLetterZ"


class TbHexagonNumber0(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber0"


class TbHexagonNumber1(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber1"


class TbHexagonNumber2(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber2"


class TbHexagonNumber3(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber3"


class TbHexagonNumber4(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber4"


class TbHexagonNumber5(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber5"


class TbHexagonNumber6(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber6"


class TbHexagonNumber7(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber7"


class TbHexagonNumber8(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber8"


class TbHexagonNumber9(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonNumber9"


class TbHexagonOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonOff"


class TbHexagon(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagon"


class TbHexagonalPrismOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonalPrismOff"


class TbHexagonalPrismPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonalPrismPlus"


class TbHexagonalPrism(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonalPrism"


class TbHexagonalPyramidOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonalPyramidOff"


class TbHexagonalPyramidPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonalPyramidPlus"


class TbHexagonalPyramid(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonalPyramid"


class TbHexagonsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagonsOff"


class TbHexagons(rx.Component):
    library = "react-icons/tb"
    tag = "TbHexagons"


class TbHierarchy2(rx.Component):
    library = "react-icons/tb"
    tag = "TbHierarchy2"


class TbHierarchy3(rx.Component):
    library = "react-icons/tb"
    tag = "TbHierarchy3"


class TbHierarchyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHierarchyOff"


class TbHierarchy(rx.Component):
    library = "react-icons/tb"
    tag = "TbHierarchy"


class TbHighlightOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHighlightOff"


class TbHighlight(rx.Component):
    library = "react-icons/tb"
    tag = "TbHighlight"


class TbHistoryOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHistoryOff"


class TbHistoryToggle(rx.Component):
    library = "react-icons/tb"
    tag = "TbHistoryToggle"


class TbHistory(rx.Component):
    library = "react-icons/tb"
    tag = "TbHistory"


class TbHome2(rx.Component):
    library = "react-icons/tb"
    tag = "TbHome2"


class TbHomeBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeBolt"


class TbHomeCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeCancel"


class TbHomeCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeCheck"


class TbHomeCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeCog"


class TbHomeDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeDollar"


class TbHomeDot(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeDot"


class TbHomeDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeDown"


class TbHomeEco(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeEco"


class TbHomeEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeEdit"


class TbHomeExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeExclamation"


class TbHomeHand(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeHand"


class TbHomeHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeHeart"


class TbHomeInfinity(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeInfinity"


class TbHomeLink(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeLink"


class TbHomeMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeMinus"


class TbHomeMove(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeMove"


class TbHomeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeOff"


class TbHomePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomePlus"


class TbHomeQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeQuestion"


class TbHomeRibbon(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeRibbon"


class TbHomeSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeSearch"


class TbHomeShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeShare"


class TbHomeShield(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeShield"


class TbHomeSignal(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeSignal"


class TbHomeStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeStar"


class TbHomeStats(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeStats"


class TbHomeUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeUp"


class TbHomeX(rx.Component):
    library = "react-icons/tb"
    tag = "TbHomeX"


class TbHome(rx.Component):
    library = "react-icons/tb"
    tag = "TbHome"


class TbHorseToy(rx.Component):
    library = "react-icons/tb"
    tag = "TbHorseToy"


class TbHotelService(rx.Component):
    library = "react-icons/tb"
    tag = "TbHotelService"


class TbHourglassEmpty(rx.Component):
    library = "react-icons/tb"
    tag = "TbHourglassEmpty"


class TbHourglassFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbHourglassFilled"


class TbHourglassHigh(rx.Component):
    library = "react-icons/tb"
    tag = "TbHourglassHigh"


class TbHourglassLow(rx.Component):
    library = "react-icons/tb"
    tag = "TbHourglassLow"


class TbHourglassOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbHourglassOff"


class TbHourglass(rx.Component):
    library = "react-icons/tb"
    tag = "TbHourglass"


class TbHtml(rx.Component):
    library = "react-icons/tb"
    tag = "TbHtml"


class TbHttpConnect(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpConnect"


class TbHttpDelete(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpDelete"


class TbHttpGet(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpGet"


class TbHttpHead(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpHead"


class TbHttpOptions(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpOptions"


class TbHttpPatch(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpPatch"


class TbHttpPost(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpPost"


class TbHttpPut(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpPut"


class TbHttpQue(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpQue"


class TbHttpTrace(rx.Component):
    library = "react-icons/tb"
    tag = "TbHttpTrace"


class TbIceCream2(rx.Component):
    library = "react-icons/tb"
    tag = "TbIceCream2"


class TbIceCreamOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbIceCreamOff"


class TbIceCream(rx.Component):
    library = "react-icons/tb"
    tag = "TbIceCream"


class TbIceSkating(rx.Component):
    library = "react-icons/tb"
    tag = "TbIceSkating"


class TbIconsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbIconsOff"


class TbIcons(rx.Component):
    library = "react-icons/tb"
    tag = "TbIcons"


class TbIdBadge2(rx.Component):
    library = "react-icons/tb"
    tag = "TbIdBadge2"


class TbIdBadgeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbIdBadgeOff"


class TbIdBadge(rx.Component):
    library = "react-icons/tb"
    tag = "TbIdBadge"


class TbIdOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbIdOff"


class TbId(rx.Component):
    library = "react-icons/tb"
    tag = "TbId"


class TbInboxOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbInboxOff"


class TbInbox(rx.Component):
    library = "react-icons/tb"
    tag = "TbInbox"


class TbIndentDecrease(rx.Component):
    library = "react-icons/tb"
    tag = "TbIndentDecrease"


class TbIndentIncrease(rx.Component):
    library = "react-icons/tb"
    tag = "TbIndentIncrease"


class TbInfinityOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfinityOff"


class TbInfinity(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfinity"


class TbInfoCircleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoCircleFilled"


class TbInfoCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoCircle"


class TbInfoHexagonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoHexagonFilled"


class TbInfoHexagon(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoHexagon"


class TbInfoOctagonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoOctagonFilled"


class TbInfoOctagon(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoOctagon"


class TbInfoSmall(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoSmall"


class TbInfoSquareFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoSquareFilled"


class TbInfoSquareRoundedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoSquareRoundedFilled"


class TbInfoSquareRounded(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoSquareRounded"


class TbInfoSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoSquare"


class TbInfoTriangleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoTriangleFilled"


class TbInfoTriangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbInfoTriangle"


class TbInnerShadowBottomFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowBottomFilled"


class TbInnerShadowBottomLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowBottomLeftFilled"


class TbInnerShadowBottomLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowBottomLeft"


class TbInnerShadowBottomRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowBottomRightFilled"


class TbInnerShadowBottomRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowBottomRight"


class TbInnerShadowBottom(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowBottom"


class TbInnerShadowLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowLeftFilled"


class TbInnerShadowLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowLeft"


class TbInnerShadowRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowRightFilled"


class TbInnerShadowRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowRight"


class TbInnerShadowTopFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowTopFilled"


class TbInnerShadowTopLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowTopLeftFilled"


class TbInnerShadowTopLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowTopLeft"


class TbInnerShadowTopRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowTopRightFilled"


class TbInnerShadowTopRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowTopRight"


class TbInnerShadowTop(rx.Component):
    library = "react-icons/tb"
    tag = "TbInnerShadowTop"


class TbInputSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbInputSearch"


class TbIroning1(rx.Component):
    library = "react-icons/tb"
    tag = "TbIroning1"


class TbIroning2(rx.Component):
    library = "react-icons/tb"
    tag = "TbIroning2"


class TbIroning3(rx.Component):
    library = "react-icons/tb"
    tag = "TbIroning3"


class TbIroningOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbIroningOff"


class TbIroningSteamOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbIroningSteamOff"


class TbIroningSteam(rx.Component):
    library = "react-icons/tb"
    tag = "TbIroningSteam"


class TbIroning(rx.Component):
    library = "react-icons/tb"
    tag = "TbIroning"


class TbIrregularPolyhedronOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbIrregularPolyhedronOff"


class TbIrregularPolyhedronPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbIrregularPolyhedronPlus"


class TbIrregularPolyhedron(rx.Component):
    library = "react-icons/tb"
    tag = "TbIrregularPolyhedron"


class TbItalic(rx.Component):
    library = "react-icons/tb"
    tag = "TbItalic"


class TbJacket(rx.Component):
    library = "react-icons/tb"
    tag = "TbJacket"


class TbJetpack(rx.Component):
    library = "react-icons/tb"
    tag = "TbJetpack"


class TbJewishStarFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbJewishStarFilled"


class TbJewishStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbJewishStar"


class TbJpg(rx.Component):
    library = "react-icons/tb"
    tag = "TbJpg"


class TbJson(rx.Component):
    library = "react-icons/tb"
    tag = "TbJson"


class TbJumpRope(rx.Component):
    library = "react-icons/tb"
    tag = "TbJumpRope"


class TbKarate(rx.Component):
    library = "react-icons/tb"
    tag = "TbKarate"


class TbKayak(rx.Component):
    library = "react-icons/tb"
    tag = "TbKayak"


class TbKering(rx.Component):
    library = "react-icons/tb"
    tag = "TbKering"


class TbKeyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyOff"


class TbKey(rx.Component):
    library = "react-icons/tb"
    tag = "TbKey"


class TbKeyboardHide(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyboardHide"


class TbKeyboardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyboardOff"


class TbKeyboardShow(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyboardShow"


class TbKeyboard(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyboard"


class TbKeyframeAlignCenter(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyframeAlignCenter"


class TbKeyframeAlignHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyframeAlignHorizontal"


class TbKeyframeAlignVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyframeAlignVertical"


class TbKeyframe(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyframe"


class TbKeyframes(rx.Component):
    library = "react-icons/tb"
    tag = "TbKeyframes"


class TbLadderOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLadderOff"


class TbLadder(rx.Component):
    library = "react-icons/tb"
    tag = "TbLadder"


class TbLambda(rx.Component):
    library = "react-icons/tb"
    tag = "TbLambda"


class TbLamp2(rx.Component):
    library = "react-icons/tb"
    tag = "TbLamp2"


class TbLampOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLampOff"


class TbLamp(rx.Component):
    library = "react-icons/tb"
    tag = "TbLamp"


class TbLanguageHiragana(rx.Component):
    library = "react-icons/tb"
    tag = "TbLanguageHiragana"


class TbLanguageKatakana(rx.Component):
    library = "react-icons/tb"
    tag = "TbLanguageKatakana"


class TbLanguageOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLanguageOff"


class TbLanguage(rx.Component):
    library = "react-icons/tb"
    tag = "TbLanguage"


class TbLassoOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLassoOff"


class TbLassoPolygon(rx.Component):
    library = "react-icons/tb"
    tag = "TbLassoPolygon"


class TbLasso(rx.Component):
    library = "react-icons/tb"
    tag = "TbLasso"


class TbLayersDifference(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayersDifference"


class TbLayersIntersect2(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayersIntersect2"


class TbLayersIntersect(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayersIntersect"


class TbLayersLinked(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayersLinked"


class TbLayersOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayersOff"


class TbLayersSubtract(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayersSubtract"


class TbLayersUnion(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayersUnion"


class TbLayout2(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayout2"


class TbLayoutAlignBottom(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutAlignBottom"


class TbLayoutAlignCenter(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutAlignCenter"


class TbLayoutAlignLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutAlignLeft"


class TbLayoutAlignMiddle(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutAlignMiddle"


class TbLayoutAlignRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutAlignRight"


class TbLayoutAlignTop(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutAlignTop"


class TbLayoutBoardSplit(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutBoardSplit"


class TbLayoutBoard(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutBoard"


class TbLayoutBottombarCollapse(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutBottombarCollapse"


class TbLayoutBottombarExpand(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutBottombarExpand"


class TbLayoutBottombar(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutBottombar"


class TbLayoutCards(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutCards"


class TbLayoutCollage(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutCollage"


class TbLayoutColumns(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutColumns"


class TbLayoutDashboard(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutDashboard"


class TbLayoutDistributeHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutDistributeHorizontal"


class TbLayoutDistributeVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutDistributeVertical"


class TbLayoutGridAdd(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutGridAdd"


class TbLayoutGridRemove(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutGridRemove"


class TbLayoutGrid(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutGrid"


class TbLayoutKanban(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutKanban"


class TbLayoutList(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutList"


class TbLayoutNavbarCollapse(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutNavbarCollapse"


class TbLayoutNavbarExpand(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutNavbarExpand"


class TbLayoutNavbar(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutNavbar"


class TbLayoutOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutOff"


class TbLayoutRows(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutRows"


class TbLayoutSidebarLeftCollapse(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutSidebarLeftCollapse"


class TbLayoutSidebarLeftExpand(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutSidebarLeftExpand"


class TbLayoutSidebarRightCollapse(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutSidebarRightCollapse"


class TbLayoutSidebarRightExpand(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutSidebarRightExpand"


class TbLayoutSidebarRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutSidebarRight"


class TbLayoutSidebar(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayoutSidebar"


class TbLayout(rx.Component):
    library = "react-icons/tb"
    tag = "TbLayout"


class TbLeafOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLeafOff"


class TbLeaf(rx.Component):
    library = "react-icons/tb"
    tag = "TbLeaf"


class TbLegoOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLegoOff"


class TbLego(rx.Component):
    library = "react-icons/tb"
    tag = "TbLego"


class TbLemon2(rx.Component):
    library = "react-icons/tb"
    tag = "TbLemon2"


class TbLemon(rx.Component):
    library = "react-icons/tb"
    tag = "TbLemon"


class TbLetterA(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterA"


class TbLetterB(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterB"


class TbLetterC(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterC"


class TbLetterCaseLower(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterCaseLower"


class TbLetterCaseToggle(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterCaseToggle"


class TbLetterCaseUpper(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterCaseUpper"


class TbLetterCase(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterCase"


class TbLetterD(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterD"


class TbLetterE(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterE"


class TbLetterF(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterF"


class TbLetterG(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterG"


class TbLetterH(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterH"


class TbLetterI(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterI"


class TbLetterJ(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterJ"


class TbLetterK(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterK"


class TbLetterL(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterL"


class TbLetterM(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterM"


class TbLetterN(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterN"


class TbLetterO(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterO"


class TbLetterP(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterP"


class TbLetterQ(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterQ"


class TbLetterR(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterR"


class TbLetterS(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterS"


class TbLetterSpacing(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterSpacing"


class TbLetterT(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterT"


class TbLetterU(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterU"


class TbLetterV(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterV"


class TbLetterW(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterW"


class TbLetterX(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterX"


class TbLetterY(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterY"


class TbLetterZ(rx.Component):
    library = "react-icons/tb"
    tag = "TbLetterZ"


class TbLicenseOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLicenseOff"


class TbLicense(rx.Component):
    library = "react-icons/tb"
    tag = "TbLicense"


class TbLifebuoyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLifebuoyOff"


class TbLifebuoy(rx.Component):
    library = "react-icons/tb"
    tag = "TbLifebuoy"


class TbLighter(rx.Component):
    library = "react-icons/tb"
    tag = "TbLighter"


class TbLineDashed(rx.Component):
    library = "react-icons/tb"
    tag = "TbLineDashed"


class TbLineDotted(rx.Component):
    library = "react-icons/tb"
    tag = "TbLineDotted"


class TbLineHeight(rx.Component):
    library = "react-icons/tb"
    tag = "TbLineHeight"


class TbLine(rx.Component):
    library = "react-icons/tb"
    tag = "TbLine"


class TbLinkOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLinkOff"


class TbLink(rx.Component):
    library = "react-icons/tb"
    tag = "TbLink"


class TbListCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbListCheck"


class TbListDetails(rx.Component):
    library = "react-icons/tb"
    tag = "TbListDetails"


class TbListNumbers(rx.Component):
    library = "react-icons/tb"
    tag = "TbListNumbers"


class TbListSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbListSearch"


class TbList(rx.Component):
    library = "react-icons/tb"
    tag = "TbList"


class TbLivePhotoOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLivePhotoOff"


class TbLivePhoto(rx.Component):
    library = "react-icons/tb"
    tag = "TbLivePhoto"


class TbLiveView(rx.Component):
    library = "react-icons/tb"
    tag = "TbLiveView"


class TbLoadBalancer(rx.Component):
    library = "react-icons/tb"
    tag = "TbLoadBalancer"


class TbLoader2(rx.Component):
    library = "react-icons/tb"
    tag = "TbLoader2"


class TbLoader3(rx.Component):
    library = "react-icons/tb"
    tag = "TbLoader3"


class TbLoaderQuarter(rx.Component):
    library = "react-icons/tb"
    tag = "TbLoaderQuarter"


class TbLoader(rx.Component):
    library = "react-icons/tb"
    tag = "TbLoader"


class TbLocationBroken(rx.Component):
    library = "react-icons/tb"
    tag = "TbLocationBroken"


class TbLocationFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbLocationFilled"


class TbLocationOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLocationOff"


class TbLocation(rx.Component):
    library = "react-icons/tb"
    tag = "TbLocation"


class TbLockAccessOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockAccessOff"


class TbLockAccess(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockAccess"


class TbLockBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockBolt"


class TbLockCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockCancel"


class TbLockCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockCheck"


class TbLockCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockCode"


class TbLockCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockCog"


class TbLockDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockDollar"


class TbLockDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockDown"


class TbLockExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockExclamation"


class TbLockHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockHeart"


class TbLockMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockMinus"


class TbLockOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockOff"


class TbLockOpenOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockOpenOff"


class TbLockOpen(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockOpen"


class TbLockPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockPause"


class TbLockPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockPin"


class TbLockPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockPlus"


class TbLockQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockQuestion"


class TbLockSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockSearch"


class TbLockShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockShare"


class TbLockSquareRoundedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockSquareRoundedFilled"


class TbLockSquareRounded(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockSquareRounded"


class TbLockSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockSquare"


class TbLockStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockStar"


class TbLockUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockUp"


class TbLockX(rx.Component):
    library = "react-icons/tb"
    tag = "TbLockX"


class TbLock(rx.Component):
    library = "react-icons/tb"
    tag = "TbLock"


class TbLogicAnd(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogicAnd"


class TbLogicBuffer(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogicBuffer"


class TbLogicNand(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogicNand"


class TbLogicNor(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogicNor"


class TbLogicNot(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogicNot"


class TbLogicOr(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogicOr"


class TbLogicXnor(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogicXnor"


class TbLogicXor(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogicXor"


class TbLogin(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogin"


class TbLogout2(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogout2"


class TbLogout(rx.Component):
    library = "react-icons/tb"
    tag = "TbLogout"


class TbLollipopOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLollipopOff"


class TbLollipop(rx.Component):
    library = "react-icons/tb"
    tag = "TbLollipop"


class TbLuggageOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLuggageOff"


class TbLuggage(rx.Component):
    library = "react-icons/tb"
    tag = "TbLuggage"


class TbLungsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbLungsOff"


class TbLungs(rx.Component):
    library = "react-icons/tb"
    tag = "TbLungs"


class TbMacroOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMacroOff"


class TbMacro(rx.Component):
    library = "react-icons/tb"
    tag = "TbMacro"


class TbMagnetOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMagnetOff"


class TbMagnet(rx.Component):
    library = "react-icons/tb"
    tag = "TbMagnet"


class TbMailAi(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailAi"


class TbMailBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailBolt"


class TbMailCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailCancel"


class TbMailCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailCheck"


class TbMailCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailCode"


class TbMailCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailCog"


class TbMailDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailDollar"


class TbMailDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailDown"


class TbMailExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailExclamation"


class TbMailFast(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailFast"


class TbMailFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailFilled"


class TbMailForward(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailForward"


class TbMailHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailHeart"


class TbMailMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailMinus"


class TbMailOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailOff"


class TbMailOpenedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailOpenedFilled"


class TbMailOpened(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailOpened"


class TbMailPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailPause"


class TbMailPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailPin"


class TbMailPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailPlus"


class TbMailQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailQuestion"


class TbMailSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailSearch"


class TbMailShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailShare"


class TbMailStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailStar"


class TbMailUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailUp"


class TbMailX(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailX"


class TbMail(rx.Component):
    library = "react-icons/tb"
    tag = "TbMail"


class TbMailboxOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailboxOff"


class TbMailbox(rx.Component):
    library = "react-icons/tb"
    tag = "TbMailbox"


class TbMan(rx.Component):
    library = "react-icons/tb"
    tag = "TbMan"


class TbManualGearbox(rx.Component):
    library = "react-icons/tb"
    tag = "TbManualGearbox"


class TbMap2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMap2"


class TbMapOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapOff"


class TbMapPinBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinBolt"


class TbMapPinCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinCancel"


class TbMapPinCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinCheck"


class TbMapPinCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinCode"


class TbMapPinCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinCog"


class TbMapPinDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinDollar"


class TbMapPinDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinDown"


class TbMapPinExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinExclamation"


class TbMapPinFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinFilled"


class TbMapPinHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinHeart"


class TbMapPinMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinMinus"


class TbMapPinOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinOff"


class TbMapPinPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinPause"


class TbMapPinPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinPin"


class TbMapPinPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinPlus"


class TbMapPinQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinQuestion"


class TbMapPinSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinSearch"


class TbMapPinShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinShare"


class TbMapPinStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinStar"


class TbMapPinUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinUp"


class TbMapPinX(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPinX"


class TbMapPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPin"


class TbMapPins(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapPins"


class TbMapSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbMapSearch"


class TbMap(rx.Component):
    library = "react-icons/tb"
    tag = "TbMap"


class TbMarkdownOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMarkdownOff"


class TbMarkdown(rx.Component):
    library = "react-icons/tb"
    tag = "TbMarkdown"


class TbMarquee2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMarquee2"


class TbMarqueeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMarqueeOff"


class TbMarquee(rx.Component):
    library = "react-icons/tb"
    tag = "TbMarquee"


class TbMars(rx.Component):
    library = "react-icons/tb"
    tag = "TbMars"


class TbMaskOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMaskOff"


class TbMask(rx.Component):
    library = "react-icons/tb"
    tag = "TbMask"


class TbMasksTheaterOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMasksTheaterOff"


class TbMasksTheater(rx.Component):
    library = "react-icons/tb"
    tag = "TbMasksTheater"


class TbMassage(rx.Component):
    library = "react-icons/tb"
    tag = "TbMassage"


class TbMatchstick(rx.Component):
    library = "react-icons/tb"
    tag = "TbMatchstick"


class TbMath1Divide2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMath1Divide2"


class TbMath1Divide3(rx.Component):
    library = "react-icons/tb"
    tag = "TbMath1Divide3"


class TbMathAvg(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathAvg"


class TbMathEqualGreater(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathEqualGreater"


class TbMathEqualLower(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathEqualLower"


class TbMathFunctionOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathFunctionOff"


class TbMathFunctionY(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathFunctionY"


class TbMathFunction(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathFunction"


class TbMathGreater(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathGreater"


class TbMathIntegralX(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathIntegralX"


class TbMathIntegral(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathIntegral"


class TbMathIntegrals(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathIntegrals"


class TbMathLower(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathLower"


class TbMathMax(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathMax"


class TbMathMin(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathMin"


class TbMathNot(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathNot"


class TbMathOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathOff"


class TbMathPiDivide2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathPiDivide2"


class TbMathPi(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathPi"


class TbMathSymbols(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathSymbols"


class TbMathXDivide2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathXDivide2"


class TbMathXDivideY2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathXDivideY2"


class TbMathXDivideY(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathXDivideY"


class TbMathXMinusX(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathXMinusX"


class TbMathXMinusY(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathXMinusY"


class TbMathXPlusX(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathXPlusX"


class TbMathXPlusY(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathXPlusY"


class TbMathXy(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathXy"


class TbMathYMinusY(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathYMinusY"


class TbMathYPlusY(rx.Component):
    library = "react-icons/tb"
    tag = "TbMathYPlusY"


class TbMath(rx.Component):
    library = "react-icons/tb"
    tag = "TbMath"


class TbMaximizeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMaximizeOff"


class TbMaximize(rx.Component):
    library = "react-icons/tb"
    tag = "TbMaximize"


class TbMeatOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMeatOff"


class TbMeat(rx.Component):
    library = "react-icons/tb"
    tag = "TbMeat"


class TbMedal2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMedal2"


class TbMedal(rx.Component):
    library = "react-icons/tb"
    tag = "TbMedal"


class TbMedicalCrossFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMedicalCrossFilled"


class TbMedicalCrossOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMedicalCrossOff"


class TbMedicalCross(rx.Component):
    library = "react-icons/tb"
    tag = "TbMedicalCross"


class TbMedicineSyrup(rx.Component):
    library = "react-icons/tb"
    tag = "TbMedicineSyrup"


class TbMeeple(rx.Component):
    library = "react-icons/tb"
    tag = "TbMeeple"


class TbMenorah(rx.Component):
    library = "react-icons/tb"
    tag = "TbMenorah"


class TbMenu2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMenu2"


class TbMenuOrder(rx.Component):
    library = "react-icons/tb"
    tag = "TbMenuOrder"


class TbMenu(rx.Component):
    library = "react-icons/tb"
    tag = "TbMenu"


class TbMessage2Bolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Bolt"


class TbMessage2Cancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Cancel"


class TbMessage2Check(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Check"


class TbMessage2Code(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Code"


class TbMessage2Cog(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Cog"


class TbMessage2Dollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Dollar"


class TbMessage2Down(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Down"


class TbMessage2Exclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Exclamation"


class TbMessage2Heart(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Heart"


class TbMessage2Minus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Minus"


class TbMessage2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Off"


class TbMessage2Pause(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Pause"


class TbMessage2Pin(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Pin"


class TbMessage2Plus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Plus"


class TbMessage2Question(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Question"


class TbMessage2Search(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Search"


class TbMessage2Share(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Share"


class TbMessage2Star(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Star"


class TbMessage2Up(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2Up"


class TbMessage2X(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2X"


class TbMessage2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage2"


class TbMessageBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageBolt"


class TbMessageCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCancel"


class TbMessageChatbot(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageChatbot"


class TbMessageCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCheck"


class TbMessageCircle2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircle2Filled"


class TbMessageCircle2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircle2"


class TbMessageCircleBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleBolt"


class TbMessageCircleCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleCancel"


class TbMessageCircleCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleCheck"


class TbMessageCircleCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleCode"


class TbMessageCircleCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleCog"


class TbMessageCircleDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleDollar"


class TbMessageCircleDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleDown"


class TbMessageCircleExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleExclamation"


class TbMessageCircleHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleHeart"


class TbMessageCircleMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleMinus"


class TbMessageCircleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleOff"


class TbMessageCirclePause(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCirclePause"


class TbMessageCirclePin(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCirclePin"


class TbMessageCirclePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCirclePlus"


class TbMessageCircleQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleQuestion"


class TbMessageCircleSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleSearch"


class TbMessageCircleShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleShare"


class TbMessageCircleStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleStar"


class TbMessageCircleUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleUp"


class TbMessageCircleX(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircleX"


class TbMessageCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCircle"


class TbMessageCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCode"


class TbMessageCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageCog"


class TbMessageDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageDollar"


class TbMessageDots(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageDots"


class TbMessageDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageDown"


class TbMessageExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageExclamation"


class TbMessageForward(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageForward"


class TbMessageHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageHeart"


class TbMessageLanguage(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageLanguage"


class TbMessageMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageMinus"


class TbMessageOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageOff"


class TbMessagePause(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessagePause"


class TbMessagePin(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessagePin"


class TbMessagePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessagePlus"


class TbMessageQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageQuestion"


class TbMessageReport(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageReport"


class TbMessageSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageSearch"


class TbMessageShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageShare"


class TbMessageStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageStar"


class TbMessageUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageUp"


class TbMessageX(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessageX"


class TbMessage(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessage"


class TbMessagesOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessagesOff"


class TbMessages(rx.Component):
    library = "react-icons/tb"
    tag = "TbMessages"


class TbMeteorOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMeteorOff"


class TbMeteor(rx.Component):
    library = "react-icons/tb"
    tag = "TbMeteor"


class TbMickeyFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMickeyFilled"


class TbMickey(rx.Component):
    library = "react-icons/tb"
    tag = "TbMickey"


class TbMicrophone2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbMicrophone2Off"


class TbMicrophone2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMicrophone2"


class TbMicrophoneOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMicrophoneOff"


class TbMicrophone(rx.Component):
    library = "react-icons/tb"
    tag = "TbMicrophone"


class TbMicroscopeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMicroscopeOff"


class TbMicroscope(rx.Component):
    library = "react-icons/tb"
    tag = "TbMicroscope"


class TbMicrowaveOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMicrowaveOff"


class TbMicrowave(rx.Component):
    library = "react-icons/tb"
    tag = "TbMicrowave"


class TbMilitaryAward(rx.Component):
    library = "react-icons/tb"
    tag = "TbMilitaryAward"


class TbMilitaryRank(rx.Component):
    library = "react-icons/tb"
    tag = "TbMilitaryRank"


class TbMilkOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMilkOff"


class TbMilk(rx.Component):
    library = "react-icons/tb"
    tag = "TbMilk"


class TbMilkshake(rx.Component):
    library = "react-icons/tb"
    tag = "TbMilkshake"


class TbMinimize(rx.Component):
    library = "react-icons/tb"
    tag = "TbMinimize"


class TbMinusVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbMinusVertical"


class TbMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMinus"


class TbMistOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMistOff"


class TbMist(rx.Component):
    library = "react-icons/tb"
    tag = "TbMist"


class TbMobiledataOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMobiledataOff"


class TbMobiledata(rx.Component):
    library = "react-icons/tb"
    tag = "TbMobiledata"


class TbMoneybag(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoneybag"


class TbMoodAngry(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodAngry"


class TbMoodAnnoyed2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodAnnoyed2"


class TbMoodAnnoyed(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodAnnoyed"


class TbMoodBoy(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodBoy"


class TbMoodCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodCheck"


class TbMoodCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodCog"


class TbMoodConfuzedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodConfuzedFilled"


class TbMoodConfuzed(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodConfuzed"


class TbMoodCrazyHappy(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodCrazyHappy"


class TbMoodCry(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodCry"


class TbMoodDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodDollar"


class TbMoodEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodEdit"


class TbMoodEmptyFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodEmptyFilled"


class TbMoodEmpty(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodEmpty"


class TbMoodHappyFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodHappyFilled"


class TbMoodHappy(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodHappy"


class TbMoodHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodHeart"


class TbMoodKidFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodKidFilled"


class TbMoodKid(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodKid"


class TbMoodLookLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodLookLeft"


class TbMoodLookRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodLookRight"


class TbMoodMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodMinus"


class TbMoodNerd(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodNerd"


class TbMoodNervous(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodNervous"


class TbMoodNeutralFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodNeutralFilled"


class TbMoodNeutral(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodNeutral"


class TbMoodOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodOff"


class TbMoodPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodPin"


class TbMoodPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodPlus"


class TbMoodSad2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSad2"


class TbMoodSadDizzy(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSadDizzy"


class TbMoodSadFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSadFilled"


class TbMoodSadSquint(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSadSquint"


class TbMoodSad(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSad"


class TbMoodSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSearch"


class TbMoodShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodShare"


class TbMoodSick(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSick"


class TbMoodSilence(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSilence"


class TbMoodSing(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSing"


class TbMoodSmileBeam(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSmileBeam"


class TbMoodSmileDizzy(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSmileDizzy"


class TbMoodSmileFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSmileFilled"


class TbMoodSmile(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSmile"


class TbMoodSuprised(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodSuprised"


class TbMoodTongueWink2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodTongueWink2"


class TbMoodTongueWink(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodTongueWink"


class TbMoodTongue(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodTongue"


class TbMoodUnamused(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodUnamused"


class TbMoodUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodUp"


class TbMoodWink2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodWink2"


class TbMoodWink(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodWink"


class TbMoodWrrr(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodWrrr"


class TbMoodX(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodX"


class TbMoodXd(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoodXd"


class TbMoon2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoon2"


class TbMoonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoonFilled"


class TbMoonOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoonOff"


class TbMoonStars(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoonStars"


class TbMoon(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoon"


class TbMoped(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoped"


class TbMotorbike(rx.Component):
    library = "react-icons/tb"
    tag = "TbMotorbike"


class TbMountainOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMountainOff"


class TbMountain(rx.Component):
    library = "react-icons/tb"
    tag = "TbMountain"


class TbMouse2(rx.Component):
    library = "react-icons/tb"
    tag = "TbMouse2"


class TbMouseOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMouseOff"


class TbMouse(rx.Component):
    library = "react-icons/tb"
    tag = "TbMouse"


class TbMoustache(rx.Component):
    library = "react-icons/tb"
    tag = "TbMoustache"


class TbMovieOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMovieOff"


class TbMovie(rx.Component):
    library = "react-icons/tb"
    tag = "TbMovie"


class TbMugOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMugOff"


class TbMug(rx.Component):
    library = "react-icons/tb"
    tag = "TbMug"


class TbMultiplier05X(rx.Component):
    library = "react-icons/tb"
    tag = "TbMultiplier05X"


class TbMultiplier15X(rx.Component):
    library = "react-icons/tb"
    tag = "TbMultiplier15X"


class TbMultiplier1X(rx.Component):
    library = "react-icons/tb"
    tag = "TbMultiplier1X"


class TbMultiplier2X(rx.Component):
    library = "react-icons/tb"
    tag = "TbMultiplier2X"


class TbMushroomFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbMushroomFilled"


class TbMushroomOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMushroomOff"


class TbMushroom(rx.Component):
    library = "react-icons/tb"
    tag = "TbMushroom"


class TbMusicOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbMusicOff"


class TbMusic(rx.Component):
    library = "react-icons/tb"
    tag = "TbMusic"


class TbNavigationFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbNavigationFilled"


class TbNavigationOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbNavigationOff"


class TbNavigation(rx.Component):
    library = "react-icons/tb"
    tag = "TbNavigation"


class TbNeedleThread(rx.Component):
    library = "react-icons/tb"
    tag = "TbNeedleThread"


class TbNeedle(rx.Component):
    library = "react-icons/tb"
    tag = "TbNeedle"


class TbNetworkOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbNetworkOff"


class TbNetwork(rx.Component):
    library = "react-icons/tb"
    tag = "TbNetwork"


class TbNewSection(rx.Component):
    library = "react-icons/tb"
    tag = "TbNewSection"


class TbNewsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbNewsOff"


class TbNews(rx.Component):
    library = "react-icons/tb"
    tag = "TbNews"


class TbNfcOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbNfcOff"


class TbNfc(rx.Component):
    library = "react-icons/tb"
    tag = "TbNfc"


class TbNoCopyright(rx.Component):
    library = "react-icons/tb"
    tag = "TbNoCopyright"


class TbNoCreativeCommons(rx.Component):
    library = "react-icons/tb"
    tag = "TbNoCreativeCommons"


class TbNoDerivatives(rx.Component):
    library = "react-icons/tb"
    tag = "TbNoDerivatives"


class TbNorthStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbNorthStar"


class TbNoteOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbNoteOff"


class TbNote(rx.Component):
    library = "react-icons/tb"
    tag = "TbNote"


class TbNotebookOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbNotebookOff"


class TbNotebook(rx.Component):
    library = "react-icons/tb"
    tag = "TbNotebook"


class TbNotesOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbNotesOff"


class TbNotes(rx.Component):
    library = "react-icons/tb"
    tag = "TbNotes"


class TbNotificationOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbNotificationOff"


class TbNotification(rx.Component):
    library = "react-icons/tb"
    tag = "TbNotification"


class TbNumber0(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber0"


class TbNumber1(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber1"


class TbNumber2(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber2"


class TbNumber3(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber3"


class TbNumber4(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber4"


class TbNumber5(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber5"


class TbNumber6(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber6"


class TbNumber7(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber7"


class TbNumber8(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber8"


class TbNumber9(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber9"


class TbNumber(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumber"


class TbNumbers(rx.Component):
    library = "react-icons/tb"
    tag = "TbNumbers"


class TbNurse(rx.Component):
    library = "react-icons/tb"
    tag = "TbNurse"


class TbOctagonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbOctagonFilled"


class TbOctagonOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbOctagonOff"


class TbOctagon(rx.Component):
    library = "react-icons/tb"
    tag = "TbOctagon"


class TbOctahedronOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbOctahedronOff"


class TbOctahedronPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbOctahedronPlus"


class TbOctahedron(rx.Component):
    library = "react-icons/tb"
    tag = "TbOctahedron"


class TbOld(rx.Component):
    library = "react-icons/tb"
    tag = "TbOld"


class TbOlympicsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbOlympicsOff"


class TbOlympics(rx.Component):
    library = "react-icons/tb"
    tag = "TbOlympics"


class TbOm(rx.Component):
    library = "react-icons/tb"
    tag = "TbOm"


class TbOmega(rx.Component):
    library = "react-icons/tb"
    tag = "TbOmega"


class TbOutbound(rx.Component):
    library = "react-icons/tb"
    tag = "TbOutbound"


class TbOutlet(rx.Component):
    library = "react-icons/tb"
    tag = "TbOutlet"


class TbOvalFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbOvalFilled"


class TbOvalVerticalFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbOvalVerticalFilled"


class TbOvalVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbOvalVertical"


class TbOval(rx.Component):
    library = "react-icons/tb"
    tag = "TbOval"


class TbOverline(rx.Component):
    library = "react-icons/tb"
    tag = "TbOverline"


class TbPackageExport(rx.Component):
    library = "react-icons/tb"
    tag = "TbPackageExport"


class TbPackageImport(rx.Component):
    library = "react-icons/tb"
    tag = "TbPackageImport"


class TbPackageOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPackageOff"


class TbPackage(rx.Component):
    library = "react-icons/tb"
    tag = "TbPackage"


class TbPackages(rx.Component):
    library = "react-icons/tb"
    tag = "TbPackages"


class TbPacman(rx.Component):
    library = "react-icons/tb"
    tag = "TbPacman"


class TbPageBreak(rx.Component):
    library = "react-icons/tb"
    tag = "TbPageBreak"


class TbPaintFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPaintFilled"


class TbPaintOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPaintOff"


class TbPaint(rx.Component):
    library = "react-icons/tb"
    tag = "TbPaint"


class TbPaletteOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPaletteOff"


class TbPalette(rx.Component):
    library = "react-icons/tb"
    tag = "TbPalette"


class TbPanoramaHorizontalOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPanoramaHorizontalOff"


class TbPanoramaHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbPanoramaHorizontal"


class TbPanoramaVerticalOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPanoramaVerticalOff"


class TbPanoramaVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbPanoramaVertical"


class TbPaperBagOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPaperBagOff"


class TbPaperBag(rx.Component):
    library = "react-icons/tb"
    tag = "TbPaperBag"


class TbPaperclip(rx.Component):
    library = "react-icons/tb"
    tag = "TbPaperclip"


class TbParachuteOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbParachuteOff"


class TbParachute(rx.Component):
    library = "react-icons/tb"
    tag = "TbParachute"


class TbParenthesesOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbParenthesesOff"


class TbParentheses(rx.Component):
    library = "react-icons/tb"
    tag = "TbParentheses"


class TbParkingOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbParkingOff"


class TbParking(rx.Component):
    library = "react-icons/tb"
    tag = "TbParking"


class TbPassword(rx.Component):
    library = "react-icons/tb"
    tag = "TbPassword"


class TbPawFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPawFilled"


class TbPawOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPawOff"


class TbPaw(rx.Component):
    library = "react-icons/tb"
    tag = "TbPaw"


class TbPdf(rx.Component):
    library = "react-icons/tb"
    tag = "TbPdf"


class TbPeace(rx.Component):
    library = "react-icons/tb"
    tag = "TbPeace"


class TbPencilMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPencilMinus"


class TbPencilOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPencilOff"


class TbPencilPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPencilPlus"


class TbPencil(rx.Component):
    library = "react-icons/tb"
    tag = "TbPencil"


class TbPennant2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPennant2Filled"


class TbPennant2(rx.Component):
    library = "react-icons/tb"
    tag = "TbPennant2"


class TbPennantFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPennantFilled"


class TbPennantOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPennantOff"


class TbPennant(rx.Component):
    library = "react-icons/tb"
    tag = "TbPennant"


class TbPentagonFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPentagonFilled"


class TbPentagonOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPentagonOff"


class TbPentagon(rx.Component):
    library = "react-icons/tb"
    tag = "TbPentagon"


class TbPentagram(rx.Component):
    library = "react-icons/tb"
    tag = "TbPentagram"


class TbPepperOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPepperOff"


class TbPepper(rx.Component):
    library = "react-icons/tb"
    tag = "TbPepper"


class TbPercentage(rx.Component):
    library = "react-icons/tb"
    tag = "TbPercentage"


class TbPerfume(rx.Component):
    library = "react-icons/tb"
    tag = "TbPerfume"


class TbPerspectiveOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPerspectiveOff"


class TbPerspective(rx.Component):
    library = "react-icons/tb"
    tag = "TbPerspective"


class TbPhoneCall(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhoneCall"


class TbPhoneCalling(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhoneCalling"


class TbPhoneCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhoneCheck"


class TbPhoneFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhoneFilled"


class TbPhoneIncoming(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhoneIncoming"


class TbPhoneOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhoneOff"


class TbPhoneOutgoing(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhoneOutgoing"


class TbPhonePause(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhonePause"


class TbPhonePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhonePlus"


class TbPhoneX(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhoneX"


class TbPhone(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhone"


class TbPhotoAi(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoAi"


class TbPhotoBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoBolt"


class TbPhotoCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoCancel"


class TbPhotoCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoCheck"


class TbPhotoCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoCode"


class TbPhotoCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoCog"


class TbPhotoDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoDollar"


class TbPhotoDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoDown"


class TbPhotoEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoEdit"


class TbPhotoExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoExclamation"


class TbPhotoFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoFilled"


class TbPhotoHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoHeart"


class TbPhotoMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoMinus"


class TbPhotoOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoOff"


class TbPhotoPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoPause"


class TbPhotoPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoPin"


class TbPhotoPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoPlus"


class TbPhotoQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoQuestion"


class TbPhotoSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoSearch"


class TbPhotoSensor2(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoSensor2"


class TbPhotoSensor3(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoSensor3"


class TbPhotoSensor(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoSensor"


class TbPhotoShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoShare"


class TbPhotoShield(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoShield"


class TbPhotoStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoStar"


class TbPhotoUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoUp"


class TbPhotoX(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhotoX"


class TbPhoto(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhoto"


class TbPhysotherapist(rx.Component):
    library = "react-icons/tb"
    tag = "TbPhysotherapist"


class TbPictureInPictureOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPictureInPictureOff"


class TbPictureInPictureOn(rx.Component):
    library = "react-icons/tb"
    tag = "TbPictureInPictureOn"


class TbPictureInPictureTop(rx.Component):
    library = "react-icons/tb"
    tag = "TbPictureInPictureTop"


class TbPictureInPicture(rx.Component):
    library = "react-icons/tb"
    tag = "TbPictureInPicture"


class TbPigMoney(rx.Component):
    library = "react-icons/tb"
    tag = "TbPigMoney"


class TbPigOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPigOff"


class TbPig(rx.Component):
    library = "react-icons/tb"
    tag = "TbPig"


class TbPilcrow(rx.Component):
    library = "react-icons/tb"
    tag = "TbPilcrow"


class TbPillOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPillOff"


class TbPill(rx.Component):
    library = "react-icons/tb"
    tag = "TbPill"


class TbPills(rx.Component):
    library = "react-icons/tb"
    tag = "TbPills"


class TbPinFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPinFilled"


class TbPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbPin"


class TbPingPong(rx.Component):
    library = "react-icons/tb"
    tag = "TbPingPong"


class TbPinnedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPinnedFilled"


class TbPinnedOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPinnedOff"


class TbPinned(rx.Component):
    library = "react-icons/tb"
    tag = "TbPinned"


class TbPizzaOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPizzaOff"


class TbPizza(rx.Component):
    library = "react-icons/tb"
    tag = "TbPizza"


class TbPlaceholder(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaceholder"


class TbPlaneArrival(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaneArrival"


class TbPlaneDeparture(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaneDeparture"


class TbPlaneInflight(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaneInflight"


class TbPlaneOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaneOff"


class TbPlaneTilt(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaneTilt"


class TbPlane(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlane"


class TbPlanetOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlanetOff"


class TbPlanet(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlanet"


class TbPlant2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlant2Off"


class TbPlant2(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlant2"


class TbPlantOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlantOff"


class TbPlant(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlant"


class TbPlayBasketball(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayBasketball"


class TbPlayCardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayCardOff"


class TbPlayCard(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayCard"


class TbPlayFootball(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayFootball"


class TbPlayHandball(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayHandball"


class TbPlayVolleyball(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayVolleyball"


class TbPlayerEjectFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerEjectFilled"


class TbPlayerEject(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerEject"


class TbPlayerPauseFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerPauseFilled"


class TbPlayerPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerPause"


class TbPlayerPlayFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerPlayFilled"


class TbPlayerPlay(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerPlay"


class TbPlayerRecordFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerRecordFilled"


class TbPlayerRecord(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerRecord"


class TbPlayerSkipBackFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerSkipBackFilled"


class TbPlayerSkipBack(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerSkipBack"


class TbPlayerSkipForwardFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerSkipForwardFilled"


class TbPlayerSkipForward(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerSkipForward"


class TbPlayerStopFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerStopFilled"


class TbPlayerStop(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerStop"


class TbPlayerTrackNextFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerTrackNextFilled"


class TbPlayerTrackNext(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerTrackNext"


class TbPlayerTrackPrevFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerTrackPrevFilled"


class TbPlayerTrackPrev(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlayerTrackPrev"


class TbPlaylistAdd(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaylistAdd"


class TbPlaylistOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaylistOff"


class TbPlaylistX(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaylistX"


class TbPlaylist(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaylist"


class TbPlaystationCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaystationCircle"


class TbPlaystationSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaystationSquare"


class TbPlaystationTriangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaystationTriangle"


class TbPlaystationX(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlaystationX"


class TbPlugConnectedX(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlugConnectedX"


class TbPlugConnected(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlugConnected"


class TbPlugOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlugOff"


class TbPlugX(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlugX"


class TbPlug(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlug"


class TbPlusEqual(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlusEqual"


class TbPlusMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlusMinus"


class TbPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPlus"


class TbPng(rx.Component):
    library = "react-icons/tb"
    tag = "TbPng"


class TbPodiumOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPodiumOff"


class TbPodium(rx.Component):
    library = "react-icons/tb"
    tag = "TbPodium"


class TbPointFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointFilled"


class TbPointOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointOff"


class TbPoint(rx.Component):
    library = "react-icons/tb"
    tag = "TbPoint"


class TbPointerBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerBolt"


class TbPointerCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerCancel"


class TbPointerCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerCheck"


class TbPointerCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerCode"


class TbPointerCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerCog"


class TbPointerDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerDollar"


class TbPointerDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerDown"


class TbPointerExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerExclamation"


class TbPointerHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerHeart"


class TbPointerMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerMinus"


class TbPointerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerOff"


class TbPointerPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerPause"


class TbPointerPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerPin"


class TbPointerPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerPlus"


class TbPointerQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerQuestion"


class TbPointerSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerSearch"


class TbPointerShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerShare"


class TbPointerStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerStar"


class TbPointerUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerUp"


class TbPointerX(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointerX"


class TbPointer(rx.Component):
    library = "react-icons/tb"
    tag = "TbPointer"


class TbPokeballOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPokeballOff"


class TbPokeball(rx.Component):
    library = "react-icons/tb"
    tag = "TbPokeball"


class TbPokerChip(rx.Component):
    library = "react-icons/tb"
    tag = "TbPokerChip"


class TbPolaroidFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPolaroidFilled"


class TbPolaroid(rx.Component):
    library = "react-icons/tb"
    tag = "TbPolaroid"


class TbPolygonOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPolygonOff"


class TbPolygon(rx.Component):
    library = "react-icons/tb"
    tag = "TbPolygon"


class TbPoo(rx.Component):
    library = "react-icons/tb"
    tag = "TbPoo"


class TbPoolOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPoolOff"


class TbPool(rx.Component):
    library = "react-icons/tb"
    tag = "TbPool"


class TbPower(rx.Component):
    library = "react-icons/tb"
    tag = "TbPower"


class TbPray(rx.Component):
    library = "react-icons/tb"
    tag = "TbPray"


class TbPremiumRights(rx.Component):
    library = "react-icons/tb"
    tag = "TbPremiumRights"


class TbPrescription(rx.Component):
    library = "react-icons/tb"
    tag = "TbPrescription"


class TbPresentationAnalytics(rx.Component):
    library = "react-icons/tb"
    tag = "TbPresentationAnalytics"


class TbPresentationOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPresentationOff"


class TbPresentation(rx.Component):
    library = "react-icons/tb"
    tag = "TbPresentation"


class TbPrinterOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPrinterOff"


class TbPrinter(rx.Component):
    library = "react-icons/tb"
    tag = "TbPrinter"


class TbPrismOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPrismOff"


class TbPrismPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPrismPlus"


class TbPrism(rx.Component):
    library = "react-icons/tb"
    tag = "TbPrism"


class TbPrison(rx.Component):
    library = "react-icons/tb"
    tag = "TbPrison"


class TbProgressAlert(rx.Component):
    library = "react-icons/tb"
    tag = "TbProgressAlert"


class TbProgressBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbProgressBolt"


class TbProgressCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbProgressCheck"


class TbProgressDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbProgressDown"


class TbProgressHelp(rx.Component):
    library = "react-icons/tb"
    tag = "TbProgressHelp"


class TbProgressX(rx.Component):
    library = "react-icons/tb"
    tag = "TbProgressX"


class TbProgress(rx.Component):
    library = "react-icons/tb"
    tag = "TbProgress"


class TbPrompt(rx.Component):
    library = "react-icons/tb"
    tag = "TbPrompt"


class TbPropellerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPropellerOff"


class TbPropeller(rx.Component):
    library = "react-icons/tb"
    tag = "TbPropeller"


class TbPumpkinScary(rx.Component):
    library = "react-icons/tb"
    tag = "TbPumpkinScary"


class TbPuzzle2(rx.Component):
    library = "react-icons/tb"
    tag = "TbPuzzle2"


class TbPuzzleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbPuzzleFilled"


class TbPuzzleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPuzzleOff"


class TbPuzzle(rx.Component):
    library = "react-icons/tb"
    tag = "TbPuzzle"


class TbPyramidOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbPyramidOff"


class TbPyramidPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbPyramidPlus"


class TbPyramid(rx.Component):
    library = "react-icons/tb"
    tag = "TbPyramid"


class TbQrcodeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbQrcodeOff"


class TbQrcode(rx.Component):
    library = "react-icons/tb"
    tag = "TbQrcode"


class TbQuestionMark(rx.Component):
    library = "react-icons/tb"
    tag = "TbQuestionMark"


class TbQuoteOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbQuoteOff"


class TbQuote(rx.Component):
    library = "react-icons/tb"
    tag = "TbQuote"


class TbRadar2(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadar2"


class TbRadarOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadarOff"


class TbRadar(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadar"


class TbRadioOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadioOff"


class TbRadio(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadio"


class TbRadioactiveFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadioactiveFilled"


class TbRadioactiveOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadioactiveOff"


class TbRadioactive(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadioactive"


class TbRadiusBottomLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadiusBottomLeft"


class TbRadiusBottomRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadiusBottomRight"


class TbRadiusTopLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadiusTopLeft"


class TbRadiusTopRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbRadiusTopRight"


class TbRainbowOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRainbowOff"


class TbRainbow(rx.Component):
    library = "react-icons/tb"
    tag = "TbRainbow"


class TbRating12Plus(rx.Component):
    library = "react-icons/tb"
    tag = "TbRating12Plus"


class TbRating14Plus(rx.Component):
    library = "react-icons/tb"
    tag = "TbRating14Plus"


class TbRating16Plus(rx.Component):
    library = "react-icons/tb"
    tag = "TbRating16Plus"


class TbRating18Plus(rx.Component):
    library = "react-icons/tb"
    tag = "TbRating18Plus"


class TbRating21Plus(rx.Component):
    library = "react-icons/tb"
    tag = "TbRating21Plus"


class TbRazorElectric(rx.Component):
    library = "react-icons/tb"
    tag = "TbRazorElectric"


class TbRazor(rx.Component):
    library = "react-icons/tb"
    tag = "TbRazor"


class TbReceipt2(rx.Component):
    library = "react-icons/tb"
    tag = "TbReceipt2"


class TbReceiptOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbReceiptOff"


class TbReceiptRefund(rx.Component):
    library = "react-icons/tb"
    tag = "TbReceiptRefund"


class TbReceiptTax(rx.Component):
    library = "react-icons/tb"
    tag = "TbReceiptTax"


class TbReceipt(rx.Component):
    library = "react-icons/tb"
    tag = "TbReceipt"


class TbRecharging(rx.Component):
    library = "react-icons/tb"
    tag = "TbRecharging"


class TbRecordMailOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRecordMailOff"


class TbRecordMail(rx.Component):
    library = "react-icons/tb"
    tag = "TbRecordMail"


class TbRectangleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbRectangleFilled"


class TbRectangleVerticalFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbRectangleVerticalFilled"


class TbRectangleVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbRectangleVertical"


class TbRectangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbRectangle"


class TbRectangularPrismOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRectangularPrismOff"


class TbRectangularPrismPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbRectangularPrismPlus"


class TbRectangularPrism(rx.Component):
    library = "react-icons/tb"
    tag = "TbRectangularPrism"


class TbRecycleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRecycleOff"


class TbRecycle(rx.Component):
    library = "react-icons/tb"
    tag = "TbRecycle"


class TbRefreshAlert(rx.Component):
    library = "react-icons/tb"
    tag = "TbRefreshAlert"


class TbRefreshDot(rx.Component):
    library = "react-icons/tb"
    tag = "TbRefreshDot"


class TbRefreshOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRefreshOff"


class TbRefresh(rx.Component):
    library = "react-icons/tb"
    tag = "TbRefresh"


class TbRegexOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRegexOff"


class TbRegex(rx.Component):
    library = "react-icons/tb"
    tag = "TbRegex"


class TbRegistered(rx.Component):
    library = "react-icons/tb"
    tag = "TbRegistered"


class TbRelationManyToMany(rx.Component):
    library = "react-icons/tb"
    tag = "TbRelationManyToMany"


class TbRelationOneToMany(rx.Component):
    library = "react-icons/tb"
    tag = "TbRelationOneToMany"


class TbRelationOneToOne(rx.Component):
    library = "react-icons/tb"
    tag = "TbRelationOneToOne"


class TbReload(rx.Component):
    library = "react-icons/tb"
    tag = "TbReload"


class TbRepeatOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRepeatOff"


class TbRepeatOnce(rx.Component):
    library = "react-icons/tb"
    tag = "TbRepeatOnce"


class TbRepeat(rx.Component):
    library = "react-icons/tb"
    tag = "TbRepeat"


class TbReplaceFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbReplaceFilled"


class TbReplaceOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbReplaceOff"


class TbReplace(rx.Component):
    library = "react-icons/tb"
    tag = "TbReplace"


class TbReportAnalytics(rx.Component):
    library = "react-icons/tb"
    tag = "TbReportAnalytics"


class TbReportMedical(rx.Component):
    library = "react-icons/tb"
    tag = "TbReportMedical"


class TbReportMoney(rx.Component):
    library = "react-icons/tb"
    tag = "TbReportMoney"


class TbReportOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbReportOff"


class TbReportSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbReportSearch"


class TbReport(rx.Component):
    library = "react-icons/tb"
    tag = "TbReport"


class TbReservedLine(rx.Component):
    library = "react-icons/tb"
    tag = "TbReservedLine"


class TbResize(rx.Component):
    library = "react-icons/tb"
    tag = "TbResize"


class TbRewindBackward10(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindBackward10"


class TbRewindBackward15(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindBackward15"


class TbRewindBackward20(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindBackward20"


class TbRewindBackward30(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindBackward30"


class TbRewindBackward40(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindBackward40"


class TbRewindBackward5(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindBackward5"


class TbRewindBackward50(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindBackward50"


class TbRewindBackward60(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindBackward60"


class TbRewindForward10(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindForward10"


class TbRewindForward15(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindForward15"


class TbRewindForward20(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindForward20"


class TbRewindForward30(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindForward30"


class TbRewindForward40(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindForward40"


class TbRewindForward5(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindForward5"


class TbRewindForward50(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindForward50"


class TbRewindForward60(rx.Component):
    library = "react-icons/tb"
    tag = "TbRewindForward60"


class TbRibbonHealth(rx.Component):
    library = "react-icons/tb"
    tag = "TbRibbonHealth"


class TbRings(rx.Component):
    library = "react-icons/tb"
    tag = "TbRings"


class TbRippleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRippleOff"


class TbRipple(rx.Component):
    library = "react-icons/tb"
    tag = "TbRipple"


class TbRoadOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRoadOff"


class TbRoadSign(rx.Component):
    library = "react-icons/tb"
    tag = "TbRoadSign"


class TbRoad(rx.Component):
    library = "react-icons/tb"
    tag = "TbRoad"


class TbRobotOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRobotOff"


class TbRobot(rx.Component):
    library = "react-icons/tb"
    tag = "TbRobot"


class TbRocketOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRocketOff"


class TbRocket(rx.Component):
    library = "react-icons/tb"
    tag = "TbRocket"


class TbRollerSkating(rx.Component):
    library = "react-icons/tb"
    tag = "TbRollerSkating"


class TbRollercoasterOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRollercoasterOff"


class TbRollercoaster(rx.Component):
    library = "react-icons/tb"
    tag = "TbRollercoaster"


class TbRosetteFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteFilled"


class TbRosetteNumber0(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber0"


class TbRosetteNumber1(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber1"


class TbRosetteNumber2(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber2"


class TbRosetteNumber3(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber3"


class TbRosetteNumber4(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber4"


class TbRosetteNumber5(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber5"


class TbRosetteNumber6(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber6"


class TbRosetteNumber7(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber7"


class TbRosetteNumber8(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber8"


class TbRosetteNumber9(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosetteNumber9"


class TbRosette(rx.Component):
    library = "react-icons/tb"
    tag = "TbRosette"


class TbRotate2(rx.Component):
    library = "react-icons/tb"
    tag = "TbRotate2"


class TbRotate360(rx.Component):
    library = "react-icons/tb"
    tag = "TbRotate360"


class TbRotateClockwise2(rx.Component):
    library = "react-icons/tb"
    tag = "TbRotateClockwise2"


class TbRotateClockwise(rx.Component):
    library = "react-icons/tb"
    tag = "TbRotateClockwise"


class TbRotateDot(rx.Component):
    library = "react-icons/tb"
    tag = "TbRotateDot"


class TbRotateRectangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbRotateRectangle"


class TbRotate(rx.Component):
    library = "react-icons/tb"
    tag = "TbRotate"


class TbRoute2(rx.Component):
    library = "react-icons/tb"
    tag = "TbRoute2"


class TbRouteOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRouteOff"


class TbRoute(rx.Component):
    library = "react-icons/tb"
    tag = "TbRoute"


class TbRouterOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRouterOff"


class TbRouter(rx.Component):
    library = "react-icons/tb"
    tag = "TbRouter"


class TbRowInsertBottom(rx.Component):
    library = "react-icons/tb"
    tag = "TbRowInsertBottom"


class TbRowInsertTop(rx.Component):
    library = "react-icons/tb"
    tag = "TbRowInsertTop"


class TbRss(rx.Component):
    library = "react-icons/tb"
    tag = "TbRss"


class TbRubberStampOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRubberStampOff"


class TbRubberStamp(rx.Component):
    library = "react-icons/tb"
    tag = "TbRubberStamp"


class TbRuler2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbRuler2Off"


class TbRuler2(rx.Component):
    library = "react-icons/tb"
    tag = "TbRuler2"


class TbRuler3(rx.Component):
    library = "react-icons/tb"
    tag = "TbRuler3"


class TbRulerMeasure(rx.Component):
    library = "react-icons/tb"
    tag = "TbRulerMeasure"


class TbRulerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbRulerOff"


class TbRuler(rx.Component):
    library = "react-icons/tb"
    tag = "TbRuler"


class TbRun(rx.Component):
    library = "react-icons/tb"
    tag = "TbRun"


class TbSTurnDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbSTurnDown"


class TbSTurnLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbSTurnLeft"


class TbSTurnRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbSTurnRight"


class TbSTurnUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbSTurnUp"


class TbSailboat2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSailboat2"


class TbSailboatOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSailboatOff"


class TbSailboat(rx.Component):
    library = "react-icons/tb"
    tag = "TbSailboat"


class TbSalad(rx.Component):
    library = "react-icons/tb"
    tag = "TbSalad"


class TbSalt(rx.Component):
    library = "react-icons/tb"
    tag = "TbSalt"


class TbSatelliteOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSatelliteOff"


class TbSatellite(rx.Component):
    library = "react-icons/tb"
    tag = "TbSatellite"


class TbSausage(rx.Component):
    library = "react-icons/tb"
    tag = "TbSausage"


class TbScaleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbScaleOff"


class TbScaleOutlineOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbScaleOutlineOff"


class TbScaleOutline(rx.Component):
    library = "react-icons/tb"
    tag = "TbScaleOutline"


class TbScale(rx.Component):
    library = "react-icons/tb"
    tag = "TbScale"


class TbScanEye(rx.Component):
    library = "react-icons/tb"
    tag = "TbScanEye"


class TbScan(rx.Component):
    library = "react-icons/tb"
    tag = "TbScan"


class TbSchemaOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSchemaOff"


class TbSchema(rx.Component):
    library = "react-icons/tb"
    tag = "TbSchema"


class TbSchoolBell(rx.Component):
    library = "react-icons/tb"
    tag = "TbSchoolBell"


class TbSchoolOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSchoolOff"


class TbSchool(rx.Component):
    library = "react-icons/tb"
    tag = "TbSchool"


class TbScissorsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbScissorsOff"


class TbScissors(rx.Component):
    library = "react-icons/tb"
    tag = "TbScissors"


class TbScooterElectric(rx.Component):
    library = "react-icons/tb"
    tag = "TbScooterElectric"


class TbScooter(rx.Component):
    library = "react-icons/tb"
    tag = "TbScooter"


class TbScoreboard(rx.Component):
    library = "react-icons/tb"
    tag = "TbScoreboard"


class TbScreenShareOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbScreenShareOff"


class TbScreenShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbScreenShare"


class TbScreenshot(rx.Component):
    library = "react-icons/tb"
    tag = "TbScreenshot"


class TbScribbleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbScribbleOff"


class TbScribble(rx.Component):
    library = "react-icons/tb"
    tag = "TbScribble"


class TbScriptMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbScriptMinus"


class TbScriptPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbScriptPlus"


class TbScriptX(rx.Component):
    library = "react-icons/tb"
    tag = "TbScriptX"


class TbScript(rx.Component):
    library = "react-icons/tb"
    tag = "TbScript"


class TbScubaMaskOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbScubaMaskOff"


class TbScubaMask(rx.Component):
    library = "react-icons/tb"
    tag = "TbScubaMask"


class TbSdk(rx.Component):
    library = "react-icons/tb"
    tag = "TbSdk"


class TbSearchOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSearchOff"


class TbSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbSearch"


class TbSectionSign(rx.Component):
    library = "react-icons/tb"
    tag = "TbSectionSign"


class TbSection(rx.Component):
    library = "react-icons/tb"
    tag = "TbSection"


class TbSeedingOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSeedingOff"


class TbSeeding(rx.Component):
    library = "react-icons/tb"
    tag = "TbSeeding"


class TbSelectAll(rx.Component):
    library = "react-icons/tb"
    tag = "TbSelectAll"


class TbSelect(rx.Component):
    library = "react-icons/tb"
    tag = "TbSelect"


class TbSelector(rx.Component):
    library = "react-icons/tb"
    tag = "TbSelector"


class TbSendOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSendOff"


class TbSend(rx.Component):
    library = "react-icons/tb"
    tag = "TbSend"


class TbSeo(rx.Component):
    library = "react-icons/tb"
    tag = "TbSeo"


class TbSeparatorHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbSeparatorHorizontal"


class TbSeparatorVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbSeparatorVertical"


class TbSeparator(rx.Component):
    library = "react-icons/tb"
    tag = "TbSeparator"


class TbServer2(rx.Component):
    library = "react-icons/tb"
    tag = "TbServer2"


class TbServerBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbServerBolt"


class TbServerCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbServerCog"


class TbServerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbServerOff"


class TbServer(rx.Component):
    library = "react-icons/tb"
    tag = "TbServer"


class TbServicemark(rx.Component):
    library = "react-icons/tb"
    tag = "TbServicemark"


class TbSettings2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettings2"


class TbSettingsAutomation(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsAutomation"


class TbSettingsBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsBolt"


class TbSettingsCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsCancel"


class TbSettingsCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsCheck"


class TbSettingsCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsCode"


class TbSettingsCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsCog"


class TbSettingsDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsDollar"


class TbSettingsDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsDown"


class TbSettingsExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsExclamation"


class TbSettingsFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsFilled"


class TbSettingsHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsHeart"


class TbSettingsMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsMinus"


class TbSettingsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsOff"


class TbSettingsPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsPause"


class TbSettingsPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsPin"


class TbSettingsPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsPlus"


class TbSettingsQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsQuestion"


class TbSettingsSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsSearch"


class TbSettingsShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsShare"


class TbSettingsStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsStar"


class TbSettingsUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsUp"


class TbSettingsX(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettingsX"


class TbSettings(rx.Component):
    library = "react-icons/tb"
    tag = "TbSettings"


class TbShadowOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbShadowOff"


class TbShadow(rx.Component):
    library = "react-icons/tb"
    tag = "TbShadow"


class TbShape2(rx.Component):
    library = "react-icons/tb"
    tag = "TbShape2"


class TbShape3(rx.Component):
    library = "react-icons/tb"
    tag = "TbShape3"


class TbShapeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbShapeOff"


class TbShape(rx.Component):
    library = "react-icons/tb"
    tag = "TbShape"


class TbShare2(rx.Component):
    library = "react-icons/tb"
    tag = "TbShare2"


class TbShare3(rx.Component):
    library = "react-icons/tb"
    tag = "TbShare3"


class TbShareOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbShareOff"


class TbShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbShare"


class TbShiJumping(rx.Component):
    library = "react-icons/tb"
    tag = "TbShiJumping"


class TbShieldBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldBolt"


class TbShieldCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldCancel"


class TbShieldCheckFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldCheckFilled"


class TbShieldCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldCheck"


class TbShieldCheckeredFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldCheckeredFilled"


class TbShieldCheckered(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldCheckered"


class TbShieldChevron(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldChevron"


class TbShieldCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldCode"


class TbShieldCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldCog"


class TbShieldDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldDollar"


class TbShieldDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldDown"


class TbShieldExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldExclamation"


class TbShieldFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldFilled"


class TbShieldHalfFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldHalfFilled"


class TbShieldHalf(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldHalf"


class TbShieldHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldHeart"


class TbShieldLockFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldLockFilled"


class TbShieldLock(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldLock"


class TbShieldMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldMinus"


class TbShieldOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldOff"


class TbShieldPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldPause"


class TbShieldPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldPin"


class TbShieldPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldPlus"


class TbShieldQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldQuestion"


class TbShieldSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldSearch"


class TbShieldShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldShare"


class TbShieldStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldStar"


class TbShieldUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldUp"


class TbShieldX(rx.Component):
    library = "react-icons/tb"
    tag = "TbShieldX"


class TbShield(rx.Component):
    library = "react-icons/tb"
    tag = "TbShield"


class TbShipOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbShipOff"


class TbShip(rx.Component):
    library = "react-icons/tb"
    tag = "TbShip"


class TbShirtFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbShirtFilled"


class TbShirtOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbShirtOff"


class TbShirtSport(rx.Component):
    library = "react-icons/tb"
    tag = "TbShirtSport"


class TbShirt(rx.Component):
    library = "react-icons/tb"
    tag = "TbShirt"


class TbShoeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbShoeOff"


class TbShoe(rx.Component):
    library = "react-icons/tb"
    tag = "TbShoe"


class TbShoppingBag(rx.Component):
    library = "react-icons/tb"
    tag = "TbShoppingBag"


class TbShoppingCartDiscount(rx.Component):
    library = "react-icons/tb"
    tag = "TbShoppingCartDiscount"


class TbShoppingCartOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbShoppingCartOff"


class TbShoppingCartPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbShoppingCartPlus"


class TbShoppingCartX(rx.Component):
    library = "react-icons/tb"
    tag = "TbShoppingCartX"


class TbShoppingCart(rx.Component):
    library = "react-icons/tb"
    tag = "TbShoppingCart"


class TbShovel(rx.Component):
    library = "react-icons/tb"
    tag = "TbShovel"


class TbShredder(rx.Component):
    library = "react-icons/tb"
    tag = "TbShredder"


class TbSignLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignLeftFilled"


class TbSignLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignLeft"


class TbSignRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignRightFilled"


class TbSignRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignRight"


class TbSignal2G(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignal2G"


class TbSignal3G(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignal3G"


class TbSignal4GPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignal4GPlus"


class TbSignal4G(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignal4G"


class TbSignal5G(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignal5G"


class TbSignal6G(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignal6G"


class TbSignalE(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignalE"


class TbSignalG(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignalG"


class TbSignalHPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignalHPlus"


class TbSignalH(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignalH"


class TbSignalLte(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignalLte"


class TbSignatureOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignatureOff"


class TbSignature(rx.Component):
    library = "react-icons/tb"
    tag = "TbSignature"


class TbSitemapOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSitemapOff"


class TbSitemap(rx.Component):
    library = "react-icons/tb"
    tag = "TbSitemap"


class TbSkateboardOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSkateboardOff"


class TbSkateboard(rx.Component):
    library = "react-icons/tb"
    tag = "TbSkateboard"


class TbSkateboarding(rx.Component):
    library = "react-icons/tb"
    tag = "TbSkateboarding"


class TbSkull(rx.Component):
    library = "react-icons/tb"
    tag = "TbSkull"


class TbSlash(rx.Component):
    library = "react-icons/tb"
    tag = "TbSlash"


class TbSlashes(rx.Component):
    library = "react-icons/tb"
    tag = "TbSlashes"


class TbSleigh(rx.Component):
    library = "react-icons/tb"
    tag = "TbSleigh"


class TbSlice(rx.Component):
    library = "react-icons/tb"
    tag = "TbSlice"


class TbSlideshow(rx.Component):
    library = "react-icons/tb"
    tag = "TbSlideshow"


class TbSmartHomeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSmartHomeOff"


class TbSmartHome(rx.Component):
    library = "react-icons/tb"
    tag = "TbSmartHome"


class TbSmokingNo(rx.Component):
    library = "react-icons/tb"
    tag = "TbSmokingNo"


class TbSmoking(rx.Component):
    library = "react-icons/tb"
    tag = "TbSmoking"


class TbSnowflakeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSnowflakeOff"


class TbSnowflake(rx.Component):
    library = "react-icons/tb"
    tag = "TbSnowflake"


class TbSnowman(rx.Component):
    library = "react-icons/tb"
    tag = "TbSnowman"


class TbSoccerField(rx.Component):
    library = "react-icons/tb"
    tag = "TbSoccerField"


class TbSocialOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSocialOff"


class TbSocial(rx.Component):
    library = "react-icons/tb"
    tag = "TbSocial"


class TbSock(rx.Component):
    library = "react-icons/tb"
    tag = "TbSock"


class TbSofaOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSofaOff"


class TbSofa(rx.Component):
    library = "react-icons/tb"
    tag = "TbSofa"


class TbSolarPanel2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSolarPanel2"


class TbSolarPanel(rx.Component):
    library = "react-icons/tb"
    tag = "TbSolarPanel"


class TbSort09(rx.Component):
    library = "react-icons/tb"
    tag = "TbSort09"


class TbSort90(rx.Component):
    library = "react-icons/tb"
    tag = "TbSort90"


class TbSortAZ(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortAZ"


class TbSortAscending2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortAscending2"


class TbSortAscendingLetters(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortAscendingLetters"


class TbSortAscendingNumbers(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortAscendingNumbers"


class TbSortAscending(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortAscending"


class TbSortDescending2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortDescending2"


class TbSortDescendingLetters(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortDescendingLetters"


class TbSortDescendingNumbers(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortDescendingNumbers"


class TbSortDescending(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortDescending"


class TbSortZA(rx.Component):
    library = "react-icons/tb"
    tag = "TbSortZA"


class TbSos(rx.Component):
    library = "react-icons/tb"
    tag = "TbSos"


class TbSoupOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSoupOff"


class TbSoup(rx.Component):
    library = "react-icons/tb"
    tag = "TbSoup"


class TbSourceCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbSourceCode"


class TbSpaceOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpaceOff"


class TbSpace(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpace"


class TbSpacingHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpacingHorizontal"


class TbSpacingVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpacingVertical"


class TbSpadeFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpadeFilled"


class TbSpade(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpade"


class TbSparkles(rx.Component):
    library = "react-icons/tb"
    tag = "TbSparkles"


class TbSpeakerphone(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpeakerphone"


class TbSpeedboat(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpeedboat"


class TbSphereOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSphereOff"


class TbSpherePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpherePlus"


class TbSphere(rx.Component):
    library = "react-icons/tb"
    tag = "TbSphere"


class TbSpider(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpider"


class TbSpiralOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpiralOff"


class TbSpiral(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpiral"


class TbSportBillard(rx.Component):
    library = "react-icons/tb"
    tag = "TbSportBillard"


class TbSpray(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpray"


class TbSpyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpyOff"


class TbSpy(rx.Component):
    library = "react-icons/tb"
    tag = "TbSpy"


class TbSql(rx.Component):
    library = "react-icons/tb"
    tag = "TbSql"


class TbSquare0Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare0Filled"


class TbSquare1Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare1Filled"


class TbSquare2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare2Filled"


class TbSquare3Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare3Filled"


class TbSquare4Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare4Filled"


class TbSquare5Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare5Filled"


class TbSquare6Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare6Filled"


class TbSquare7Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare7Filled"


class TbSquare8Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare8Filled"


class TbSquare9Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare9Filled"


class TbSquareArrowDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareArrowDown"


class TbSquareArrowLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareArrowLeft"


class TbSquareArrowRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareArrowRight"


class TbSquareArrowUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareArrowUp"


class TbSquareAsterisk(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareAsterisk"


class TbSquareCheckFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareCheckFilled"


class TbSquareCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareCheck"


class TbSquareChevronDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareChevronDown"


class TbSquareChevronLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareChevronLeft"


class TbSquareChevronRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareChevronRight"


class TbSquareChevronUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareChevronUp"


class TbSquareChevronsDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareChevronsDown"


class TbSquareChevronsLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareChevronsLeft"


class TbSquareChevronsRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareChevronsRight"


class TbSquareChevronsUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareChevronsUp"


class TbSquareDot(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareDot"


class TbSquareF0Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF0Filled"


class TbSquareF0(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF0"


class TbSquareF1Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF1Filled"


class TbSquareF1(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF1"


class TbSquareF2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF2Filled"


class TbSquareF2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF2"


class TbSquareF3Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF3Filled"


class TbSquareF3(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF3"


class TbSquareF4Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF4Filled"


class TbSquareF4(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF4"


class TbSquareF5Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF5Filled"


class TbSquareF5(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF5"


class TbSquareF6Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF6Filled"


class TbSquareF6(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF6"


class TbSquareF7Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF7Filled"


class TbSquareF7(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF7"


class TbSquareF8Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF8Filled"


class TbSquareF8(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF8"


class TbSquareF9Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF9Filled"


class TbSquareF9(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareF9"


class TbSquareForbid2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareForbid2"


class TbSquareForbid(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareForbid"


class TbSquareHalf(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareHalf"


class TbSquareKey(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareKey"


class TbSquareLetterA(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterA"


class TbSquareLetterB(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterB"


class TbSquareLetterC(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterC"


class TbSquareLetterD(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterD"


class TbSquareLetterE(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterE"


class TbSquareLetterF(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterF"


class TbSquareLetterG(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterG"


class TbSquareLetterH(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterH"


class TbSquareLetterI(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterI"


class TbSquareLetterJ(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterJ"


class TbSquareLetterK(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterK"


class TbSquareLetterL(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterL"


class TbSquareLetterM(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterM"


class TbSquareLetterN(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterN"


class TbSquareLetterO(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterO"


class TbSquareLetterP(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterP"


class TbSquareLetterQ(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterQ"


class TbSquareLetterR(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterR"


class TbSquareLetterS(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterS"


class TbSquareLetterT(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterT"


class TbSquareLetterU(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterU"


class TbSquareLetterV(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterV"


class TbSquareLetterW(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterW"


class TbSquareLetterX(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterX"


class TbSquareLetterY(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterY"


class TbSquareLetterZ(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareLetterZ"


class TbSquareMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareMinus"


class TbSquareNumber0(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber0"


class TbSquareNumber1(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber1"


class TbSquareNumber2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber2"


class TbSquareNumber3(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber3"


class TbSquareNumber4(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber4"


class TbSquareNumber5(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber5"


class TbSquareNumber6(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber6"


class TbSquareNumber7(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber7"


class TbSquareNumber8(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber8"


class TbSquareNumber9(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareNumber9"


class TbSquareOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareOff"


class TbSquarePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquarePlus"


class TbSquareRoot2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoot2"


class TbSquareRoot(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoot"


class TbSquareRotatedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRotatedFilled"


class TbSquareRotatedForbid2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRotatedForbid2"


class TbSquareRotatedForbid(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRotatedForbid"


class TbSquareRotatedOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRotatedOff"


class TbSquareRotated(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRotated"


class TbSquareRoundedArrowDownFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedArrowDownFilled"


class TbSquareRoundedArrowDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedArrowDown"


class TbSquareRoundedArrowLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedArrowLeftFilled"


class TbSquareRoundedArrowLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedArrowLeft"


class TbSquareRoundedArrowRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedArrowRightFilled"


class TbSquareRoundedArrowRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedArrowRight"


class TbSquareRoundedArrowUpFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedArrowUpFilled"


class TbSquareRoundedArrowUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedArrowUp"


class TbSquareRoundedCheckFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedCheckFilled"


class TbSquareRoundedCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedCheck"


class TbSquareRoundedChevronDownFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronDownFilled"


class TbSquareRoundedChevronDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronDown"


class TbSquareRoundedChevronLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronLeftFilled"


class TbSquareRoundedChevronLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronLeft"


class TbSquareRoundedChevronRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronRightFilled"


class TbSquareRoundedChevronRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronRight"


class TbSquareRoundedChevronUpFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronUpFilled"


class TbSquareRoundedChevronUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronUp"


class TbSquareRoundedChevronsDownFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronsDownFilled"


class TbSquareRoundedChevronsDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronsDown"


class TbSquareRoundedChevronsLeftFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronsLeftFilled"


class TbSquareRoundedChevronsLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronsLeft"


class TbSquareRoundedChevronsRightFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronsRightFilled"


class TbSquareRoundedChevronsRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronsRight"


class TbSquareRoundedChevronsUpFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronsUpFilled"


class TbSquareRoundedChevronsUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedChevronsUp"


class TbSquareRoundedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedFilled"


class TbSquareRoundedLetterA(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterA"


class TbSquareRoundedLetterB(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterB"


class TbSquareRoundedLetterC(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterC"


class TbSquareRoundedLetterD(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterD"


class TbSquareRoundedLetterE(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterE"


class TbSquareRoundedLetterF(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterF"


class TbSquareRoundedLetterG(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterG"


class TbSquareRoundedLetterH(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterH"


class TbSquareRoundedLetterI(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterI"


class TbSquareRoundedLetterJ(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterJ"


class TbSquareRoundedLetterK(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterK"


class TbSquareRoundedLetterL(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterL"


class TbSquareRoundedLetterM(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterM"


class TbSquareRoundedLetterN(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterN"


class TbSquareRoundedLetterO(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterO"


class TbSquareRoundedLetterP(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterP"


class TbSquareRoundedLetterQ(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterQ"


class TbSquareRoundedLetterR(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterR"


class TbSquareRoundedLetterS(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterS"


class TbSquareRoundedLetterT(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterT"


class TbSquareRoundedLetterU(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterU"


class TbSquareRoundedLetterV(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterV"


class TbSquareRoundedLetterW(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterW"


class TbSquareRoundedLetterX(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterX"


class TbSquareRoundedLetterY(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterY"


class TbSquareRoundedLetterZ(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedLetterZ"


class TbSquareRoundedMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedMinus"


class TbSquareRoundedNumber0Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber0Filled"


class TbSquareRoundedNumber0(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber0"


class TbSquareRoundedNumber1Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber1Filled"


class TbSquareRoundedNumber1(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber1"


class TbSquareRoundedNumber2Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber2Filled"


class TbSquareRoundedNumber2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber2"


class TbSquareRoundedNumber3Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber3Filled"


class TbSquareRoundedNumber3(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber3"


class TbSquareRoundedNumber4Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber4Filled"


class TbSquareRoundedNumber4(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber4"


class TbSquareRoundedNumber5Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber5Filled"


class TbSquareRoundedNumber5(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber5"


class TbSquareRoundedNumber6Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber6Filled"


class TbSquareRoundedNumber6(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber6"


class TbSquareRoundedNumber7Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber7Filled"


class TbSquareRoundedNumber7(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber7"


class TbSquareRoundedNumber8Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber8Filled"


class TbSquareRoundedNumber8(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber8"


class TbSquareRoundedNumber9Filled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber9Filled"


class TbSquareRoundedNumber9(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedNumber9"


class TbSquareRoundedPlusFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedPlusFilled"


class TbSquareRoundedPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedPlus"


class TbSquareRoundedXFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedXFilled"


class TbSquareRoundedX(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRoundedX"


class TbSquareRounded(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareRounded"


class TbSquareToggleHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareToggleHorizontal"


class TbSquareToggle(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareToggle"


class TbSquareX(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquareX"


class TbSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquare"


class TbSquaresDiagonal(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquaresDiagonal"


class TbSquaresFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSquaresFilled"


class TbStack2(rx.Component):
    library = "react-icons/tb"
    tag = "TbStack2"


class TbStack3(rx.Component):
    library = "react-icons/tb"
    tag = "TbStack3"


class TbStackPop(rx.Component):
    library = "react-icons/tb"
    tag = "TbStackPop"


class TbStackPush(rx.Component):
    library = "react-icons/tb"
    tag = "TbStackPush"


class TbStack(rx.Component):
    library = "react-icons/tb"
    tag = "TbStack"


class TbStairsDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbStairsDown"


class TbStairsUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbStairsUp"


class TbStairs(rx.Component):
    library = "react-icons/tb"
    tag = "TbStairs"


class TbStarFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbStarFilled"


class TbStarHalfFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbStarHalfFilled"


class TbStarHalf(rx.Component):
    library = "react-icons/tb"
    tag = "TbStarHalf"


class TbStarOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbStarOff"


class TbStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbStar"


class TbStarsFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbStarsFilled"


class TbStarsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbStarsOff"


class TbStars(rx.Component):
    library = "react-icons/tb"
    tag = "TbStars"


class TbStatusChange(rx.Component):
    library = "react-icons/tb"
    tag = "TbStatusChange"


class TbSteam(rx.Component):
    library = "react-icons/tb"
    tag = "TbSteam"


class TbSteeringWheelOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSteeringWheelOff"


class TbSteeringWheel(rx.Component):
    library = "react-icons/tb"
    tag = "TbSteeringWheel"


class TbStepInto(rx.Component):
    library = "react-icons/tb"
    tag = "TbStepInto"


class TbStepOut(rx.Component):
    library = "react-icons/tb"
    tag = "TbStepOut"


class TbStereoGlasses(rx.Component):
    library = "react-icons/tb"
    tag = "TbStereoGlasses"


class TbStethoscopeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbStethoscopeOff"


class TbStethoscope(rx.Component):
    library = "react-icons/tb"
    tag = "TbStethoscope"


class TbSticker(rx.Component):
    library = "react-icons/tb"
    tag = "TbSticker"


class TbStormOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbStormOff"


class TbStorm(rx.Component):
    library = "react-icons/tb"
    tag = "TbStorm"


class TbStretching2(rx.Component):
    library = "react-icons/tb"
    tag = "TbStretching2"


class TbStretching(rx.Component):
    library = "react-icons/tb"
    tag = "TbStretching"


class TbStrikethrough(rx.Component):
    library = "react-icons/tb"
    tag = "TbStrikethrough"


class TbSubmarine(rx.Component):
    library = "react-icons/tb"
    tag = "TbSubmarine"


class TbSubscript(rx.Component):
    library = "react-icons/tb"
    tag = "TbSubscript"


class TbSubtask(rx.Component):
    library = "react-icons/tb"
    tag = "TbSubtask"


class TbSumOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSumOff"


class TbSum(rx.Component):
    library = "react-icons/tb"
    tag = "TbSum"


class TbSunFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunFilled"


class TbSunHigh(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunHigh"


class TbSunLow(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunLow"


class TbSunMoon(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunMoon"


class TbSunOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunOff"


class TbSunWind(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunWind"


class TbSun(rx.Component):
    library = "react-icons/tb"
    tag = "TbSun"


class TbSunglasses(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunglasses"


class TbSunrise(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunrise"


class TbSunset2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunset2"


class TbSunset(rx.Component):
    library = "react-icons/tb"
    tag = "TbSunset"


class TbSuperscript(rx.Component):
    library = "react-icons/tb"
    tag = "TbSuperscript"


class TbSvg(rx.Component):
    library = "react-icons/tb"
    tag = "TbSvg"


class TbSwimming(rx.Component):
    library = "react-icons/tb"
    tag = "TbSwimming"


class TbSwipe(rx.Component):
    library = "react-icons/tb"
    tag = "TbSwipe"


class TbSwitch2(rx.Component):
    library = "react-icons/tb"
    tag = "TbSwitch2"


class TbSwitch3(rx.Component):
    library = "react-icons/tb"
    tag = "TbSwitch3"


class TbSwitchHorizontal(rx.Component):
    library = "react-icons/tb"
    tag = "TbSwitchHorizontal"


class TbSwitchVertical(rx.Component):
    library = "react-icons/tb"
    tag = "TbSwitchVertical"


class TbSwitch(rx.Component):
    library = "react-icons/tb"
    tag = "TbSwitch"


class TbSwordOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbSwordOff"


class TbSword(rx.Component):
    library = "react-icons/tb"
    tag = "TbSword"


class TbSwords(rx.Component):
    library = "react-icons/tb"
    tag = "TbSwords"


class TbTableAlias(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableAlias"


class TbTableDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableDown"


class TbTableExport(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableExport"


class TbTableFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableFilled"


class TbTableHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableHeart"


class TbTableImport(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableImport"


class TbTableMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableMinus"


class TbTableOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableOff"


class TbTableOptions(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableOptions"


class TbTablePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbTablePlus"


class TbTableShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableShare"


class TbTableShortcut(rx.Component):
    library = "react-icons/tb"
    tag = "TbTableShortcut"


class TbTable(rx.Component):
    library = "react-icons/tb"
    tag = "TbTable"


class TbTagOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTagOff"


class TbTag(rx.Component):
    library = "react-icons/tb"
    tag = "TbTag"


class TbTagsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTagsOff"


class TbTags(rx.Component):
    library = "react-icons/tb"
    tag = "TbTags"


class TbTallymark1(rx.Component):
    library = "react-icons/tb"
    tag = "TbTallymark1"


class TbTallymark2(rx.Component):
    library = "react-icons/tb"
    tag = "TbTallymark2"


class TbTallymark3(rx.Component):
    library = "react-icons/tb"
    tag = "TbTallymark3"


class TbTallymark4(rx.Component):
    library = "react-icons/tb"
    tag = "TbTallymark4"


class TbTallymarks(rx.Component):
    library = "react-icons/tb"
    tag = "TbTallymarks"


class TbTank(rx.Component):
    library = "react-icons/tb"
    tag = "TbTank"


class TbTargetArrow(rx.Component):
    library = "react-icons/tb"
    tag = "TbTargetArrow"


class TbTargetOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTargetOff"


class TbTarget(rx.Component):
    library = "react-icons/tb"
    tag = "TbTarget"


class TbTeapot(rx.Component):
    library = "react-icons/tb"
    tag = "TbTeapot"


class TbTelescopeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTelescopeOff"


class TbTelescope(rx.Component):
    library = "react-icons/tb"
    tag = "TbTelescope"


class TbTemperatureCelsius(rx.Component):
    library = "react-icons/tb"
    tag = "TbTemperatureCelsius"


class TbTemperatureFahrenheit(rx.Component):
    library = "react-icons/tb"
    tag = "TbTemperatureFahrenheit"


class TbTemperatureMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbTemperatureMinus"


class TbTemperatureOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTemperatureOff"


class TbTemperaturePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbTemperaturePlus"


class TbTemperature(rx.Component):
    library = "react-icons/tb"
    tag = "TbTemperature"


class TbTemplateOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTemplateOff"


class TbTemplate(rx.Component):
    library = "react-icons/tb"
    tag = "TbTemplate"


class TbTentOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTentOff"


class TbTent(rx.Component):
    library = "react-icons/tb"
    tag = "TbTent"


class TbTerminal2(rx.Component):
    library = "react-icons/tb"
    tag = "TbTerminal2"


class TbTerminal(rx.Component):
    library = "react-icons/tb"
    tag = "TbTerminal"


class TbTestPipe2(rx.Component):
    library = "react-icons/tb"
    tag = "TbTestPipe2"


class TbTestPipeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTestPipeOff"


class TbTestPipe(rx.Component):
    library = "react-icons/tb"
    tag = "TbTestPipe"


class TbTex(rx.Component):
    library = "react-icons/tb"
    tag = "TbTex"


class TbTextCaption(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextCaption"


class TbTextColor(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextColor"


class TbTextDecrease(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextDecrease"


class TbTextDirectionLtr(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextDirectionLtr"


class TbTextDirectionRtl(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextDirectionRtl"


class TbTextIncrease(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextIncrease"


class TbTextOrientation(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextOrientation"


class TbTextPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextPlus"


class TbTextRecognition(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextRecognition"


class TbTextResize(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextResize"


class TbTextSize(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextSize"


class TbTextSpellcheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextSpellcheck"


class TbTextWrapDisabled(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextWrapDisabled"


class TbTextWrap(rx.Component):
    library = "react-icons/tb"
    tag = "TbTextWrap"


class TbTexture(rx.Component):
    library = "react-icons/tb"
    tag = "TbTexture"


class TbTheater(rx.Component):
    library = "react-icons/tb"
    tag = "TbTheater"


class TbThermometer(rx.Component):
    library = "react-icons/tb"
    tag = "TbThermometer"


class TbThumbDownFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbThumbDownFilled"


class TbThumbDownOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbThumbDownOff"


class TbThumbDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbThumbDown"


class TbThumbUpFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbThumbUpFilled"


class TbThumbUpOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbThumbUpOff"


class TbThumbUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbThumbUp"


class TbTicTac(rx.Component):
    library = "react-icons/tb"
    tag = "TbTicTac"


class TbTicketOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTicketOff"


class TbTicket(rx.Component):
    library = "react-icons/tb"
    tag = "TbTicket"


class TbTie(rx.Component):
    library = "react-icons/tb"
    tag = "TbTie"


class TbTilde(rx.Component):
    library = "react-icons/tb"
    tag = "TbTilde"


class TbTiltShiftOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTiltShiftOff"


class TbTiltShift(rx.Component):
    library = "react-icons/tb"
    tag = "TbTiltShift"


class TbTimelineEventExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbTimelineEventExclamation"


class TbTimelineEventMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbTimelineEventMinus"


class TbTimelineEventPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbTimelineEventPlus"


class TbTimelineEventText(rx.Component):
    library = "react-icons/tb"
    tag = "TbTimelineEventText"


class TbTimelineEventX(rx.Component):
    library = "react-icons/tb"
    tag = "TbTimelineEventX"


class TbTimelineEvent(rx.Component):
    library = "react-icons/tb"
    tag = "TbTimelineEvent"


class TbTimeline(rx.Component):
    library = "react-icons/tb"
    tag = "TbTimeline"


class TbTir(rx.Component):
    library = "react-icons/tb"
    tag = "TbTir"


class TbToggleLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbToggleLeft"


class TbToggleRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbToggleRight"


class TbToiletPaperOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbToiletPaperOff"


class TbToiletPaper(rx.Component):
    library = "react-icons/tb"
    tag = "TbToiletPaper"


class TbToml(rx.Component):
    library = "react-icons/tb"
    tag = "TbToml"


class TbTool(rx.Component):
    library = "react-icons/tb"
    tag = "TbTool"


class TbToolsKitchen2Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbToolsKitchen2Off"


class TbToolsKitchen2(rx.Component):
    library = "react-icons/tb"
    tag = "TbToolsKitchen2"


class TbToolsKitchenOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbToolsKitchenOff"


class TbToolsKitchen(rx.Component):
    library = "react-icons/tb"
    tag = "TbToolsKitchen"


class TbToolsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbToolsOff"


class TbTools(rx.Component):
    library = "react-icons/tb"
    tag = "TbTools"


class TbTooltip(rx.Component):
    library = "react-icons/tb"
    tag = "TbTooltip"


class TbTopologyBus(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyBus"


class TbTopologyComplex(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyComplex"


class TbTopologyFullHierarchy(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyFullHierarchy"


class TbTopologyFull(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyFull"


class TbTopologyRing2(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyRing2"


class TbTopologyRing3(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyRing3"


class TbTopologyRing(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyRing"


class TbTopologyStar2(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyStar2"


class TbTopologyStar3(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyStar3"


class TbTopologyStarRing2(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyStarRing2"


class TbTopologyStarRing3(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyStarRing3"


class TbTopologyStarRing(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyStarRing"


class TbTopologyStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbTopologyStar"


class TbTorii(rx.Component):
    library = "react-icons/tb"
    tag = "TbTorii"


class TbTornado(rx.Component):
    library = "react-icons/tb"
    tag = "TbTornado"


class TbTournament(rx.Component):
    library = "react-icons/tb"
    tag = "TbTournament"


class TbTowerOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTowerOff"


class TbTower(rx.Component):
    library = "react-icons/tb"
    tag = "TbTower"


class TbTrack(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrack"


class TbTractor(rx.Component):
    library = "react-icons/tb"
    tag = "TbTractor"


class TbTrademark(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrademark"


class TbTrafficConeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrafficConeOff"


class TbTrafficCone(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrafficCone"


class TbTrafficLightsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrafficLightsOff"


class TbTrafficLights(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrafficLights"


class TbTrain(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrain"


class TbTransferIn(rx.Component):
    library = "react-icons/tb"
    tag = "TbTransferIn"


class TbTransferOut(rx.Component):
    library = "react-icons/tb"
    tag = "TbTransferOut"


class TbTransformFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbTransformFilled"


class TbTransform(rx.Component):
    library = "react-icons/tb"
    tag = "TbTransform"


class TbTransitionBottom(rx.Component):
    library = "react-icons/tb"
    tag = "TbTransitionBottom"


class TbTransitionLeft(rx.Component):
    library = "react-icons/tb"
    tag = "TbTransitionLeft"


class TbTransitionRight(rx.Component):
    library = "react-icons/tb"
    tag = "TbTransitionRight"


class TbTransitionTop(rx.Component):
    library = "react-icons/tb"
    tag = "TbTransitionTop"


class TbTrashFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrashFilled"


class TbTrashOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrashOff"


class TbTrashXFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrashXFilled"


class TbTrashX(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrashX"


class TbTrash(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrash"


class TbTreadmill(rx.Component):
    library = "react-icons/tb"
    tag = "TbTreadmill"


class TbTree(rx.Component):
    library = "react-icons/tb"
    tag = "TbTree"


class TbTrees(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrees"


class TbTrekking(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrekking"


class TbTrendingDown2(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrendingDown2"


class TbTrendingDown3(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrendingDown3"


class TbTrendingDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrendingDown"


class TbTrendingUp2(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrendingUp2"


class TbTrendingUp3(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrendingUp3"


class TbTrendingUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrendingUp"


class TbTriangleFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbTriangleFilled"


class TbTriangleInvertedFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbTriangleInvertedFilled"


class TbTriangleInverted(rx.Component):
    library = "react-icons/tb"
    tag = "TbTriangleInverted"


class TbTriangleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTriangleOff"


class TbTriangleSquareCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbTriangleSquareCircle"


class TbTriangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbTriangle"


class TbTriangles(rx.Component):
    library = "react-icons/tb"
    tag = "TbTriangles"


class TbTrident(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrident"


class TbTrolley(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrolley"


class TbTrophyFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrophyFilled"


class TbTrophyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrophyOff"


class TbTrophy(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrophy"


class TbTrowel(rx.Component):
    library = "react-icons/tb"
    tag = "TbTrowel"


class TbTruckDelivery(rx.Component):
    library = "react-icons/tb"
    tag = "TbTruckDelivery"


class TbTruckLoading(rx.Component):
    library = "react-icons/tb"
    tag = "TbTruckLoading"


class TbTruckOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTruckOff"


class TbTruckReturn(rx.Component):
    library = "react-icons/tb"
    tag = "TbTruckReturn"


class TbTruck(rx.Component):
    library = "react-icons/tb"
    tag = "TbTruck"


class TbTxt(rx.Component):
    library = "react-icons/tb"
    tag = "TbTxt"


class TbTypographyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbTypographyOff"


class TbTypography(rx.Component):
    library = "react-icons/tb"
    tag = "TbTypography"


class TbUfoOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbUfoOff"


class TbUfo(rx.Component):
    library = "react-icons/tb"
    tag = "TbUfo"


class TbUmbrellaFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbUmbrellaFilled"


class TbUmbrellaOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbUmbrellaOff"


class TbUmbrella(rx.Component):
    library = "react-icons/tb"
    tag = "TbUmbrella"


class TbUnderline(rx.Component):
    library = "react-icons/tb"
    tag = "TbUnderline"


class TbUnlink(rx.Component):
    library = "react-icons/tb"
    tag = "TbUnlink"


class TbUpload(rx.Component):
    library = "react-icons/tb"
    tag = "TbUpload"


class TbUrgent(rx.Component):
    library = "react-icons/tb"
    tag = "TbUrgent"


class TbUsb(rx.Component):
    library = "react-icons/tb"
    tag = "TbUsb"


class TbUserBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserBolt"


class TbUserCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserCancel"


class TbUserCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserCheck"


class TbUserCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserCircle"


class TbUserCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserCode"


class TbUserCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserCog"


class TbUserDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserDollar"


class TbUserDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserDown"


class TbUserEdit(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserEdit"


class TbUserExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserExclamation"


class TbUserHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserHeart"


class TbUserMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserMinus"


class TbUserOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserOff"


class TbUserPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserPause"


class TbUserPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserPin"


class TbUserPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserPlus"


class TbUserQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserQuestion"


class TbUserSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserSearch"


class TbUserShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserShare"


class TbUserShield(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserShield"


class TbUserStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserStar"


class TbUserUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserUp"


class TbUserX(rx.Component):
    library = "react-icons/tb"
    tag = "TbUserX"


class TbUser(rx.Component):
    library = "react-icons/tb"
    tag = "TbUser"


class TbUsersGroup(rx.Component):
    library = "react-icons/tb"
    tag = "TbUsersGroup"


class TbUsersMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbUsersMinus"


class TbUsersPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbUsersPlus"


class TbUsers(rx.Component):
    library = "react-icons/tb"
    tag = "TbUsers"


class TbUvIndex(rx.Component):
    library = "react-icons/tb"
    tag = "TbUvIndex"


class TbUxCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbUxCircle"


class TbVaccineBottleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVaccineBottleOff"


class TbVaccineBottle(rx.Component):
    library = "react-icons/tb"
    tag = "TbVaccineBottle"


class TbVaccineOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVaccineOff"


class TbVaccine(rx.Component):
    library = "react-icons/tb"
    tag = "TbVaccine"


class TbVacuumCleaner(rx.Component):
    library = "react-icons/tb"
    tag = "TbVacuumCleaner"


class TbVariableMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbVariableMinus"


class TbVariableOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVariableOff"


class TbVariablePlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbVariablePlus"


class TbVariable(rx.Component):
    library = "react-icons/tb"
    tag = "TbVariable"


class TbVectorBezier2(rx.Component):
    library = "react-icons/tb"
    tag = "TbVectorBezier2"


class TbVectorBezierArc(rx.Component):
    library = "react-icons/tb"
    tag = "TbVectorBezierArc"


class TbVectorBezierCircle(rx.Component):
    library = "react-icons/tb"
    tag = "TbVectorBezierCircle"


class TbVectorBezier(rx.Component):
    library = "react-icons/tb"
    tag = "TbVectorBezier"


class TbVectorOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVectorOff"


class TbVectorSpline(rx.Component):
    library = "react-icons/tb"
    tag = "TbVectorSpline"


class TbVectorTriangleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVectorTriangleOff"


class TbVectorTriangle(rx.Component):
    library = "react-icons/tb"
    tag = "TbVectorTriangle"


class TbVector(rx.Component):
    library = "react-icons/tb"
    tag = "TbVector"


class TbVenus(rx.Component):
    library = "react-icons/tb"
    tag = "TbVenus"


class TbVersionsFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbVersionsFilled"


class TbVersionsOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVersionsOff"


class TbVersions(rx.Component):
    library = "react-icons/tb"
    tag = "TbVersions"


class TbVideoMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbVideoMinus"


class TbVideoOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVideoOff"


class TbVideoPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbVideoPlus"


class TbVideo(rx.Component):
    library = "react-icons/tb"
    tag = "TbVideo"


class TbView360Off(rx.Component):
    library = "react-icons/tb"
    tag = "TbView360Off"


class TbView360(rx.Component):
    library = "react-icons/tb"
    tag = "TbView360"


class TbViewfinderOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbViewfinderOff"


class TbViewfinder(rx.Component):
    library = "react-icons/tb"
    tag = "TbViewfinder"


class TbViewportNarrow(rx.Component):
    library = "react-icons/tb"
    tag = "TbViewportNarrow"


class TbViewportWide(rx.Component):
    library = "react-icons/tb"
    tag = "TbViewportWide"


class TbVinyl(rx.Component):
    library = "react-icons/tb"
    tag = "TbVinyl"


class TbVipOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVipOff"


class TbVip(rx.Component):
    library = "react-icons/tb"
    tag = "TbVip"


class TbVirusOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVirusOff"


class TbVirusSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbVirusSearch"


class TbVirus(rx.Component):
    library = "react-icons/tb"
    tag = "TbVirus"


class TbVocabularyOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVocabularyOff"


class TbVocabulary(rx.Component):
    library = "react-icons/tb"
    tag = "TbVocabulary"


class TbVolcano(rx.Component):
    library = "react-icons/tb"
    tag = "TbVolcano"


class TbVolume2(rx.Component):
    library = "react-icons/tb"
    tag = "TbVolume2"


class TbVolume3(rx.Component):
    library = "react-icons/tb"
    tag = "TbVolume3"


class TbVolumeOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbVolumeOff"


class TbVolume(rx.Component):
    library = "react-icons/tb"
    tag = "TbVolume"


class TbWalk(rx.Component):
    library = "react-icons/tb"
    tag = "TbWalk"


class TbWallOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWallOff"


class TbWall(rx.Component):
    library = "react-icons/tb"
    tag = "TbWall"


class TbWalletOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWalletOff"


class TbWallet(rx.Component):
    library = "react-icons/tb"
    tag = "TbWallet"


class TbWallpaperOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWallpaperOff"


class TbWallpaper(rx.Component):
    library = "react-icons/tb"
    tag = "TbWallpaper"


class TbWandOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWandOff"


class TbWand(rx.Component):
    library = "react-icons/tb"
    tag = "TbWand"


class TbWashDry1(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDry1"


class TbWashDry2(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDry2"


class TbWashDry3(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDry3"


class TbWashDryA(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryA"


class TbWashDryDip(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryDip"


class TbWashDryF(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryF"


class TbWashDryFlat(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryFlat"


class TbWashDryHang(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryHang"


class TbWashDryOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryOff"


class TbWashDryP(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryP"


class TbWashDryShade(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryShade"


class TbWashDryW(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryW"


class TbWashDry(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDry"


class TbWashDrycleanOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDrycleanOff"


class TbWashDryclean(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashDryclean"


class TbWashEco(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashEco"


class TbWashGentle(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashGentle"


class TbWashHand(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashHand"


class TbWashMachine(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashMachine"


class TbWashOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashOff"


class TbWashPress(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashPress"


class TbWashTemperature1(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashTemperature1"


class TbWashTemperature2(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashTemperature2"


class TbWashTemperature3(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashTemperature3"


class TbWashTemperature4(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashTemperature4"


class TbWashTemperature5(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashTemperature5"


class TbWashTemperature6(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashTemperature6"


class TbWashTumbleDry(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashTumbleDry"


class TbWashTumbleOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWashTumbleOff"


class TbWash(rx.Component):
    library = "react-icons/tb"
    tag = "TbWash"


class TbWaterpolo(rx.Component):
    library = "react-icons/tb"
    tag = "TbWaterpolo"


class TbWaveSawTool(rx.Component):
    library = "react-icons/tb"
    tag = "TbWaveSawTool"


class TbWaveSine(rx.Component):
    library = "react-icons/tb"
    tag = "TbWaveSine"


class TbWaveSquare(rx.Component):
    library = "react-icons/tb"
    tag = "TbWaveSquare"


class TbWebhookOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWebhookOff"


class TbWebhook(rx.Component):
    library = "react-icons/tb"
    tag = "TbWebhook"


class TbWeight(rx.Component):
    library = "react-icons/tb"
    tag = "TbWeight"


class TbWheelchairOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWheelchairOff"


class TbWheelchair(rx.Component):
    library = "react-icons/tb"
    tag = "TbWheelchair"


class TbWhirl(rx.Component):
    library = "react-icons/tb"
    tag = "TbWhirl"


class TbWifi0(rx.Component):
    library = "react-icons/tb"
    tag = "TbWifi0"


class TbWifi1(rx.Component):
    library = "react-icons/tb"
    tag = "TbWifi1"


class TbWifi2(rx.Component):
    library = "react-icons/tb"
    tag = "TbWifi2"


class TbWifiOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWifiOff"


class TbWifi(rx.Component):
    library = "react-icons/tb"
    tag = "TbWifi"


class TbWindOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWindOff"


class TbWind(rx.Component):
    library = "react-icons/tb"
    tag = "TbWind"


class TbWindmillFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbWindmillFilled"


class TbWindmillOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWindmillOff"


class TbWindmill(rx.Component):
    library = "react-icons/tb"
    tag = "TbWindmill"


class TbWindowMaximize(rx.Component):
    library = "react-icons/tb"
    tag = "TbWindowMaximize"


class TbWindowMinimize(rx.Component):
    library = "react-icons/tb"
    tag = "TbWindowMinimize"


class TbWindowOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWindowOff"


class TbWindow(rx.Component):
    library = "react-icons/tb"
    tag = "TbWindow"


class TbWindsock(rx.Component):
    library = "react-icons/tb"
    tag = "TbWindsock"


class TbWiperWash(rx.Component):
    library = "react-icons/tb"
    tag = "TbWiperWash"


class TbWiper(rx.Component):
    library = "react-icons/tb"
    tag = "TbWiper"


class TbWoman(rx.Component):
    library = "react-icons/tb"
    tag = "TbWoman"


class TbWood(rx.Component):
    library = "react-icons/tb"
    tag = "TbWood"


class TbWorldBolt(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldBolt"


class TbWorldCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldCancel"


class TbWorldCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldCheck"


class TbWorldCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldCode"


class TbWorldCog(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldCog"


class TbWorldDollar(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldDollar"


class TbWorldDown(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldDown"


class TbWorldDownload(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldDownload"


class TbWorldExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldExclamation"


class TbWorldHeart(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldHeart"


class TbWorldLatitude(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldLatitude"


class TbWorldLongitude(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldLongitude"


class TbWorldMinus(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldMinus"


class TbWorldOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldOff"


class TbWorldPause(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldPause"


class TbWorldPin(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldPin"


class TbWorldPlus(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldPlus"


class TbWorldQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldQuestion"


class TbWorldSearch(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldSearch"


class TbWorldShare(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldShare"


class TbWorldStar(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldStar"


class TbWorldUp(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldUp"


class TbWorldUpload(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldUpload"


class TbWorldWww(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldWww"


class TbWorldX(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorldX"


class TbWorld(rx.Component):
    library = "react-icons/tb"
    tag = "TbWorld"


class TbWreckingBall(rx.Component):
    library = "react-icons/tb"
    tag = "TbWreckingBall"


class TbWritingOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWritingOff"


class TbWritingSignOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbWritingSignOff"


class TbWritingSign(rx.Component):
    library = "react-icons/tb"
    tag = "TbWritingSign"


class TbWriting(rx.Component):
    library = "react-icons/tb"
    tag = "TbWriting"


class TbX(rx.Component):
    library = "react-icons/tb"
    tag = "TbX"


class TbXboxA(rx.Component):
    library = "react-icons/tb"
    tag = "TbXboxA"


class TbXboxB(rx.Component):
    library = "react-icons/tb"
    tag = "TbXboxB"


class TbXboxX(rx.Component):
    library = "react-icons/tb"
    tag = "TbXboxX"


class TbXboxY(rx.Component):
    library = "react-icons/tb"
    tag = "TbXboxY"


class TbXd(rx.Component):
    library = "react-icons/tb"
    tag = "TbXd"


class TbYinYangFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbYinYangFilled"


class TbYinYang(rx.Component):
    library = "react-icons/tb"
    tag = "TbYinYang"


class TbYoga(rx.Component):
    library = "react-icons/tb"
    tag = "TbYoga"


class TbZeppelinOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbZeppelinOff"


class TbZeppelin(rx.Component):
    library = "react-icons/tb"
    tag = "TbZeppelin"


class TbZip(rx.Component):
    library = "react-icons/tb"
    tag = "TbZip"


class TbZodiacAquarius(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacAquarius"


class TbZodiacAries(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacAries"


class TbZodiacCancer(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacCancer"


class TbZodiacCapricorn(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacCapricorn"


class TbZodiacGemini(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacGemini"


class TbZodiacLeo(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacLeo"


class TbZodiacLibra(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacLibra"


class TbZodiacPisces(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacPisces"


class TbZodiacSagittarius(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacSagittarius"


class TbZodiacScorpio(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacScorpio"


class TbZodiacTaurus(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacTaurus"


class TbZodiacVirgo(rx.Component):
    library = "react-icons/tb"
    tag = "TbZodiacVirgo"


class TbZoomCancel(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomCancel"


class TbZoomCheckFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomCheckFilled"


class TbZoomCheck(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomCheck"


class TbZoomCode(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomCode"


class TbZoomExclamation(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomExclamation"


class TbZoomFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomFilled"


class TbZoomInAreaFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomInAreaFilled"


class TbZoomInArea(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomInArea"


class TbZoomInFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomInFilled"


class TbZoomIn(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomIn"


class TbZoomMoney(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomMoney"


class TbZoomOutArea(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomOutArea"


class TbZoomOutFilled(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomOutFilled"


class TbZoomOut(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomOut"


class TbZoomPan(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomPan"


class TbZoomQuestion(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomQuestion"


class TbZoomReplace(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomReplace"


class TbZoomReset(rx.Component):
    library = "react-icons/tb"
    tag = "TbZoomReset"


class TbZzzOff(rx.Component):
    library = "react-icons/tb"
    tag = "TbZzzOff"


class TbZzz(rx.Component):
    library = "react-icons/tb"
    tag = "TbZzz"


